/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "manhattan_mcp.gitmem_coding.coding_hybrid_retriever",
        "sources": [
            "src/manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py"
        ]
    },
    "module_name": "manhattan_mcp.gitmem_coding.coding_hybrid_retriever"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 1
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 1
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PYPY_VERSION_NUM >= 0x07030C00)
  #endif
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_NUM >= 0x07031100)
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND (__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #ifndef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 1
  #endif
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #ifdef Py_GIL_DISABLED
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 1
  #else
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #endif
  #if PY_VERSION_HEX < 0x030A0000
    #undef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #elif !defined(CYTHON_USE_TYPE_SLOTS)
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLIST_INTERNALS)
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #elif !defined(CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL 0
  #elif !defined(CYTHON_FAST_GIL)
    #define CYTHON_FAST_GIL (PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_SYS_MONITORING
    #define CYTHON_USE_SYS_MONITORING (PY_VERSION_HEX >= 0x030d00B1)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5 && !CYTHON_USE_MODULE_STATE)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS (!CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
  #if defined(CYTHON_IMMORTAL_CONSTANTS) && PY_VERSION_HEX < 0x030C0000
    #undef CYTHON_IMMORTAL_CONSTANTS
    #define CYTHON_IMMORTAL_CONSTANTS 0  // definitely won't work
  #elif !defined(CYTHON_IMMORTAL_CONSTANTS)
    #define CYTHON_IMMORTAL_CONSTANTS (PY_VERSION_HEX >= 0x030C0000 && !CYTHON_USE_MODULE_STATE && CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
#endif
#ifndef CYTHON_COMPRESS_STRINGS
  #define CYTHON_COMPRESS_STRINGS 1
#endif
#ifndef CYTHON_FAST_PYCCALL
#define CYTHON_FAST_PYCCALL  CYTHON_FAST_PYCALL
#endif
#ifndef CYTHON_VECTORCALL
#if CYTHON_COMPILING_IN_LIMITED_API
#define CYTHON_VECTORCALL  (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
#else
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL)
#endif
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#include <stdint.h>
typedef uintptr_t  __pyx_uintptr_t;
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifndef Py_UNREACHABLE
  #define Py_UNREACHABLE()  assert(0); abort()
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#define __Pyx_BUILTIN_MODULE_NAME "builtins"
#define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    #ifndef CO_OPTIMIZED
    static int CO_OPTIMIZED;
    #endif
    #ifndef CO_NEWLOCALS
    static int CO_NEWLOCALS;
    #endif
    #ifndef CO_VARARGS
    static int CO_VARARGS;
    #endif
    #ifndef CO_VARKEYWORDS
    static int CO_VARKEYWORDS;
    #endif
    #ifndef CO_ASYNC_GENERATOR
    static int CO_ASYNC_GENERATOR;
    #endif
    #ifndef CO_GENERATOR
    static int CO_GENERATOR;
    #endif
    #ifndef CO_COROUTINE
    static int CO_COROUTINE;
    #endif
#else
    #ifndef CO_COROUTINE
      #define CO_COROUTINE 0x80
    #endif
    #ifndef CO_ASYNC_GENERATOR
      #define CO_ASYNC_GENERATOR 0x200
    #endif
#endif
static int __Pyx_init_co_variables(void);
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef Py_TPFLAGS_IMMUTABLETYPE
  #define Py_TPFLAGS_IMMUTABLETYPE (1UL << 8)
#endif
#ifndef Py_TPFLAGS_DISALLOW_INSTANTIATION
  #define Py_TPFLAGS_DISALLOW_INSTANTIATION (1UL << 7)
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#ifndef METH_FASTCALL
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void (*cfunc)(void)) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if PY_VERSION_HEX < 0x03090000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) GraalPyFrame_SetLineNumber((frame), (lineno))
#elif CYTHON_COMPILING_IN_GRAAL
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) _PyFrame_SetLineNumber((frame), (lineno))
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#endif
#if CYTHON_USE_MODULE_STATE
static CYTHON_INLINE void *__Pyx__PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#define __Pyx_PyModule_GetState(o) (__pyx_mstatetype *)__Pyx__PyModule_GetState(o)
#else
#define __Pyx_PyModule_GetState(op) ((void)op,__pyx_mstate_global)
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE((PyObject *) obj), name, func_ctype)
#define __Pyx_PyObject_TryGetSlot(obj, name, func_ctype) __Pyx_PyType_TryGetSlot(Py_TYPE(obj), name, func_ctype)
#define __Pyx_PyObject_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#define __Pyx_PyObject_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype) __Pyx_PyType_GetSlot(type, name, func_ctype)
  #define __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype) (((type)->sub) ? ((type)->sub->name) : NULL)
  #define __Pyx_PyType_TryGetSubSlot(type, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype)
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype)\
    ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000 ||\
     (PyType_GetFlags(type) & Py_TPFLAGS_HEAPTYPE) || __Pyx_get_runtime_version() >= 0x030A0000) ?\
     __Pyx_PyType_GetSlot(type, name, func_ctype) : NULL)
  #define __Pyx_PyType_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSlot(obj, name, func_ctype)
  #define __Pyx_PyType_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSlot(obj, name, func_ctype)
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
#define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
#endif
#define __Pyx_PyObject_GetIterNextFunc(iterator)  __Pyx_PyObject_GetSlot(iterator, tp_iternext, iternextfunc)
#if CYTHON_USE_TYPE_SPECS
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#else
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains)
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && PyUnstable_Object_IsUniquelyReferenced(obj)) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#elif CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
enum __Pyx_ReferenceSharing {
  __Pyx_ReferenceSharing_DefinitelyUnique, // We created it so we know it's unshared - no need to check
  __Pyx_ReferenceSharing_OwnStrongReference,
  __Pyx_ReferenceSharing_FunctionArgument,
  __Pyx_ReferenceSharing_SharedReference, // Never trust it to be unshared because it's a global or similar
};
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && PY_VERSION_HEX >= 0x030E0000
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing)\
    (sharing == __Pyx_ReferenceSharing_DefinitelyUnique ? 1 :\
      (sharing == __Pyx_ReferenceSharing_FunctionArgument ? PyUnstable_Object_IsUniqueReferencedTemporary(o) :\
      (sharing == __Pyx_ReferenceSharing_OwnStrongReference ? PyUnstable_Object_IsUniquelyReferenced(o) : 0)))
#elif (CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING) || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)sharing), Py_REFCNT(o) == 1)
#else
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)o), ((void)sharing), 0)
#endif
#if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyList_GetItemRef(o, i) (likely((i) >= 0) ? PySequence_GetItem(o, i) : (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
  #else
    #define __Pyx_PyList_GetItemRef(o, i) PySequence_ITEM(o, i)
  #endif
#elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #else
    #define __Pyx_PyList_GetItemRef(o, i) __Pyx_XNewRef(PyList_GetItem(o, i))
  #endif
#else
  #define __Pyx_PyList_GetItemRef(o, i) __Pyx_NewRef(PyList_GET_ITEM(o, i))
#endif
#if CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS && !CYTHON_COMPILING_IN_LIMITED_API && CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) (__Pyx_IS_UNIQUELY_REFERENCED(o, unsafe_shared) ?\
    __Pyx_NewRef(PyList_GET_ITEM(o, i)) : __Pyx_PyList_GetItemRef(o, i))
#else
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) __Pyx_PyList_GetItemRef(o, i)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyDict_GetItemRef(dict, key, result) PyDict_GetItemRef(dict, key, result)
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyObject_GetItem(dict, key);
  if (*result == NULL) {
    if (PyErr_ExceptionMatches(PyExc_KeyError)) {
      PyErr_Clear();
      return 0;
    }
    return -1;
  }
  return 1;
}
#else
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyDict_GetItemWithError(dict, key);
  if (*result == NULL) {
    return PyErr_Occurred() ? -1 : 0;
  }
  Py_INCREF(*result);
  return 1;
}
#endif
#if defined(CYTHON_DEBUG_VISIT_CONST) && CYTHON_DEBUG_VISIT_CONST
  #define __Pyx_VISIT_CONST(obj)  Py_VISIT(obj)
#else
  #define __Pyx_VISIT_CONST(obj)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GET_ITEM(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GET_ITEM(o, i)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GetItem(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GetItem(o, i)
#endif
#if CYTHON_ASSUME_SAFE_SIZE
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GET_LENGTH(o)
#else
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GetLength(o)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_InternFromString)
  #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
#endif
#define __Pyx_PyLong_FromHash_t PyLong_FromSsize_t
#define __Pyx_PyLong_AsHash_t   __Pyx_PyIndex_AsSsize_t
#if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
    #define __Pyx_PySendResult PySendResult
#else
    typedef enum {
        PYGEN_RETURN = 0,
        PYGEN_ERROR = -1,
        PYGEN_NEXT = 1,
    } __Pyx_PySendResult;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030A00A3
  typedef __Pyx_PySendResult (*__Pyx_pyiter_sendfunc)(PyObject *iter, PyObject *value, PyObject **result);
#else
  #define __Pyx_pyiter_sendfunc sendfunc
#endif
#if !CYTHON_USE_AM_SEND
#define __PYX_HAS_PY_AM_SEND 0
#elif __PYX_LIMITED_VERSION_HEX >= 0x030A0000
#define __PYX_HAS_PY_AM_SEND 1
#else
#define __PYX_HAS_PY_AM_SEND 2  // our own backported implementation
#endif
#if __PYX_HAS_PY_AM_SEND < 2
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
        __Pyx_pyiter_sendfunc am_send;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_SlotTpAsAsync(s) ((PyAsyncMethods*)(s))
#endif
#if CYTHON_USE_AM_SEND && PY_VERSION_HEX < 0x030A00F0
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (1UL << 21)
#else
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (0)
#endif
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyInterpreterState_Get() PyInterpreterState_Get()
#else
#define __Pyx_PyInterpreterState_Get() PyThreadState_Get()->interp
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030A0000
#ifdef __cplusplus
extern "C"
#endif
PyAPI_FUNC(void *) PyMem_Calloc(size_t nelem, size_t elsize);
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_init_co_variable(PyObject *inspect, const char* name, int *write_to) {
    int value;
    PyObject *py_value = PyObject_GetAttrString(inspect, name);
    if (!py_value) return 0;
    value = (int) PyLong_AsLong(py_value);
    Py_DECREF(py_value);
    *write_to = value;
    return value != -1 || !PyErr_Occurred();
}
static int __Pyx_init_co_variables(void) {
    PyObject *inspect;
    int result;
    inspect = PyImport_ImportModule("inspect");
    result =
#if !defined(CO_OPTIMIZED)
        __Pyx_init_co_variable(inspect, "CO_OPTIMIZED", &CO_OPTIMIZED) &&
#endif
#if !defined(CO_NEWLOCALS)
        __Pyx_init_co_variable(inspect, "CO_NEWLOCALS", &CO_NEWLOCALS) &&
#endif
#if !defined(CO_VARARGS)
        __Pyx_init_co_variable(inspect, "CO_VARARGS", &CO_VARARGS) &&
#endif
#if !defined(CO_VARKEYWORDS)
        __Pyx_init_co_variable(inspect, "CO_VARKEYWORDS", &CO_VARKEYWORDS) &&
#endif
#if !defined(CO_ASYNC_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_ASYNC_GENERATOR", &CO_ASYNC_GENERATOR) &&
#endif
#if !defined(CO_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_GENERATOR", &CO_GENERATOR) &&
#endif
#if !defined(CO_COROUTINE)
        __Pyx_init_co_variable(inspect, "CO_COROUTINE", &CO_COROUTINE) &&
#endif
        1;
    Py_DECREF(inspect);
    return result ? 0 : -1;
}
#else
static int __Pyx_init_co_variables(void) {
    return 0;  // It's a limited API-only feature
}
#endif

/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__manhattan_mcp__gitmem_coding__coding_hybrid_retriever
#define __PYX_HAVE_API__manhattan_mcp__gitmem_coding__coding_hybrid_retriever
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "src/manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __PYX_GET_CYTHON_COMPILING_IN_CPYTHON_FREETHREADING() CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_ptr_type atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) atomic_fetch_add_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) atomic_load(value)
    #define __pyx_atomic_store(value, new_value) atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) atomic_load_explicit(value, memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) atomic_load_explicit(value, memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_ptr_type std::atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) std::atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) std::atomic_load(value)
    #define __pyx_atomic_store(value, new_value) std::atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) std::atomic_load_explicit(value, std::memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) std::atomic_load_explicit(value, std::memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) std::atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_ptr_type void*
    #define __pyx_nonatomic_ptr_type void*
    #define __pyx_atomic_incr_relaxed(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) __sync_fetch_and_sub(value, 1)
    #define __pyx_atomic_sub(value, arg) __sync_fetch_and_sub(value, arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_store(value, new_value) __sync_lock_test_and_set(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_load_acquire(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) __sync_lock_test_and_set(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_nonatomic_ptr_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_atomic_ptr_type void*
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #define __pyx_nonatomic_ptr_type void*
    #pragma intrinsic (_InterlockedExchangeAdd, _InterlockedExchange, _InterlockedCompareExchange, _InterlockedCompareExchangePointer, _InterlockedExchangePointer)
    #define __pyx_atomic_incr_relaxed(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) _InterlockedExchangeAdd(value, -1)
    #define __pyx_atomic_sub(value, arg) _InterlockedExchangeAdd(value, -arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = _InterlockedCompareExchange(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) _InterlockedExchangeAdd(value, 0)
    #define __pyx_atomic_store(value, new_value) _InterlockedExchange(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) *(void * volatile *)value
    #define __pyx_atomic_pointer_load_acquire(value) _InterlockedCompareExchangePointer(value, 0, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) _InterlockedExchangePointer(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_atomic_ptr_type old = _InterlockedCompareExchangePointer(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif

/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks;
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr;
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr;
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr;
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr;
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr;
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr;
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr;
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr;

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":368
 *     # =====================================================================
 * 
 *     def _hybrid_search_chunks(             # <<<<<<<<<<<<<<
 *         self,
 *         agent_id: str,
*/
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks {
  PyObject_HEAD
  PyObject *__pyx_v_doc_freq;
  PyObject *__pyx_v_idf;
  PyObject *__pyx_v_original_query_keywords;
  PyObject *__pyx_v_parent_class;
  Py_ssize_t __pyx_v_total_docs;
};


/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":420
 *                 route_patterns.append(clean_rt)
 *                 segments = [seg for seg in clean_rt.split('/') if seg and seg not in _STOP_WORDS]
 *                 query_keywords.update(s.lower() for s in segments)             # <<<<<<<<<<<<<<
 * 
 *         #  B. Build corpus-level IDF (per search, lightweight)
*/
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_s;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
};


/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":430
 *         chunk_to_ctx: List[Tuple[Dict[str, Any], str]] = []  # (chunk, file_path)
 * 
 *         normalized_file_paths_filter = set(os.path.normpath(fp) for fp in file_paths_filter) if file_paths_filter else None             # <<<<<<<<<<<<<<
 * 
 *         for ctx in contexts:
*/
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_fp;
};


/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":484
 *             if query_vector and chunk_vec and len(chunk_vec) > 0:
 *                 try:
 *                     dot = sum(a * b for a, b in zip(query_vector, chunk_vec))             # <<<<<<<<<<<<<<
 *                     # Normalise to [0, 1] via cosine (vectors should be pre-normalised,
 *                     # but guard anyway)
*/
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_a;
  PyObject *__pyx_v_b;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":487
 *                     # Normalise to [0, 1] via cosine (vectors should be pre-normalised,
 *                     # but guard anyway)
 *                     mag_q = math.sqrt(sum(a * a for a in query_vector)) or 1.0             # <<<<<<<<<<<<<<
 *                     mag_c = math.sqrt(sum(b * b for b in chunk_vec)) or 1.0
 *                     vec_score = max(0.0, dot / (mag_q * mag_c))
*/
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_a;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
};


/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":488
 *                     # but guard anyway)
 *                     mag_q = math.sqrt(sum(a * a for a in query_vector)) or 1.0
 *                     mag_c = math.sqrt(sum(b * b for b in chunk_vec)) or 1.0             # <<<<<<<<<<<<<<
 *                     vec_score = max(0.0, dot / (mag_q * mag_c))
 *                 except Exception:
*/
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_b;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":517
 *                 overlap = query_keywords & chunk_text_bag
 *                 if overlap:
 *                     idf_sum = sum(idf(t) for t in overlap if t in original_query_keywords)             # <<<<<<<<<<<<<<
 *                     idf_total = sum(idf(t) for t in original_query_keywords) or 1.0
 *                     # Also credit expanded-keyword matches (lower weight)
*/
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr {
  PyObject_HEAD
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_t;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":518
 *                 if overlap:
 *                     idf_sum = sum(idf(t) for t in overlap if t in original_query_keywords)
 *                     idf_total = sum(idf(t) for t in original_query_keywords) or 1.0             # <<<<<<<<<<<<<<
 *                     # Also credit expanded-keyword matches (lower weight)
 *                     expanded_only = overlap - original_query_keywords
*/
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr {
  PyObject_HEAD
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_t;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
};


/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":575
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3             # <<<<<<<<<<<<<<
 *                     ):
 *                         relationship_boost = 0.3
*/
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr {
  PyObject_HEAD
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_qkw;
};

/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_PySequence_ITEM(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_NewRef(__Pyx_PyTuple_GET_ITEM(args, i))
#else
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_XNewRef(PyTuple_GetItem(args, i))
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_ArgRef_FASTCALL(args, i) __Pyx_NewRef(args[i])
    #define __Pyx_NumKwargs_FASTCALL(kwds) __Pyx_PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
#else
    #define __Pyx_ArgRef_FASTCALL __Pyx_ArgRef_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#if CYTHON_METH_FASTCALL || (CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(args + start, stop - start)
#else
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCallOneArg) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* pyint_simplify.proto */
static CYTHON_INLINE int __Pyx_PyInt_FromNumber(PyObject **number_var, const char *argname, int accept_none);

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* PyDictVersioning.proto (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __Pyx_XNewRef(__pyx_dict_cached_value);\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_mstate_global->__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* PyObjectCallNoArg.proto (used by pyfrozenset_new) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* pyfrozenset_new.proto (used by PySetContains) */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* PySetContains.proto */
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectVectorCallKwBuilder.proto (used by PyObjectVectorCallMethodKwBuilder) */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* PyObjectCall2Args.proto (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* CallUnboundCMethod1.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* PyUnicodeContains.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_ContainsTF(PyObject* substring, PyObject* text, int eq) {
    int result = PyUnicode_Contains(text, substring);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* set_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set);
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck, unsafe_shared) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck, int unsafe_shared);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* RaiseClosureNameError.proto */
static void __Pyx_RaiseClosureNameError(const char *varname);

/* PyFloatBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_AddObjC(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyFloat_AddObjC(op1, op2, floatval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* RaiseUnboundLocalError.proto */
static void __Pyx_RaiseUnboundLocalError(const char *varname);

/* GetException.proto (used by pep479) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* pep479.proto */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* HasAttr.proto */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* py_set_discard.proto */
static CYTHON_INLINE int __Pyx_PySet_Discard(PyObject *set, PyObject *key);

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto (used by FetchCommonType) */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* CallTypeTraverse.proto (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && CYTHON_METH_FASTCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_dict;
#endif
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    PyObject *defaults;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_mstate_global->__pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_mstate_global->__pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void));
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func,
                                                         PyTypeObject *defaults_type);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* PyRange_Check.proto */
#if CYTHON_COMPILING_IN_PYPY && !defined(PyRange_Check)
  #define PyRange_Check(obj)  __Pyx_TypeCheck((obj), &PyRange_Type)
#endif

/* PyFloatBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_TrueDivideCObj(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyFloat_TrueDivideCObj(op1, op2, floatval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceTrueDivide(op1, op2) : PyNumber_TrueDivide(op1, op2))
#endif

/* PyFloatBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_AddCObj(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyFloat_AddCObj(op1, op2, floatval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* py_abs.proto */
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject *__Pyx_PyLong_AbsNeg(PyObject *num);
#define __Pyx_PyNumber_Absolute(x)\
    ((likely(PyLong_CheckExact(x))) ?\
         (likely(__Pyx_PyLong_IsNonNeg(x)) ? __Pyx_NewRef(x) : __Pyx_PyLong_AbsNeg(x)) :\
         PyNumber_Absolute(x))
#else
#define __Pyx_PyNumber_Absolute(x)  PyNumber_Absolute(x)
#endif

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNoneIterError.proto (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
    PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple);
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* CheckTypeForFreelists.proto */
#if CYTHON_USE_FREELISTS
#if CYTHON_USE_TYPE_SPECS
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t) == (expected_tp)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  Py_TPFLAGS_IS_ABSTRACT
#else
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t)->tp_basicsize == (expected_size)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)
#endif
#define __PYX_CHECK_TYPE_FOR_FREELISTS(t, expected_tp, expected_size)\
    (__PYX_CHECK_FINAL_TYPE_FOR_FREELISTS((t), (expected_tp), (expected_size)) &\
     (int) (!__Pyx_PyType_HasFeature((t), __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS)))
#endif

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* CalculateMetaclass.proto (used by Py3ClassCreate) */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* PyObjectLookupSpecial.proto (used by Py3ClassCreate) */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2) {
    return PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2);
}
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#ifdef PyExceptionInstance_Check
  #define __Pyx_PyBaseException_Check(obj) PyExceptionInstance_Check(obj)
#else
  #define __Pyx_PyBaseException_Check(obj) __Pyx_TypeCheck(obj, PyExc_BaseException)
#endif

/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* IterNextPlain.proto (used by CoroutineBase) */
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next_Plain(PyObject *iterator);
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *__Pyx_GetBuiltinNext_LimitedAPI(void);
#endif

/* PyObjectCallMethod1.proto (used by CoroutineBase) */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* ReturnWithStopIteration.proto (used by CoroutineBase) */
static CYTHON_INLINE void __Pyx_ReturnWithStopIteration(PyObject* value, int async, int iternext);

/* CoroutineBase.proto (used by Generator) */
struct __pyx_CoroutineObject;
typedef PyObject *(*__pyx_coroutine_body_t)(struct __pyx_CoroutineObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct __pyx_CoroutineObject {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *gi_weakreflist;
#endif
    PyObject *classobj;
    PyObject *yieldfrom;
    __Pyx_pyiter_sendfunc yieldfrom_am_send;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
#if CYTHON_USE_SYS_MONITORING && (CYTHON_PROFILE || CYTHON_TRACE)
    PyMonitoringState __pyx_pymonitoring_state[__Pyx_MonitoringEventTypes_CyGen_count];
    uint64_t __pyx_pymonitoring_version;
#endif
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static __Pyx_PySendResult __Pyx_Coroutine_AmSend(PyObject *self, PyObject *value, PyObject **retval);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static __Pyx_PySendResult __Pyx_Coroutine_Close(PyObject *self, PyObject **retval);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);
static char __Pyx_Coroutine_test_and_set_is_running(__pyx_CoroutineObject *gen);
static void __Pyx_Coroutine_unset_is_running(__pyx_CoroutineObject *gen);
static char __Pyx_Coroutine_get_is_running(__pyx_CoroutineObject *gen);
static PyObject *__Pyx_Coroutine_get_is_running_getter(PyObject *gen, void *closure);
#if __PYX_HAS_PY_AM_SEND == 2
static void __Pyx_SetBackportTypeAmSend(PyTypeObject *type, __Pyx_PyAsyncMethodsStruct *static_amsend_methods, __Pyx_pyiter_sendfunc am_send);
#endif
static PyObject *__Pyx_Coroutine_fail_reduce_ex(PyObject *self, PyObject *arg);

/* Generator.proto */
#define __Pyx_Generator_USED
#define __Pyx_Generator_CheckExact(obj) __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_mstate_global->__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(PyObject *module);
static CYTHON_INLINE PyObject *__Pyx_Generator_GetInlinedResult(PyObject *self);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
    #if CYTHON_METH_FASTCALL
        #define __PYX_FASTCALL_ABI_SUFFIX  "_fastcall"
    #else
        #define __PYX_FASTCALL_ABI_SUFFIX
    #endif
    #define __PYX_LIMITED_ABI_SUFFIX "limited" __PYX_FASTCALL_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#else
    #define __PYX_LIMITED_ABI_SUFFIX
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    #define __PYX_AM_SEND_ABI_SUFFIX
#elif __PYX_HAS_PY_AM_SEND == 2
    #define __PYX_AM_SEND_ABI_SUFFIX "amsendbackport"
#else
    #define __PYX_AM_SEND_ABI_SUFFIX "noamsend"
#endif
#ifndef __PYX_MONITORING_ABI_SUFFIX
    #define __PYX_MONITORING_ABI_SUFFIX
#endif
#if CYTHON_USE_TP_FINALIZE
    #define __PYX_TP_FINALIZE_ABI_SUFFIX
#else
    #define __PYX_TP_FINALIZE_ABI_SUFFIX "nofinalize"
#endif
#if CYTHON_USE_FREELISTS || !defined(__Pyx_AsyncGen_USED)
    #define __PYX_FREELISTS_ABI_SUFFIX
#else
    #define __PYX_FREELISTS_ABI_SUFFIX "nofreelists"
#endif
#define CYTHON_ABI  __PYX_ABI_VERSION __PYX_LIMITED_ABI_SUFFIX __PYX_MONITORING_ABI_SUFFIX __PYX_TP_FINALIZE_ABI_SUFFIX __PYX_FREELISTS_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."


/* Module declarations from "manhattan_mcp.gitmem_coding.coding_hybrid_retriever" */
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "manhattan_mcp.gitmem_coding.coding_hybrid_retriever"
extern int __pyx_module_is_main_manhattan_mcp__gitmem_coding__coding_hybrid_retriever;
int __pyx_module_is_main_manhattan_mcp__gitmem_coding__coding_hybrid_retriever = 0;

/* Implementation of "manhattan_mcp.gitmem_coding.coding_hybrid_retriever" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_staticmethod;
static PyObject *__pyx_builtin_sum;
static PyObject *__pyx_builtin_round;
static PyObject *__pyx_builtin_zip;
/* #### Code section: string_decls ### */
static const char __pyx_k_Coding_Hybrid_Retriever_v2_Opti[] = "\nCoding Hybrid Retriever \342\200\223 v2 (Optimized for Q&A about code)\n\nHandles retrieval of code chunks using a multi-signal hybrid approach:\n  1. Vector similarity  (semantic)\n  2. Keyword overlap     (lexical)\n  3. Summary NLP match   (natural-language overlap)\n  4. Content grep match  (exact symbol/pattern match)\n  5. Name / Type match   (structural)\n  6. Line-number proximity\n  7. Parent-child class/method boost\n  8. Query-intent detection (broad vs narrow)\n\nLoads vectors from the dedicated CodingVectorStore (vectors.json).\n";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_store, PyObject *__pyx_v_vector_store, PyObject *__pyx_v_embedding_client); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_2search(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_agent_id, PyObject *__pyx_v_query, PyObject *__pyx_v_top_k, double __pyx_v_hybrid_alpha, PyObject *__pyx_v_file_paths_filter); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_4_decompose_compound(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_token); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_6_extract_line_numbers(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_query); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_8_expand_concepts(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_keywords); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_10_detect_query_intent(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_query); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_idf(PyObject *__pyx_self, PyObject *__pyx_v_term); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_2genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_5genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_8genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_11genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_14genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_17genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_20genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_23genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda8(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_12_hybrid_search_chunks(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_agent_id, PyObject *__pyx_v_query, PyObject *__pyx_v_top_k, double __pyx_v_alpha, PyObject *__pyx_v_file_filter, PyObject *__pyx_v_route_tokens, CYTHON_UNUSED int __pyx_v_is_broad, PyObject *__pyx_v_file_paths_filter); /* proto */
static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_14_get_chunk_text_bag(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_chunk); /* proto */
static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyObject *__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks;
  PyObject *__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr;
  PyObject *__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr;
  PyObject *__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr;
  PyObject *__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr;
  PyObject *__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr;
  PyObject *__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr;
  PyObject *__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr;
  PyObject *__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr;
  PyTypeObject *__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks;
  PyTypeObject *__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr;
  PyTypeObject *__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr;
  PyTypeObject *__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr;
  PyTypeObject *__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr;
  PyTypeObject *__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr;
  PyTypeObject *__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr;
  PyTypeObject *__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr;
  PyTypeObject *__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  __Pyx_CachedCFunction __pyx_umethod_PyList_Type__tolist;
  __Pyx_CachedCFunction __pyx_umethod_PySet_Type__update;
  __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type__lower;
  __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type__lstrip;
  PyObject *__pyx_tuple[8];
  PyObject *__pyx_codeobj_tab[18];
  PyObject *__pyx_string_tab[625];
  PyObject *__pyx_number_tab[13];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;


#if CYTHON_USE_FREELISTS
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks[8];
int __pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr[8];
int __pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr[8];
int __pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr[8];
int __pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr[8];
int __pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr[8];
int __pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr[8];
int __pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr[8];
int __pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr[8];
int __pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr;
#endif
/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* IterNextPlain.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
PyObject *__Pyx_GetBuiltinNext_LimitedAPI_cache;
#endif

/* Generator.module_state_decls */
PyTypeObject *__pyx_GeneratorType;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_Centralized_retrieval_logic_for __pyx_string_tab[1]
#define __pyx_kp_u_Dict_str_Any __pyx_string_tab[2]
#define __pyx_kp_u_Dict_str_Set_str __pyx_string_tab[3]
#define __pyx_kp_u_Embedding_generation_failed_for __pyx_string_tab[4]
#define __pyx_kp_u_List_Dict_str_Any __pyx_string_tab[5]
#define __pyx_kp_u_List_int __pyx_string_tab[6]
#define __pyx_kp_u_List_str __pyx_string_tab[7]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[8]
#define __pyx_kp_u_Optional_RemoteEmbeddingClient __pyx_string_tab[9]
#define __pyx_kp_u_Set_str __pyx_string_tab[10]
#define __pyx_kp_u__10 __pyx_string_tab[11]
#define __pyx_kp_u__2 __pyx_string_tab[12]
#define __pyx_kp_u__3 __pyx_string_tab[13]
#define __pyx_kp_u__4 __pyx_string_tab[14]
#define __pyx_kp_u__6 __pyx_string_tab[15]
#define __pyx_kp_u__7 __pyx_string_tab[16]
#define __pyx_kp_u__8 __pyx_string_tab[17]
#define __pyx_kp_u__9 __pyx_string_tab[18]
#define __pyx_kp_u_a_z0_9 __pyx_string_tab[19]
#define __pyx_kp_u_a_z_A_Z_a_z_A_Z_A_Z_a_z __pyx_string_tab[20]
#define __pyx_kp_u_add_note __pyx_string_tab[21]
#define __pyx_kp_u_b_all_every_list_show_me_overvi __pyx_string_tab[22]
#define __pyx_kp_u_b_d_3_b __pyx_string_tab[23]
#define __pyx_kp_u_b_how_is_where_is_which_use_int __pyx_string_tab[24]
#define __pyx_kp_u_bash __pyx_string_tab[25]
#define __pyx_kp_u_bline_s_d __pyx_string_tab[26]
#define __pyx_kp_u_blines_s_s_d __pyx_string_tab[27]
#define __pyx_kp_u_c __pyx_string_tab[28]
#define __pyx_kp_u_cpp __pyx_string_tab[29]
#define __pyx_kp_u_cs __pyx_string_tab[30]
#define __pyx_kp_u_css __pyx_string_tab[31]
#define __pyx_kp_u_disable __pyx_string_tab[32]
#define __pyx_kp_u_enable __pyx_string_tab[33]
#define __pyx_kp_u_flask_login __pyx_string_tab[34]
#define __pyx_kp_u_gc __pyx_string_tab[35]
#define __pyx_kp_u_go __pyx_string_tab[36]
#define __pyx_kp_u_h __pyx_string_tab[37]
#define __pyx_kp_u_hpp __pyx_string_tab[38]
#define __pyx_kp_u_html __pyx_string_tab[39]
#define __pyx_kp_u_isenabled __pyx_string_tab[40]
#define __pyx_kp_u_java __pyx_string_tab[41]
#define __pyx_kp_u_js __pyx_string_tab[42]
#define __pyx_kp_u_json __pyx_string_tab[43]
#define __pyx_kp_u_jsx __pyx_string_tab[44]
#define __pyx_kp_u_keep_alive __pyx_string_tab[45]
#define __pyx_kp_u_kt __pyx_string_tab[46]
#define __pyx_kp_u_lua __pyx_string_tab[47]
#define __pyx_kp_u_m __pyx_string_tab[48]
#define __pyx_kp_u_manhattan_mcp_gitmem_coding_ast __pyx_string_tab[49]
#define __pyx_kp_u_manhattan_mcp_gitmem_coding_codi_2 __pyx_string_tab[50]
#define __pyx_kp_u_manhattan_mcp_gitmem_coding_codi_3 __pyx_string_tab[51]
#define __pyx_kp_u_manhattan_mcp_gitmem_embedding __pyx_string_tab[52]
#define __pyx_kp_u_md __pyx_string_tab[53]
#define __pyx_kp_u_php __pyx_string_tab[54]
#define __pyx_kp_u_py __pyx_string_tab[55]
#define __pyx_kp_u_r __pyx_string_tab[56]
#define __pyx_kp_u_rb __pyx_string_tab[57]
#define __pyx_kp_u_rs __pyx_string_tab[58]
#define __pyx_kp_u_scala __pyx_string_tab[59]
#define __pyx_kp_u_scss __pyx_string_tab[60]
#define __pyx_kp_u_sh __pyx_string_tab[61]
#define __pyx_kp_u_sql __pyx_string_tab[62]
#define __pyx_kp_u_src_manhattan_mcp_gitmem_coding __pyx_string_tab[63]
#define __pyx_kp_u_summary_overview __pyx_string_tab[64]
#define __pyx_kp_u_svelte __pyx_string_tab[65]
#define __pyx_kp_u_swift __pyx_string_tab[66]
#define __pyx_kp_u_toml __pyx_string_tab[67]
#define __pyx_kp_u_ts __pyx_string_tab[68]
#define __pyx_kp_u_tsx __pyx_string_tab[69]
#define __pyx_kp_u_txt __pyx_string_tab[70]
#define __pyx_kp_u_vue __pyx_string_tab[71]
#define __pyx_kp_u_xml __pyx_string_tab[72]
#define __pyx_kp_u_yaml __pyx_string_tab[73]
#define __pyx_kp_u_yml __pyx_string_tab[74]
#define __pyx_kp_u_zig __pyx_string_tab[75]
#define __pyx_n_u_Any __pyx_string_tab[76]
#define __pyx_n_u_BROAD_INTENT_SIGNALS __pyx_string_tab[77]
#define __pyx_n_u_CONCEPT_MAP __pyx_string_tab[78]
#define __pyx_n_u_CodingContextStore __pyx_string_tab[79]
#define __pyx_n_u_CodingHybridRetriever __pyx_string_tab[80]
#define __pyx_n_u_CodingHybridRetriever___init __pyx_string_tab[81]
#define __pyx_n_u_CodingHybridRetriever__decompose __pyx_string_tab[82]
#define __pyx_n_u_CodingHybridRetriever__detect_qu __pyx_string_tab[83]
#define __pyx_n_u_CodingHybridRetriever__expand_co __pyx_string_tab[84]
#define __pyx_n_u_CodingHybridRetriever__extract_l __pyx_string_tab[85]
#define __pyx_n_u_CodingHybridRetriever__get_chunk __pyx_string_tab[86]
#define __pyx_n_u_CodingHybridRetriever__hybrid_se __pyx_string_tab[87]
#define __pyx_n_u_CodingHybridRetriever__hybrid_se_2 __pyx_string_tab[88]
#define __pyx_n_u_CodingHybridRetriever__hybrid_se_3 __pyx_string_tab[89]
#define __pyx_n_u_CodingHybridRetriever__hybrid_se_4 __pyx_string_tab[90]
#define __pyx_n_u_CodingHybridRetriever_search __pyx_string_tab[91]
#define __pyx_n_u_CodingVectorStore __pyx_string_tab[92]
#define __pyx_n_u_Counter __pyx_string_tab[93]
#define __pyx_n_u_Dict __pyx_string_tab[94]
#define __pyx_n_u_FILE_EXTENSIONS __pyx_string_tab[95]
#define __pyx_n_u_IGNORECASE __pyx_string_tab[96]
#define __pyx_n_u_List __pyx_string_tab[97]
#define __pyx_n_u_Optional __pyx_string_tab[98]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[99]
#define __pyx_n_u_RemoteEmbeddingClient __pyx_string_tab[100]
#define __pyx_n_u_STOP_WORDS __pyx_string_tab[101]
#define __pyx_n_u_SYNONYM_MAP __pyx_string_tab[102]
#define __pyx_n_u_Set __pyx_string_tab[103]
#define __pyx_n_u_Tuple __pyx_string_tab[104]
#define __pyx_n_u__5 __pyx_string_tab[105]
#define __pyx_n_u_a __pyx_string_tab[106]
#define __pyx_n_u_about __pyx_string_tab[107]
#define __pyx_n_u_agent_detail __pyx_string_tab[108]
#define __pyx_n_u_agent_id __pyx_string_tab[109]
#define __pyx_n_u_all __pyx_string_tab[110]
#define __pyx_n_u_all_chunks_flat __pyx_string_tab[111]
#define __pyx_n_u_all_vectors __pyx_string_tab[112]
#define __pyx_n_u_alpha __pyx_string_tab[113]
#define __pyx_n_u_also __pyx_string_tab[114]
#define __pyx_n_u_alter __pyx_string_tab[115]
#define __pyx_n_u_an __pyx_string_tab[116]
#define __pyx_n_u_and __pyx_string_tab[117]
#define __pyx_n_u_annotations __pyx_string_tab[118]
#define __pyx_n_u_any __pyx_string_tab[119]
#define __pyx_n_u_api __pyx_string_tab[120]
#define __pyx_n_u_api_key __pyx_string_tab[121]
#define __pyx_n_u_are __pyx_string_tab[122]
#define __pyx_n_u_associated __pyx_string_tab[123]
#define __pyx_n_u_ast_skeleton __pyx_string_tab[124]
#define __pyx_n_u_async __pyx_string_tab[125]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[126]
#define __pyx_n_u_at __pyx_string_tab[127]
#define __pyx_n_u_auth __pyx_string_tab[128]
#define __pyx_n_u_authentication __pyx_string_tab[129]
#define __pyx_n_u_authorisation __pyx_string_tab[130]
#define __pyx_n_u_authorization __pyx_string_tab[131]
#define __pyx_n_u_authorize __pyx_string_tab[132]
#define __pyx_n_u_b __pyx_string_tab[133]
#define __pyx_n_u_background __pyx_string_tab[134]
#define __pyx_n_u_bag __pyx_string_tab[135]
#define __pyx_n_u_base_kw __pyx_string_tab[136]
#define __pyx_n_u_basename __pyx_string_tab[137]
#define __pyx_n_u_bcrypt __pyx_string_tab[138]
#define __pyx_n_u_be __pyx_string_tab[139]
#define __pyx_n_u_been __pyx_string_tab[140]
#define __pyx_n_u_benchmark __pyx_string_tab[141]
#define __pyx_n_u_bigram __pyx_string_tab[142]
#define __pyx_n_u_bigram_boost __pyx_string_tab[143]
#define __pyx_n_u_block __pyx_string_tab[144]
#define __pyx_n_u_blocks __pyx_string_tab[145]
#define __pyx_n_u_blueprint __pyx_string_tab[146]
#define __pyx_n_u_bool __pyx_string_tab[147]
#define __pyx_n_u_broad __pyx_string_tab[148]
#define __pyx_n_u_but __pyx_string_tab[149]
#define __pyx_n_u_by __pyx_string_tab[150]
#define __pyx_n_u_cache __pyx_string_tab[151]
#define __pyx_n_u_cache_result __pyx_string_tab[152]
#define __pyx_n_u_caching __pyx_string_tab[153]
#define __pyx_n_u_call __pyx_string_tab[154]
#define __pyx_n_u_camel_parts __pyx_string_tab[155]
#define __pyx_n_u_can __pyx_string_tab[156]
#define __pyx_n_u_certificate __pyx_string_tab[157]
#define __pyx_n_u_change __pyx_string_tab[158]
#define __pyx_n_u_changes __pyx_string_tab[159]
#define __pyx_n_u_check __pyx_string_tab[160]
#define __pyx_n_u_chunk __pyx_string_tab[161]
#define __pyx_n_u_chunk_content __pyx_string_tab[162]
#define __pyx_n_u_chunk_kws __pyx_string_tab[163]
#define __pyx_n_u_chunk_name __pyx_string_tab[164]
#define __pyx_n_u_chunk_name_parts __pyx_string_tab[165]
#define __pyx_n_u_chunk_summary __pyx_string_tab[166]
#define __pyx_n_u_chunk_text_bag __pyx_string_tab[167]
#define __pyx_n_u_chunk_to_ctx __pyx_string_tab[168]
#define __pyx_n_u_chunk_type __pyx_string_tab[169]
#define __pyx_n_u_chunk_vec __pyx_string_tab[170]
#define __pyx_n_u_chunks __pyx_string_tab[171]
#define __pyx_n_u_class __pyx_string_tab[172]
#define __pyx_n_u_class_getitem __pyx_string_tab[173]
#define __pyx_n_u_class_names __pyx_string_tab[174]
#define __pyx_n_u_classes __pyx_string_tab[175]
#define __pyx_n_u_clean __pyx_string_tab[176]
#define __pyx_n_u_clean_query __pyx_string_tab[177]
#define __pyx_n_u_clean_rt __pyx_string_tab[178]
#define __pyx_n_u_clean_token __pyx_string_tab[179]
#define __pyx_n_u_cleaned __pyx_string_tab[180]
#define __pyx_n_u_client __pyx_string_tab[181]
#define __pyx_n_u_client_ip __pyx_string_tab[182]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[183]
#define __pyx_n_u_close __pyx_string_tab[184]
#define __pyx_n_u_coding_store __pyx_string_tab[185]
#define __pyx_n_u_coding_vector_store __pyx_string_tab[186]
#define __pyx_n_u_collections __pyx_string_tab[187]
#define __pyx_n_u_column __pyx_string_tab[188]
#define __pyx_n_u_concept __pyx_string_tab[189]
#define __pyx_n_u_concurrent __pyx_string_tab[190]
#define __pyx_n_u_connected __pyx_string_tab[191]
#define __pyx_n_u_content __pyx_string_tab[192]
#define __pyx_n_u_content_hits __pyx_string_tab[193]
#define __pyx_n_u_content_match_boost __pyx_string_tab[194]
#define __pyx_n_u_content_words __pyx_string_tab[195]
#define __pyx_n_u_context __pyx_string_tab[196]
#define __pyx_n_u_contexts __pyx_string_tab[197]
#define __pyx_n_u_controller __pyx_string_tab[198]
#define __pyx_n_u_could __pyx_string_tab[199]
#define __pyx_n_u_count __pyx_string_tab[200]
#define __pyx_n_u_cp __pyx_string_tab[201]
#define __pyx_n_u_create __pyx_string_tab[202]
#define __pyx_n_u_credentials __pyx_string_tab[203]
#define __pyx_n_u_ctx __pyx_string_tab[204]
#define __pyx_n_u_daemon __pyx_string_tab[205]
#define __pyx_n_u_dashboard __pyx_string_tab[206]
#define __pyx_n_u_data __pyx_string_tab[207]
#define __pyx_n_u_database __pyx_string_tab[208]
#define __pyx_n_u_ddos __pyx_string_tab[209]
#define __pyx_n_u_decompose_compound __pyx_string_tab[210]
#define __pyx_n_u_decorator __pyx_string_tab[211]
#define __pyx_n_u_decrypt __pyx_string_tab[212]
#define __pyx_n_u_defend __pyx_string_tab[213]
#define __pyx_n_u_delete __pyx_string_tab[214]
#define __pyx_n_u_deployment __pyx_string_tab[215]
#define __pyx_n_u_describe __pyx_string_tab[216]
#define __pyx_n_u_detect_query_intent __pyx_string_tab[217]
#define __pyx_n_u_devops __pyx_string_tab[218]
#define __pyx_n_u_df __pyx_string_tab[219]
#define __pyx_n_u_do __pyx_string_tab[220]
#define __pyx_n_u_doc __pyx_string_tab[221]
#define __pyx_n_u_doc_freq __pyx_string_tab[222]
#define __pyx_n_u_does __pyx_string_tab[223]
#define __pyx_n_u_dot __pyx_string_tab[224]
#define __pyx_n_u_down_sql __pyx_string_tab[225]
#define __pyx_n_u_drop __pyx_string_tab[226]
#define __pyx_n_u_e __pyx_string_tab[227]
#define __pyx_n_u_each __pyx_string_tab[228]
#define __pyx_n_u_edit __pyx_string_tab[229]
#define __pyx_n_u_effective_alpha __pyx_string_tab[230]
#define __pyx_n_u_effective_top_k __pyx_string_tab[231]
#define __pyx_n_u_efficient __pyx_string_tab[232]
#define __pyx_n_u_email __pyx_string_tab[233]
#define __pyx_n_u_embed __pyx_string_tab[234]
#define __pyx_n_u_embedding_client __pyx_string_tab[235]
#define __pyx_n_u_embedding_id __pyx_string_tab[236]
#define __pyx_n_u_encrypt __pyx_string_tab[237]
#define __pyx_n_u_end_line __pyx_string_tab[238]
#define __pyx_n_u_endpoint __pyx_string_tab[239]
#define __pyx_n_u_engine __pyx_string_tab[240]
#define __pyx_n_u_escape __pyx_string_tab[241]
#define __pyx_n_u_every __pyx_string_tab[242]
#define __pyx_n_u_expand_concepts __pyx_string_tab[243]
#define __pyx_n_u_expanded __pyx_string_tab[244]
#define __pyx_n_u_expanded_credit __pyx_string_tab[245]
#define __pyx_n_u_expanded_only __pyx_string_tab[246]
#define __pyx_n_u_expensive __pyx_string_tab[247]
#define __pyx_n_u_experience __pyx_string_tab[248]
#define __pyx_n_u_expire __pyx_string_tab[249]
#define __pyx_n_u_expires __pyx_string_tab[250]
#define __pyx_n_u_expiry __pyx_string_tab[251]
#define __pyx_n_u_explain __pyx_string_tab[252]
#define __pyx_n_u_explore __pyx_string_tab[253]
#define __pyx_n_u_ext __pyx_string_tab[254]
#define __pyx_n_u_extend __pyx_string_tab[255]
#define __pyx_n_u_extension_validation __pyx_string_tab[256]
#define __pyx_n_u_extract_line_numbers __pyx_string_tab[257]
#define __pyx_n_u_file __pyx_string_tab[258]
#define __pyx_n_u_file_contexts __pyx_string_tab[259]
#define __pyx_n_u_file_filter __pyx_string_tab[260]
#define __pyx_n_u_file_path __pyx_string_tab[261]
#define __pyx_n_u_file_paths_filter __pyx_string_tab[262]
#define __pyx_n_u_filter __pyx_string_tab[263]
#define __pyx_n_u_final_score __pyx_string_tab[264]
#define __pyx_n_u_find __pyx_string_tab[265]
#define __pyx_n_u_findall __pyx_string_tab[266]
#define __pyx_n_u_finditer __pyx_string_tab[267]
#define __pyx_n_u_flash __pyx_string_tab[268]
#define __pyx_n_u_flask __pyx_string_tab[269]
#define __pyx_n_u_float __pyx_string_tab[270]
#define __pyx_n_u_flood __pyx_string_tab[271]
#define __pyx_n_u_for __pyx_string_tab[272]
#define __pyx_n_u_forget __pyx_string_tab[273]
#define __pyx_n_u_forgot __pyx_string_tab[274]
#define __pyx_n_u_form __pyx_string_tab[275]
#define __pyx_n_u_format __pyx_string_tab[276]
#define __pyx_n_u_fp __pyx_string_tab[277]
#define __pyx_n_u_from __pyx_string_tab[278]
#define __pyx_n_u_func __pyx_string_tab[279]
#define __pyx_n_u_function __pyx_string_tab[280]
#define __pyx_n_u_functions __pyx_string_tab[281]
#define __pyx_n_u_genexpr __pyx_string_tab[282]
#define __pyx_n_u_get __pyx_string_tab[283]
#define __pyx_n_u_getLogger __pyx_string_tab[284]
#define __pyx_n_u_get_chunk_text_bag __pyx_string_tab[285]
#define __pyx_n_u_gevent __pyx_string_tab[286]
#define __pyx_n_u_gitmem_embedding __pyx_string_tab[287]
#define __pyx_n_u_give __pyx_string_tab[288]
#define __pyx_n_u_group __pyx_string_tab[289]
#define __pyx_n_u_guard __pyx_string_tab[290]
#define __pyx_n_u_handler __pyx_string_tab[291]
#define __pyx_n_u_has __pyx_string_tab[292]
#define __pyx_n_u_hash __pyx_string_tab[293]
#define __pyx_n_u_hash_id __pyx_string_tab[294]
#define __pyx_n_u_hashed_key __pyx_string_tab[295]
#define __pyx_n_u_have __pyx_string_tab[296]
#define __pyx_n_u_health __pyx_string_tab[297]
#define __pyx_n_u_heavy __pyx_string_tab[298]
#define __pyx_n_u_how __pyx_string_tab[299]
#define __pyx_n_u_html_escape __pyx_string_tab[300]
#define __pyx_n_u_hybrid_alpha __pyx_string_tab[301]
#define __pyx_n_u_hybrid_search_chunks __pyx_string_tab[302]
#define __pyx_n_u_i __pyx_string_tab[303]
#define __pyx_n_u_idf __pyx_string_tab[304]
#define __pyx_n_u_idf_sum __pyx_string_tab[305]
#define __pyx_n_u_idf_total __pyx_string_tab[306]
#define __pyx_n_u_if __pyx_string_tab[307]
#define __pyx_n_u_import __pyx_string_tab[308]
#define __pyx_n_u_in __pyx_string_tab[309]
#define __pyx_n_u_in_memory __pyx_string_tab[310]
#define __pyx_n_u_infrastructure __pyx_string_tab[311]
#define __pyx_n_u_init __pyx_string_tab[312]
#define __pyx_n_u_initialization __pyx_string_tab[313]
#define __pyx_n_u_insert __pyx_string_tab[314]
#define __pyx_n_u_int __pyx_string_tab[315]
#define __pyx_n_u_intent __pyx_string_tab[316]
#define __pyx_n_u_interact __pyx_string_tab[317]
#define __pyx_n_u_invoke __pyx_string_tab[318]
#define __pyx_n_u_involved __pyx_string_tab[319]
#define __pyx_n_u_is __pyx_string_tab[320]
#define __pyx_n_u_is_broad __pyx_string_tab[321]
#define __pyx_n_u_is_coroutine __pyx_string_tab[322]
#define __pyx_n_u_it __pyx_string_tab[323]
#define __pyx_n_u_items __pyx_string_tab[324]
#define __pyx_n_u_its __pyx_string_tab[325]
#define __pyx_n_u_json_2 __pyx_string_tab[326]
#define __pyx_n_u_jsonify __pyx_string_tab[327]
#define __pyx_n_u_just __pyx_string_tab[328]
#define __pyx_n_u_jwt __pyx_string_tab[329]
#define __pyx_n_u_k __pyx_string_tab[330]
#define __pyx_n_u_key __pyx_string_tab[331]
#define __pyx_n_u_keywords __pyx_string_tab[332]
#define __pyx_n_u_kw __pyx_string_tab[333]
#define __pyx_n_u_kw_score __pyx_string_tab[334]
#define __pyx_n_u_lambda __pyx_string_tab[335]
#define __pyx_n_u_language __pyx_string_tab[336]
#define __pyx_n_u_latency __pyx_string_tab[337]
#define __pyx_n_u_like __pyx_string_tab[338]
#define __pyx_n_u_line __pyx_string_tab[339]
#define __pyx_n_u_line_match_boost __pyx_string_tab[340]
#define __pyx_n_u_line_nums __pyx_string_tab[341]
#define __pyx_n_u_list __pyx_string_tab[342]
#define __pyx_n_u_ln __pyx_string_tab[343]
#define __pyx_n_u_load_agent_data __pyx_string_tab[344]
#define __pyx_n_u_load_vectors __pyx_string_tab[345]
#define __pyx_n_u_log __pyx_string_tab[346]
#define __pyx_n_u_logger __pyx_string_tab[347]
#define __pyx_n_u_logging __pyx_string_tab[348]
#define __pyx_n_u_login __pyx_string_tab[349]
#define __pyx_n_u_login_google __pyx_string_tab[350]
#define __pyx_n_u_login_required __pyx_string_tab[351]
#define __pyx_n_u_lost __pyx_string_tab[352]
#define __pyx_n_u_lower __pyx_string_tab[353]
#define __pyx_n_u_lru __pyx_string_tab[354]
#define __pyx_n_u_lstrip __pyx_string_tab[355]
#define __pyx_n_u_m_2 __pyx_string_tab[356]
#define __pyx_n_u_mag_c __pyx_string_tab[357]
#define __pyx_n_u_mag_q __pyx_string_tab[358]
#define __pyx_n_u_main __pyx_string_tab[359]
#define __pyx_n_u_manage __pyx_string_tab[360]
#define __pyx_n_u_managed __pyx_string_tab[361]
#define __pyx_n_u_manager __pyx_string_tab[362]
#define __pyx_n_u_manhattan_mcp_gitmem_coding_codi __pyx_string_tab[363]
#define __pyx_n_u_math __pyx_string_tab[364]
#define __pyx_n_u_max_requests __pyx_string_tab[365]
#define __pyx_n_u_may __pyx_string_tab[366]
#define __pyx_n_u_me __pyx_string_tab[367]
#define __pyx_n_u_memoization __pyx_string_tab[368]
#define __pyx_n_u_memoize __pyx_string_tab[369]
#define __pyx_n_u_memory __pyx_string_tab[370]
#define __pyx_n_u_metaclass __pyx_string_tab[371]
#define __pyx_n_u_method __pyx_string_tab[372]
#define __pyx_n_u_methods __pyx_string_tab[373]
#define __pyx_n_u_middleware __pyx_string_tab[374]
#define __pyx_n_u_might __pyx_string_tab[375]
#define __pyx_n_u_migration __pyx_string_tab[376]
#define __pyx_n_u_modify __pyx_string_tab[377]
#define __pyx_n_u_module __pyx_string_tab[378]
#define __pyx_n_u_module_2 __pyx_string_tab[379]
#define __pyx_n_u_modules __pyx_string_tab[380]
#define __pyx_n_u_monkey_patch __pyx_string_tab[381]
#define __pyx_n_u_must __pyx_string_tab[382]
#define __pyx_n_u_my __pyx_string_tab[383]
#define __pyx_n_u_name __pyx_string_tab[384]
#define __pyx_n_u_name_2 __pyx_string_tab[385]
#define __pyx_n_u_name_match_boost __pyx_string_tab[386]
#define __pyx_n_u_need __pyx_string_tab[387]
#define __pyx_n_u_next __pyx_string_tab[388]
#define __pyx_n_u_normalized_file_paths_filter __pyx_string_tab[389]
#define __pyx_n_u_normalized_filter __pyx_string_tab[390]
#define __pyx_n_u_normpath __pyx_string_tab[391]
#define __pyx_n_u_not __pyx_string_tab[392]
#define __pyx_n_u_num __pyx_string_tab[393]
#define __pyx_n_u_oauth __pyx_string_tab[394]
#define __pyx_n_u_of __pyx_string_tab[395]
#define __pyx_n_u_on __pyx_string_tab[396]
#define __pyx_n_u_onboarding __pyx_string_tab[397]
#define __pyx_n_u_only __pyx_string_tab[398]
#define __pyx_n_u_optimize __pyx_string_tab[399]
#define __pyx_n_u_or __pyx_string_tab[400]
#define __pyx_n_u_orchestrator __pyx_string_tab[401]
#define __pyx_n_u_original_query_keywords __pyx_string_tab[402]
#define __pyx_n_u_os __pyx_string_tab[403]
#define __pyx_n_u_our __pyx_string_tab[404]
#define __pyx_n_u_overlap __pyx_string_tab[405]
#define __pyx_n_u_overload __pyx_string_tab[406]
#define __pyx_n_u_overview __pyx_string_tab[407]
#define __pyx_n_u_overwhelm __pyx_string_tab[408]
#define __pyx_n_u_page __pyx_string_tab[409]
#define __pyx_n_u_parent_class __pyx_string_tab[410]
#define __pyx_n_u_parse __pyx_string_tab[411]
#define __pyx_n_u_parts __pyx_string_tab[412]
#define __pyx_n_u_password __pyx_string_tab[413]
#define __pyx_n_u_path __pyx_string_tab[414]
#define __pyx_n_u_path_lower __pyx_string_tab[415]
#define __pyx_n_u_pattern __pyx_string_tab[416]
#define __pyx_n_u_performance __pyx_string_tab[417]
#define __pyx_n_u_permissions __pyx_string_tab[418]
#define __pyx_n_u_persistence __pyx_string_tab[419]
#define __pyx_n_u_ping __pyx_string_tab[420]
#define __pyx_n_u_pop __pyx_string_tab[421]
#define __pyx_n_u_post __pyx_string_tab[422]
#define __pyx_n_u_prepare __pyx_string_tab[423]
#define __pyx_n_u_profile __pyx_string_tab[424]
#define __pyx_n_u_profiles __pyx_string_tab[425]
#define __pyx_n_u_profiling __pyx_string_tab[426]
#define __pyx_n_u_protect __pyx_string_tab[427]
#define __pyx_n_u_pull __pyx_string_tab[428]
#define __pyx_n_u_punctuation __pyx_string_tab[429]
#define __pyx_n_u_q_2 __pyx_string_tab[430]
#define __pyx_n_u_q_words __pyx_string_tab[431]
#define __pyx_n_u_qkw __pyx_string_tab[432]
#define __pyx_n_u_qt __pyx_string_tab[433]
#define __pyx_n_u_qualname __pyx_string_tab[434]
#define __pyx_n_u_query __pyx_string_tab[435]
#define __pyx_n_u_query_keywords __pyx_string_tab[436]
#define __pyx_n_u_query_line_numbers __pyx_string_tab[437]
#define __pyx_n_u_query_lower __pyx_string_tab[438]
#define __pyx_n_u_query_lower_set __pyx_string_tab[439]
#define __pyx_n_u_query_type_mentions __pyx_string_tab[440]
#define __pyx_n_u_query_vector __pyx_string_tab[441]
#define __pyx_n_u_rag __pyx_string_tab[442]
#define __pyx_n_u_rate_limit __pyx_string_tab[443]
#define __pyx_n_u_ratelimiter __pyx_string_tab[444]
#define __pyx_n_u_raw_tokens __pyx_string_tab[445]
#define __pyx_n_u_re __pyx_string_tab[446]
#define __pyx_n_u_recover __pyx_string_tab[447]
#define __pyx_n_u_redirect __pyx_string_tab[448]
#define __pyx_n_u_redis __pyx_string_tab[449]
#define __pyx_n_u_refresh __pyx_string_tab[450]
#define __pyx_n_u_regex __pyx_string_tab[451]
#define __pyx_n_u_register __pyx_string_tab[452]
#define __pyx_n_u_related __pyx_string_tab[453]
#define __pyx_n_u_relationship_boost __pyx_string_tab[454]
#define __pyx_n_u_relevant __pyx_string_tab[455]
#define __pyx_n_u_render __pyx_string_tab[456]
#define __pyx_n_u_render_template __pyx_string_tab[457]
#define __pyx_n_u_renew __pyx_string_tab[458]
#define __pyx_n_u_request __pyx_string_tab[459]
#define __pyx_n_u_reset __pyx_string_tab[460]
#define __pyx_n_u_response __pyx_string_tab[461]
#define __pyx_n_u_rest __pyx_string_tab[462]
#define __pyx_n_u_results __pyx_string_tab[463]
#define __pyx_n_u_retrieve_path __pyx_string_tab[464]
#define __pyx_n_u_return __pyx_string_tab[465]
#define __pyx_n_u_reverse __pyx_string_tab[466]
#define __pyx_n_u_rls __pyx_string_tab[467]
#define __pyx_n_u_role __pyx_string_tab[468]
#define __pyx_n_u_rollback __pyx_string_tab[469]
#define __pyx_n_u_round __pyx_string_tab[470]
#define __pyx_n_u_route __pyx_string_tab[471]
#define __pyx_n_u_route_match_boost __pyx_string_tab[472]
#define __pyx_n_u_route_patterns __pyx_string_tab[473]
#define __pyx_n_u_route_tokens __pyx_string_tab[474]
#define __pyx_n_u_rp __pyx_string_tab[475]
#define __pyx_n_u_rstrip __pyx_string_tab[476]
#define __pyx_n_u_rt __pyx_string_tab[477]
#define __pyx_n_u_s __pyx_string_tab[478]
#define __pyx_n_u_sanitization __pyx_string_tab[479]
#define __pyx_n_u_save __pyx_string_tab[480]
#define __pyx_n_u_schema __pyx_string_tab[481]
#define __pyx_n_u_score __pyx_string_tab[482]
#define __pyx_n_u_scored_chunks __pyx_string_tab[483]
#define __pyx_n_u_search __pyx_string_tab[484]
#define __pyx_n_u_search_results __pyx_string_tab[485]
#define __pyx_n_u_secret __pyx_string_tab[486]
#define __pyx_n_u_secure __pyx_string_tab[487]
#define __pyx_n_u_security __pyx_string_tab[488]
#define __pyx_n_u_seg __pyx_string_tab[489]
#define __pyx_n_u_segments __pyx_string_tab[490]
#define __pyx_n_u_select __pyx_string_tab[491]
#define __pyx_n_u_self __pyx_string_tab[492]
#define __pyx_n_u_send __pyx_string_tab[493]
#define __pyx_n_u_sep __pyx_string_tab[494]
#define __pyx_n_u_server __pyx_string_tab[495]
#define __pyx_n_u_session __pyx_string_tab[496]
#define __pyx_n_u_set_name __pyx_string_tab[497]
#define __pyx_n_u_setdefault __pyx_string_tab[498]
#define __pyx_n_u_sha256 __pyx_string_tab[499]
#define __pyx_n_u_shall __pyx_string_tab[500]
#define __pyx_n_u_should __pyx_string_tab[501]
#define __pyx_n_u_show __pyx_string_tab[502]
#define __pyx_n_u_sign_in_with_password __pyx_string_tab[503]
#define __pyx_n_u_signup __pyx_string_tab[504]
#define __pyx_n_u_sliding_window __pyx_string_tab[505]
#define __pyx_n_u_slow __pyx_string_tab[506]
#define __pyx_n_u_so __pyx_string_tab[507]
#define __pyx_n_u_socketio __pyx_string_tab[508]
#define __pyx_n_u_some __pyx_string_tab[509]
#define __pyx_n_u_sort __pyx_string_tab[510]
#define __pyx_n_u_span __pyx_string_tab[511]
#define __pyx_n_u_speed __pyx_string_tab[512]
#define __pyx_n_u_split __pyx_string_tab[513]
#define __pyx_n_u_splitext __pyx_string_tab[514]
#define __pyx_n_u_sql_2 __pyx_string_tab[515]
#define __pyx_n_u_sqlalchemy __pyx_string_tab[516]
#define __pyx_n_u_sqrt __pyx_string_tab[517]
#define __pyx_n_u_ssl __pyx_string_tab[518]
#define __pyx_n_u_start_line __pyx_string_tab[519]
#define __pyx_n_u_staticmethod __pyx_string_tab[520]
#define __pyx_n_u_status __pyx_string_tab[521]
#define __pyx_n_u_storage __pyx_string_tab[522]
#define __pyx_n_u_store __pyx_string_tab[523]
#define __pyx_n_u_str __pyx_string_tab[524]
#define __pyx_n_u_string __pyx_string_tab[525]
#define __pyx_n_u_strip __pyx_string_tab[526]
#define __pyx_n_u_sum __pyx_string_tab[527]
#define __pyx_n_u_summary __pyx_string_tab[528]
#define __pyx_n_u_summary_chunk __pyx_string_tab[529]
#define __pyx_n_u_summary_match_boost __pyx_string_tab[530]
#define __pyx_n_u_summary_overlap __pyx_string_tab[531]
#define __pyx_n_u_summary_words __pyx_string_tab[532]
#define __pyx_n_u_supabase __pyx_string_tab[533]
#define __pyx_n_u_symbol __pyx_string_tab[534]
#define __pyx_n_u_t __pyx_string_tab[535]
#define __pyx_n_u_table __pyx_string_tab[536]
#define __pyx_n_u_tell __pyx_string_tab[537]
#define __pyx_n_u_template __pyx_string_tab[538]
#define __pyx_n_u_term __pyx_string_tab[539]
#define __pyx_n_u_test __pyx_string_tab[540]
#define __pyx_n_u_that __pyx_string_tab[541]
#define __pyx_n_u_the __pyx_string_tab[542]
#define __pyx_n_u_then __pyx_string_tab[543]
#define __pyx_n_u_there __pyx_string_tab[544]
#define __pyx_n_u_this __pyx_string_tab[545]
#define __pyx_n_u_thread __pyx_string_tab[546]
#define __pyx_n_u_throttle __pyx_string_tab[547]
#define __pyx_n_u_throw __pyx_string_tab[548]
#define __pyx_n_u_tightness __pyx_string_tab[549]
#define __pyx_n_u_timeout __pyx_string_tab[550]
#define __pyx_n_u_timer __pyx_string_tab[551]
#define __pyx_n_u_tls __pyx_string_tab[552]
#define __pyx_n_u_to __pyx_string_tab[553]
#define __pyx_n_u_token __pyx_string_tab[554]
#define __pyx_n_u_token_count __pyx_string_tab[555]
#define __pyx_n_u_tokens __pyx_string_tab[556]
#define __pyx_n_u_tolist __pyx_string_tab[557]
#define __pyx_n_u_top_k __pyx_string_tab[558]
#define __pyx_n_u_total_docs __pyx_string_tab[559]
#define __pyx_n_u_ttl __pyx_string_tab[560]
#define __pyx_n_u_type __pyx_string_tab[561]
#define __pyx_n_u_type_match_boost __pyx_string_tab[562]
#define __pyx_n_u_type_query_words __pyx_string_tab[563]
#define __pyx_n_u_typing __pyx_string_tab[564]
#define __pyx_n_u_up_sql __pyx_string_tab[565]
#define __pyx_n_u_update __pyx_string_tab[566]
#define __pyx_n_u_upload __pyx_string_tab[567]
#define __pyx_n_u_upsert __pyx_string_tab[568]
#define __pyx_n_u_url_for __pyx_string_tab[569]
#define __pyx_n_u_us __pyx_string_tab[570]
#define __pyx_n_u_usage __pyx_string_tab[571]
#define __pyx_n_u_use __pyx_string_tab[572]
#define __pyx_n_u_used __pyx_string_tab[573]
#define __pyx_n_u_user __pyx_string_tab[574]
#define __pyx_n_u_username_unique __pyx_string_tab[575]
#define __pyx_n_u_using __pyx_string_tab[576]
#define __pyx_n_u_v __pyx_string_tab[577]
#define __pyx_n_u_validate __pyx_string_tab[578]
#define __pyx_n_u_validation __pyx_string_tab[579]
#define __pyx_n_u_value __pyx_string_tab[580]
#define __pyx_n_u_values __pyx_string_tab[581]
#define __pyx_n_u_vec_score __pyx_string_tab[582]
#define __pyx_n_u_vector __pyx_string_tab[583]
#define __pyx_n_u_vector_store __pyx_string_tab[584]
#define __pyx_n_u_verify __pyx_string_tab[585]
#define __pyx_n_u_version __pyx_string_tab[586]
#define __pyx_n_u_version_control __pyx_string_tab[587]
#define __pyx_n_u_versioned __pyx_string_tab[588]
#define __pyx_n_u_w __pyx_string_tab[589]
#define __pyx_n_u_want __pyx_string_tab[590]
#define __pyx_n_u_warning __pyx_string_tab[591]
#define __pyx_n_u_was __pyx_string_tab[592]
#define __pyx_n_u_we __pyx_string_tab[593]
#define __pyx_n_u_welcome __pyx_string_tab[594]
#define __pyx_n_u_were __pyx_string_tab[595]
#define __pyx_n_u_what __pyx_string_tab[596]
#define __pyx_n_u_when __pyx_string_tab[597]
#define __pyx_n_u_where __pyx_string_tab[598]
#define __pyx_n_u_which __pyx_string_tab[599]
#define __pyx_n_u_whitelist __pyx_string_tab[600]
#define __pyx_n_u_will __pyx_string_tab[601]
#define __pyx_n_u_with __pyx_string_tab[602]
#define __pyx_n_u_would __pyx_string_tab[603]
#define __pyx_n_u_x __pyx_string_tab[604]
#define __pyx_n_u_you __pyx_string_tab[605]
#define __pyx_n_u_your __pyx_string_tab[606]
#define __pyx_n_u_zip __pyx_string_tab[607]
#define __pyx_kp_b_iso88591_1 __pyx_string_tab[608]
#define __pyx_kp_b_iso88591_A __pyx_string_tab[609]
#define __pyx_kp_b_iso88591_A_1_Q_WAT_q_a_4q_1_4s_uF_1_c_r_q __pyx_string_tab[610]
#define __pyx_kp_b_iso88591_A_2 __pyx_string_tab[611]
#define __pyx_kp_b_iso88591_A_6a_1_F_t1L_t1BfA_7_2XQoU_a_V1 __pyx_string_tab[612]
#define __pyx_kp_b_iso88591_A_A_E_q_2WA_a_1_2WA_q_1_2WA_H_1 __pyx_string_tab[613]
#define __pyx_kp_b_iso88591_A_IQ_A_1_L __pyx_string_tab[614]
#define __pyx_kp_b_iso88591_A_Q_a_1_1_A_4_0_aq_wa_Q_7_A_EYaq __pyx_string_tab[615]
#define __pyx_kp_b_iso88591_A_Q_q_E_9A_7wb_WAS_E_9A_a_QavQa __pyx_string_tab[616]
#define __pyx_kp_b_iso88591_A_q_a_1_a_a_7_86_xwa_X_Yhixwa_9H __pyx_string_tab[617]
#define __pyx_kp_b_iso88591_Q __pyx_string_tab[618]
#define __pyx_kp_b_iso88591_Q_2 __pyx_string_tab[619]
#define __pyx_kp_b_iso88591__11 __pyx_string_tab[620]
#define __pyx_kp_b_iso88591_a_3aq_F_s_T_q_L_s_T_q_L_q __pyx_string_tab[621]
#define __pyx_kp_b_iso88591_ha_QfA_4t2_S_2T_1 __pyx_string_tab[622]
#define __pyx_kp_b_iso88591_q __pyx_string_tab[623]
#define __pyx_kp_b_iso88591_z_1 __pyx_string_tab[624]
#define __pyx_float_0_0 __pyx_number_tab[0]
#define __pyx_float_0_4 __pyx_number_tab[1]
#define __pyx_float_0_5 __pyx_number_tab[2]
#define __pyx_float_0_7 __pyx_number_tab[3]
#define __pyx_float_1_0 __pyx_number_tab[4]
#define __pyx_float_0_01 __pyx_number_tab[5]
#define __pyx_float_20_0 __pyx_number_tab[6]
#define __pyx_int_0 __pyx_number_tab[7]
#define __pyx_int_1 __pyx_number_tab[8]
#define __pyx_int_3 __pyx_number_tab[9]
#define __pyx_int_5 __pyx_number_tab[10]
#define __pyx_int_10 __pyx_number_tab[11]
#define __pyx_int_50000 __pyx_number_tab[12]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks);
  Py_CLEAR(clear_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks);
  Py_CLEAR(clear_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr);
  for (int i=0; i<8; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<18; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<625; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<13; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* Generator.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_GeneratorType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks);
  Py_VISIT(traverse_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks);
  Py_VISIT(traverse_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr);
  for (int i=0; i<8; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<18; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<625; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<13; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* Generator.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_GeneratorType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":61
 *     """
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         store: CodingContextStore,
*/

/* Python wrapper */
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever___init__, "CodingHybridRetriever.__init__(self, store: CodingContextStore, vector_store: CodingVectorStore, embedding_client: Optional[RemoteEmbeddingClient] = None)");
static PyMethodDef __pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_1__init__ = {"__init__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever___init__};
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_store = 0;
  PyObject *__pyx_v_vector_store = 0;
  PyObject *__pyx_v_embedding_client = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_store,&__pyx_mstate_global->__pyx_n_u_vector_store,&__pyx_mstate_global->__pyx_n_u_embedding_client,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 61, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 61, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 61, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 61, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 61, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 61, __pyx_L3_error)

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":65
 *         store: CodingContextStore,
 *         vector_store: CodingVectorStore,
 *         embedding_client: Optional[RemoteEmbeddingClient] = None,             # <<<<<<<<<<<<<<
 *     ):
 *         self.store = store
*/
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 4, i); __PYX_ERR(0, 61, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 61, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 61, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 61, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 61, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_store = values[1];
    __pyx_v_vector_store = values[2];
    __pyx_v_embedding_client = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 61, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever___init__(__pyx_self, __pyx_v_self, __pyx_v_store, __pyx_v_vector_store, __pyx_v_embedding_client);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":61
 *     """
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         store: CodingContextStore,
*/

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_store, PyObject *__pyx_v_vector_store, PyObject *__pyx_v_embedding_client) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":67
 *         embedding_client: Optional[RemoteEmbeddingClient] = None,
 *     ):
 *         self.store = store             # <<<<<<<<<<<<<<
 *         self.vector_store = vector_store
 *         self.embedding_client = embedding_client or vector_store.embedding_client
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_store, __pyx_v_store) < (0)) __PYX_ERR(0, 67, __pyx_L1_error)

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":68
 *     ):
 *         self.store = store
 *         self.vector_store = vector_store             # <<<<<<<<<<<<<<
 *         self.embedding_client = embedding_client or vector_store.embedding_client
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_vector_store, __pyx_v_vector_store) < (0)) __PYX_ERR(0, 68, __pyx_L1_error)

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":69
 *         self.store = store
 *         self.vector_store = vector_store
 *         self.embedding_client = embedding_client or vector_store.embedding_client             # <<<<<<<<<<<<<<
 * 
 *     # =====================================================================
*/
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_embedding_client); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 69, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __Pyx_INCREF(__pyx_v_embedding_client);
    __pyx_t_1 = __pyx_v_embedding_client;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_vector_store, __pyx_mstate_global->__pyx_n_u_embedding_client); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_embedding_client, __pyx_t_1) < (0)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":61
 *     """
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         store: CodingContextStore,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":212
 *     # =====================================================================
 * 
 *     def search(             # <<<<<<<<<<<<<<
 *         self,
 *         agent_id: str,
*/

/* Python wrapper */
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_3search(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_2search, "CodingHybridRetriever.search(self, str agent_id: str, str query: str, int top_k: int = 5, double hybrid_alpha: float = 0.55, list file_paths_filter: List[str] = None) -> Dict[str, Any]\n\nPerform a hybrid search for the query with metadata filtering.\n\nArgs:\n    agent_id: The agent identifier.\n    query: Natural-language question about the code.\n    top_k: Max results to return.\n    hybrid_alpha: Weight for vector score (1-alpha goes to keyword).");
static PyMethodDef __pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_3search = {"search", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_3search, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_2search};
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_3search(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_agent_id = 0;
  PyObject *__pyx_v_query = 0;
  PyObject *__pyx_v_top_k = 0;
  double __pyx_v_hybrid_alpha;
  PyObject *__pyx_v_file_paths_filter = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("search (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_agent_id,&__pyx_mstate_global->__pyx_n_u_query,&__pyx_mstate_global->__pyx_n_u_top_k,&__pyx_mstate_global->__pyx_n_u_hybrid_alpha,&__pyx_mstate_global->__pyx_n_u_file_paths_filter,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 212, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "search", 0) < (0)) __PYX_ERR(0, 212, __pyx_L3_error)
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject*)((PyObject*)__pyx_mstate_global->__pyx_int_5)));

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":218
 *         top_k: int = 5,
 *         hybrid_alpha: float = 0.55,
 *         file_paths_filter: List[str] = None,             # <<<<<<<<<<<<<<
 *     ) -> Dict[str, Any]:
 *         """
*/
      if (!values[5]) values[5] = __Pyx_NewRef(((PyObject*)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("search", 0, 3, 6, i); __PYX_ERR(0, 212, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 212, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 212, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 212, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 212, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[3]) values[3] = __Pyx_NewRef(((PyObject*)((PyObject*)__pyx_mstate_global->__pyx_int_5)));
      if (!values[5]) values[5] = __Pyx_NewRef(((PyObject*)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_agent_id = ((PyObject*)values[1]);
    __pyx_v_query = ((PyObject*)values[2]);
    if (__Pyx_PyInt_FromNumber(&values[3], "top_k", 0) < (0)) __PYX_ERR(0, 216, __pyx_L3_error)
    __pyx_v_top_k = ((PyObject*)values[3]);
    if (values[4]) {
      __pyx_v_hybrid_alpha = __Pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_hybrid_alpha == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 217, __pyx_L3_error)
    } else {
      __pyx_v_hybrid_alpha = ((double)((double)0.55));
    }
    __pyx_v_file_paths_filter = ((PyObject*)values[5]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("search", 0, 3, 6, __pyx_nargs); __PYX_ERR(0, 212, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever.search", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_agent_id), (&PyUnicode_Type), 0, "agent_id", 2))) __PYX_ERR(0, 214, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_query), (&PyUnicode_Type), 0, "query", 2))) __PYX_ERR(0, 215, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_top_k), (&PyLong_Type), 0, "top_k", 2))) __PYX_ERR(0, 216, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_file_paths_filter), (&PyList_Type), 1, "file_paths_filter", 2))) __PYX_ERR(0, 218, __pyx_L1_error)
  __pyx_r = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_2search(__pyx_self, __pyx_v_self, __pyx_v_agent_id, __pyx_v_query, __pyx_v_top_k, __pyx_v_hybrid_alpha, __pyx_v_file_paths_filter);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":212
 *     # =====================================================================
 * 
 *     def search(             # <<<<<<<<<<<<<<
 *         self,
 *         agent_id: str,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_2search(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_agent_id, PyObject *__pyx_v_query, PyObject *__pyx_v_top_k, double __pyx_v_hybrid_alpha, PyObject *__pyx_v_file_paths_filter) {
  PyObject *__pyx_v_file_filter = NULL;
  PyObject *__pyx_v_clean_query = NULL;
  PyObject *__pyx_v_route_tokens = 0;
  PyObject *__pyx_v_FILE_EXTENSIONS = NULL;
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_v_token = NULL;
  PyObject *__pyx_v_clean_token = NULL;
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_ext = NULL;
  PyObject *__pyx_v_query_lower_set = NULL;
  int __pyx_v_is_broad;
  PyObject *__pyx_v_effective_top_k = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_t_11;
  int __pyx_t_12;
  long __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("search", 0);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":230
 *         """
 *         # 1. Metadata Filtering Extraction
 *         file_filter = None             # <<<<<<<<<<<<<<
 *         clean_query = query
 *         route_tokens: List[str] = []
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_file_filter = Py_None;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":231
 *         # 1. Metadata Filtering Extraction
 *         file_filter = None
 *         clean_query = query             # <<<<<<<<<<<<<<
 *         route_tokens: List[str] = []
 * 
*/
  __Pyx_INCREF(__pyx_v_query);
  __pyx_v_clean_query = __pyx_v_query;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":232
 *         file_filter = None
 *         clean_query = query
 *         route_tokens: List[str] = []             # <<<<<<<<<<<<<<
 * 
 *         FILE_EXTENSIONS = {
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_route_tokens = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":235
 * 
 *         FILE_EXTENSIONS = {
 *             '.py', '.js', '.ts', '.jsx', '.tsx', '.java', '.go', '.rs',             # <<<<<<<<<<<<<<
 *             '.rb', '.php', '.c', '.cpp', '.h', '.hpp', '.cs', '.swift',
 *             '.kt', '.scala', '.vue', '.svelte', '.html', '.css', '.scss',
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_py) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_js) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_ts) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_jsx) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_tsx) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_java) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_go) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_rs) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_rb) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_php) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_c) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_cpp) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_h) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_hpp) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_cs) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_swift) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_kt) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_scala) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_vue) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_svelte) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_html) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_css) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_scss) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_json) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_yaml) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_yml) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_toml) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_xml) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_md) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_txt) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_sh) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_bash) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_sql) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_r) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_m) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_lua) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_zig) < (0)) __PYX_ERR(0, 235, __pyx_L1_error)
  __pyx_v_FILE_EXTENSIONS = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":242
 *         }
 * 
 *         tokens = query.split()             # <<<<<<<<<<<<<<
 *         for token in tokens:
 *             clean_token = token.strip(string.punctuation + "'\"")
*/
  __pyx_t_1 = PyUnicode_Split(__pyx_v_query, ((PyObject *)NULL), -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_tokens = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":243
 * 
 *         tokens = query.split()
 *         for token in tokens:             # <<<<<<<<<<<<<<
 *             clean_token = token.strip(string.punctuation + "'\"")
 *             if not clean_token:
*/
  __pyx_t_1 = __pyx_v_tokens; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 243, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_2;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_token, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":244
 *         tokens = query.split()
 *         for token in tokens:
 *             clean_token = token.strip(string.punctuation + "'\"")             # <<<<<<<<<<<<<<
 *             if not clean_token:
 *                 continue
*/
    __pyx_t_4 = __pyx_v_token;
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_string); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_punctuation); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 244, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_clean_token, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":245
 *         for token in tokens:
 *             clean_token = token.strip(string.punctuation + "'\"")
 *             if not clean_token:             # <<<<<<<<<<<<<<
 *                 continue
 *             _, ext = os.path.splitext(clean_token)
*/
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_clean_token); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 245, __pyx_L1_error)
    __pyx_t_9 = (!__pyx_t_8);
    if (__pyx_t_9) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":246
 *             clean_token = token.strip(string.punctuation + "'\"")
 *             if not clean_token:
 *                 continue             # <<<<<<<<<<<<<<
 *             _, ext = os.path.splitext(clean_token)
 *             if ext.lower() in FILE_EXTENSIONS:
*/
      goto __pyx_L3_continue;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":245
 *         for token in tokens:
 *             clean_token = token.strip(string.punctuation + "'\"")
 *             if not clean_token:             # <<<<<<<<<<<<<<
 *                 continue
 *             _, ext = os.path.splitext(clean_token)
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":247
 *             if not clean_token:
 *                 continue
 *             _, ext = os.path.splitext(clean_token)             # <<<<<<<<<<<<<<
 *             if ext.lower() in FILE_EXTENSIONS:
 *                 file_filter = clean_token
*/
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __pyx_t_6;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_clean_token};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_splitext, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 247, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_5);
      } else {
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 247, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 247, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
      }
      #else
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_10 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
      index = 0; __pyx_t_6 = __pyx_t_10(__pyx_t_4); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_5 = __pyx_t_10(__pyx_t_4); if (unlikely(!__pyx_t_5)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_4), 2) < (0)) __PYX_ERR(0, 247, __pyx_L1_error)
      __pyx_t_10 = NULL;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_10 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 247, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v__, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_ext, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":248
 *                 continue
 *             _, ext = os.path.splitext(clean_token)
 *             if ext.lower() in FILE_EXTENSIONS:             # <<<<<<<<<<<<<<
 *                 file_filter = clean_token
 *                 clean_query = query.replace(token, "").strip()
*/
    __pyx_t_5 = __pyx_v_ext;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_9 = (__Pyx_PySet_ContainsTF(__pyx_t_3, __pyx_v_FILE_EXTENSIONS, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 248, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_9) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":249
 *             _, ext = os.path.splitext(clean_token)
 *             if ext.lower() in FILE_EXTENSIONS:
 *                 file_filter = clean_token             # <<<<<<<<<<<<<<
 *                 clean_query = query.replace(token, "").strip()
 *                 break
*/
      __Pyx_INCREF(__pyx_v_clean_token);
      __Pyx_DECREF_SET(__pyx_v_file_filter, __pyx_v_clean_token);

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":250
 *             if ext.lower() in FILE_EXTENSIONS:
 *                 file_filter = clean_token
 *                 clean_query = query.replace(token, "").strip()             # <<<<<<<<<<<<<<
 *                 break
 *             if '/' in clean_token and not ext:
*/
      __pyx_t_6 = PyUnicode_Replace(__pyx_v_query, __pyx_v_token, __pyx_mstate_global->__pyx_kp_u__2, -1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 250, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __pyx_t_6;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 250, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_DECREF_SET(__pyx_v_clean_query, ((PyObject*)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":251
 *                 file_filter = clean_token
 *                 clean_query = query.replace(token, "").strip()
 *                 break             # <<<<<<<<<<<<<<
 *             if '/' in clean_token and not ext:
 *                 route_tokens.append(clean_token)
*/
      goto __pyx_L4_break;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":248
 *                 continue
 *             _, ext = os.path.splitext(clean_token)
 *             if ext.lower() in FILE_EXTENSIONS:             # <<<<<<<<<<<<<<
 *                 file_filter = clean_token
 *                 clean_query = query.replace(token, "").strip()
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":252
 *                 clean_query = query.replace(token, "").strip()
 *                 break
 *             if '/' in clean_token and not ext:             # <<<<<<<<<<<<<<
 *                 route_tokens.append(clean_token)
 * 
*/
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u__3, __pyx_v_clean_token, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 252, __pyx_L1_error)
    if (__pyx_t_8) {
    } else {
      __pyx_t_9 = __pyx_t_8;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_ext); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 252, __pyx_L1_error)
    __pyx_t_11 = (!__pyx_t_8);
    __pyx_t_9 = __pyx_t_11;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_9) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":253
 *                 break
 *             if '/' in clean_token and not ext:
 *                 route_tokens.append(clean_token)             # <<<<<<<<<<<<<<
 * 
 *         if not clean_query:
*/
      __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_route_tokens, __pyx_v_clean_token); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 253, __pyx_L1_error)

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":252
 *                 clean_query = query.replace(token, "").strip()
 *                 break
 *             if '/' in clean_token and not ext:             # <<<<<<<<<<<<<<
 *                 route_tokens.append(clean_token)
 * 
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":243
 * 
 *         tokens = query.split()
 *         for token in tokens:             # <<<<<<<<<<<<<<
 *             clean_token = token.strip(string.punctuation + "'\"")
 *             if not clean_token:
*/
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L12_for_end;
  __pyx_L4_break:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  goto __pyx_L12_for_end;
  __pyx_L12_for_end:;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":255
 *                 route_tokens.append(clean_token)
 * 
 *         if not clean_query:             # <<<<<<<<<<<<<<
 *             clean_query = "summary overview"
 * 
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_v_clean_query);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 255, __pyx_L1_error)
    __pyx_t_9 = (__pyx_temp != 0);
  }

  __pyx_t_11 = (!__pyx_t_9);
  if (__pyx_t_11) {

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":256
 * 
 *         if not clean_query:
 *             clean_query = "summary overview"             # <<<<<<<<<<<<<<
 * 
 *         # 2. Detect broad vs narrow intent
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_summary_overview);
    __Pyx_DECREF_SET(__pyx_v_clean_query, __pyx_mstate_global->__pyx_kp_u_summary_overview);

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":255
 *                 route_tokens.append(clean_token)
 * 
 *         if not clean_query:             # <<<<<<<<<<<<<<
 *             clean_query = "summary overview"
 * 
*/
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":259
 * 
 *         # 2. Detect broad vs narrow intent
 *         query_lower_set = set(clean_query.lower().split())             # <<<<<<<<<<<<<<
 *         is_broad = bool(query_lower_set & _BROAD_INTENT_SIGNALS)
 *         # If caller requested a strictly small top_k (e.g. batch queries), don't override it.
*/
  __pyx_t_1 = __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyUnicode_Type__lower, __pyx_v_clean_query); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyUnicode_Split(((PyObject*)__pyx_t_1), ((PyObject *)NULL), -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PySet_New(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_query_lower_set = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":260
 *         # 2. Detect broad vs narrow intent
 *         query_lower_set = set(clean_query.lower().split())
 *         is_broad = bool(query_lower_set & _BROAD_INTENT_SIGNALS)             # <<<<<<<<<<<<<<
 *         # If caller requested a strictly small top_k (e.g. batch queries), don't override it.
 *         effective_top_k = max(top_k, 8) if is_broad and top_k >= 5 else top_k
*/
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_BROAD_INTENT_SIGNALS); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_And(__pyx_v_query_lower_set, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_is_broad = (!(!__pyx_t_11));

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":262
 *         is_broad = bool(query_lower_set & _BROAD_INTENT_SIGNALS)
 *         # If caller requested a strictly small top_k (e.g. batch queries), don't override it.
 *         effective_top_k = max(top_k, 8) if is_broad and top_k >= 5 else top_k             # <<<<<<<<<<<<<<
 * 
 *         # 3. Search
*/
  if (__pyx_v_is_broad) {
  } else {
    __pyx_t_11 = __pyx_v_is_broad;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_top_k, __pyx_mstate_global->__pyx_int_5, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 262, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_11 = __pyx_t_9;
  __pyx_L14_bool_binop_done:;
  if (__pyx_t_11) {
    __pyx_t_13 = 8;
    __Pyx_INCREF(__pyx_v_top_k);
    __pyx_t_14 = __pyx_v_top_k;
    __pyx_t_6 = __Pyx_PyLong_From_long(__pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_6, __pyx_t_14, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_9) {
      __pyx_t_5 = __Pyx_PyLong_From_long(__pyx_t_13); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 262, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_PyInt_FromNumber(&__pyx_t_5, NULL, 0) < (0)) __PYX_ERR(0, 262, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_5;
      __pyx_t_5 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_14);
      __pyx_t_1 = __pyx_t_14;
    }
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_INCREF(__pyx_v_top_k);
    __pyx_t_3 = __pyx_v_top_k;
  }
  __pyx_v_effective_top_k = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":265
 * 
 *         # 3. Search
 *         results = self._hybrid_search_chunks(             # <<<<<<<<<<<<<<
 *             agent_id, clean_query, effective_top_k, hybrid_alpha,
 *             file_filter=file_filter,
*/
  __pyx_t_1 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_1);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":266
 *         # 3. Search
 *         results = self._hybrid_search_chunks(
 *             agent_id, clean_query, effective_top_k, hybrid_alpha,             # <<<<<<<<<<<<<<
 *             file_filter=file_filter,
 *             route_tokens=route_tokens,
*/
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_hybrid_alpha); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":269
 *             file_filter=file_filter,
 *             route_tokens=route_tokens,
 *             is_broad=is_broad,             # <<<<<<<<<<<<<<
 *             file_paths_filter=file_paths_filter,
 *         )
*/
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_is_broad); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":270
 *             route_tokens=route_tokens,
 *             is_broad=is_broad,
 *             file_paths_filter=file_paths_filter,             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[5 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_1, __pyx_v_agent_id, __pyx_v_clean_query, __pyx_v_effective_top_k, __pyx_t_5};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_file_filter, __pyx_v_file_filter, __pyx_t_4, __pyx_callargs+5, 0) < (0)) __PYX_ERR(0, 265, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_route_tokens, __pyx_v_route_tokens, __pyx_t_4, __pyx_callargs+5, 1) < (0)) __PYX_ERR(0, 265, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_is_broad, __pyx_t_6, __pyx_t_4, __pyx_callargs+5, 2) < (0)) __PYX_ERR(0, 265, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_file_paths_filter, __pyx_v_file_paths_filter, __pyx_t_4, __pyx_callargs+5, 3) < (0)) __PYX_ERR(0, 265, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_hybrid_search_chunks, __pyx_callargs+__pyx_t_7, (5-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_v_results = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":273
 *         )
 * 
 *         return {             # <<<<<<<<<<<<<<
 *             "status": "search_results",
 *             "query": clean_query,
*/
  __Pyx_XDECREF(__pyx_r);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":274
 * 
 *         return {
 *             "status": "search_results",             # <<<<<<<<<<<<<<
 *             "query": clean_query,
 *             "filter": file_filter,
*/
  __pyx_t_3 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_status, __pyx_mstate_global->__pyx_n_u_search_results) < (0)) __PYX_ERR(0, 274, __pyx_L1_error)

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":275
 *         return {
 *             "status": "search_results",
 *             "query": clean_query,             # <<<<<<<<<<<<<<
 *             "filter": file_filter,
 *             "results": results,
*/
  if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_query, __pyx_v_clean_query) < (0)) __PYX_ERR(0, 274, __pyx_L1_error)

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":276
 *             "status": "search_results",
 *             "query": clean_query,
 *             "filter": file_filter,             # <<<<<<<<<<<<<<
 *             "results": results,
 *             "count": len(results),
*/
  if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_filter, __pyx_v_file_filter) < (0)) __PYX_ERR(0, 274, __pyx_L1_error)

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":277
 *             "query": clean_query,
 *             "filter": file_filter,
 *             "results": results,             # <<<<<<<<<<<<<<
 *             "count": len(results),
 *         }
*/
  if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_results, __pyx_v_results) < (0)) __PYX_ERR(0, 274, __pyx_L1_error)

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":278
 *             "filter": file_filter,
 *             "results": results,
 *             "count": len(results),             # <<<<<<<<<<<<<<
 *         }
 * 
*/
  __pyx_t_2 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 278, __pyx_L1_error)
  __pyx_t_4 = PyLong_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_count, __pyx_t_4) < (0)) __PYX_ERR(0, 274, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":212
 *     # =====================================================================
 * 
 *     def search(             # <<<<<<<<<<<<<<
 *         self,
 *         agent_id: str,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever.search", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_file_filter);
  __Pyx_XDECREF(__pyx_v_clean_query);
  __Pyx_XDECREF(__pyx_v_route_tokens);
  __Pyx_XDECREF(__pyx_v_FILE_EXTENSIONS);
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_token);
  __Pyx_XDECREF(__pyx_v_clean_token);
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_ext);
  __Pyx_XDECREF(__pyx_v_query_lower_set);
  __Pyx_XDECREF(__pyx_v_effective_top_k);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":285
 *     # =====================================================================
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _decompose_compound(token: str) -> Set[str]:
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_5_decompose_compound(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_4_decompose_compound, "CodingHybridRetriever._decompose_compound(str token: str) -> Set[str]\n\nDecompose compound identifiers into sub-tokens.\ne.g., 'login_required' -> {'login', 'required'}\n      'camelCase'      -> {'camel', 'case'}\n      '@decorator'     -> {'decorator'}");
static PyMethodDef __pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_5_decompose_compound = {"_decompose_compound", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_5_decompose_compound, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_4_decompose_compound};
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_5_decompose_compound(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_token = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_decompose_compound (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_token,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 285, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 285, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_decompose_compound", 0) < (0)) __PYX_ERR(0, 285, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_decompose_compound", 1, 1, 1, i); __PYX_ERR(0, 285, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 285, __pyx_L3_error)
    }
    __pyx_v_token = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_decompose_compound", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 285, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._decompose_compound", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_token), (&PyUnicode_Type), 0, "token", 2))) __PYX_ERR(0, 286, __pyx_L1_error)
  __pyx_r = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_4_decompose_compound(__pyx_self, __pyx_v_token);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_4_decompose_compound(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_token) {
  PyObject *__pyx_v_parts = 0;
  PyObject *__pyx_v_clean = NULL;
  PyObject *__pyx_v_seg = NULL;
  PyObject *__pyx_v_camel_parts = NULL;
  PyObject *__pyx_v_cp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_decompose_compound", 0);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":293
 *               '@decorator'     -> {'decorator'}
 *         """
 *         parts: Set[str] = set()             # <<<<<<<<<<<<<<
 *         clean = token.lstrip('@').strip(string.punctuation)
 *         if not clean:
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_parts = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":294
 *         """
 *         parts: Set[str] = set()
 *         clean = token.lstrip('@').strip(string.punctuation)             # <<<<<<<<<<<<<<
 *         if not clean:
 *             return parts
*/
  __pyx_t_3 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyUnicode_Type__lstrip, __pyx_v_token, __pyx_mstate_global->__pyx_kp_u__4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_string); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_punctuation); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_clean = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":295
 *         parts: Set[str] = set()
 *         clean = token.lstrip('@').strip(string.punctuation)
 *         if not clean:             # <<<<<<<<<<<<<<
 *             return parts
 * 
*/
  {
    Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_v_clean);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 295, __pyx_L1_error)
    __pyx_t_7 = (__pyx_temp != 0);
  }

  __pyx_t_8 = (!__pyx_t_7);
  if (__pyx_t_8) {

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":296
 *         clean = token.lstrip('@').strip(string.punctuation)
 *         if not clean:
 *             return parts             # <<<<<<<<<<<<<<
 * 
 *         # Split on underscores
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_parts);
    __pyx_r = __pyx_v_parts;
    goto __pyx_L0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":295
 *         parts: Set[str] = set()
 *         clean = token.lstrip('@').strip(string.punctuation)
 *         if not clean:             # <<<<<<<<<<<<<<
 *             return parts
 * 
*/
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":299
 * 
 *         # Split on underscores
 *         if '_' in clean:             # <<<<<<<<<<<<<<
 *             for seg in clean.split('_'):
 *                 seg = seg.lower().strip()
*/
  __pyx_t_8 = (__Pyx_PyUnicode_ContainsTF(__pyx_mstate_global->__pyx_n_u__5, __pyx_v_clean, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 299, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":300
 *         # Split on underscores
 *         if '_' in clean:
 *             for seg in clean.split('_'):             # <<<<<<<<<<<<<<
 *                 seg = seg.lower().strip()
 *                 if len(seg) > 1:
*/
    __pyx_t_1 = PyUnicode_Split(__pyx_v_clean, __pyx_mstate_global->__pyx_n_u__5, -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 300, __pyx_L1_error)
        #endif
        if (__pyx_t_9 >= __pyx_temp) break;
      }
      __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_9, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_9;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_seg, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":301
 *         if '_' in clean:
 *             for seg in clean.split('_'):
 *                 seg = seg.lower().strip()             # <<<<<<<<<<<<<<
 *                 if len(seg) > 1:
 *                     parts.add(seg)
*/
      __pyx_t_4 = __pyx_v_seg;
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 301, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_t_5 = __pyx_t_2;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 301, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_DECREF_SET(__pyx_v_seg, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":302
 *             for seg in clean.split('_'):
 *                 seg = seg.lower().strip()
 *                 if len(seg) > 1:             # <<<<<<<<<<<<<<
 *                     parts.add(seg)
 * 
*/
      __pyx_t_10 = PyObject_Length(__pyx_v_seg); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 302, __pyx_L1_error)
      __pyx_t_8 = (__pyx_t_10 > 1);
      if (__pyx_t_8) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":303
 *                 seg = seg.lower().strip()
 *                 if len(seg) > 1:
 *                     parts.add(seg)             # <<<<<<<<<<<<<<
 * 
 *         # Split camelCase
*/
        __pyx_t_11 = PySet_Add(__pyx_v_parts, __pyx_v_seg); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 303, __pyx_L1_error)

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":302
 *             for seg in clean.split('_'):
 *                 seg = seg.lower().strip()
 *                 if len(seg) > 1:             # <<<<<<<<<<<<<<
 *                     parts.add(seg)
 * 
*/
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":300
 *         # Split on underscores
 *         if '_' in clean:
 *             for seg in clean.split('_'):             # <<<<<<<<<<<<<<
 *                 seg = seg.lower().strip()
 *                 if len(seg) > 1:
*/
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":299
 * 
 *         # Split on underscores
 *         if '_' in clean:             # <<<<<<<<<<<<<<
 *             for seg in clean.split('_'):
 *                 seg = seg.lower().strip()
*/
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":306
 * 
 *         # Split camelCase
 *         camel_parts = re.findall(r'[a-z]+|[A-Z][a-z]*|[A-Z]+(?=[A-Z][a-z]|$)', clean)             # <<<<<<<<<<<<<<
 *         for cp in camel_parts:
 *             cp = cp.lower().strip()
*/
  __pyx_t_1 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_findall); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_a_z_A_Z_a_z_A_Z_A_Z_a_z, __pyx_v_clean};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_v_camel_parts = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":307
 *         # Split camelCase
 *         camel_parts = re.findall(r'[a-z]+|[A-Z][a-z]*|[A-Z]+(?=[A-Z][a-z]|$)', clean)
 *         for cp in camel_parts:             # <<<<<<<<<<<<<<
 *             cp = cp.lower().strip()
 *             if len(cp) > 1:
*/
  if (likely(PyList_CheckExact(__pyx_v_camel_parts)) || PyTuple_CheckExact(__pyx_v_camel_parts)) {
    __pyx_t_3 = __pyx_v_camel_parts; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_9 = 0;
    __pyx_t_12 = NULL;
  } else {
    __pyx_t_9 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_camel_parts); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_12 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 307, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_12)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 307, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_9, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_9;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 307, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_9));
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_9);
        #endif
        ++__pyx_t_9;
      }
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 307, __pyx_L1_error)
    } else {
      __pyx_t_5 = __pyx_t_12(__pyx_t_3);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 307, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_cp, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":308
 *         camel_parts = re.findall(r'[a-z]+|[A-Z][a-z]*|[A-Z]+(?=[A-Z][a-z]|$)', clean)
 *         for cp in camel_parts:
 *             cp = cp.lower().strip()             # <<<<<<<<<<<<<<
 *             if len(cp) > 1:
 *                 parts.add(cp)
*/
    __pyx_t_4 = __pyx_v_cp;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 308, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_1 = __pyx_t_2;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 308, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_DECREF_SET(__pyx_v_cp, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":309
 *         for cp in camel_parts:
 *             cp = cp.lower().strip()
 *             if len(cp) > 1:             # <<<<<<<<<<<<<<
 *                 parts.add(cp)
 * 
*/
    __pyx_t_10 = PyObject_Length(__pyx_v_cp); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 309, __pyx_L1_error)
    __pyx_t_8 = (__pyx_t_10 > 1);
    if (__pyx_t_8) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":310
 *             cp = cp.lower().strip()
 *             if len(cp) > 1:
 *                 parts.add(cp)             # <<<<<<<<<<<<<<
 * 
 *         parts.add(clean.lower())
*/
      __pyx_t_11 = PySet_Add(__pyx_v_parts, __pyx_v_cp); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 310, __pyx_L1_error)

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":309
 *         for cp in camel_parts:
 *             cp = cp.lower().strip()
 *             if len(cp) > 1:             # <<<<<<<<<<<<<<
 *                 parts.add(cp)
 * 
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":307
 *         # Split camelCase
 *         camel_parts = re.findall(r'[a-z]+|[A-Z][a-z]*|[A-Z]+(?=[A-Z][a-z]|$)', clean)
 *         for cp in camel_parts:             # <<<<<<<<<<<<<<
 *             cp = cp.lower().strip()
 *             if len(cp) > 1:
*/
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":312
 *                 parts.add(cp)
 * 
 *         parts.add(clean.lower())             # <<<<<<<<<<<<<<
 *         return parts
 * 
*/
  __pyx_t_3 = __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyUnicode_Type__lower, __pyx_v_clean); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_11 = PySet_Add(__pyx_v_parts, __pyx_t_3); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":313
 * 
 *         parts.add(clean.lower())
 *         return parts             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_parts);
  __pyx_r = __pyx_v_parts;
  goto __pyx_L0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":285
 *     # =====================================================================
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _decompose_compound(token: str) -> Set[str]:
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._decompose_compound", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_parts);
  __Pyx_XDECREF(__pyx_v_clean);
  __Pyx_XDECREF(__pyx_v_seg);
  __Pyx_XDECREF(__pyx_v_camel_parts);
  __Pyx_XDECREF(__pyx_v_cp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":315
 *         return parts
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _extract_line_numbers(query: str) -> List[int]:
 *         """Extract line numbers from query like 'line 447' or 'at line 100'."""
*/

/* Python wrapper */
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_7_extract_line_numbers(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_6_extract_line_numbers, "CodingHybridRetriever._extract_line_numbers(str query: str) -> List[int]\n\nExtract line numbers from query like 'line 447' or 'at line 100'.");
static PyMethodDef __pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_7_extract_line_numbers = {"_extract_line_numbers", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_7_extract_line_numbers, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_6_extract_line_numbers};
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_7_extract_line_numbers(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_query = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_extract_line_numbers (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_query,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 315, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 315, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_extract_line_numbers", 0) < (0)) __PYX_ERR(0, 315, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_extract_line_numbers", 1, 1, 1, i); __PYX_ERR(0, 315, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 315, __pyx_L3_error)
    }
    __pyx_v_query = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_extract_line_numbers", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 315, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._extract_line_numbers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_query), (&PyUnicode_Type), 0, "query", 2))) __PYX_ERR(0, 316, __pyx_L1_error)
  __pyx_r = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_6_extract_line_numbers(__pyx_self, __pyx_v_query);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_6_extract_line_numbers(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_query) {
  PyObject *__pyx_v_line_nums = 0;
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_v_num = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_extract_line_numbers", 0);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":318
 *     def _extract_line_numbers(query: str) -> List[int]:
 *         """Extract line numbers from query like 'line 447' or 'at line 100'."""
 *         line_nums: List[int] = []             # <<<<<<<<<<<<<<
 *         for m in re.finditer(r'\blines?\s*:?\s*(\d+)', query, re.IGNORECASE):
 *             line_nums.append(int(m.group(1)))
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_line_nums = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":319
 *         """Extract line numbers from query like 'line 447' or 'at line 100'."""
 *         line_nums: List[int] = []
 *         for m in re.finditer(r'\blines?\s*:?\s*(\d+)', query, re.IGNORECASE):             # <<<<<<<<<<<<<<
 *             line_nums.append(int(m.group(1)))
 *         for m in re.finditer(r'\b(\d{3,})\b', query):
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_finditer); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_IGNORECASE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_blines_s_s_d, __pyx_v_query, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (4-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4);
    __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 319, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 319, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_4, __pyx_t_7, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_7;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 319, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_7));
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_7);
        #endif
        ++__pyx_t_7;
      }
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 319, __pyx_L1_error)
    } else {
      __pyx_t_1 = __pyx_t_8(__pyx_t_4);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 319, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_m, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":320
 *         line_nums: List[int] = []
 *         for m in re.finditer(r'\blines?\s*:?\s*(\d+)', query, re.IGNORECASE):
 *             line_nums.append(int(m.group(1)))             # <<<<<<<<<<<<<<
 *         for m in re.finditer(r'\b(\d{3,})\b', query):
 *             num = int(m.group(1))
*/
    __pyx_t_5 = __pyx_v_m;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_int_1};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_group, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 320, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_line_nums, __pyx_t_5); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 320, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":319
 *         """Extract line numbers from query like 'line 447' or 'at line 100'."""
 *         line_nums: List[int] = []
 *         for m in re.finditer(r'\blines?\s*:?\s*(\d+)', query, re.IGNORECASE):             # <<<<<<<<<<<<<<
 *             line_nums.append(int(m.group(1)))
 *         for m in re.finditer(r'\b(\d{3,})\b', query):
*/
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":321
 *         for m in re.finditer(r'\blines?\s*:?\s*(\d+)', query, re.IGNORECASE):
 *             line_nums.append(int(m.group(1)))
 *         for m in re.finditer(r'\b(\d{3,})\b', query):             # <<<<<<<<<<<<<<
 *             num = int(m.group(1))
 *             if num < 50000:
*/
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_finditer); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_b_d_3_b, __pyx_v_query};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_2 = __pyx_t_4; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 321, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 321, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_7, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_7;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 321, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_7));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7);
        #endif
        ++__pyx_t_7;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 321, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_8(__pyx_t_2);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 321, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_m, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":322
 *             line_nums.append(int(m.group(1)))
 *         for m in re.finditer(r'\b(\d{3,})\b', query):
 *             num = int(m.group(1))             # <<<<<<<<<<<<<<
 *             if num < 50000:
 *                 line_nums.append(num)
*/
    __pyx_t_5 = __pyx_v_m;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_int_1};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_group, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 322, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_num, ((PyObject*)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":323
 *         for m in re.finditer(r'\b(\d{3,})\b', query):
 *             num = int(m.group(1))
 *             if num < 50000:             # <<<<<<<<<<<<<<
 *                 line_nums.append(num)
 *         return line_nums
*/
    __pyx_t_5 = PyObject_RichCompare(__pyx_v_num, __pyx_mstate_global->__pyx_int_50000, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 323, __pyx_L1_error)
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 323, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_10) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":324
 *             num = int(m.group(1))
 *             if num < 50000:
 *                 line_nums.append(num)             # <<<<<<<<<<<<<<
 *         return line_nums
 * 
*/
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_line_nums, __pyx_v_num); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 324, __pyx_L1_error)

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":323
 *         for m in re.finditer(r'\b(\d{3,})\b', query):
 *             num = int(m.group(1))
 *             if num < 50000:             # <<<<<<<<<<<<<<
 *                 line_nums.append(num)
 *         return line_nums
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":321
 *         for m in re.finditer(r'\blines?\s*:?\s*(\d+)', query, re.IGNORECASE):
 *             line_nums.append(int(m.group(1)))
 *         for m in re.finditer(r'\b(\d{3,})\b', query):             # <<<<<<<<<<<<<<
 *             num = int(m.group(1))
 *             if num < 50000:
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":325
 *             if num < 50000:
 *                 line_nums.append(num)
 *         return line_nums             # <<<<<<<<<<<<<<
 * 
 *     # =====================================================================
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_line_nums);
  __pyx_r = __pyx_v_line_nums;
  goto __pyx_L0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":315
 *         return parts
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _extract_line_numbers(query: str) -> List[int]:
 *         """Extract line numbers from query like 'line 447' or 'at line 100'."""
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._extract_line_numbers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_line_nums);
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XDECREF(__pyx_v_num);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":331
 *     # =====================================================================
 * 
 *     def _expand_concepts(self, keywords: Set[str]) -> Set[str]:             # <<<<<<<<<<<<<<
 *         """Expand abstract concept keywords into concrete searchable terms."""
 *         expanded = set(keywords)
*/

/* Python wrapper */
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_9_expand_concepts(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_8_expand_concepts, "CodingHybridRetriever._expand_concepts(self, set keywords: Set[str]) -> Set[str]\n\nExpand abstract concept keywords into concrete searchable terms.");
static PyMethodDef __pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_9_expand_concepts = {"_expand_concepts", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_9_expand_concepts, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_8_expand_concepts};
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_9_expand_concepts(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_keywords = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_expand_concepts (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_keywords,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 331, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 331, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 331, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_expand_concepts", 0) < (0)) __PYX_ERR(0, 331, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_expand_concepts", 1, 2, 2, i); __PYX_ERR(0, 331, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 331, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 331, __pyx_L3_error)
    }
    __pyx_v_self = values[0];
    __pyx_v_keywords = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_expand_concepts", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 331, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._expand_concepts", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_keywords), (&PySet_Type), 0, "keywords", 2))) __PYX_ERR(0, 331, __pyx_L1_error)
  __pyx_r = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_8_expand_concepts(__pyx_self, __pyx_v_self, __pyx_v_keywords);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_8_expand_concepts(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_keywords) {
  PyObject *__pyx_v_expanded = NULL;
  PyObject *__pyx_v_kw = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_expand_concepts", 0);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":333
 *     def _expand_concepts(self, keywords: Set[str]) -> Set[str]:
 *         """Expand abstract concept keywords into concrete searchable terms."""
 *         expanded = set(keywords)             # <<<<<<<<<<<<<<
 *         for kw in keywords:
 *             if kw in self.CONCEPT_MAP:
*/
  __pyx_t_1 = PySet_New(__pyx_v_keywords); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_expanded = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":334
 *         """Expand abstract concept keywords into concrete searchable terms."""
 *         expanded = set(keywords)
 *         for kw in keywords:             # <<<<<<<<<<<<<<
 *             if kw in self.CONCEPT_MAP:
 *                 expanded.update(self.CONCEPT_MAP[kw])
*/
  __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_set_iterator(__pyx_v_keywords, 1, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_kw, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":335
 *         expanded = set(keywords)
 *         for kw in keywords:
 *             if kw in self.CONCEPT_MAP:             # <<<<<<<<<<<<<<
 *                 expanded.update(self.CONCEPT_MAP[kw])
 *             if kw in self.SYNONYM_MAP:
*/
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_CONCEPT_MAP); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_v_kw, __pyx_t_5, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 335, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":336
 *         for kw in keywords:
 *             if kw in self.CONCEPT_MAP:
 *                 expanded.update(self.CONCEPT_MAP[kw])             # <<<<<<<<<<<<<<
 *             if kw in self.SYNONYM_MAP:
 *                 expanded.update(self.SYNONYM_MAP[kw])
*/
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_CONCEPT_MAP); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_v_kw); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PySet_Type__update, __pyx_v_expanded, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":335
 *         expanded = set(keywords)
 *         for kw in keywords:
 *             if kw in self.CONCEPT_MAP:             # <<<<<<<<<<<<<<
 *                 expanded.update(self.CONCEPT_MAP[kw])
 *             if kw in self.SYNONYM_MAP:
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":337
 *             if kw in self.CONCEPT_MAP:
 *                 expanded.update(self.CONCEPT_MAP[kw])
 *             if kw in self.SYNONYM_MAP:             # <<<<<<<<<<<<<<
 *                 expanded.update(self.SYNONYM_MAP[kw])
 *         return expanded
*/
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_SYNONYM_MAP); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_v_kw, __pyx_t_5, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":338
 *                 expanded.update(self.CONCEPT_MAP[kw])
 *             if kw in self.SYNONYM_MAP:
 *                 expanded.update(self.SYNONYM_MAP[kw])             # <<<<<<<<<<<<<<
 *         return expanded
 * 
*/
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_SYNONYM_MAP); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_v_kw); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PySet_Type__update, __pyx_v_expanded, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":337
 *             if kw in self.CONCEPT_MAP:
 *                 expanded.update(self.CONCEPT_MAP[kw])
 *             if kw in self.SYNONYM_MAP:             # <<<<<<<<<<<<<<
 *                 expanded.update(self.SYNONYM_MAP[kw])
 *         return expanded
*/
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":339
 *             if kw in self.SYNONYM_MAP:
 *                 expanded.update(self.SYNONYM_MAP[kw])
 *         return expanded             # <<<<<<<<<<<<<<
 * 
 *     # =====================================================================
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_expanded);
  __pyx_r = __pyx_v_expanded;
  goto __pyx_L0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":331
 *     # =====================================================================
 * 
 *     def _expand_concepts(self, keywords: Set[str]) -> Set[str]:             # <<<<<<<<<<<<<<
 *         """Expand abstract concept keywords into concrete searchable terms."""
 *         expanded = set(keywords)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._expand_concepts", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_expanded);
  __Pyx_XDECREF(__pyx_v_kw);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":345
 *     # =====================================================================
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _detect_query_intent(query: str) -> str:
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_11_detect_query_intent(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_10_detect_query_intent, "CodingHybridRetriever._detect_query_intent(str query: str) -> str\n\nDetect the intent category of a query to fine-tune scoring.\nReturns one of: 'symbol', 'concept', 'usage', 'line', 'broad'.");
static PyMethodDef __pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_11_detect_query_intent = {"_detect_query_intent", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_11_detect_query_intent, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_10_detect_query_intent};
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_11_detect_query_intent(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_query = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_detect_query_intent (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_query,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 345, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 345, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_detect_query_intent", 0) < (0)) __PYX_ERR(0, 345, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_detect_query_intent", 1, 1, 1, i); __PYX_ERR(0, 345, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 345, __pyx_L3_error)
    }
    __pyx_v_query = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_detect_query_intent", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 345, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._detect_query_intent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_query), (&PyUnicode_Type), 0, "query", 2))) __PYX_ERR(0, 346, __pyx_L1_error)
  __pyx_r = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_10_detect_query_intent(__pyx_self, __pyx_v_query);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_10_detect_query_intent(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_query) {
  PyObject *__pyx_v_q = NULL;
  PyObject *__pyx_v_content_words = NULL;
  PyObject *__pyx_7genexpr__pyx_v_w = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_detect_query_intent", 0);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":351
 *         Returns one of: 'symbol', 'concept', 'usage', 'line', 'broad'.
 *         """
 *         q = query.lower()             # <<<<<<<<<<<<<<
 *         if re.search(r'\bline\s*\d+', q):
 *             return "line"
*/
  __pyx_t_1 = __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyUnicode_Type__lower, __pyx_v_query); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_q = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":352
 *         """
 *         q = query.lower()
 *         if re.search(r'\bline\s*\d+', q):             # <<<<<<<<<<<<<<
 *             return "line"
 *         if re.search(r'\b(all|every|list|show me|overview)\b', q):
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_search); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_bline_s_d, __pyx_v_q};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 352, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":353
 *         q = query.lower()
 *         if re.search(r'\bline\s*\d+', q):
 *             return "line"             # <<<<<<<<<<<<<<
 *         if re.search(r'\b(all|every|list|show me|overview)\b', q):
 *             return "broad"
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_line);
    __pyx_r = __pyx_mstate_global->__pyx_n_u_line;
    goto __pyx_L0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":352
 *         """
 *         q = query.lower()
 *         if re.search(r'\bline\s*\d+', q):             # <<<<<<<<<<<<<<
 *             return "line"
 *         if re.search(r'\b(all|every|list|show me|overview)\b', q):
*/
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":354
 *         if re.search(r'\bline\s*\d+', q):
 *             return "line"
 *         if re.search(r'\b(all|every|list|show me|overview)\b', q):             # <<<<<<<<<<<<<<
 *             return "broad"
 *         if re.search(r'\b(how is|where is|which.*use|interact|call)\b', q):
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_search); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_b_all_every_list_show_me_overvi, __pyx_v_q};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 354, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":355
 *             return "line"
 *         if re.search(r'\b(all|every|list|show me|overview)\b', q):
 *             return "broad"             # <<<<<<<<<<<<<<
 *         if re.search(r'\b(how is|where is|which.*use|interact|call)\b', q):
 *             return "usage"
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_broad);
    __pyx_r = __pyx_mstate_global->__pyx_n_u_broad;
    goto __pyx_L0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":354
 *         if re.search(r'\bline\s*\d+', q):
 *             return "line"
 *         if re.search(r'\b(all|every|list|show me|overview)\b', q):             # <<<<<<<<<<<<<<
 *             return "broad"
 *         if re.search(r'\b(how is|where is|which.*use|interact|call)\b', q):
*/
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":356
 *         if re.search(r'\b(all|every|list|show me|overview)\b', q):
 *             return "broad"
 *         if re.search(r'\b(how is|where is|which.*use|interact|call)\b', q):             # <<<<<<<<<<<<<<
 *             return "usage"
 *         # Check if query is mainly a single identifier
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_search); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_b_how_is_where_is_which_use_int, __pyx_v_q};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":357
 *             return "broad"
 *         if re.search(r'\b(how is|where is|which.*use|interact|call)\b', q):
 *             return "usage"             # <<<<<<<<<<<<<<
 *         # Check if query is mainly a single identifier
 *         content_words = [w for w in q.split() if w not in _STOP_WORDS]
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_usage);
    __pyx_r = __pyx_mstate_global->__pyx_n_u_usage;
    goto __pyx_L0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":356
 *         if re.search(r'\b(all|every|list|show me|overview)\b', q):
 *             return "broad"
 *         if re.search(r'\b(how is|where is|which.*use|interact|call)\b', q):             # <<<<<<<<<<<<<<
 *             return "usage"
 *         # Check if query is mainly a single identifier
*/
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":359
 *             return "usage"
 *         # Check if query is mainly a single identifier
 *         content_words = [w for w in q.split() if w not in _STOP_WORDS]             # <<<<<<<<<<<<<<
 *         if len(content_words) <= 2:
 *             return "symbol"
*/
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 359, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyUnicode_Split(__pyx_v_q, ((PyObject *)NULL), -1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 359, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 359, __pyx_L8_error)
        #endif
        if (__pyx_t_7 >= __pyx_temp) break;
      }
      __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_7, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_7;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 359, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_w, __pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_STOP_WORDS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 359, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_7genexpr__pyx_v_w, __pyx_t_2, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 359, __pyx_L8_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_6) {
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_7genexpr__pyx_v_w))) __PYX_ERR(0, 359, __pyx_L8_error)
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_w); __pyx_7genexpr__pyx_v_w = 0;
    goto __pyx_L13_exit_scope;
    __pyx_L8_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_w); __pyx_7genexpr__pyx_v_w = 0;
    goto __pyx_L1_error;
    __pyx_L13_exit_scope:;
  } /* exit inner scope */
  __pyx_v_content_words = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":360
 *         # Check if query is mainly a single identifier
 *         content_words = [w for w in q.split() if w not in _STOP_WORDS]
 *         if len(content_words) <= 2:             # <<<<<<<<<<<<<<
 *             return "symbol"
 *         return "concept"
*/
  __pyx_t_7 = __Pyx_PyList_GET_SIZE(__pyx_v_content_words); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 360, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_7 <= 2);
  if (__pyx_t_6) {

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":361
 *         content_words = [w for w in q.split() if w not in _STOP_WORDS]
 *         if len(content_words) <= 2:
 *             return "symbol"             # <<<<<<<<<<<<<<
 *         return "concept"
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_symbol);
    __pyx_r = __pyx_mstate_global->__pyx_n_u_symbol;
    goto __pyx_L0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":360
 *         # Check if query is mainly a single identifier
 *         content_words = [w for w in q.split() if w not in _STOP_WORDS]
 *         if len(content_words) <= 2:             # <<<<<<<<<<<<<<
 *             return "symbol"
 *         return "concept"
*/
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":362
 *         if len(content_words) <= 2:
 *             return "symbol"
 *         return "concept"             # <<<<<<<<<<<<<<
 * 
 *     # =====================================================================
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_concept);
  __pyx_r = __pyx_mstate_global->__pyx_n_u_concept;
  goto __pyx_L0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":345
 *     # =====================================================================
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _detect_query_intent(query: str) -> str:
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._detect_query_intent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_q);
  __Pyx_XDECREF(__pyx_v_content_words);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_w);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":368
 *     # =====================================================================
 * 
 *     def _hybrid_search_chunks(             # <<<<<<<<<<<<<<
 *         self,
 *         agent_id: str,
*/

/* Python wrapper */
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_13_hybrid_search_chunks(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_12_hybrid_search_chunks, "CodingHybridRetriever._hybrid_search_chunks(self, str agent_id: str, str query: str, int top_k: int, double alpha: float, str file_filter: str = None, list route_tokens: List[str] = None, bool is_broad: bool = False, list file_paths_filter: List[str] = None) -> List[Dict[str, Any]]\n\nExecute multi-signal hybrid search.");
static PyMethodDef __pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_13_hybrid_search_chunks = {"_hybrid_search_chunks", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_13_hybrid_search_chunks, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_12_hybrid_search_chunks};
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_13_hybrid_search_chunks(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_agent_id = 0;
  PyObject *__pyx_v_query = 0;
  PyObject *__pyx_v_top_k = 0;
  double __pyx_v_alpha;
  PyObject *__pyx_v_file_filter = 0;
  PyObject *__pyx_v_route_tokens = 0;
  CYTHON_UNUSED int __pyx_v_is_broad;
  PyObject *__pyx_v_file_paths_filter = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_hybrid_search_chunks (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_self,&__pyx_mstate_global->__pyx_n_u_agent_id,&__pyx_mstate_global->__pyx_n_u_query,&__pyx_mstate_global->__pyx_n_u_top_k,&__pyx_mstate_global->__pyx_n_u_alpha,&__pyx_mstate_global->__pyx_n_u_file_filter,&__pyx_mstate_global->__pyx_n_u_route_tokens,&__pyx_mstate_global->__pyx_n_u_is_broad,&__pyx_mstate_global->__pyx_n_u_file_paths_filter,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 368, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  9:
        values[8] = __Pyx_ArgRef_FASTCALL(__pyx_args, 8);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[8])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  8:
        values[7] = __Pyx_ArgRef_FASTCALL(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  4:
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_hybrid_search_chunks", 0) < (0)) __PYX_ERR(0, 368, __pyx_L3_error)

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":374
 *         top_k: int,
 *         alpha: float,
 *         file_filter: str = None,             # <<<<<<<<<<<<<<
 *         route_tokens: List[str] = None,
 *         is_broad: bool = False,
*/
      if (!values[5]) values[5] = __Pyx_NewRef(((PyObject*)Py_None));

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":375
 *         alpha: float,
 *         file_filter: str = None,
 *         route_tokens: List[str] = None,             # <<<<<<<<<<<<<<
 *         is_broad: bool = False,
 *         file_paths_filter: List[str] = None,
*/
      if (!values[6]) values[6] = __Pyx_NewRef(((PyObject*)Py_None));

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":377
 *         route_tokens: List[str] = None,
 *         is_broad: bool = False,
 *         file_paths_filter: List[str] = None,             # <<<<<<<<<<<<<<
 *     ) -> List[Dict[str, Any]]:
 *         """Execute multi-signal hybrid search."""
*/
      if (!values[8]) values[8] = __Pyx_NewRef(((PyObject*)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 5; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_hybrid_search_chunks", 0, 5, 9, i); __PYX_ERR(0, 368, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  9:
        values[8] = __Pyx_ArgRef_FASTCALL(__pyx_args, 8);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[8])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  8:
        values[7] = __Pyx_ArgRef_FASTCALL(__pyx_args, 7);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[7])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  7:
        values[6] = __Pyx_ArgRef_FASTCALL(__pyx_args, 6);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[6])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  6:
        values[5] = __Pyx_ArgRef_FASTCALL(__pyx_args, 5);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[5])) __PYX_ERR(0, 368, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  5:
        values[4] = __Pyx_ArgRef_FASTCALL(__pyx_args, 4);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[4])) __PYX_ERR(0, 368, __pyx_L3_error)
        values[3] = __Pyx_ArgRef_FASTCALL(__pyx_args, 3);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[3])) __PYX_ERR(0, 368, __pyx_L3_error)
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 368, __pyx_L3_error)
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 368, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 368, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":374
 *         top_k: int,
 *         alpha: float,
 *         file_filter: str = None,             # <<<<<<<<<<<<<<
 *         route_tokens: List[str] = None,
 *         is_broad: bool = False,
*/
      if (!values[5]) values[5] = __Pyx_NewRef(((PyObject*)Py_None));

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":375
 *         alpha: float,
 *         file_filter: str = None,
 *         route_tokens: List[str] = None,             # <<<<<<<<<<<<<<
 *         is_broad: bool = False,
 *         file_paths_filter: List[str] = None,
*/
      if (!values[6]) values[6] = __Pyx_NewRef(((PyObject*)Py_None));

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":377
 *         route_tokens: List[str] = None,
 *         is_broad: bool = False,
 *         file_paths_filter: List[str] = None,             # <<<<<<<<<<<<<<
 *     ) -> List[Dict[str, Any]]:
 *         """Execute multi-signal hybrid search."""
*/
      if (!values[8]) values[8] = __Pyx_NewRef(((PyObject*)Py_None));
    }
    __pyx_v_self = values[0];
    __pyx_v_agent_id = ((PyObject*)values[1]);
    __pyx_v_query = ((PyObject*)values[2]);
    if (__Pyx_PyInt_FromNumber(&values[3], "top_k", 0) < (0)) __PYX_ERR(0, 372, __pyx_L3_error)
    __pyx_v_top_k = ((PyObject*)values[3]);
    __pyx_v_alpha = __Pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_alpha == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 373, __pyx_L3_error)
    __pyx_v_file_filter = ((PyObject*)values[5]);
    __pyx_v_route_tokens = ((PyObject*)values[6]);
    if (values[7]) {
      __pyx_v_is_broad = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_is_broad == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 376, __pyx_L3_error)
    } else {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":376
 *         file_filter: str = None,
 *         route_tokens: List[str] = None,
 *         is_broad: bool = False,             # <<<<<<<<<<<<<<
 *         file_paths_filter: List[str] = None,
 *     ) -> List[Dict[str, Any]]:
*/
      __pyx_v_is_broad = ((int)((int)0));
    }
    __pyx_v_file_paths_filter = ((PyObject*)values[8]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_hybrid_search_chunks", 0, 5, 9, __pyx_nargs); __PYX_ERR(0, 368, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_agent_id), (&PyUnicode_Type), 0, "agent_id", 2))) __PYX_ERR(0, 370, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_query), (&PyUnicode_Type), 0, "query", 2))) __PYX_ERR(0, 371, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_top_k), (&PyLong_Type), 0, "top_k", 2))) __PYX_ERR(0, 372, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_file_filter), (&PyUnicode_Type), 1, "file_filter", 2))) __PYX_ERR(0, 374, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_route_tokens), (&PyList_Type), 1, "route_tokens", 2))) __PYX_ERR(0, 375, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_file_paths_filter), (&PyList_Type), 1, "file_paths_filter", 2))) __PYX_ERR(0, 377, __pyx_L1_error)
  __pyx_r = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_12_hybrid_search_chunks(__pyx_self, __pyx_v_self, __pyx_v_agent_id, __pyx_v_query, __pyx_v_top_k, __pyx_v_alpha, __pyx_v_file_filter, __pyx_v_route_tokens, __pyx_v_is_broad, __pyx_v_file_paths_filter);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":368
 *     # =====================================================================
 * 
 *     def _hybrid_search_chunks(             # <<<<<<<<<<<<<<
 *         self,
 *         agent_id: str,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":460
 *                     doc_freq[kw] += 1
 * 
 *         def idf(term: str) -> float:             # <<<<<<<<<<<<<<
 *             df = doc_freq.get(term, 0)
 *             return math.log((total_docs + 1) / (df + 1)) + 1.0
*/

/* Python wrapper */
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_1idf(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_1idf = {"idf", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_1idf, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_1idf(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_term = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("idf (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_term,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 460, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 460, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "idf", 0) < (0)) __PYX_ERR(0, 460, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("idf", 1, 1, 1, i); __PYX_ERR(0, 460, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 460, __pyx_L3_error)
    }
    __pyx_v_term = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("idf", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 460, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.idf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_term), (&PyUnicode_Type), 0, "term", 2))) __PYX_ERR(0, 460, __pyx_L1_error)
  __pyx_r = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_idf(__pyx_self, __pyx_v_term);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_idf(PyObject *__pyx_self, PyObject *__pyx_v_term) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *__pyx_cur_scope;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *__pyx_outer_scope;
  PyObject *__pyx_v_df = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("idf", 0);
  __pyx_outer_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":461
 * 
 *         def idf(term: str) -> float:
 *             df = doc_freq.get(term, 0)             # <<<<<<<<<<<<<<
 *             return math.log((total_docs + 1) / (df + 1)) + 1.0
 * 
*/
  if (unlikely(!__pyx_cur_scope->__pyx_v_doc_freq)) { __Pyx_RaiseClosureNameError("doc_freq"); __PYX_ERR(0, 461, __pyx_L1_error) }
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_doc_freq;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_term, __pyx_mstate_global->__pyx_int_0};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":462
 *         def idf(term: str) -> float:
 *             df = doc_freq.get(term, 0)
 *             return math.log((total_docs + 1) / (df + 1)) + 1.0             # <<<<<<<<<<<<<<
 * 
 *         #  C. Build parent-class index for relationship boosts
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_math); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_log); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyLong_FromSsize_t((__pyx_cur_scope->__pyx_v_total_docs + 1)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyLong_AddObjC(__pyx_v_df, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyNumber_Divide(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 462, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_5 = __Pyx_PyFloat_AddObjC(__pyx_t_1, __pyx_mstate_global->__pyx_float_1_0, 1.0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":460
 *                     doc_freq[kw] += 1
 * 
 *         def idf(term: str) -> float:             # <<<<<<<<<<<<<<
 *             df = doc_freq.get(term, 0)
 *             return math.log((total_docs + 1) / (df + 1)) + 1.0
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.idf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_df);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_4generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":420
 *                 route_patterns.append(clean_rt)
 *                 segments = [seg for seg in clean_rt.split('/') if seg and seg not in _STOP_WORDS]
 *                 query_keywords.update(s.lower() for s in segments)             # <<<<<<<<<<<<<<
 * 
 *         #  B. Build corpus-level IDF (per search, lightweight)
*/

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_2genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr(__pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 420, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_4generator, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_genexpr, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi); if (unlikely(!gen)) __PYX_ERR(0, 420, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_4generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *__pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(0, 420, __pyx_L1_error)
  }
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 420, __pyx_L1_error) }
  __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 420, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_2;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_s);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_s, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_4 = __pyx_cur_scope->__pyx_v_s;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 420, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 420, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_7generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":430
 *         chunk_to_ctx: List[Tuple[Dict[str, Any], str]] = []  # (chunk, file_path)
 * 
 *         normalized_file_paths_filter = set(os.path.normpath(fp) for fp in file_paths_filter) if file_paths_filter else None             # <<<<<<<<<<<<<<
 * 
 *         for ctx in contexts:
*/

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_5genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr(__pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 430, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_7generator1, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_genexpr, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi); if (unlikely(!gen)) __PYX_ERR(0, 430, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_7generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *__pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 430, __pyx_L1_error)
  __pyx_r = PySet_New(NULL); if (unlikely(!__pyx_r)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 430, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_genexpr_arg_0 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 430, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 430, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_2;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_fp);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_fp, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_4 = __pyx_t_6;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_cur_scope->__pyx_v_fp};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_normpath, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 430, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    if (unlikely(PySet_Add(__pyx_r, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 430, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_10generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":484
 *             if query_vector and chunk_vec and len(chunk_vec) > 0:
 *                 try:
 *                     dot = sum(a * b for a, b in zip(query_vector, chunk_vec))             # <<<<<<<<<<<<<<
 *                     # Normalise to [0, 1] via cosine (vectors should be pre-normalised,
 *                     # but guard anyway)
*/

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_8genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr(__pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 484, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_10generator2, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_genexpr, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi); if (unlikely(!gen)) __PYX_ERR(0, 484, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_10generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *__pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L8_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(0, 484, __pyx_L1_error)
  }
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 484, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 484, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 484, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_2;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 484, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);
        #endif
        ++__pyx_t_2;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 484, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 484, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 484, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_6);
      } else {
        __pyx_t_5 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 484, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 484, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_6);
      }
      #else
      __pyx_t_5 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 484, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 484, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 484, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < (0)) __PYX_ERR(0, 484, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 484, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_a);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_a, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_b);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_b, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_cur_scope->__pyx_v_a, __pyx_cur_scope->__pyx_v_b); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 484, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L8_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 484, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_13generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":487
 *                     # Normalise to [0, 1] via cosine (vectors should be pre-normalised,
 *                     # but guard anyway)
 *                     mag_q = math.sqrt(sum(a * a for a in query_vector)) or 1.0             # <<<<<<<<<<<<<<
 *                     mag_c = math.sqrt(sum(b * b for b in chunk_vec)) or 1.0
 *                     vec_score = max(0.0, dot / (mag_q * mag_c))
*/

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_11genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr(__pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 487, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_13generator3, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_genexpr, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi); if (unlikely(!gen)) __PYX_ERR(0, 487, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_13generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *__pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(0, 487, __pyx_L1_error)
  }
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 487, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_genexpr_arg_0 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 487, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 487, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_2;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 487, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_a);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_a, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Multiply(__pyx_cur_scope->__pyx_v_a, __pyx_cur_scope->__pyx_v_a); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 487, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 487, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_16generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":488
 *                     # but guard anyway)
 *                     mag_q = math.sqrt(sum(a * a for a in query_vector)) or 1.0
 *                     mag_c = math.sqrt(sum(b * b for b in chunk_vec)) or 1.0             # <<<<<<<<<<<<<<
 *                     vec_score = max(0.0, dot / (mag_q * mag_c))
 *                 except Exception:
*/

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_14genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr(__pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 488, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_16generator4, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_genexpr, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi); if (unlikely(!gen)) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_16generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *__pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(0, 488, __pyx_L1_error)
  }
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 488, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 488, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 488, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_2;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 488, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);
        #endif
        ++__pyx_t_2;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 488, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 488, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_b);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_b, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_cur_scope->__pyx_v_b, __pyx_cur_scope->__pyx_v_b); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 488, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_19generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":517
 *                 overlap = query_keywords & chunk_text_bag
 *                 if overlap:
 *                     idf_sum = sum(idf(t) for t in overlap if t in original_query_keywords)             # <<<<<<<<<<<<<<
 *                     idf_total = sum(idf(t) for t in original_query_keywords) or 1.0
 *                     # Also credit expanded-keyword matches (lower weight)
*/

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_17genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr(__pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 517, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_19generator5, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_genexpr, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi); if (unlikely(!gen)) __PYX_ERR(0, 517, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_19generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *__pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(0, 517, __pyx_L1_error)
  }
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 517, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 517, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 517, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_2;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 517, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2));
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2);
        #endif
        ++__pyx_t_2;
      }
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 517, __pyx_L1_error)
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 517, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_t);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_t, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_original_query_keywords)) { __Pyx_RaiseClosureNameError("original_query_keywords"); __PYX_ERR(0, 517, __pyx_L1_error) }
    if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_original_query_keywords == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 517, __pyx_L1_error)
    }
    __pyx_t_5 = (__Pyx_PySet_ContainsTF(__pyx_cur_scope->__pyx_v_t, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_original_query_keywords, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 517, __pyx_L1_error)
    if (__pyx_t_5) {
      __pyx_t_4 = __pyx_cur_scope->__pyx_v_t;
      __Pyx_INCREF(__pyx_t_4);
      if (!(likely(PyUnicode_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_4))) __PYX_ERR(0, 517, __pyx_L1_error)
      if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_idf)) { __Pyx_RaiseClosureNameError("idf"); __PYX_ERR(0, 517, __pyx_L1_error) }
      __pyx_t_6 = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_idf(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_idf, ((PyObject*)__pyx_t_4)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 517, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      __Pyx_XGIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 517, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_22generator6(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":518
 *                 if overlap:
 *                     idf_sum = sum(idf(t) for t in overlap if t in original_query_keywords)
 *                     idf_total = sum(idf(t) for t in original_query_keywords) or 1.0             # <<<<<<<<<<<<<<
 *                     # Also credit expanded-keyword matches (lower weight)
 *                     expanded_only = overlap - original_query_keywords
*/

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_20genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr(__pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 518, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_22generator6, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_genexpr, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi); if (unlikely(!gen)) __PYX_ERR(0, 518, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_22generator6(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *__pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(0, 518, __pyx_L1_error)
  }
  __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 518, __pyx_L1_error) }
  __pyx_t_5 = __Pyx_set_iterator(__pyx_cur_scope->__pyx_genexpr_arg_0, 1, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_t);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_t, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_5 = __pyx_cur_scope->__pyx_v_t;
    __Pyx_INCREF(__pyx_t_5);
    if (!(likely(PyUnicode_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_5))) __PYX_ERR(0, 518, __pyx_L1_error)
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_idf)) { __Pyx_RaiseClosureNameError("idf"); __PYX_ERR(0, 518, __pyx_L1_error) }
    __pyx_t_7 = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_idf(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_idf, ((PyObject*)__pyx_t_5)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __pyx_cur_scope->__pyx_t_3 = __pyx_t_4;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    __pyx_t_4 = __pyx_cur_scope->__pyx_t_3;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 518, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_25generator7(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":575
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3             # <<<<<<<<<<<<<<
 *                     ):
 *                         relationship_boost = 0.3
*/

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_23genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr(__pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 575, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_25generator7, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_genexpr, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi); if (unlikely(!gen)) __PYX_ERR(0, 575, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_25generator7(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *__pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 575, __pyx_L1_error)
  __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 575, __pyx_L1_error) }
  __pyx_t_5 = __Pyx_set_iterator(__pyx_cur_scope->__pyx_genexpr_arg_0, 1, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_qkw);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_qkw, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_7 = PyObject_Length(__pyx_cur_scope->__pyx_v_qkw); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 575, __pyx_L1_error)
    __pyx_t_8 = (__pyx_t_7 > 3);
    if (__pyx_t_8) {
      if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_parent_class)) { __Pyx_RaiseClosureNameError("parent_class"); __PYX_ERR(0, 575, __pyx_L1_error) }
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_qkw, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_parent_class, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 575, __pyx_L1_error)
      if (__pyx_t_8) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":574
 *                 if '.' in chunk_name:
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(             # <<<<<<<<<<<<<<
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3
 *                     ):
*/
        __Pyx_XDECREF(__pyx_r);

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":575
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3             # <<<<<<<<<<<<<<
 *                     ):
 *                         relationship_boost = 0.3
*/
        __Pyx_INCREF(Py_True);
        __pyx_r = Py_True;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
    }
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":574
 *                 if '.' in chunk_name:
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(             # <<<<<<<<<<<<<<
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3
 *                     ):
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":575
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3             # <<<<<<<<<<<<<<
 *                     ):
 *                         relationship_boost = 0.3
*/
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":653
 * 
 *         # Sort and return
 *         scored_chunks.sort(key=lambda x: x["score"], reverse=True)             # <<<<<<<<<<<<<<
 *         return scored_chunks[:top_k]
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_26lambda8(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_26lambda8 = {"lambda8", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_26lambda8, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_26lambda8(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_x = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda8 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_x,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 653, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 653, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "lambda8", 0) < (0)) __PYX_ERR(0, 653, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("lambda8", 1, 1, 1, i); __PYX_ERR(0, 653, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 653, __pyx_L3_error)
    }
    __pyx_v_x = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda8", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 653, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.lambda8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_lambda8(__pyx_self, __pyx_v_x);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda8(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda8", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_x, __pyx_mstate_global->__pyx_n_u_score); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks.lambda8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":368
 *     # =====================================================================
 * 
 *     def _hybrid_search_chunks(             # <<<<<<<<<<<<<<
 *         self,
 *         agent_id: str,
*/

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_12_hybrid_search_chunks(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_agent_id, PyObject *__pyx_v_query, PyObject *__pyx_v_top_k, double __pyx_v_alpha, PyObject *__pyx_v_file_filter, PyObject *__pyx_v_route_tokens, CYTHON_UNUSED int __pyx_v_is_broad, PyObject *__pyx_v_file_paths_filter) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *__pyx_cur_scope;
  PyObject *__pyx_v_intent = NULL;
  PyObject *__pyx_v_query_vector = 0;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_raw_tokens = NULL;
  PyObject *__pyx_v_query_keywords = 0;
  PyObject *__pyx_v_w = NULL;
  PyObject *__pyx_v_cleaned = NULL;
  PyObject *__pyx_v_query_line_numbers = NULL;
  PyObject *__pyx_v_route_patterns = 0;
  PyObject *__pyx_v_rt = NULL;
  PyObject *__pyx_v_clean_rt = NULL;
  PyObject *__pyx_v_segments = NULL;
  PyObject *__pyx_v_contexts = NULL;
  PyObject *__pyx_v_all_vectors = NULL;
  PyObject *__pyx_v_all_chunks_flat = 0;
  PyObject *__pyx_v_chunk_to_ctx = 0;
  PyObject *__pyx_v_normalized_file_paths_filter = NULL;
  PyObject *__pyx_v_ctx = NULL;
  PyObject *__pyx_v_file_path = NULL;
  PyObject *__pyx_v_normalized_filter = NULL;
  PyObject *__pyx_v_path_lower = NULL;
  PyObject *__pyx_v_chunk = NULL;
  PyObject *__pyx_v_chunk_text_bag = NULL;
  PyObject *__pyx_v_kw = NULL;
  PyObject *__pyx_v_class_names = 0;
  PyObject *__pyx_v_scored_chunks = 0;
  PyObject *__pyx_v_vec_score = NULL;
  PyObject *__pyx_v_hash_id = NULL;
  PyObject *__pyx_v_chunk_vec = NULL;
  PyObject *__pyx_v_dot = NULL;
  PyObject *__pyx_v_mag_q = NULL;
  PyObject *__pyx_v_mag_c = NULL;
  PyObject *__pyx_v_kw_score = NULL;
  PyObject *__pyx_v_chunk_kws = 0;
  PyObject *__pyx_v_chunk_name = NULL;
  PyObject *__pyx_v_chunk_name_parts = NULL;
  PyObject *__pyx_v_chunk_summary = NULL;
  PyObject *__pyx_v_chunk_content = NULL;
  PyObject *__pyx_v_chunk_type = NULL;
  PyObject *__pyx_v_summary_words = NULL;
  PyObject *__pyx_v_content_words = NULL;
  PyObject *__pyx_v_overlap = NULL;
  PyObject *__pyx_v_idf_sum = NULL;
  PyObject *__pyx_v_idf_total = NULL;
  PyObject *__pyx_v_expanded_only = NULL;
  double __pyx_v_expanded_credit;
  PyObject *__pyx_v_base_kw = NULL;
  double __pyx_v_name_match_boost;
  PyObject *__pyx_v_qkw = NULL;
  PyObject *__pyx_v_summary_overlap = NULL;
  double __pyx_v_summary_match_boost;
  double __pyx_v_content_match_boost;
  PyObject *__pyx_v_content_hits = NULL;
  double __pyx_v_route_match_boost;
  PyObject *__pyx_v_rp = NULL;
  double __pyx_v_type_match_boost;
  PyObject *__pyx_v_type_query_words = NULL;
  PyObject *__pyx_v_query_type_mentions = NULL;
  PyObject *__pyx_v_qt = NULL;
  double __pyx_v_relationship_boost;
  double __pyx_v_bigram_boost;
  PyObject *__pyx_v_query_lower = NULL;
  PyObject *__pyx_v_q_words = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_bigram = NULL;
  PyObject *__pyx_v_line_match_boost = NULL;
  PyObject *__pyx_v_start_line = NULL;
  PyObject *__pyx_v_end_line = NULL;
  PyObject *__pyx_v_span = NULL;
  PyObject *__pyx_v_ln = NULL;
  PyObject *__pyx_v_tightness = NULL;
  PyObject *__pyx_v_score = NULL;
  double __pyx_v_effective_alpha;
  PyObject *__pyx_v_final_score = NULL;
  PyObject *__pyx_v_summary_chunk = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_seg = NULL;
  PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_4generator = 0;
  PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_7generator1 = 0;
  PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_10generator2 = 0;
  PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_13generator3 = 0;
  PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_16generator4 = 0;
  PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_19generator5 = 0;
  PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_22generator6 = 0;
  PyObject *__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_25generator7 = 0;
  PyObject *__pyx_9genexpr10__pyx_v_w = NULL;
  PyObject *__pyx_9genexpr11__pyx_v_k = NULL;
  PyObject *__pyx_9genexpr11__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14[4];
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  Py_ssize_t __pyx_t_24;
  int __pyx_t_25;
  int __pyx_t_26;
  Py_ssize_t __pyx_t_27;
  PyObject *(*__pyx_t_28)(PyObject *);
  PyObject *(*__pyx_t_29)(PyObject *);
  long __pyx_t_30;
  Py_ssize_t __pyx_t_31;
  PyObject *(*__pyx_t_32)(PyObject *);
  double __pyx_t_33;
  double __pyx_t_34;
  double __pyx_t_35;
  PyObject *__pyx_t_36 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_hybrid_search_chunks", 0);
  __pyx_cur_scope = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks(__pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 368, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":381
 *         """Execute multi-signal hybrid search."""
 * 
 *         intent = self._detect_query_intent(query)             # <<<<<<<<<<<<<<
 * 
 *         #  A. Query representations
*/
  __pyx_t_2 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_query};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_detect_query_intent, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_intent = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":386
 * 
 *         # Vector
 *         query_vector: List[float] = []             # <<<<<<<<<<<<<<
 *         try:
 *             query_vector = self.embedding_client.embed(query)
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_query_vector = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":387
 *         # Vector
 *         query_vector: List[float] = []
 *         try:             # <<<<<<<<<<<<<<
 *             query_vector = self.embedding_client.embed(query)
 *             if hasattr(query_vector, 'tolist'):
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":388
 *         query_vector: List[float] = []
 *         try:
 *             query_vector = self.embedding_client.embed(query)             # <<<<<<<<<<<<<<
 *             if hasattr(query_vector, 'tolist'):
 *                 query_vector = query_vector.tolist()
*/
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_embedding_client); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 388, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = __pyx_t_7;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_query};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_embed, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 388, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(0, 388, __pyx_L3_error)
      __Pyx_DECREF_SET(__pyx_v_query_vector, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":389
 *         try:
 *             query_vector = self.embedding_client.embed(query)
 *             if hasattr(query_vector, 'tolist'):             # <<<<<<<<<<<<<<
 *                 query_vector = query_vector.tolist()
 *         except Exception as e:
*/
      __pyx_t_8 = __Pyx_HasAttr(__pyx_v_query_vector, __pyx_mstate_global->__pyx_n_u_tolist); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 389, __pyx_L3_error)
      if (__pyx_t_8) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":390
 *             query_vector = self.embedding_client.embed(query)
 *             if hasattr(query_vector, 'tolist'):
 *                 query_vector = query_vector.tolist()             # <<<<<<<<<<<<<<
 *         except Exception as e:
 *             logger.warning(f"Embedding generation failed for query '{query}': {e}")
*/
        __pyx_t_1 = __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyList_Type__tolist, __pyx_v_query_vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_1))) __PYX_ERR(0, 390, __pyx_L3_error)
        __Pyx_DECREF_SET(__pyx_v_query_vector, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":389
 *         try:
 *             query_vector = self.embedding_client.embed(query)
 *             if hasattr(query_vector, 'tolist'):             # <<<<<<<<<<<<<<
 *                 query_vector = query_vector.tolist()
 *         except Exception as e:
*/
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":387
 *         # Vector
 *         query_vector: List[float] = []
 *         try:             # <<<<<<<<<<<<<<
 *             query_vector = self.embedding_client.embed(query)
 *             if hasattr(query_vector, 'tolist'):
*/
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":391
 *             if hasattr(query_vector, 'tolist'):
 *                 query_vector = query_vector.tolist()
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             logger.warning(f"Embedding generation failed for query '{query}': {e}")
 * 
*/
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_9) {
      __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_2) < 0) __PYX_ERR(0, 391, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_e = __pyx_t_7;
      /*try:*/ {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":392
 *                 query_vector = query_vector.tolist()
 *         except Exception as e:
 *             logger.warning(f"Embedding generation failed for query '{query}': {e}")             # <<<<<<<<<<<<<<
 * 
 *         # Keywords
*/
        __pyx_t_11 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_logger); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 392, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_warning); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 392, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_12 = __Pyx_PyObject_FormatSimple(__pyx_v_e, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 392, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_14[0] = __pyx_mstate_global->__pyx_kp_u_Embedding_generation_failed_for;
        __pyx_t_14[1] = __pyx_v_query;
        __pyx_t_14[2] = __pyx_mstate_global->__pyx_kp_u__6;
        __pyx_t_14[3] = __pyx_t_12;
        __pyx_t_15 = __Pyx_PyUnicode_Join(__pyx_t_14, 4, 39 + __Pyx_PyUnicode_GET_LENGTH(__pyx_v_query) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_12), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_query) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_12));
        if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 392, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_3 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_13))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
          assert(__pyx_t_11);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
          __pyx_t_3 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_15};
          __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 392, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_10);
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":391
 *             if hasattr(query_vector, 'tolist'):
 *                 query_vector = query_vector.tolist()
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             logger.warning(f"Embedding generation failed for query '{query}': {e}")
 * 
*/
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          goto __pyx_L16;
        }
        __pyx_L15_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
          if ( unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __pyx_t_9 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_XGIVEREF(__pyx_t_22);
          __Pyx_XGIVEREF(__pyx_t_23);
          __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
          goto __pyx_L5_except_error;
        }
        __pyx_L16:;
      }
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":387
 *         # Vector
 *         query_vector: List[float] = []
 *         try:             # <<<<<<<<<<<<<<
 *             query_vector = self.embedding_client.embed(query)
 *             if hasattr(query_vector, 'tolist'):
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_L8_try_end:;
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":395
 * 
 *         # Keywords
 *         raw_tokens = query.split()             # <<<<<<<<<<<<<<
 *         query_keywords: Set[str] = set()
 *         for w in raw_tokens:
*/
  __pyx_t_2 = PyUnicode_Split(__pyx_v_query, ((PyObject *)NULL), -1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_raw_tokens = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":396
 *         # Keywords
 *         raw_tokens = query.split()
 *         query_keywords: Set[str] = set()             # <<<<<<<<<<<<<<
 *         for w in raw_tokens:
 *             cleaned = w.lower().strip(string.punctuation + "'\"")
*/
  __pyx_t_2 = PySet_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_query_keywords = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":397
 *         raw_tokens = query.split()
 *         query_keywords: Set[str] = set()
 *         for w in raw_tokens:             # <<<<<<<<<<<<<<
 *             cleaned = w.lower().strip(string.punctuation + "'\"")
 *             if cleaned and cleaned not in _STOP_WORDS:
*/
  __pyx_t_2 = __pyx_v_raw_tokens; __Pyx_INCREF(__pyx_t_2);
  __pyx_t_24 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 397, __pyx_L1_error)
      #endif
      if (__pyx_t_24 >= __pyx_temp) break;
    }
    __pyx_t_7 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_24, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_24;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_XDECREF_SET(__pyx_v_w, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":398
 *         query_keywords: Set[str] = set()
 *         for w in raw_tokens:
 *             cleaned = w.lower().strip(string.punctuation + "'\"")             # <<<<<<<<<<<<<<
 *             if cleaned and cleaned not in _STOP_WORDS:
 *                 query_keywords.add(cleaned)
*/
    __pyx_t_13 = __pyx_v_w;
    __Pyx_INCREF(__pyx_t_13);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_13, NULL};
      __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    }
    __pyx_t_1 = __pyx_t_10;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_string); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_punctuation); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = PyNumber_Add(__pyx_t_15, __pyx_mstate_global->__pyx_kp_u_); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_13};
      __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_cleaned, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":399
 *         for w in raw_tokens:
 *             cleaned = w.lower().strip(string.punctuation + "'\"")
 *             if cleaned and cleaned not in _STOP_WORDS:             # <<<<<<<<<<<<<<
 *                 query_keywords.add(cleaned)
 *                 query_keywords.update(self._decompose_compound(cleaned))
*/
    __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_v_cleaned); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 399, __pyx_L1_error)
    if (__pyx_t_25) {
    } else {
      __pyx_t_8 = __pyx_t_25;
      goto __pyx_L24_bool_binop_done;
    }
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_STOP_WORDS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 399, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_25 = (__Pyx_PySequence_ContainsTF(__pyx_v_cleaned, __pyx_t_7, Py_NE)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 399, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = __pyx_t_25;
    __pyx_L24_bool_binop_done:;
    if (__pyx_t_8) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":400
 *             cleaned = w.lower().strip(string.punctuation + "'\"")
 *             if cleaned and cleaned not in _STOP_WORDS:
 *                 query_keywords.add(cleaned)             # <<<<<<<<<<<<<<
 *                 query_keywords.update(self._decompose_compound(cleaned))
 *         query_keywords.discard("")
*/
      __pyx_t_26 = PySet_Add(__pyx_v_query_keywords, __pyx_v_cleaned); if (unlikely(__pyx_t_26 == ((int)-1))) __PYX_ERR(0, 400, __pyx_L1_error)

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":401
 *             if cleaned and cleaned not in _STOP_WORDS:
 *                 query_keywords.add(cleaned)
 *                 query_keywords.update(self._decompose_compound(cleaned))             # <<<<<<<<<<<<<<
 *         query_keywords.discard("")
 * 
*/
      __pyx_t_10 = __pyx_v_self;
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_cleaned};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_decompose_compound, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_t_10 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PySet_Type__update, __pyx_v_query_keywords, __pyx_t_7); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 401, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":399
 *         for w in raw_tokens:
 *             cleaned = w.lower().strip(string.punctuation + "'\"")
 *             if cleaned and cleaned not in _STOP_WORDS:             # <<<<<<<<<<<<<<
 *                 query_keywords.add(cleaned)
 *                 query_keywords.update(self._decompose_compound(cleaned))
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":397
 *         raw_tokens = query.split()
 *         query_keywords: Set[str] = set()
 *         for w in raw_tokens:             # <<<<<<<<<<<<<<
 *             cleaned = w.lower().strip(string.punctuation + "'\"")
 *             if cleaned and cleaned not in _STOP_WORDS:
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":402
 *                 query_keywords.add(cleaned)
 *                 query_keywords.update(self._decompose_compound(cleaned))
 *         query_keywords.discard("")             # <<<<<<<<<<<<<<
 * 
 *         # Save original (pre-expansion) for IDF weighting
*/
  __pyx_t_26 = __Pyx_PySet_Discard(__pyx_v_query_keywords, __pyx_mstate_global->__pyx_kp_u__2); if (unlikely(__pyx_t_26 == ((int)-1))) __PYX_ERR(0, 402, __pyx_L1_error)

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":405
 * 
 *         # Save original (pre-expansion) for IDF weighting
 *         original_query_keywords = set(query_keywords)             # <<<<<<<<<<<<<<
 * 
 *         # Expand
*/
  __pyx_t_2 = PySet_New(__pyx_v_query_keywords); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_original_query_keywords = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":408
 * 
 *         # Expand
 *         query_keywords = self._expand_concepts(query_keywords)             # <<<<<<<<<<<<<<
 * 
 *         # Line numbers
*/
  __pyx_t_10 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_10);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_query_keywords};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_expand_concepts, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  if (!(likely(PySet_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("set", __pyx_t_2))) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_DECREF_SET(__pyx_v_query_keywords, ((PyObject*)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":411
 * 
 *         # Line numbers
 *         query_line_numbers = self._extract_line_numbers(query)             # <<<<<<<<<<<<<<
 * 
 *         # Route tokens
*/
  __pyx_t_10 = __pyx_v_self;
  __Pyx_INCREF(__pyx_t_10);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_query};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_extract_line_numbers, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v_query_line_numbers = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":414
 * 
 *         # Route tokens
 *         route_patterns: List[str] = []             # <<<<<<<<<<<<<<
 *         if route_tokens:
 *             for rt in route_tokens:
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_route_patterns = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":415
 *         # Route tokens
 *         route_patterns: List[str] = []
 *         if route_tokens:             # <<<<<<<<<<<<<<
 *             for rt in route_tokens:
 *                 clean_rt = rt.strip(string.punctuation + "'\"")
*/
  if (__pyx_v_route_tokens == Py_None) __pyx_t_8 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_route_tokens);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 415, __pyx_L1_error)
    __pyx_t_8 = (__pyx_temp != 0);
  }

  if (__pyx_t_8) {

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":416
 *         route_patterns: List[str] = []
 *         if route_tokens:
 *             for rt in route_tokens:             # <<<<<<<<<<<<<<
 *                 clean_rt = rt.strip(string.punctuation + "'\"")
 *                 route_patterns.append(clean_rt)
*/
    if (unlikely(__pyx_v_route_tokens == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 416, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_v_route_tokens; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_24 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 416, __pyx_L1_error)
        #endif
        if (__pyx_t_24 >= __pyx_temp) break;
      }
      __pyx_t_10 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_24, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_24;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_XDECREF_SET(__pyx_v_rt, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":417
 *         if route_tokens:
 *             for rt in route_tokens:
 *                 clean_rt = rt.strip(string.punctuation + "'\"")             # <<<<<<<<<<<<<<
 *                 route_patterns.append(clean_rt)
 *                 segments = [seg for seg in clean_rt.split('/') if seg and seg not in _STOP_WORDS]
*/
      __pyx_t_7 = __pyx_v_rt;
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_string); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_punctuation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = PyNumber_Add(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_13};
        __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_strip, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 417, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __Pyx_XDECREF_SET(__pyx_v_clean_rt, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":418
 *             for rt in route_tokens:
 *                 clean_rt = rt.strip(string.punctuation + "'\"")
 *                 route_patterns.append(clean_rt)             # <<<<<<<<<<<<<<
 *                 segments = [seg for seg in clean_rt.split('/') if seg and seg not in _STOP_WORDS]
 *                 query_keywords.update(s.lower() for s in segments)
*/
      __pyx_t_26 = __Pyx_PyList_Append(__pyx_v_route_patterns, __pyx_v_clean_rt); if (unlikely(__pyx_t_26 == ((int)-1))) __PYX_ERR(0, 418, __pyx_L1_error)

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":419
 *                 clean_rt = rt.strip(string.punctuation + "'\"")
 *                 route_patterns.append(clean_rt)
 *                 segments = [seg for seg in clean_rt.split('/') if seg and seg not in _STOP_WORDS]             # <<<<<<<<<<<<<<
 *                 query_keywords.update(s.lower() for s in segments)
 * 
*/
      { /* enter inner scope */
        __pyx_t_10 = PyList_New(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 419, __pyx_L32_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_7 = __pyx_v_clean_rt;
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u__3};
          __pyx_t_13 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 419, __pyx_L32_error)
          __Pyx_GOTREF(__pyx_t_13);
        }
        if (likely(PyList_CheckExact(__pyx_t_13)) || PyTuple_CheckExact(__pyx_t_13)) {
          __pyx_t_7 = __pyx_t_13; __Pyx_INCREF(__pyx_t_7);
          __pyx_t_27 = 0;
          __pyx_t_28 = NULL;
        } else {
          __pyx_t_27 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 419, __pyx_L32_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_28 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 419, __pyx_L32_error)
        }
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        for (;;) {
          if (likely(!__pyx_t_28)) {
            if (likely(PyList_CheckExact(__pyx_t_7))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 419, __pyx_L32_error)
                #endif
                if (__pyx_t_27 >= __pyx_temp) break;
              }
              __pyx_t_13 = __Pyx_PyList_GetItemRefFast(__pyx_t_7, __pyx_t_27, __Pyx_ReferenceSharing_OwnStrongReference);
              ++__pyx_t_27;
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 419, __pyx_L32_error)
                #endif
                if (__pyx_t_27 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_13 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_27));
              #else
              __pyx_t_13 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_27);
              #endif
              ++__pyx_t_27;
            }
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 419, __pyx_L32_error)
          } else {
            __pyx_t_13 = __pyx_t_28(__pyx_t_7);
            if (unlikely(!__pyx_t_13)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 419, __pyx_L32_error)
                PyErr_Clear();
              }
              break;
            }
          }
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_seg, __pyx_t_13);
          __pyx_t_13 = 0;
          __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_8genexpr1__pyx_v_seg); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 419, __pyx_L32_error)
          if (__pyx_t_25) {
          } else {
            __pyx_t_8 = __pyx_t_25;
            goto __pyx_L36_bool_binop_done;
          }
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_STOP_WORDS); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 419, __pyx_L32_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_25 = (__Pyx_PySequence_ContainsTF(__pyx_8genexpr1__pyx_v_seg, __pyx_t_13, Py_NE)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 419, __pyx_L32_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_8 = __pyx_t_25;
          __pyx_L36_bool_binop_done:;
          if (__pyx_t_8) {
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_10, (PyObject*)__pyx_8genexpr1__pyx_v_seg))) __PYX_ERR(0, 419, __pyx_L32_error)
          }
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_seg); __pyx_8genexpr1__pyx_v_seg = 0;
        goto __pyx_L39_exit_scope;
        __pyx_L32_error:;
        __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_seg); __pyx_8genexpr1__pyx_v_seg = 0;
        goto __pyx_L1_error;
        __pyx_L39_exit_scope:;
      } /* exit inner scope */
      __Pyx_XDECREF_SET(__pyx_v_segments, ((PyObject*)__pyx_t_10));
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":420
 *                 route_patterns.append(clean_rt)
 *                 segments = [seg for seg in clean_rt.split('/') if seg and seg not in _STOP_WORDS]
 *                 query_keywords.update(s.lower() for s in segments)             # <<<<<<<<<<<<<<
 * 
 *         #  B. Build corpus-level IDF (per search, lightweight)
*/
      __pyx_t_10 = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_2genexpr(NULL, __pyx_v_segments); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 420, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_7 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PySet_Type__update, __pyx_v_query_keywords, __pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 420, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":416
 *         route_patterns: List[str] = []
 *         if route_tokens:
 *             for rt in route_tokens:             # <<<<<<<<<<<<<<
 *                 clean_rt = rt.strip(string.punctuation + "'\"")
 *                 route_patterns.append(clean_rt)
*/
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":415
 *         # Route tokens
 *         route_patterns: List[str] = []
 *         if route_tokens:             # <<<<<<<<<<<<<<
 *             for rt in route_tokens:
 *                 clean_rt = rt.strip(string.punctuation + "'\"")
*/
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":424
 *         #  B. Build corpus-level IDF (per search, lightweight)
 * 
 *         contexts = self.store._load_agent_data(agent_id, "file_contexts")             # <<<<<<<<<<<<<<
 *         all_vectors = self.vector_store._load_vectors(agent_id) or {}
 * 
*/
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_store); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_7 = __pyx_t_10;
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_agent_id, __pyx_mstate_global->__pyx_n_u_file_contexts};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_load_agent_data, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v_contexts = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":425
 * 
 *         contexts = self.store._load_agent_data(agent_id, "file_contexts")
 *         all_vectors = self.vector_store._load_vectors(agent_id) or {}             # <<<<<<<<<<<<<<
 * 
 *         all_chunks_flat: List[Dict[str, Any]] = []
*/
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_mstate_global->__pyx_n_u_vector_store); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __pyx_t_13;
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_agent_id};
    __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_load_vectors, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
  }
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 425, __pyx_L1_error)
  if (!__pyx_t_8) {
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_2 = __pyx_t_10;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L41_bool_binop_done;
  }
  __pyx_t_10 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(__pyx_t_10);
  __pyx_t_2 = __pyx_t_10;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_L41_bool_binop_done:;
  __pyx_v_all_vectors = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":427
 *         all_vectors = self.vector_store._load_vectors(agent_id) or {}
 * 
 *         all_chunks_flat: List[Dict[str, Any]] = []             # <<<<<<<<<<<<<<
 *         chunk_to_ctx: List[Tuple[Dict[str, Any], str]] = []  # (chunk, file_path)
 * 
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_all_chunks_flat = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":428
 * 
 *         all_chunks_flat: List[Dict[str, Any]] = []
 *         chunk_to_ctx: List[Tuple[Dict[str, Any], str]] = []  # (chunk, file_path)             # <<<<<<<<<<<<<<
 * 
 *         normalized_file_paths_filter = set(os.path.normpath(fp) for fp in file_paths_filter) if file_paths_filter else None
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_chunk_to_ctx = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":430
 *         chunk_to_ctx: List[Tuple[Dict[str, Any], str]] = []  # (chunk, file_path)
 * 
 *         normalized_file_paths_filter = set(os.path.normpath(fp) for fp in file_paths_filter) if file_paths_filter else None             # <<<<<<<<<<<<<<
 * 
 *         for ctx in contexts:
*/
  if (__pyx_v_file_paths_filter == Py_None) __pyx_t_8 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_file_paths_filter);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 430, __pyx_L1_error)
    __pyx_t_8 = (__pyx_temp != 0);
  }

  if (__pyx_t_8) {
    __pyx_t_10 = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_5genexpr(NULL, __pyx_v_file_paths_filter); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_13 = __Pyx_Generator_GetInlinedResult(__pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_2 = __pyx_t_13;
    __pyx_t_13 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_2 = Py_None;
  }
  __pyx_v_normalized_file_paths_filter = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":432
 *         normalized_file_paths_filter = set(os.path.normpath(fp) for fp in file_paths_filter) if file_paths_filter else None
 * 
 *         for ctx in contexts:             # <<<<<<<<<<<<<<
 *             file_path = ctx.get("file_path", "")
 * 
*/
  if (likely(PyList_CheckExact(__pyx_v_contexts)) || PyTuple_CheckExact(__pyx_v_contexts)) {
    __pyx_t_2 = __pyx_v_contexts; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_24 = 0;
    __pyx_t_28 = NULL;
  } else {
    __pyx_t_24 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_contexts); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_28 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 432, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_28)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 432, __pyx_L1_error)
          #endif
          if (__pyx_t_24 >= __pyx_temp) break;
        }
        __pyx_t_13 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_24, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_24;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 432, __pyx_L1_error)
          #endif
          if (__pyx_t_24 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_13 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_24));
        #else
        __pyx_t_13 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_24);
        #endif
        ++__pyx_t_24;
      }
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 432, __pyx_L1_error)
    } else {
      __pyx_t_13 = __pyx_t_28(__pyx_t_2);
      if (unlikely(!__pyx_t_13)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 432, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_XDECREF_SET(__pyx_v_ctx, __pyx_t_13);
    __pyx_t_13 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":433
 * 
 *         for ctx in contexts:
 *             file_path = ctx.get("file_path", "")             # <<<<<<<<<<<<<<
 * 
 *             # Apply file_paths_filter if provided
*/
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_mstate_global->__pyx_tuple[0], NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF_SET(__pyx_v_file_path, __pyx_t_10);
    __pyx_t_10 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":436
 * 
 *             # Apply file_paths_filter if provided
 *             if normalized_file_paths_filter is not None:             # <<<<<<<<<<<<<<
 *                 if os.path.normpath(file_path) not in normalized_file_paths_filter:
 *                     continue
*/
    __pyx_t_8 = (__pyx_v_normalized_file_paths_filter != Py_None);
    if (__pyx_t_8) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":437
 *             # Apply file_paths_filter if provided
 *             if normalized_file_paths_filter is not None:
 *                 if os.path.normpath(file_path) not in normalized_file_paths_filter:             # <<<<<<<<<<<<<<
 *                     continue
 * 
*/
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 437, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 437, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_13 = __pyx_t_1;
      __Pyx_INCREF(__pyx_t_13);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_file_path};
        __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_normpath, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 437, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_10, __pyx_v_normalized_file_paths_filter, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 437, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (__pyx_t_8) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":438
 *             if normalized_file_paths_filter is not None:
 *                 if os.path.normpath(file_path) not in normalized_file_paths_filter:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *             if file_filter:
*/
        goto __pyx_L43_continue;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":437
 *             # Apply file_paths_filter if provided
 *             if normalized_file_paths_filter is not None:
 *                 if os.path.normpath(file_path) not in normalized_file_paths_filter:             # <<<<<<<<<<<<<<
 *                     continue
 * 
*/
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":436
 * 
 *             # Apply file_paths_filter if provided
 *             if normalized_file_paths_filter is not None:             # <<<<<<<<<<<<<<
 *                 if os.path.normpath(file_path) not in normalized_file_paths_filter:
 *                     continue
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":440
 *                     continue
 * 
 *             if file_filter:             # <<<<<<<<<<<<<<
 *                 normalized_filter = file_filter.replace("/", os.sep).replace("\\", os.sep).lower()
 *                 path_lower = file_path.lower()
*/
    if (__pyx_v_file_filter == Py_None) __pyx_t_8 = 0;
    else
    {
      Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_v_file_filter);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 440, __pyx_L1_error)
      __pyx_t_8 = (__pyx_temp != 0);
    }

    if (__pyx_t_8) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":441
 * 
 *             if file_filter:
 *                 normalized_filter = file_filter.replace("/", os.sep).replace("\\", os.sep).lower()             # <<<<<<<<<<<<<<
 *                 path_lower = file_path.lower()
 *                 if normalized_filter not in path_lower:
*/
      if (unlikely(__pyx_v_file_filter == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "replace");
        __PYX_ERR(0, 441, __pyx_L1_error)
      }
      __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_sep); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = PyUnicode_Replace(__pyx_v_file_filter, __pyx_mstate_global->__pyx_kp_u__3, __pyx_t_7, -1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_sep); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyUnicode_Replace(((PyObject*)__pyx_t_13), __pyx_mstate_global->__pyx_kp_u__7, __pyx_t_15, -1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_1 = __pyx_t_7;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 441, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __Pyx_XDECREF_SET(__pyx_v_normalized_filter, ((PyObject*)__pyx_t_10));
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":442
 *             if file_filter:
 *                 normalized_filter = file_filter.replace("/", os.sep).replace("\\", os.sep).lower()
 *                 path_lower = file_path.lower()             # <<<<<<<<<<<<<<
 *                 if normalized_filter not in path_lower:
 *                     if os.path.basename(normalized_filter) not in os.path.basename(path_lower):
*/
      __pyx_t_7 = __pyx_v_file_path;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 442, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __Pyx_XDECREF_SET(__pyx_v_path_lower, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":443
 *                 normalized_filter = file_filter.replace("/", os.sep).replace("\\", os.sep).lower()
 *                 path_lower = file_path.lower()
 *                 if normalized_filter not in path_lower:             # <<<<<<<<<<<<<<
 *                     if os.path.basename(normalized_filter) not in os.path.basename(path_lower):
 *                         continue
*/
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_normalized_filter, __pyx_v_path_lower, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 443, __pyx_L1_error)
      if (__pyx_t_8) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":444
 *                 path_lower = file_path.lower()
 *                 if normalized_filter not in path_lower:
 *                     if os.path.basename(normalized_filter) not in os.path.basename(path_lower):             # <<<<<<<<<<<<<<
 *                         continue
 *             for chunk in ctx.get("chunks", []):
*/
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 444, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 444, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_7 = __pyx_t_15;
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_normalized_filter};
          __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_basename, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 444, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
        }
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 444, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_path); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 444, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_7 = __pyx_t_13;
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_path_lower};
          __pyx_t_15 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_basename, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 444, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_15);
        }
        __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_t_10, __pyx_t_15, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 444, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (__pyx_t_8) {

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":445
 *                 if normalized_filter not in path_lower:
 *                     if os.path.basename(normalized_filter) not in os.path.basename(path_lower):
 *                         continue             # <<<<<<<<<<<<<<
 *             for chunk in ctx.get("chunks", []):
 *                 all_chunks_flat.append(chunk)
*/
          goto __pyx_L43_continue;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":444
 *                 path_lower = file_path.lower()
 *                 if normalized_filter not in path_lower:
 *                     if os.path.basename(normalized_filter) not in os.path.basename(path_lower):             # <<<<<<<<<<<<<<
 *                         continue
 *             for chunk in ctx.get("chunks", []):
*/
        }

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":443
 *                 normalized_filter = file_filter.replace("/", os.sep).replace("\\", os.sep).lower()
 *                 path_lower = file_path.lower()
 *                 if normalized_filter not in path_lower:             # <<<<<<<<<<<<<<
 *                     if os.path.basename(normalized_filter) not in os.path.basename(path_lower):
 *                         continue
*/
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":440
 *                     continue
 * 
 *             if file_filter:             # <<<<<<<<<<<<<<
 *                 normalized_filter = file_filter.replace("/", os.sep).replace("\\", os.sep).lower()
 *                 path_lower = file_path.lower()
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":446
 *                     if os.path.basename(normalized_filter) not in os.path.basename(path_lower):
 *                         continue
 *             for chunk in ctx.get("chunks", []):             # <<<<<<<<<<<<<<
 *                 all_chunks_flat.append(chunk)
 *                 chunk_to_ctx.append((chunk, file_path))
*/
    __pyx_t_10 = __pyx_v_ctx;
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_13 = PyList_New(0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_mstate_global->__pyx_n_u_chunks, __pyx_t_13};
      __pyx_t_15 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 446, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
    }
    if (likely(PyList_CheckExact(__pyx_t_15)) || PyTuple_CheckExact(__pyx_t_15)) {
      __pyx_t_13 = __pyx_t_15; __Pyx_INCREF(__pyx_t_13);
      __pyx_t_27 = 0;
      __pyx_t_29 = NULL;
    } else {
      __pyx_t_27 = -1; __pyx_t_13 = PyObject_GetIter(__pyx_t_15); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 446, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_29 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_13); if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 446, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    for (;;) {
      if (likely(!__pyx_t_29)) {
        if (likely(PyList_CheckExact(__pyx_t_13))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_13);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 446, __pyx_L1_error)
            #endif
            if (__pyx_t_27 >= __pyx_temp) break;
          }
          __pyx_t_15 = __Pyx_PyList_GetItemRefFast(__pyx_t_13, __pyx_t_27, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_27;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_13);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 446, __pyx_L1_error)
            #endif
            if (__pyx_t_27 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_15 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_13, __pyx_t_27));
          #else
          __pyx_t_15 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_27);
          #endif
          ++__pyx_t_27;
        }
        if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 446, __pyx_L1_error)
      } else {
        __pyx_t_15 = __pyx_t_29(__pyx_t_13);
        if (unlikely(!__pyx_t_15)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 446, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_XDECREF_SET(__pyx_v_chunk, __pyx_t_15);
      __pyx_t_15 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":447
 *                         continue
 *             for chunk in ctx.get("chunks", []):
 *                 all_chunks_flat.append(chunk)             # <<<<<<<<<<<<<<
 *                 chunk_to_ctx.append((chunk, file_path))
 * 
*/
      __pyx_t_26 = __Pyx_PyList_Append(__pyx_v_all_chunks_flat, __pyx_v_chunk); if (unlikely(__pyx_t_26 == ((int)-1))) __PYX_ERR(0, 447, __pyx_L1_error)

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":448
 *             for chunk in ctx.get("chunks", []):
 *                 all_chunks_flat.append(chunk)
 *                 chunk_to_ctx.append((chunk, file_path))             # <<<<<<<<<<<<<<
 * 
 *         total_docs = max(len(all_chunks_flat), 1)
*/
      __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_INCREF(__pyx_v_chunk);
      __Pyx_GIVEREF(__pyx_v_chunk);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_v_chunk) != (0)) __PYX_ERR(0, 448, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_file_path);
      __Pyx_GIVEREF(__pyx_v_file_path);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_v_file_path) != (0)) __PYX_ERR(0, 448, __pyx_L1_error);
      __pyx_t_26 = __Pyx_PyList_Append(__pyx_v_chunk_to_ctx, __pyx_t_15); if (unlikely(__pyx_t_26 == ((int)-1))) __PYX_ERR(0, 448, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":446
 *                     if os.path.basename(normalized_filter) not in os.path.basename(path_lower):
 *                         continue
 *             for chunk in ctx.get("chunks", []):             # <<<<<<<<<<<<<<
 *                 all_chunks_flat.append(chunk)
 *                 chunk_to_ctx.append((chunk, file_path))
*/
    }
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":432
 *         normalized_file_paths_filter = set(os.path.normpath(fp) for fp in file_paths_filter) if file_paths_filter else None
 * 
 *         for ctx in contexts:             # <<<<<<<<<<<<<<
 *             file_path = ctx.get("file_path", "")
 * 
*/
    __pyx_L43_continue:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":450
 *                 chunk_to_ctx.append((chunk, file_path))
 * 
 *         total_docs = max(len(all_chunks_flat), 1)             # <<<<<<<<<<<<<<
 * 
 *         # Build DF (document frequency) for keywords from original query
*/
  __pyx_t_30 = 1;
  __pyx_t_24 = __Pyx_PyList_GET_SIZE(__pyx_v_all_chunks_flat); if (unlikely(__pyx_t_24 == ((Py_ssize_t)-1))) __PYX_ERR(0, 450, __pyx_L1_error)
  __pyx_t_8 = (__pyx_t_30 > __pyx_t_24);
  if (__pyx_t_8) {
    __pyx_t_27 = __pyx_t_30;
  } else {
    __pyx_t_27 = __pyx_t_24;
  }
  __pyx_cur_scope->__pyx_v_total_docs = __pyx_t_27;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":453
 * 
 *         # Build DF (document frequency) for keywords from original query
 *         doc_freq: Counter = Counter()             # <<<<<<<<<<<<<<
 *         for chunk in all_chunks_flat:
 *             chunk_text_bag = self._get_chunk_text_bag(chunk)
*/
  __pyx_t_13 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_Counter); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_3 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_15);
    assert(__pyx_t_13);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_15);
    __Pyx_INCREF(__pyx_t_13);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_15, __pyx__function);
    __pyx_t_3 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_13, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_15, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 453, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_doc_freq = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":454
 *         # Build DF (document frequency) for keywords from original query
 *         doc_freq: Counter = Counter()
 *         for chunk in all_chunks_flat:             # <<<<<<<<<<<<<<
 *             chunk_text_bag = self._get_chunk_text_bag(chunk)
 *             for kw in original_query_keywords:
*/
  __pyx_t_2 = __pyx_v_all_chunks_flat; __Pyx_INCREF(__pyx_t_2);
  __pyx_t_27 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 454, __pyx_L1_error)
      #endif
      if (__pyx_t_27 >= __pyx_temp) break;
    }
    __pyx_t_15 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_27, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_27;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_XDECREF_SET(__pyx_v_chunk, __pyx_t_15);
    __pyx_t_15 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":455
 *         doc_freq: Counter = Counter()
 *         for chunk in all_chunks_flat:
 *             chunk_text_bag = self._get_chunk_text_bag(chunk)             # <<<<<<<<<<<<<<
 *             for kw in original_query_keywords:
 *                 if kw in chunk_text_bag:
*/
    __pyx_t_13 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_13);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_chunk};
      __pyx_t_15 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_chunk_text_bag, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 455, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
    }
    __Pyx_XDECREF_SET(__pyx_v_chunk_text_bag, __pyx_t_15);
    __pyx_t_15 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":456
 *         for chunk in all_chunks_flat:
 *             chunk_text_bag = self._get_chunk_text_bag(chunk)
 *             for kw in original_query_keywords:             # <<<<<<<<<<<<<<
 *                 if kw in chunk_text_bag:
 *                     doc_freq[kw] += 1
*/
    __pyx_t_24 = 0;
    __pyx_t_13 = __Pyx_set_iterator(__pyx_cur_scope->__pyx_v_original_query_keywords, 1, (&__pyx_t_31), (&__pyx_t_16)); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_XDECREF(__pyx_t_15);
    __pyx_t_15 = __pyx_t_13;
    __pyx_t_13 = 0;
    while (1) {
      __pyx_t_9 = __Pyx_set_iter_next(__pyx_t_15, __pyx_t_31, &__pyx_t_24, &__pyx_t_13, __pyx_t_16);
      if (unlikely(__pyx_t_9 == 0)) break;
      if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 456, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_kw, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":457
 *             chunk_text_bag = self._get_chunk_text_bag(chunk)
 *             for kw in original_query_keywords:
 *                 if kw in chunk_text_bag:             # <<<<<<<<<<<<<<
 *                     doc_freq[kw] += 1
 * 
*/
      __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_kw, __pyx_v_chunk_text_bag, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 457, __pyx_L1_error)
      if (__pyx_t_8) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":458
 *             for kw in original_query_keywords:
 *                 if kw in chunk_text_bag:
 *                     doc_freq[kw] += 1             # <<<<<<<<<<<<<<
 * 
 *         def idf(term: str) -> float:
*/
        __Pyx_INCREF(__pyx_v_kw);
        __pyx_t_13 = __pyx_v_kw;
        __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_doc_freq, __pyx_t_13); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_7 = __Pyx_PyLong_AddObjC(__pyx_t_10, __pyx_mstate_global->__pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_doc_freq, __pyx_t_13, __pyx_t_7) < 0))) __PYX_ERR(0, 458, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":457
 *             chunk_text_bag = self._get_chunk_text_bag(chunk)
 *             for kw in original_query_keywords:
 *                 if kw in chunk_text_bag:             # <<<<<<<<<<<<<<
 *                     doc_freq[kw] += 1
 * 
*/
      }
    }
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":454
 *         # Build DF (document frequency) for keywords from original query
 *         doc_freq: Counter = Counter()
 *         for chunk in all_chunks_flat:             # <<<<<<<<<<<<<<
 *             chunk_text_bag = self._get_chunk_text_bag(chunk)
 *             for kw in original_query_keywords:
*/
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":460
 *                     doc_freq[kw] += 1
 * 
 *         def idf(term: str) -> float:             # <<<<<<<<<<<<<<
 *             df = doc_freq.get(term, 0)
 *             return math.log((total_docs + 1) / (df + 1)) + 1.0
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_term, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 460, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_float) < (0)) __PYX_ERR(0, 460, __pyx_L1_error)
  __pyx_t_15 = __Pyx_CyFunction_New(&__pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_1idf, 0, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se_2, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_15, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_15);
  __pyx_cur_scope->__pyx_v_idf = __pyx_t_15;
  __pyx_t_15 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":467
 * 
 *         # Map: class_name -> list of method chunk indices
 *         class_names: Set[str] = set()             # <<<<<<<<<<<<<<
 *         for chunk in all_chunks_flat:
 *             if chunk.get("type", "").lower() in ("class",):
*/
  __pyx_t_15 = PySet_New(0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_v_class_names = ((PyObject*)__pyx_t_15);
  __pyx_t_15 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":468
 *         # Map: class_name -> list of method chunk indices
 *         class_names: Set[str] = set()
 *         for chunk in all_chunks_flat:             # <<<<<<<<<<<<<<
 *             if chunk.get("type", "").lower() in ("class",):
 *                 class_names.add(chunk.get("name", "").lower())
*/
  __pyx_t_15 = __pyx_v_all_chunks_flat; __Pyx_INCREF(__pyx_t_15);
  __pyx_t_27 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_15);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 468, __pyx_L1_error)
      #endif
      if (__pyx_t_27 >= __pyx_temp) break;
    }
    __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_15, __pyx_t_27, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_27;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 468, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_chunk, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":469
 *         class_names: Set[str] = set()
 *         for chunk in all_chunks_flat:
 *             if chunk.get("type", "").lower() in ("class",):             # <<<<<<<<<<<<<<
 *                 class_names.add(chunk.get("name", "").lower())
 * 
*/
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 469, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_mstate_global->__pyx_tuple[1], NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 469, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_13 = __pyx_t_10;
    __Pyx_INCREF(__pyx_t_13);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_13, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 469, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_class, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 469, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_25 = __pyx_t_8;
    if (__pyx_t_25) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":470
 *         for chunk in all_chunks_flat:
 *             if chunk.get("type", "").lower() in ("class",):
 *                 class_names.add(chunk.get("name", "").lower())             # <<<<<<<<<<<<<<
 * 
 *         #  D. Score each chunk
*/
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 470, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_mstate_global->__pyx_tuple[2], NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 470, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_10 = __pyx_t_7;
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 470, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_t_26 = PySet_Add(__pyx_v_class_names, __pyx_t_2); if (unlikely(__pyx_t_26 == ((int)-1))) __PYX_ERR(0, 470, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":469
 *         class_names: Set[str] = set()
 *         for chunk in all_chunks_flat:
 *             if chunk.get("type", "").lower() in ("class",):             # <<<<<<<<<<<<<<
 *                 class_names.add(chunk.get("name", "").lower())
 * 
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":468
 *         # Map: class_name -> list of method chunk indices
 *         class_names: Set[str] = set()
 *         for chunk in all_chunks_flat:             # <<<<<<<<<<<<<<
 *             if chunk.get("type", "").lower() in ("class",):
 *                 class_names.add(chunk.get("name", "").lower())
*/
  }
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":474
 *         #  D. Score each chunk
 * 
 *         scored_chunks: List[Dict[str, Any]] = []             # <<<<<<<<<<<<<<
 * 
 *         for chunk, file_path in chunk_to_ctx:
*/
  __pyx_t_15 = PyList_New(0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_v_scored_chunks = ((PyObject*)__pyx_t_15);
  __pyx_t_15 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":476
 *         scored_chunks: List[Dict[str, Any]] = []
 * 
 *         for chunk, file_path in chunk_to_ctx:             # <<<<<<<<<<<<<<
 *             # 1. Vector Score
 *             vec_score = 0.0
*/
  __pyx_t_15 = __pyx_v_chunk_to_ctx; __Pyx_INCREF(__pyx_t_15);
  __pyx_t_27 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_15);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 476, __pyx_L1_error)
      #endif
      if (__pyx_t_27 >= __pyx_temp) break;
    }
    __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_15, __pyx_t_27, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_27;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 476, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1);
        __Pyx_INCREF(__pyx_t_10);
      } else {
        __pyx_t_7 = __Pyx_PyList_GetItemRefFast(sequence, 0, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 476, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_7);
        __pyx_t_10 = __Pyx_PyList_GetItemRefFast(sequence, 1, __Pyx_ReferenceSharing_SharedReference);
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 476, __pyx_L1_error)
        __Pyx_XGOTREF(__pyx_t_10);
      }
      #else
      __pyx_t_7 = __Pyx_PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_10 = __Pyx_PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_13 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_32 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_13);
      index = 0; __pyx_t_7 = __pyx_t_32(__pyx_t_13); if (unlikely(!__pyx_t_7)) goto __pyx_L66_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      index = 1; __pyx_t_10 = __pyx_t_32(__pyx_t_13); if (unlikely(!__pyx_t_10)) goto __pyx_L66_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_10);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_32(__pyx_t_13), 2) < (0)) __PYX_ERR(0, 476, __pyx_L1_error)
      __pyx_t_32 = NULL;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L67_unpacking_done;
      __pyx_L66_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_32 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 476, __pyx_L1_error)
      __pyx_L67_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_chunk, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_file_path, __pyx_t_10);
    __pyx_t_10 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":478
 *         for chunk, file_path in chunk_to_ctx:
 *             # 1. Vector Score
 *             vec_score = 0.0             # <<<<<<<<<<<<<<
 *             hash_id = chunk.get("hash_id") or chunk.get("embedding_id")
 *             chunk_vec = all_vectors.get(hash_id) if hash_id else None
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_float_0_0);
    __Pyx_XDECREF_SET(__pyx_v_vec_score, __pyx_mstate_global->__pyx_float_0_0);

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":479
 *             # 1. Vector Score
 *             vec_score = 0.0
 *             hash_id = chunk.get("hash_id") or chunk.get("embedding_id")             # <<<<<<<<<<<<<<
 *             chunk_vec = all_vectors.get(hash_id) if hash_id else None
 * 
*/
    __pyx_t_7 = __pyx_v_chunk;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_n_u_hash_id};
      __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    }
    __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 479, __pyx_L1_error)
    if (!__pyx_t_25) {
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_2 = __pyx_t_10;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L68_bool_binop_done;
    }
    __pyx_t_7 = __pyx_v_chunk;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_n_u_embedding_id};
      __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
    }
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_2 = __pyx_t_10;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_L68_bool_binop_done:;
    __Pyx_XDECREF_SET(__pyx_v_hash_id, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":480
 *             vec_score = 0.0
 *             hash_id = chunk.get("hash_id") or chunk.get("embedding_id")
 *             chunk_vec = all_vectors.get(hash_id) if hash_id else None             # <<<<<<<<<<<<<<
 * 
 *             if query_vector and chunk_vec and len(chunk_vec) > 0:
*/
    __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_v_hash_id); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 480, __pyx_L1_error)
    if (__pyx_t_25) {
      __pyx_t_7 = __pyx_v_all_vectors;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_hash_id};
        __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 480, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __pyx_t_2 = __pyx_t_10;
      __pyx_t_10 = 0;
    } else {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    }
    __Pyx_XDECREF_SET(__pyx_v_chunk_vec, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":482
 *             chunk_vec = all_vectors.get(hash_id) if hash_id else None
 * 
 *             if query_vector and chunk_vec and len(chunk_vec) > 0:             # <<<<<<<<<<<<<<
 *                 try:
 *                     dot = sum(a * b for a, b in zip(query_vector, chunk_vec))
*/
    if (__pyx_v_query_vector == Py_None) __pyx_t_8 = 0;
    else
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_query_vector);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 482, __pyx_L1_error)
      __pyx_t_8 = (__pyx_temp != 0);
    }

    if (__pyx_t_8) {
    } else {
      __pyx_t_25 = __pyx_t_8;
      goto __pyx_L71_bool_binop_done;
    }
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_chunk_vec); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 482, __pyx_L1_error)
    if (__pyx_t_8) {
    } else {
      __pyx_t_25 = __pyx_t_8;
      goto __pyx_L71_bool_binop_done;
    }
    __pyx_t_31 = PyObject_Length(__pyx_v_chunk_vec); if (unlikely(__pyx_t_31 == ((Py_ssize_t)-1))) __PYX_ERR(0, 482, __pyx_L1_error)
    __pyx_t_8 = (__pyx_t_31 > 0);
    __pyx_t_25 = __pyx_t_8;
    __pyx_L71_bool_binop_done:;
    if (__pyx_t_25) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":483
 * 
 *             if query_vector and chunk_vec and len(chunk_vec) > 0:
 *                 try:             # <<<<<<<<<<<<<<
 *                     dot = sum(a * b for a, b in zip(query_vector, chunk_vec))
 *                     # Normalise to [0, 1] via cosine (vectors should be pre-normalised,
*/
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_4);
        /*try:*/ {

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":484
 *             if query_vector and chunk_vec and len(chunk_vec) > 0:
 *                 try:
 *                     dot = sum(a * b for a, b in zip(query_vector, chunk_vec))             # <<<<<<<<<<<<<<
 *                     # Normalise to [0, 1] via cosine (vectors should be pre-normalised,
 *                     # but guard anyway)
*/
          __pyx_t_10 = NULL;
          __pyx_t_13 = NULL;
          __pyx_t_3 = 1;
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_13, __pyx_v_query_vector, __pyx_v_chunk_vec};
            __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_zip, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 484, __pyx_L74_error)
            __Pyx_GOTREF(__pyx_t_7);
          }
          __pyx_t_13 = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_8genexpr(NULL, __pyx_t_7); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 484, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_3 = 1;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_13};
            __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_sum, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 484, __pyx_L74_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __Pyx_XDECREF_SET(__pyx_v_dot, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":487
 *                     # Normalise to [0, 1] via cosine (vectors should be pre-normalised,
 *                     # but guard anyway)
 *                     mag_q = math.sqrt(sum(a * a for a in query_vector)) or 1.0             # <<<<<<<<<<<<<<
 *                     mag_c = math.sqrt(sum(b * b for b in chunk_vec)) or 1.0
 *                     vec_score = max(0.0, dot / (mag_q * mag_c))
*/
          __pyx_t_10 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_math); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 487, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_sqrt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 487, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_11 = NULL;
          __pyx_t_12 = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_11genexpr(NULL, __pyx_v_query_vector); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 487, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_3 = 1;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_12};
            __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_sum, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 487, __pyx_L74_error)
            __Pyx_GOTREF(__pyx_t_7);
          }
          __pyx_t_3 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
            assert(__pyx_t_10);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
            __pyx_t_3 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_7};
            __pyx_t_13 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 487, __pyx_L74_error)
            __Pyx_GOTREF(__pyx_t_13);
          }
          __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 487, __pyx_L74_error)
          if (!__pyx_t_25) {
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          } else {
            __Pyx_INCREF(__pyx_t_13);
            __pyx_t_2 = __pyx_t_13;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            goto __pyx_L82_bool_binop_done;
          }
          __pyx_t_13 = PyFloat_FromDouble(1.0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 487, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_2 = __pyx_t_13;
          __pyx_t_13 = 0;
          __pyx_L82_bool_binop_done:;
          __Pyx_XDECREF_SET(__pyx_v_mag_q, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":488
 *                     # but guard anyway)
 *                     mag_q = math.sqrt(sum(a * a for a in query_vector)) or 1.0
 *                     mag_c = math.sqrt(sum(b * b for b in chunk_vec)) or 1.0             # <<<<<<<<<<<<<<
 *                     vec_score = max(0.0, dot / (mag_q * mag_c))
 *                 except Exception:
*/
          __pyx_t_1 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_math); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 488, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_sqrt); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 488, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_12 = NULL;
          __pyx_t_11 = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_14genexpr(NULL, __pyx_v_chunk_vec); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 488, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_3 = 1;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_11};
            __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_sum, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 488, __pyx_L74_error)
            __Pyx_GOTREF(__pyx_t_7);
          }
          __pyx_t_3 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
            assert(__pyx_t_1);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
            __pyx_t_3 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_7};
            __pyx_t_13 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 488, __pyx_L74_error)
            __Pyx_GOTREF(__pyx_t_13);
          }
          __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 488, __pyx_L74_error)
          if (!__pyx_t_25) {
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          } else {
            __Pyx_INCREF(__pyx_t_13);
            __pyx_t_2 = __pyx_t_13;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            goto __pyx_L84_bool_binop_done;
          }
          __pyx_t_13 = PyFloat_FromDouble(1.0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 488, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_2 = __pyx_t_13;
          __pyx_t_13 = 0;
          __pyx_L84_bool_binop_done:;
          __Pyx_XDECREF_SET(__pyx_v_mag_c, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":489
 *                     mag_q = math.sqrt(sum(a * a for a in query_vector)) or 1.0
 *                     mag_c = math.sqrt(sum(b * b for b in chunk_vec)) or 1.0
 *                     vec_score = max(0.0, dot / (mag_q * mag_c))             # <<<<<<<<<<<<<<
 *                 except Exception:
 *                     vec_score = 0.0
*/
          __pyx_t_2 = PyNumber_Multiply(__pyx_v_mag_q, __pyx_v_mag_c); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 489, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_13 = __Pyx_PyNumber_Divide(__pyx_v_dot, __pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 489, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_33 = 0.0;
          __pyx_t_10 = PyFloat_FromDouble(__pyx_t_33); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 489, __pyx_L74_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_7 = PyObject_RichCompare(__pyx_t_13, __pyx_t_10, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 489, __pyx_L74_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 489, __pyx_L74_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (__pyx_t_25) {
            __Pyx_INCREF(__pyx_t_13);
            __pyx_t_2 = __pyx_t_13;
          } else {
            __pyx_t_7 = PyFloat_FromDouble(__pyx_t_33); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 489, __pyx_L74_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_2 = __pyx_t_7;
            __pyx_t_7 = 0;
          }
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = __pyx_t_2;
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF_SET(__pyx_v_vec_score, __pyx_t_13);
          __pyx_t_13 = 0;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":483
 * 
 *             if query_vector and chunk_vec and len(chunk_vec) > 0:
 *                 try:             # <<<<<<<<<<<<<<
 *                     dot = sum(a * b for a, b in zip(query_vector, chunk_vec))
 *                     # Normalise to [0, 1] via cosine (vectors should be pre-normalised,
*/
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L81_try_end;
        __pyx_L74_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":490
 *                     mag_c = math.sqrt(sum(b * b for b in chunk_vec)) or 1.0
 *                     vec_score = max(0.0, dot / (mag_q * mag_c))
 *                 except Exception:             # <<<<<<<<<<<<<<
 *                     vec_score = 0.0
 * 
*/
        __pyx_t_16 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
        if (__pyx_t_16) {
          __Pyx_ErrRestore(0,0,0);

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":491
 *                     vec_score = max(0.0, dot / (mag_q * mag_c))
 *                 except Exception:
 *                     vec_score = 0.0             # <<<<<<<<<<<<<<
 * 
 *             # 2. Keyword Score (multi-signal)
*/
          __Pyx_INCREF(__pyx_mstate_global->__pyx_float_0_0);
          __Pyx_DECREF_SET(__pyx_v_vec_score, __pyx_mstate_global->__pyx_float_0_0);
          goto __pyx_L75_exception_handled;
        }
        goto __pyx_L76_except_error;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":483
 * 
 *             if query_vector and chunk_vec and len(chunk_vec) > 0:
 *                 try:             # <<<<<<<<<<<<<<
 *                     dot = sum(a * b for a, b in zip(query_vector, chunk_vec))
 *                     # Normalise to [0, 1] via cosine (vectors should be pre-normalised,
*/
        __pyx_L76_except_error:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
        goto __pyx_L1_error;
        __pyx_L75_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
        __pyx_L81_try_end:;
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":482
 *             chunk_vec = all_vectors.get(hash_id) if hash_id else None
 * 
 *             if query_vector and chunk_vec and len(chunk_vec) > 0:             # <<<<<<<<<<<<<<
 *                 try:
 *                     dot = sum(a * b for a, b in zip(query_vector, chunk_vec))
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":494
 * 
 *             # 2. Keyword Score (multi-signal)
 *             kw_score = 0.0             # <<<<<<<<<<<<<<
 * 
 *             chunk_kws: Set[str] = set()
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_float_0_0);
    __Pyx_XDECREF_SET(__pyx_v_kw_score, __pyx_mstate_global->__pyx_float_0_0);

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":496
 *             kw_score = 0.0
 * 
 *             chunk_kws: Set[str] = set()             # <<<<<<<<<<<<<<
 *             for kw in chunk.get("keywords", []):
 *                 chunk_kws.add(kw.lower())
*/
    __pyx_t_13 = PySet_New(0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_XDECREF_SET(__pyx_v_chunk_kws, ((PyObject*)__pyx_t_13));
    __pyx_t_13 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":497
 * 
 *             chunk_kws: Set[str] = set()
 *             for kw in chunk.get("keywords", []):             # <<<<<<<<<<<<<<
 *                 chunk_kws.add(kw.lower())
 *                 chunk_kws.update(self._decompose_compound(kw))
*/
    __pyx_t_2 = __pyx_v_chunk;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 497, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_keywords, __pyx_t_7};
      __pyx_t_13 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 497, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
    }
    if (likely(PyList_CheckExact(__pyx_t_13)) || PyTuple_CheckExact(__pyx_t_13)) {
      __pyx_t_7 = __pyx_t_13; __Pyx_INCREF(__pyx_t_7);
      __pyx_t_31 = 0;
      __pyx_t_28 = NULL;
    } else {
      __pyx_t_31 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 497, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_28 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 497, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    for (;;) {
      if (likely(!__pyx_t_28)) {
        if (likely(PyList_CheckExact(__pyx_t_7))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 497, __pyx_L1_error)
            #endif
            if (__pyx_t_31 >= __pyx_temp) break;
          }
          __pyx_t_13 = __Pyx_PyList_GetItemRefFast(__pyx_t_7, __pyx_t_31, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_31;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 497, __pyx_L1_error)
            #endif
            if (__pyx_t_31 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_13 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_31));
          #else
          __pyx_t_13 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_31);
          #endif
          ++__pyx_t_31;
        }
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 497, __pyx_L1_error)
      } else {
        __pyx_t_13 = __pyx_t_28(__pyx_t_7);
        if (unlikely(!__pyx_t_13)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 497, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_kw, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":498
 *             chunk_kws: Set[str] = set()
 *             for kw in chunk.get("keywords", []):
 *                 chunk_kws.add(kw.lower())             # <<<<<<<<<<<<<<
 *                 chunk_kws.update(self._decompose_compound(kw))
 * 
*/
      __pyx_t_2 = __pyx_v_kw;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_13 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 498, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
      }
      __pyx_t_26 = PySet_Add(__pyx_v_chunk_kws, __pyx_t_13); if (unlikely(__pyx_t_26 == ((int)-1))) __PYX_ERR(0, 498, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":499
 *             for kw in chunk.get("keywords", []):
 *                 chunk_kws.add(kw.lower())
 *                 chunk_kws.update(self._decompose_compound(kw))             # <<<<<<<<<<<<<<
 * 
 *             chunk_name = chunk.get("name", "").lower()
*/
      __pyx_t_2 = __pyx_v_self;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_kw};
        __pyx_t_13 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_decompose_compound, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 499, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
      }
      __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PySet_Type__update, __pyx_v_chunk_kws, __pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 499, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":497
 * 
 *             chunk_kws: Set[str] = set()
 *             for kw in chunk.get("keywords", []):             # <<<<<<<<<<<<<<
 *                 chunk_kws.add(kw.lower())
 *                 chunk_kws.update(self._decompose_compound(kw))
*/
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":501
 *                 chunk_kws.update(self._decompose_compound(kw))
 * 
 *             chunk_name = chunk.get("name", "").lower()             # <<<<<<<<<<<<<<
 *             chunk_name_parts = self._decompose_compound(chunk_name)
 *             chunk_summary = chunk.get("summary", "").lower()
*/
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_mstate_global->__pyx_tuple[2], NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_2 = __pyx_t_10;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_chunk_name, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":502
 * 
 *             chunk_name = chunk.get("name", "").lower()
 *             chunk_name_parts = self._decompose_compound(chunk_name)             # <<<<<<<<<<<<<<
 *             chunk_summary = chunk.get("summary", "").lower()
 *             chunk_content = chunk.get("content", "").lower()
*/
    __pyx_t_10 = __pyx_v_self;
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_chunk_name};
      __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_decompose_compound, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 502, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_chunk_name_parts, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":503
 *             chunk_name = chunk.get("name", "").lower()
 *             chunk_name_parts = self._decompose_compound(chunk_name)
 *             chunk_summary = chunk.get("summary", "").lower()             # <<<<<<<<<<<<<<
 *             chunk_content = chunk.get("content", "").lower()
 *             chunk_type = chunk.get("type", "").lower()
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[3], NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_10 = __pyx_t_13;
    __Pyx_INCREF(__pyx_t_10);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_10, NULL};
      __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 503, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_chunk_summary, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":504
 *             chunk_name_parts = self._decompose_compound(chunk_name)
 *             chunk_summary = chunk.get("summary", "").lower()
 *             chunk_content = chunk.get("content", "").lower()             # <<<<<<<<<<<<<<
 *             chunk_type = chunk.get("type", "").lower()
 * 
*/
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_mstate_global->__pyx_tuple[4], NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_13 = __pyx_t_2;
    __Pyx_INCREF(__pyx_t_13);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_13, NULL};
      __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 504, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_chunk_content, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":505
 *             chunk_summary = chunk.get("summary", "").lower()
 *             chunk_content = chunk.get("content", "").lower()
 *             chunk_type = chunk.get("type", "").lower()             # <<<<<<<<<<<<<<
 * 
 *             summary_words = set(re.findall(r'[a-z0-9_]+', chunk_summary))
*/
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_mstate_global->__pyx_tuple[1], NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_2 = __pyx_t_10;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 505, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_chunk_type, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":507
 *             chunk_type = chunk.get("type", "").lower()
 * 
 *             summary_words = set(re.findall(r'[a-z0-9_]+', chunk_summary))             # <<<<<<<<<<<<<<
 *             content_words = set(re.findall(r'[a-z0-9_]+', chunk_content)) if chunk_content else set()
 * 
*/
    __pyx_t_10 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_findall); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_13))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_13);
      assert(__pyx_t_10);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u_a_z0_9, __pyx_v_chunk_summary};
      __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 507, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __pyx_t_13 = PySet_New(__pyx_t_7); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_summary_words, ((PyObject*)__pyx_t_13));
    __pyx_t_13 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":508
 * 
 *             summary_words = set(re.findall(r'[a-z0-9_]+', chunk_summary))
 *             content_words = set(re.findall(r'[a-z0-9_]+', chunk_content)) if chunk_content else set()             # <<<<<<<<<<<<<<
 * 
 *             # Union of all searchable text for this chunk
*/
    __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_v_chunk_content); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 508, __pyx_L1_error)
    if (__pyx_t_25) {
      __pyx_t_10 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_findall); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_3 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_10);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_3 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u_a_z0_9, __pyx_v_chunk_content};
        __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 508, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_t_1 = PySet_New(__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_13 = __pyx_t_1;
      __pyx_t_1 = 0;
    } else {
      __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_13 = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_content_words, ((PyObject*)__pyx_t_13));
    __pyx_t_13 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":511
 * 
 *             # Union of all searchable text for this chunk
 *             chunk_text_bag = chunk_kws | summary_words | content_words | chunk_name_parts | {chunk_name}             # <<<<<<<<<<<<<<
 * 
 *             if query_keywords:
*/
    __pyx_t_13 = PyNumber_Or(__pyx_v_chunk_kws, __pyx_v_summary_words); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_1 = PyNumber_Or(__pyx_t_13, __pyx_v_content_words); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = PyNumber_Or(__pyx_t_1, __pyx_v_chunk_name_parts); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PySet_Add(__pyx_t_1, __pyx_v_chunk_name) < (0)) __PYX_ERR(0, 511, __pyx_L1_error)
    __pyx_t_7 = PyNumber_Or(__pyx_t_13, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_chunk_text_bag, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":513
 *             chunk_text_bag = chunk_kws | summary_words | content_words | chunk_name_parts | {chunk_name}
 * 
 *             if query_keywords:             # <<<<<<<<<<<<<<
 *                 # A. IDF-weighted keyword overlap
 *                 overlap = query_keywords & chunk_text_bag
*/
    if (__pyx_v_query_keywords == Py_None) __pyx_t_25 = 0;
    else
    {
      Py_ssize_t __pyx_temp = __Pyx_PySet_GET_SIZE(__pyx_v_query_keywords);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 513, __pyx_L1_error)
      __pyx_t_25 = (__pyx_temp != 0);
    }

    if (__pyx_t_25) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":515
 *             if query_keywords:
 *                 # A. IDF-weighted keyword overlap
 *                 overlap = query_keywords & chunk_text_bag             # <<<<<<<<<<<<<<
 *                 if overlap:
 *                     idf_sum = sum(idf(t) for t in overlap if t in original_query_keywords)
*/
      __pyx_t_7 = PyNumber_And(__pyx_v_query_keywords, __pyx_v_chunk_text_bag); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 515, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_v_overlap, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":516
 *                 # A. IDF-weighted keyword overlap
 *                 overlap = query_keywords & chunk_text_bag
 *                 if overlap:             # <<<<<<<<<<<<<<
 *                     idf_sum = sum(idf(t) for t in overlap if t in original_query_keywords)
 *                     idf_total = sum(idf(t) for t in original_query_keywords) or 1.0
*/
      __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_v_overlap); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 516, __pyx_L1_error)
      if (__pyx_t_25) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":517
 *                 overlap = query_keywords & chunk_text_bag
 *                 if overlap:
 *                     idf_sum = sum(idf(t) for t in overlap if t in original_query_keywords)             # <<<<<<<<<<<<<<
 *                     idf_total = sum(idf(t) for t in original_query_keywords) or 1.0
 *                     # Also credit expanded-keyword matches (lower weight)
*/
        __pyx_t_1 = NULL;
        __pyx_t_13 = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_17genexpr(((PyObject*)__pyx_cur_scope), __pyx_v_overlap); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 517, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_3 = 1;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_13};
          __pyx_t_7 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_sum, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 517, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_XDECREF_SET(__pyx_v_idf_sum, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":518
 *                 if overlap:
 *                     idf_sum = sum(idf(t) for t in overlap if t in original_query_keywords)
 *                     idf_total = sum(idf(t) for t in original_query_keywords) or 1.0             # <<<<<<<<<<<<<<
 *                     # Also credit expanded-keyword matches (lower weight)
 *                     expanded_only = overlap - original_query_keywords
*/
        __pyx_t_1 = NULL;
        __pyx_t_10 = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_20genexpr(((PyObject*)__pyx_cur_scope), __pyx_cur_scope->__pyx_v_original_query_keywords); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 518, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_3 = 1;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_10};
          __pyx_t_13 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_sum, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 518, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
        }
        __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 518, __pyx_L1_error)
        if (!__pyx_t_25) {
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        } else {
          __Pyx_INCREF(__pyx_t_13);
          __pyx_t_7 = __pyx_t_13;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          goto __pyx_L93_bool_binop_done;
        }
        __pyx_t_13 = PyFloat_FromDouble(1.0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 518, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_7 = __pyx_t_13;
        __pyx_t_13 = 0;
        __pyx_L93_bool_binop_done:;
        __Pyx_XDECREF_SET(__pyx_v_idf_total, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":520
 *                     idf_total = sum(idf(t) for t in original_query_keywords) or 1.0
 *                     # Also credit expanded-keyword matches (lower weight)
 *                     expanded_only = overlap - original_query_keywords             # <<<<<<<<<<<<<<
 *                     expanded_credit = len(expanded_only) * 0.3
 *                     base_kw = min(1.0, (idf_sum / idf_total) * 0.7 + expanded_credit * 0.1)
*/
        __pyx_t_7 = PyNumber_Subtract(__pyx_v_overlap, __pyx_cur_scope->__pyx_v_original_query_keywords); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 520, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_XDECREF_SET(__pyx_v_expanded_only, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":521
 *                     # Also credit expanded-keyword matches (lower weight)
 *                     expanded_only = overlap - original_query_keywords
 *                     expanded_credit = len(expanded_only) * 0.3             # <<<<<<<<<<<<<<
 *                     base_kw = min(1.0, (idf_sum / idf_total) * 0.7 + expanded_credit * 0.1)
 *                 else:
*/
        __pyx_t_31 = PyObject_Length(__pyx_v_expanded_only); if (unlikely(__pyx_t_31 == ((Py_ssize_t)-1))) __PYX_ERR(0, 521, __pyx_L1_error)
        __pyx_v_expanded_credit = (__pyx_t_31 * 0.3);

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":522
 *                     expanded_only = overlap - original_query_keywords
 *                     expanded_credit = len(expanded_only) * 0.3
 *                     base_kw = min(1.0, (idf_sum / idf_total) * 0.7 + expanded_credit * 0.1)             # <<<<<<<<<<<<<<
 *                 else:
 *                     base_kw = 0.0
*/
        __pyx_t_7 = __Pyx_PyNumber_Divide(__pyx_v_idf_sum, __pyx_v_idf_total); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 522, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_13 = PyNumber_Multiply(__pyx_t_7, __pyx_mstate_global->__pyx_float_0_7); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 522, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyFloat_FromDouble((__pyx_v_expanded_credit * 0.1)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 522, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = PyNumber_Add(__pyx_t_13, __pyx_t_7); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 522, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_33 = 1.0;
        __pyx_t_13 = PyFloat_FromDouble(__pyx_t_33); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 522, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_10, __pyx_t_13, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 522, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 522, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_25) {
          __Pyx_INCREF(__pyx_t_10);
          __pyx_t_7 = __pyx_t_10;
        } else {
          __pyx_t_1 = PyFloat_FromDouble(__pyx_t_33); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 522, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_7 = __pyx_t_1;
          __pyx_t_1 = 0;
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = __pyx_t_7;
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF_SET(__pyx_v_base_kw, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":516
 *                 # A. IDF-weighted keyword overlap
 *                 overlap = query_keywords & chunk_text_bag
 *                 if overlap:             # <<<<<<<<<<<<<<
 *                     idf_sum = sum(idf(t) for t in overlap if t in original_query_keywords)
 *                     idf_total = sum(idf(t) for t in original_query_keywords) or 1.0
*/
        goto __pyx_L92;
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":524
 *                     base_kw = min(1.0, (idf_sum / idf_total) * 0.7 + expanded_credit * 0.1)
 *                 else:
 *                     base_kw = 0.0             # <<<<<<<<<<<<<<
 * 
 *                 # B. Name Match Boost
*/
      /*else*/ {
        __Pyx_INCREF(__pyx_mstate_global->__pyx_float_0_0);
        __Pyx_XDECREF_SET(__pyx_v_base_kw, __pyx_mstate_global->__pyx_float_0_0);
      }
      __pyx_L92:;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":527
 * 
 *                 # B. Name Match Boost
 *                 name_match_boost = 0.0             # <<<<<<<<<<<<<<
 *                 for qkw in query_keywords:
 *                     if qkw == chunk_name:
*/
      __pyx_v_name_match_boost = 0.0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":528
 *                 # B. Name Match Boost
 *                 name_match_boost = 0.0
 *                 for qkw in query_keywords:             # <<<<<<<<<<<<<<
 *                     if qkw == chunk_name:
 *                         name_match_boost = 0.8
*/
      __pyx_t_31 = 0;
      __pyx_t_7 = __Pyx_set_iterator(__pyx_v_query_keywords, 1, (&__pyx_t_24), (&__pyx_t_16)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 528, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_10);
      __pyx_t_10 = __pyx_t_7;
      __pyx_t_7 = 0;
      while (1) {
        __pyx_t_9 = __Pyx_set_iter_next(__pyx_t_10, __pyx_t_24, &__pyx_t_31, &__pyx_t_7, __pyx_t_16);
        if (unlikely(__pyx_t_9 == 0)) break;
        if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 528, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_XDECREF_SET(__pyx_v_qkw, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":529
 *                 name_match_boost = 0.0
 *                 for qkw in query_keywords:
 *                     if qkw == chunk_name:             # <<<<<<<<<<<<<<
 *                         name_match_boost = 0.8
 *                         break
*/
        __pyx_t_7 = PyObject_RichCompare(__pyx_v_qkw, __pyx_v_chunk_name, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 529, __pyx_L1_error)
        __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 529, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_25) {

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":530
 *                 for qkw in query_keywords:
 *                     if qkw == chunk_name:
 *                         name_match_boost = 0.8             # <<<<<<<<<<<<<<
 *                         break
 *                     elif qkw in chunk_name_parts:
*/
          __pyx_v_name_match_boost = 0.8;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":531
 *                     if qkw == chunk_name:
 *                         name_match_boost = 0.8
 *                         break             # <<<<<<<<<<<<<<
 *                     elif qkw in chunk_name_parts:
 *                         name_match_boost = max(name_match_boost, 0.5)
*/
          goto __pyx_L96_break;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":529
 *                 name_match_boost = 0.0
 *                 for qkw in query_keywords:
 *                     if qkw == chunk_name:             # <<<<<<<<<<<<<<
 *                         name_match_boost = 0.8
 *                         break
*/
        }

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":532
 *                         name_match_boost = 0.8
 *                         break
 *                     elif qkw in chunk_name_parts:             # <<<<<<<<<<<<<<
 *                         name_match_boost = max(name_match_boost, 0.5)
 *                     elif qkw in chunk_name:
*/
        __pyx_t_25 = (__Pyx_PySequence_ContainsTF(__pyx_v_qkw, __pyx_v_chunk_name_parts, Py_EQ)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 532, __pyx_L1_error)
        if (__pyx_t_25) {

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":533
 *                         break
 *                     elif qkw in chunk_name_parts:
 *                         name_match_boost = max(name_match_boost, 0.5)             # <<<<<<<<<<<<<<
 *                     elif qkw in chunk_name:
 *                         name_match_boost = max(name_match_boost, 0.4)
*/
          __pyx_t_33 = 0.5;
          __pyx_t_34 = __pyx_v_name_match_boost;
          __pyx_t_25 = (__pyx_t_33 > __pyx_t_34);
          if (__pyx_t_25) {
            __pyx_t_35 = __pyx_t_33;
          } else {
            __pyx_t_35 = __pyx_t_34;
          }
          __pyx_v_name_match_boost = __pyx_t_35;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":532
 *                         name_match_boost = 0.8
 *                         break
 *                     elif qkw in chunk_name_parts:             # <<<<<<<<<<<<<<
 *                         name_match_boost = max(name_match_boost, 0.5)
 *                     elif qkw in chunk_name:
*/
          goto __pyx_L97;
        }

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":534
 *                     elif qkw in chunk_name_parts:
 *                         name_match_boost = max(name_match_boost, 0.5)
 *                     elif qkw in chunk_name:             # <<<<<<<<<<<<<<
 *                         name_match_boost = max(name_match_boost, 0.4)
 * 
*/
        __pyx_t_25 = (__Pyx_PySequence_ContainsTF(__pyx_v_qkw, __pyx_v_chunk_name, Py_EQ)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 534, __pyx_L1_error)
        if (__pyx_t_25) {

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":535
 *                         name_match_boost = max(name_match_boost, 0.5)
 *                     elif qkw in chunk_name:
 *                         name_match_boost = max(name_match_boost, 0.4)             # <<<<<<<<<<<<<<
 * 
 *                 # C. Summary sentence overlap (percentage of query words in summary)
*/
          __pyx_t_35 = 0.4;
          __pyx_t_33 = __pyx_v_name_match_boost;
          __pyx_t_25 = (__pyx_t_35 > __pyx_t_33);
          if (__pyx_t_25) {
            __pyx_t_34 = __pyx_t_35;
          } else {
            __pyx_t_34 = __pyx_t_33;
          }
          __pyx_v_name_match_boost = __pyx_t_34;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":534
 *                     elif qkw in chunk_name_parts:
 *                         name_match_boost = max(name_match_boost, 0.5)
 *                     elif qkw in chunk_name:             # <<<<<<<<<<<<<<
 *                         name_match_boost = max(name_match_boost, 0.4)
 * 
*/
        }
        __pyx_L97:;
      }
      __pyx_L96_break:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":538
 * 
 *                 # C. Summary sentence overlap (percentage of query words in summary)
 *                 summary_overlap = original_query_keywords & summary_words             # <<<<<<<<<<<<<<
 *                 summary_match_boost = 0.0
 *                 if summary_overlap:
*/
      __pyx_t_10 = PyNumber_And(__pyx_cur_scope->__pyx_v_original_query_keywords, __pyx_v_summary_words); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 538, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_XDECREF_SET(__pyx_v_summary_overlap, ((PyObject*)__pyx_t_10));
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":539
 *                 # C. Summary sentence overlap (percentage of query words in summary)
 *                 summary_overlap = original_query_keywords & summary_words
 *                 summary_match_boost = 0.0             # <<<<<<<<<<<<<<
 *                 if summary_overlap:
 *                     summary_match_boost = (len(summary_overlap) / len(original_query_keywords)) * 0.4
*/
      __pyx_v_summary_match_boost = 0.0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":540
 *                 summary_overlap = original_query_keywords & summary_words
 *                 summary_match_boost = 0.0
 *                 if summary_overlap:             # <<<<<<<<<<<<<<
 *                     summary_match_boost = (len(summary_overlap) / len(original_query_keywords)) * 0.4
 * 
*/
      {
        Py_ssize_t __pyx_temp = __Pyx_PySet_GET_SIZE(__pyx_v_summary_overlap);
        if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 540, __pyx_L1_error)
        __pyx_t_25 = (__pyx_temp != 0);
      }

      if (__pyx_t_25) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":541
 *                 summary_match_boost = 0.0
 *                 if summary_overlap:
 *                     summary_match_boost = (len(summary_overlap) / len(original_query_keywords)) * 0.4             # <<<<<<<<<<<<<<
 * 
 *                 # D. Content grep: check if the *original* query tokens appear in content
*/
        __pyx_t_24 = __Pyx_PySet_GET_SIZE(__pyx_v_summary_overlap); if (unlikely(__pyx_t_24 == ((Py_ssize_t)-1))) __PYX_ERR(0, 541, __pyx_L1_error)
        __pyx_t_10 = __pyx_cur_scope->__pyx_v_original_query_keywords;
        __Pyx_INCREF(__pyx_t_10);
        __pyx_t_31 = __Pyx_PySet_GET_SIZE(__pyx_t_10); if (unlikely(__pyx_t_31 == ((Py_ssize_t)-1))) __PYX_ERR(0, 541, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(__pyx_t_31 == 0)) {
          PyErr_SetString(PyExc_ZeroDivisionError, "float division");
          __PYX_ERR(0, 541, __pyx_L1_error)
        }
        __pyx_v_summary_match_boost = ((((double)__pyx_t_24) / ((double)__pyx_t_31)) * 0.4);

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":540
 *                 summary_overlap = original_query_keywords & summary_words
 *                 summary_match_boost = 0.0
 *                 if summary_overlap:             # <<<<<<<<<<<<<<
 *                     summary_match_boost = (len(summary_overlap) / len(original_query_keywords)) * 0.4
 * 
*/
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":544
 * 
 *                 # D. Content grep: check if the *original* query tokens appear in content
 *                 content_match_boost = 0.0             # <<<<<<<<<<<<<<
 *                 if chunk_content:
 *                     content_hits = original_query_keywords & content_words
*/
      __pyx_v_content_match_boost = 0.0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":545
 *                 # D. Content grep: check if the *original* query tokens appear in content
 *                 content_match_boost = 0.0
 *                 if chunk_content:             # <<<<<<<<<<<<<<
 *                     content_hits = original_query_keywords & content_words
 *                     if content_hits:
*/
      __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_v_chunk_content); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 545, __pyx_L1_error)
      if (__pyx_t_25) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":546
 *                 content_match_boost = 0.0
 *                 if chunk_content:
 *                     content_hits = original_query_keywords & content_words             # <<<<<<<<<<<<<<
 *                     if content_hits:
 *                         content_match_boost = min(0.35, (len(content_hits) / len(original_query_keywords)) * 0.35)
*/
        __pyx_t_10 = PyNumber_And(__pyx_cur_scope->__pyx_v_original_query_keywords, __pyx_v_content_words); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 546, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_XDECREF_SET(__pyx_v_content_hits, ((PyObject*)__pyx_t_10));
        __pyx_t_10 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":547
 *                 if chunk_content:
 *                     content_hits = original_query_keywords & content_words
 *                     if content_hits:             # <<<<<<<<<<<<<<
 *                         content_match_boost = min(0.35, (len(content_hits) / len(original_query_keywords)) * 0.35)
 * 
*/
        {
          Py_ssize_t __pyx_temp = __Pyx_PySet_GET_SIZE(__pyx_v_content_hits);
          if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 547, __pyx_L1_error)
          __pyx_t_25 = (__pyx_temp != 0);
        }

        if (__pyx_t_25) {

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":548
 *                     content_hits = original_query_keywords & content_words
 *                     if content_hits:
 *                         content_match_boost = min(0.35, (len(content_hits) / len(original_query_keywords)) * 0.35)             # <<<<<<<<<<<<<<
 * 
 *                 # E. Route/pattern match
*/
          __pyx_t_31 = __Pyx_PySet_GET_SIZE(__pyx_v_content_hits); if (unlikely(__pyx_t_31 == ((Py_ssize_t)-1))) __PYX_ERR(0, 548, __pyx_L1_error)
          __pyx_t_10 = __pyx_cur_scope->__pyx_v_original_query_keywords;
          __Pyx_INCREF(__pyx_t_10);
          __pyx_t_24 = __Pyx_PySet_GET_SIZE(__pyx_t_10); if (unlikely(__pyx_t_24 == ((Py_ssize_t)-1))) __PYX_ERR(0, 548, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(__pyx_t_24 == 0)) {
            PyErr_SetString(PyExc_ZeroDivisionError, "float division");
            __PYX_ERR(0, 548, __pyx_L1_error)
          }
          __pyx_t_34 = ((((double)__pyx_t_31) / ((double)__pyx_t_24)) * 0.35);
          __pyx_t_35 = 0.35;
          __pyx_t_25 = (__pyx_t_34 < __pyx_t_35);
          if (__pyx_t_25) {
            __pyx_t_33 = __pyx_t_34;
          } else {
            __pyx_t_33 = __pyx_t_35;
          }
          __pyx_v_content_match_boost = __pyx_t_33;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":547
 *                 if chunk_content:
 *                     content_hits = original_query_keywords & content_words
 *                     if content_hits:             # <<<<<<<<<<<<<<
 *                         content_match_boost = min(0.35, (len(content_hits) / len(original_query_keywords)) * 0.35)
 * 
*/
        }

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":545
 *                 # D. Content grep: check if the *original* query tokens appear in content
 *                 content_match_boost = 0.0
 *                 if chunk_content:             # <<<<<<<<<<<<<<
 *                     content_hits = original_query_keywords & content_words
 *                     if content_hits:
*/
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":551
 * 
 *                 # E. Route/pattern match
 *                 route_match_boost = 0.0             # <<<<<<<<<<<<<<
 *                 if route_patterns:
 *                     for rp in route_patterns:
*/
      __pyx_v_route_match_boost = 0.0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":552
 *                 # E. Route/pattern match
 *                 route_match_boost = 0.0
 *                 if route_patterns:             # <<<<<<<<<<<<<<
 *                     for rp in route_patterns:
 *                         if rp in chunk_content or rp in chunk_summary:
*/
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_route_patterns);
        if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 552, __pyx_L1_error)
        __pyx_t_25 = (__pyx_temp != 0);
      }

      if (__pyx_t_25) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":553
 *                 route_match_boost = 0.0
 *                 if route_patterns:
 *                     for rp in route_patterns:             # <<<<<<<<<<<<<<
 *                         if rp in chunk_content or rp in chunk_summary:
 *                             route_match_boost = 0.6
*/
        __pyx_t_10 = __pyx_v_route_patterns; __Pyx_INCREF(__pyx_t_10);
        __pyx_t_24 = 0;
        for (;;) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_10);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 553, __pyx_L1_error)
            #endif
            if (__pyx_t_24 >= __pyx_temp) break;
          }
          __pyx_t_7 = __Pyx_PyList_GetItemRefFast(__pyx_t_10, __pyx_t_24, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_24;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 553, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_XDECREF_SET(__pyx_v_rp, __pyx_t_7);
          __pyx_t_7 = 0;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":554
 *                 if route_patterns:
 *                     for rp in route_patterns:
 *                         if rp in chunk_content or rp in chunk_summary:             # <<<<<<<<<<<<<<
 *                             route_match_boost = 0.6
 *                             break
*/
          __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_rp, __pyx_v_chunk_content, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 554, __pyx_L1_error)
          if (!__pyx_t_8) {
          } else {
            __pyx_t_25 = __pyx_t_8;
            goto __pyx_L105_bool_binop_done;
          }
          __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_rp, __pyx_v_chunk_summary, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 554, __pyx_L1_error)
          __pyx_t_25 = __pyx_t_8;
          __pyx_L105_bool_binop_done:;
          if (__pyx_t_25) {

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":555
 *                     for rp in route_patterns:
 *                         if rp in chunk_content or rp in chunk_summary:
 *                             route_match_boost = 0.6             # <<<<<<<<<<<<<<
 *                             break
 * 
*/
            __pyx_v_route_match_boost = 0.6;

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":556
 *                         if rp in chunk_content or rp in chunk_summary:
 *                             route_match_boost = 0.6
 *                             break             # <<<<<<<<<<<<<<
 * 
 *                 # F. Type match
*/
            goto __pyx_L103_break;

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":554
 *                 if route_patterns:
 *                     for rp in route_patterns:
 *                         if rp in chunk_content or rp in chunk_summary:             # <<<<<<<<<<<<<<
 *                             route_match_boost = 0.6
 *                             break
*/
          }

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":553
 *                 route_match_boost = 0.0
 *                 if route_patterns:
 *                     for rp in route_patterns:             # <<<<<<<<<<<<<<
 *                         if rp in chunk_content or rp in chunk_summary:
 *                             route_match_boost = 0.6
*/
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L107_for_end;
        __pyx_L103_break:;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L107_for_end;
        __pyx_L107_for_end:;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":552
 *                 # E. Route/pattern match
 *                 route_match_boost = 0.0
 *                 if route_patterns:             # <<<<<<<<<<<<<<
 *                     for rp in route_patterns:
 *                         if rp in chunk_content or rp in chunk_summary:
*/
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":559
 * 
 *                 # F. Type match
 *                 type_match_boost = 0.0             # <<<<<<<<<<<<<<
 *                 type_query_words = {"class", "function", "module", "block", "import",
 *                                     "classes", "functions", "modules", "blocks", "method", "methods"}
*/
      __pyx_v_type_match_boost = 0.0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":560
 *                 # F. Type match
 *                 type_match_boost = 0.0
 *                 type_query_words = {"class", "function", "module", "block", "import",             # <<<<<<<<<<<<<<
 *                                     "classes", "functions", "modules", "blocks", "method", "methods"}
 *                 query_type_mentions = query_keywords & type_query_words
*/
      __pyx_t_10 = PySet_New(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_class) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_function) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_module) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_block) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_import) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_classes) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_functions) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_modules) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_blocks) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_method) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      if (PySet_Add(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_methods) < (0)) __PYX_ERR(0, 560, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_type_query_words, ((PyObject*)__pyx_t_10));
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":562
 *                 type_query_words = {"class", "function", "module", "block", "import",
 *                                     "classes", "functions", "modules", "blocks", "method", "methods"}
 *                 query_type_mentions = query_keywords & type_query_words             # <<<<<<<<<<<<<<
 *                 if query_type_mentions and chunk_type:
 *                     for qt in query_type_mentions:
*/
      __pyx_t_10 = PyNumber_And(__pyx_v_query_keywords, __pyx_v_type_query_words); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_XDECREF_SET(__pyx_v_query_type_mentions, ((PyObject*)__pyx_t_10));
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":563
 *                                     "classes", "functions", "modules", "blocks", "method", "methods"}
 *                 query_type_mentions = query_keywords & type_query_words
 *                 if query_type_mentions and chunk_type:             # <<<<<<<<<<<<<<
 *                     for qt in query_type_mentions:
 *                         if qt.rstrip('s') == chunk_type or qt == chunk_type:
*/
      {
        Py_ssize_t __pyx_temp = __Pyx_PySet_GET_SIZE(__pyx_v_query_type_mentions);
        if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(0, 563, __pyx_L1_error)
        __pyx_t_8 = (__pyx_temp != 0);
      }

      if (__pyx_t_8) {
      } else {
        __pyx_t_25 = __pyx_t_8;
        goto __pyx_L109_bool_binop_done;
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_chunk_type); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 563, __pyx_L1_error)
      __pyx_t_25 = __pyx_t_8;
      __pyx_L109_bool_binop_done:;
      if (__pyx_t_25) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":564
 *                 query_type_mentions = query_keywords & type_query_words
 *                 if query_type_mentions and chunk_type:
 *                     for qt in query_type_mentions:             # <<<<<<<<<<<<<<
 *                         if qt.rstrip('s') == chunk_type or qt == chunk_type:
 *                             type_match_boost = 0.2
*/
        __pyx_t_24 = 0;
        __pyx_t_7 = __Pyx_set_iterator(__pyx_v_query_type_mentions, 1, (&__pyx_t_31), (&__pyx_t_16)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 564, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_10);
        __pyx_t_10 = __pyx_t_7;
        __pyx_t_7 = 0;
        while (1) {
          __pyx_t_9 = __Pyx_set_iter_next(__pyx_t_10, __pyx_t_31, &__pyx_t_24, &__pyx_t_7, __pyx_t_16);
          if (unlikely(__pyx_t_9 == 0)) break;
          if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 564, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_XDECREF_SET(__pyx_v_qt, __pyx_t_7);
          __pyx_t_7 = 0;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":565
 *                 if query_type_mentions and chunk_type:
 *                     for qt in query_type_mentions:
 *                         if qt.rstrip('s') == chunk_type or qt == chunk_type:             # <<<<<<<<<<<<<<
 *                             type_match_boost = 0.2
 *                             break
*/
          __pyx_t_1 = __pyx_v_qt;
          __Pyx_INCREF(__pyx_t_1);
          __pyx_t_3 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_n_u_s};
            __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_rstrip, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 565, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
          }
          __pyx_t_1 = PyObject_RichCompare(__pyx_t_7, __pyx_v_chunk_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 565, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (!__pyx_t_8) {
          } else {
            __pyx_t_25 = __pyx_t_8;
            goto __pyx_L114_bool_binop_done;
          }
          __pyx_t_1 = PyObject_RichCompare(__pyx_v_qt, __pyx_v_chunk_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error)
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 565, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_25 = __pyx_t_8;
          __pyx_L114_bool_binop_done:;
          if (__pyx_t_25) {

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":566
 *                     for qt in query_type_mentions:
 *                         if qt.rstrip('s') == chunk_type or qt == chunk_type:
 *                             type_match_boost = 0.2             # <<<<<<<<<<<<<<
 *                             break
 * 
*/
            __pyx_v_type_match_boost = 0.2;

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":567
 *                         if qt.rstrip('s') == chunk_type or qt == chunk_type:
 *                             type_match_boost = 0.2
 *                             break             # <<<<<<<<<<<<<<
 * 
 *                 # G. Parent-class relationship boost
*/
            goto __pyx_L112_break;

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":565
 *                 if query_type_mentions and chunk_type:
 *                     for qt in query_type_mentions:
 *                         if qt.rstrip('s') == chunk_type or qt == chunk_type:             # <<<<<<<<<<<<<<
 *                             type_match_boost = 0.2
 *                             break
*/
          }
        }
        __pyx_L112_break:;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":563
 *                                     "classes", "functions", "modules", "blocks", "method", "methods"}
 *                 query_type_mentions = query_keywords & type_query_words
 *                 if query_type_mentions and chunk_type:             # <<<<<<<<<<<<<<
 *                     for qt in query_type_mentions:
 *                         if qt.rstrip('s') == chunk_type or qt == chunk_type:
*/
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":571
 *                 # G. Parent-class relationship boost
 *                 # If query matches a class, boost its methods too
 *                 relationship_boost = 0.0             # <<<<<<<<<<<<<<
 *                 if '.' in chunk_name:
 *                     parent_class = chunk_name.split('.')[0]
*/
      __pyx_v_relationship_boost = 0.0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":572
 *                 # If query matches a class, boost its methods too
 *                 relationship_boost = 0.0
 *                 if '.' in chunk_name:             # <<<<<<<<<<<<<<
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(
*/
      __pyx_t_25 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_kp_u__8, __pyx_v_chunk_name, Py_EQ)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 572, __pyx_L1_error)
      if (__pyx_t_25) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":573
 *                 relationship_boost = 0.0
 *                 if '.' in chunk_name:
 *                     parent_class = chunk_name.split('.')[0]             # <<<<<<<<<<<<<<
 *                     if parent_class in query_keywords or any(
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3
*/
        __pyx_t_1 = __pyx_v_chunk_name;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__8};
          __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 573, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
        }
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_10, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 573, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_parent_class);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_parent_class, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __pyx_t_1 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":574
 *                 if '.' in chunk_name:
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(             # <<<<<<<<<<<<<<
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3
 *                     ):
*/
        if (unlikely(__pyx_v_query_keywords == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(0, 574, __pyx_L1_error)
        }
        __pyx_t_8 = (__Pyx_PySet_ContainsTF(__pyx_cur_scope->__pyx_v_parent_class, __pyx_v_query_keywords, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 574, __pyx_L1_error)
        if (!__pyx_t_8) {
        } else {
          __pyx_t_25 = __pyx_t_8;
          goto __pyx_L118_bool_binop_done;
        }

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":575
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3             # <<<<<<<<<<<<<<
 *                     ):
 *                         relationship_boost = 0.3
*/
        __pyx_t_1 = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_23genexpr(((PyObject*)__pyx_cur_scope), __pyx_v_query_keywords); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 575, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = __Pyx_Generator_GetInlinedResult(__pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 575, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 575, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_25 = __pyx_t_8;
        __pyx_L118_bool_binop_done:;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":574
 *                 if '.' in chunk_name:
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(             # <<<<<<<<<<<<<<
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3
 *                     ):
*/
        if (__pyx_t_25) {

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":577
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3
 *                     ):
 *                         relationship_boost = 0.3             # <<<<<<<<<<<<<<
 * 
 *                 # H. Exact phrase / bigram match in summary
*/
          __pyx_v_relationship_boost = 0.3;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":574
 *                 if '.' in chunk_name:
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(             # <<<<<<<<<<<<<<
 *                         qkw in parent_class for qkw in query_keywords if len(qkw) > 3
 *                     ):
*/
        }

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":572
 *                 # If query matches a class, boost its methods too
 *                 relationship_boost = 0.0
 *                 if '.' in chunk_name:             # <<<<<<<<<<<<<<
 *                     parent_class = chunk_name.split('.')[0]
 *                     if parent_class in query_keywords or any(
*/
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":580
 * 
 *                 # H. Exact phrase / bigram match in summary
 *                 bigram_boost = 0.0             # <<<<<<<<<<<<<<
 *                 query_lower = query.lower()
 *                 # Check 2-word subsequences from query appearing in summary
*/
      __pyx_v_bigram_boost = 0.0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":581
 *                 # H. Exact phrase / bigram match in summary
 *                 bigram_boost = 0.0
 *                 query_lower = query.lower()             # <<<<<<<<<<<<<<
 *                 # Check 2-word subsequences from query appearing in summary
 *                 q_words = [w for w in query_lower.split() if w not in _STOP_WORDS]
*/
      __pyx_t_10 = __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyUnicode_Type__lower, __pyx_v_query); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_XDECREF_SET(__pyx_v_query_lower, ((PyObject*)__pyx_t_10));
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":583
 *                 query_lower = query.lower()
 *                 # Check 2-word subsequences from query appearing in summary
 *                 q_words = [w for w in query_lower.split() if w not in _STOP_WORDS]             # <<<<<<<<<<<<<<
 *                 for i in range(len(q_words) - 1):
 *                     bigram = q_words[i] + " " + q_words[i + 1]
*/
      { /* enter inner scope */
        __pyx_t_10 = PyList_New(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 583, __pyx_L122_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_1 = PyUnicode_Split(__pyx_v_query_lower, ((PyObject *)NULL), -1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 583, __pyx_L122_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __pyx_t_1; __Pyx_INCREF(__pyx_t_7);
        __pyx_t_31 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        for (;;) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 583, __pyx_L122_error)
            #endif
            if (__pyx_t_31 >= __pyx_temp) break;
          }
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_7, __pyx_t_31, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_31;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 583, __pyx_L122_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_9genexpr10__pyx_v_w, __pyx_t_1);
          __pyx_t_1 = 0;
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_STOP_WORDS); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 583, __pyx_L122_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_25 = (__Pyx_PySequence_ContainsTF(__pyx_9genexpr10__pyx_v_w, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 583, __pyx_L122_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_25) {
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_10, (PyObject*)__pyx_9genexpr10__pyx_v_w))) __PYX_ERR(0, 583, __pyx_L122_error)
          }
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_9genexpr10__pyx_v_w); __pyx_9genexpr10__pyx_v_w = 0;
        goto __pyx_L127_exit_scope;
        __pyx_L122_error:;
        __Pyx_XDECREF(__pyx_9genexpr10__pyx_v_w); __pyx_9genexpr10__pyx_v_w = 0;
        goto __pyx_L1_error;
        __pyx_L127_exit_scope:;
      } /* exit inner scope */
      __Pyx_XDECREF_SET(__pyx_v_q_words, ((PyObject*)__pyx_t_10));
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":584
 *                 # Check 2-word subsequences from query appearing in summary
 *                 q_words = [w for w in query_lower.split() if w not in _STOP_WORDS]
 *                 for i in range(len(q_words) - 1):             # <<<<<<<<<<<<<<
 *                     bigram = q_words[i] + " " + q_words[i + 1]
 *                     if bigram in chunk_summary:
*/
      __pyx_t_7 = NULL;
      __pyx_t_31 = __Pyx_PyList_GET_SIZE(__pyx_v_q_words); if (unlikely(__pyx_t_31 == ((Py_ssize_t)-1))) __PYX_ERR(0, 584, __pyx_L1_error)
      __pyx_t_1 = PyLong_FromSsize_t((__pyx_t_31 - 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
        __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)(&PyRange_Type), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 584, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __pyx_t_1 = PyObject_GetIter(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_28 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 584, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      for (;;) {
        {
          __pyx_t_10 = __pyx_t_28(__pyx_t_1);
          if (unlikely(!__pyx_t_10)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 584, __pyx_L1_error)
              PyErr_Clear();
            }
            break;
          }
        }
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":585
 *                 q_words = [w for w in query_lower.split() if w not in _STOP_WORDS]
 *                 for i in range(len(q_words) - 1):
 *                     bigram = q_words[i] + " " + q_words[i + 1]             # <<<<<<<<<<<<<<
 *                     if bigram in chunk_summary:
 *                         bigram_boost = 0.25
*/
        __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_v_q_words, __pyx_v_i); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 585, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_7 = PyNumber_Add(__pyx_t_10, __pyx_mstate_global->__pyx_kp_u__9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 585, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = __Pyx_PyLong_AddObjC(__pyx_v_i, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 585, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_13 = __Pyx_PyObject_GetItem(__pyx_v_q_words, __pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 585, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = PyNumber_Add(__pyx_t_7, __pyx_t_13); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 585, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF_SET(__pyx_v_bigram, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":586
 *                 for i in range(len(q_words) - 1):
 *                     bigram = q_words[i] + " " + q_words[i + 1]
 *                     if bigram in chunk_summary:             # <<<<<<<<<<<<<<
 *                         bigram_boost = 0.25
 *                         break
*/
        __pyx_t_25 = (__Pyx_PySequence_ContainsTF(__pyx_v_bigram, __pyx_v_chunk_summary, Py_EQ)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 586, __pyx_L1_error)
        if (__pyx_t_25) {

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":587
 *                     bigram = q_words[i] + " " + q_words[i + 1]
 *                     if bigram in chunk_summary:
 *                         bigram_boost = 0.25             # <<<<<<<<<<<<<<
 *                         break
 * 
*/
          __pyx_v_bigram_boost = 0.25;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":588
 *                     if bigram in chunk_summary:
 *                         bigram_boost = 0.25
 *                         break             # <<<<<<<<<<<<<<
 * 
 *                 # Combine
*/
          goto __pyx_L129_break;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":586
 *                 for i in range(len(q_words) - 1):
 *                     bigram = q_words[i] + " " + q_words[i + 1]
 *                     if bigram in chunk_summary:             # <<<<<<<<<<<<<<
 *                         bigram_boost = 0.25
 *                         break
*/
        }

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":584
 *                 # Check 2-word subsequences from query appearing in summary
 *                 q_words = [w for w in query_lower.split() if w not in _STOP_WORDS]
 *                 for i in range(len(q_words) - 1):             # <<<<<<<<<<<<<<
 *                     bigram = q_words[i] + " " + q_words[i + 1]
 *                     if bigram in chunk_summary:
*/
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L131_for_end;
      __pyx_L129_break:;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L131_for_end;
      __pyx_L131_for_end:;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":593
 *                 kw_score = min(1.0,
 *                     base_kw
 *                     + name_match_boost             # <<<<<<<<<<<<<<
 *                     + summary_match_boost
 *                     + content_match_boost
*/
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_name_match_boost); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 593, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = PyNumber_Add(__pyx_v_base_kw, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 593, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":594
 *                     base_kw
 *                     + name_match_boost
 *                     + summary_match_boost             # <<<<<<<<<<<<<<
 *                     + content_match_boost
 *                     + route_match_boost
*/
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_summary_match_boost); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_13 = PyNumber_Add(__pyx_t_10, __pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 594, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":595
 *                     + name_match_boost
 *                     + summary_match_boost
 *                     + content_match_boost             # <<<<<<<<<<<<<<
 *                     + route_match_boost
 *                     + type_match_boost
*/
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_content_match_boost); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 595, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = PyNumber_Add(__pyx_t_13, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 595, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":596
 *                     + summary_match_boost
 *                     + content_match_boost
 *                     + route_match_boost             # <<<<<<<<<<<<<<
 *                     + type_match_boost
 *                     + relationship_boost
*/
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_route_match_boost); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_13 = PyNumber_Add(__pyx_t_10, __pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":597
 *                     + content_match_boost
 *                     + route_match_boost
 *                     + type_match_boost             # <<<<<<<<<<<<<<
 *                     + relationship_boost
 *                     + bigram_boost
*/
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_type_match_boost); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = PyNumber_Add(__pyx_t_13, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":598
 *                     + route_match_boost
 *                     + type_match_boost
 *                     + relationship_boost             # <<<<<<<<<<<<<<
 *                     + bigram_boost
 *                 )
*/
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_relationship_boost); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_13 = PyNumber_Add(__pyx_t_10, __pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":599
 *                     + type_match_boost
 *                     + relationship_boost
 *                     + bigram_boost             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_bigram_boost); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 599, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = PyNumber_Add(__pyx_t_13, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 599, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_33 = 1.0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":591
 * 
 *                 # Combine
 *                 kw_score = min(1.0,             # <<<<<<<<<<<<<<
 *                     base_kw
 *                     + name_match_boost
*/
      __pyx_t_13 = PyFloat_FromDouble(__pyx_t_33); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 591, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_7 = PyObject_RichCompare(__pyx_t_10, __pyx_t_13, Py_LT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 599, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":599
 *                     + type_match_boost
 *                     + relationship_boost
 *                     + bigram_boost             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
      __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 599, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_25) {
        __Pyx_INCREF(__pyx_t_10);
        __pyx_t_1 = __pyx_t_10;
      } else {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":591
 * 
 *                 # Combine
 *                 kw_score = min(1.0,             # <<<<<<<<<<<<<<
 *                     base_kw
 *                     + name_match_boost
*/
        __pyx_t_7 = PyFloat_FromDouble(__pyx_t_33); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 591, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_1 = __pyx_t_7;
        __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":599
 *                     + type_match_boost
 *                     + relationship_boost
 *                     + bigram_boost             # <<<<<<<<<<<<<<
 *                 )
 * 
*/
      __pyx_t_10 = __pyx_t_1;
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_kw_score, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":513
 *             chunk_text_bag = chunk_kws | summary_words | content_words | chunk_name_parts | {chunk_name}
 * 
 *             if query_keywords:             # <<<<<<<<<<<<<<
 *                 # A. IDF-weighted keyword overlap
 *                 overlap = query_keywords & chunk_text_bag
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":603
 * 
 *             # 3. Line Number Matching (prefer tight ranges)
 *             line_match_boost = 0.0             # <<<<<<<<<<<<<<
 *             if query_line_numbers:
 *                 start_line = chunk.get("start_line", 0)
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_float_0_0);
    __Pyx_XDECREF_SET(__pyx_v_line_match_boost, __pyx_mstate_global->__pyx_float_0_0);

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":604
 *             # 3. Line Number Matching (prefer tight ranges)
 *             line_match_boost = 0.0
 *             if query_line_numbers:             # <<<<<<<<<<<<<<
 *                 start_line = chunk.get("start_line", 0)
 *                 end_line = chunk.get("end_line", 0)
*/
    __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_v_query_line_numbers); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 604, __pyx_L1_error)
    if (__pyx_t_25) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":605
 *             line_match_boost = 0.0
 *             if query_line_numbers:
 *                 start_line = chunk.get("start_line", 0)             # <<<<<<<<<<<<<<
 *                 end_line = chunk.get("end_line", 0)
 *                 if start_line or end_line:
*/
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_mstate_global->__pyx_tuple[5], NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF_SET(__pyx_v_start_line, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":606
 *             if query_line_numbers:
 *                 start_line = chunk.get("start_line", 0)
 *                 end_line = chunk.get("end_line", 0)             # <<<<<<<<<<<<<<
 *                 if start_line or end_line:
 *                     span = max(end_line - start_line, 1)
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_mstate_global->__pyx_tuple[6], NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_end_line, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":607
 *                 start_line = chunk.get("start_line", 0)
 *                 end_line = chunk.get("end_line", 0)
 *                 if start_line or end_line:             # <<<<<<<<<<<<<<
 *                     span = max(end_line - start_line, 1)
 *                     for ln in query_line_numbers:
*/
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_start_line); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 607, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __pyx_t_25 = __pyx_t_8;
        goto __pyx_L134_bool_binop_done;
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_end_line); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 607, __pyx_L1_error)
      __pyx_t_25 = __pyx_t_8;
      __pyx_L134_bool_binop_done:;
      if (__pyx_t_25) {

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":608
 *                 end_line = chunk.get("end_line", 0)
 *                 if start_line or end_line:
 *                     span = max(end_line - start_line, 1)             # <<<<<<<<<<<<<<
 *                     for ln in query_line_numbers:
 *                         if start_line <= ln <= end_line:
*/
        __pyx_t_30 = 1;
        __pyx_t_10 = PyNumber_Subtract(__pyx_v_end_line, __pyx_v_start_line); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 608, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_7 = __Pyx_PyLong_From_long(__pyx_t_30); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 608, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_13 = PyObject_RichCompare(__pyx_t_7, __pyx_t_10, Py_GT); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 608, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 608, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (__pyx_t_25) {
          __pyx_t_13 = __Pyx_PyLong_From_long(__pyx_t_30); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 608, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_1 = __pyx_t_13;
          __pyx_t_13 = 0;
        } else {
          __Pyx_INCREF(__pyx_t_10);
          __pyx_t_1 = __pyx_t_10;
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = __pyx_t_1;
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_span, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":609
 *                 if start_line or end_line:
 *                     span = max(end_line - start_line, 1)
 *                     for ln in query_line_numbers:             # <<<<<<<<<<<<<<
 *                         if start_line <= ln <= end_line:
 *                             # Tighter span  higher boost (inverse span reward)
*/
        if (likely(PyList_CheckExact(__pyx_v_query_line_numbers)) || PyTuple_CheckExact(__pyx_v_query_line_numbers)) {
          __pyx_t_10 = __pyx_v_query_line_numbers; __Pyx_INCREF(__pyx_t_10);
          __pyx_t_31 = 0;
          __pyx_t_28 = NULL;
        } else {
          __pyx_t_31 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_v_query_line_numbers); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 609, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_28 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_10); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 609, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_28)) {
            if (likely(PyList_CheckExact(__pyx_t_10))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_10);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 609, __pyx_L1_error)
                #endif
                if (__pyx_t_31 >= __pyx_temp) break;
              }
              __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_10, __pyx_t_31, __Pyx_ReferenceSharing_OwnStrongReference);
              ++__pyx_t_31;
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_10);
                #if !CYTHON_ASSUME_SAFE_SIZE
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 609, __pyx_L1_error)
                #endif
                if (__pyx_t_31 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_31));
              #else
              __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_10, __pyx_t_31);
              #endif
              ++__pyx_t_31;
            }
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 609, __pyx_L1_error)
          } else {
            __pyx_t_1 = __pyx_t_28(__pyx_t_10);
            if (unlikely(!__pyx_t_1)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 609, __pyx_L1_error)
                PyErr_Clear();
              }
              break;
            }
          }
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_v_ln, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":610
 *                     span = max(end_line - start_line, 1)
 *                     for ln in query_line_numbers:
 *                         if start_line <= ln <= end_line:             # <<<<<<<<<<<<<<
 *                             # Tighter span  higher boost (inverse span reward)
 *                             tightness = min(1.0, 20.0 / span)
*/
          __pyx_t_1 = PyObject_RichCompare(__pyx_v_start_line, __pyx_v_ln, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 610, __pyx_L1_error)
          if (__Pyx_PyObject_IsTrue(__pyx_t_1)) {
            __Pyx_DECREF(__pyx_t_1);
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_ln, __pyx_v_end_line, Py_LE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 610, __pyx_L1_error)
          }
          __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 610, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_25) {

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":612
 *                         if start_line <= ln <= end_line:
 *                             # Tighter span  higher boost (inverse span reward)
 *                             tightness = min(1.0, 20.0 / span)             # <<<<<<<<<<<<<<
 *                             score = 0.5 + 0.4 * tightness  # 0.5  0.9
 *                             line_match_boost = max(line_match_boost, score)
*/
            __pyx_t_1 = __Pyx_PyFloat_TrueDivideCObj(__pyx_mstate_global->__pyx_float_20_0, __pyx_v_span, 20.0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 612, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_33 = 1.0;
            __pyx_t_7 = PyFloat_FromDouble(__pyx_t_33); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 612, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_t_7, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 612, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 612, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (__pyx_t_25) {
              __Pyx_INCREF(__pyx_t_1);
              __pyx_t_13 = __pyx_t_1;
            } else {
              __pyx_t_2 = PyFloat_FromDouble(__pyx_t_33); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 612, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_13 = __pyx_t_2;
              __pyx_t_2 = 0;
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = __pyx_t_13;
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF_SET(__pyx_v_tightness, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":613
 *                             # Tighter span  higher boost (inverse span reward)
 *                             tightness = min(1.0, 20.0 / span)
 *                             score = 0.5 + 0.4 * tightness  # 0.5  0.9             # <<<<<<<<<<<<<<
 *                             line_match_boost = max(line_match_boost, score)
 *                         elif abs(ln - start_line) <= 10 or abs(ln - end_line) <= 10:
*/
            __pyx_t_1 = PyNumber_Multiply(__pyx_mstate_global->__pyx_float_0_4, __pyx_v_tightness); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 613, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_13 = __Pyx_PyFloat_AddCObj(__pyx_mstate_global->__pyx_float_0_5, __pyx_t_1, 0.5, 0, 0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 613, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF_SET(__pyx_v_score, __pyx_t_13);
            __pyx_t_13 = 0;

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":614
 *                             tightness = min(1.0, 20.0 / span)
 *                             score = 0.5 + 0.4 * tightness  # 0.5  0.9
 *                             line_match_boost = max(line_match_boost, score)             # <<<<<<<<<<<<<<
 *                         elif abs(ln - start_line) <= 10 or abs(ln - end_line) <= 10:
 *                             line_match_boost = max(line_match_boost, 0.3)
*/
            __Pyx_INCREF(__pyx_v_score);
            __pyx_t_13 = __pyx_v_score;
            __Pyx_INCREF(__pyx_v_line_match_boost);
            __pyx_t_1 = __pyx_v_line_match_boost;
            __pyx_t_7 = PyObject_RichCompare(__pyx_t_13, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 614, __pyx_L1_error)
            __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 614, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (__pyx_t_25) {
              __Pyx_INCREF(__pyx_t_13);
              __pyx_t_2 = __pyx_t_13;
            } else {
              __Pyx_INCREF(__pyx_t_1);
              __pyx_t_2 = __pyx_t_1;
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_13 = __pyx_t_2;
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF_SET(__pyx_v_line_match_boost, __pyx_t_13);
            __pyx_t_13 = 0;

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":610
 *                     span = max(end_line - start_line, 1)
 *                     for ln in query_line_numbers:
 *                         if start_line <= ln <= end_line:             # <<<<<<<<<<<<<<
 *                             # Tighter span  higher boost (inverse span reward)
 *                             tightness = min(1.0, 20.0 / span)
*/
            goto __pyx_L138;
          }

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":615
 *                             score = 0.5 + 0.4 * tightness  # 0.5  0.9
 *                             line_match_boost = max(line_match_boost, score)
 *                         elif abs(ln - start_line) <= 10 or abs(ln - end_line) <= 10:             # <<<<<<<<<<<<<<
 *                             line_match_boost = max(line_match_boost, 0.3)
 * 
*/
          __pyx_t_13 = PyNumber_Subtract(__pyx_v_ln, __pyx_v_start_line); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 615, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_2 = __Pyx_PyNumber_Absolute(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 615, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = PyObject_RichCompare(__pyx_t_2, __pyx_mstate_global->__pyx_int_10, Py_LE); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 615, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 615, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (!__pyx_t_8) {
          } else {
            __pyx_t_25 = __pyx_t_8;
            goto __pyx_L139_bool_binop_done;
          }
          __pyx_t_13 = PyNumber_Subtract(__pyx_v_ln, __pyx_v_end_line); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 615, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_2 = __Pyx_PyNumber_Absolute(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 615, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = PyObject_RichCompare(__pyx_t_2, __pyx_mstate_global->__pyx_int_10, Py_LE); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 615, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 615, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_25 = __pyx_t_8;
          __pyx_L139_bool_binop_done:;
          if (__pyx_t_25) {

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":616
 *                             line_match_boost = max(line_match_boost, score)
 *                         elif abs(ln - start_line) <= 10 or abs(ln - end_line) <= 10:
 *                             line_match_boost = max(line_match_boost, 0.3)             # <<<<<<<<<<<<<<
 * 
 *             # 4. Final hybrid combination
*/
            __pyx_t_33 = 0.3;
            __Pyx_INCREF(__pyx_v_line_match_boost);
            __pyx_t_13 = __pyx_v_line_match_boost;
            __pyx_t_1 = PyFloat_FromDouble(__pyx_t_33); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 616, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_7 = PyObject_RichCompare(__pyx_t_1, __pyx_t_13, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 616, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 616, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (__pyx_t_25) {
              __pyx_t_7 = PyFloat_FromDouble(__pyx_t_33); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 616, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __pyx_t_2 = __pyx_t_7;
              __pyx_t_7 = 0;
            } else {
              __Pyx_INCREF(__pyx_t_13);
              __pyx_t_2 = __pyx_t_13;
            }
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_13 = __pyx_t_2;
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF_SET(__pyx_v_line_match_boost, __pyx_t_13);
            __pyx_t_13 = 0;

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":615
 *                             score = 0.5 + 0.4 * tightness  # 0.5  0.9
 *                             line_match_boost = max(line_match_boost, score)
 *                         elif abs(ln - start_line) <= 10 or abs(ln - end_line) <= 10:             # <<<<<<<<<<<<<<
 *                             line_match_boost = max(line_match_boost, 0.3)
 * 
*/
          }
          __pyx_L138:;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":609
 *                 if start_line or end_line:
 *                     span = max(end_line - start_line, 1)
 *                     for ln in query_line_numbers:             # <<<<<<<<<<<<<<
 *                         if start_line <= ln <= end_line:
 *                             # Tighter span  higher boost (inverse span reward)
*/
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":607
 *                 start_line = chunk.get("start_line", 0)
 *                 end_line = chunk.get("end_line", 0)
 *                 if start_line or end_line:             # <<<<<<<<<<<<<<
 *                     span = max(end_line - start_line, 1)
 *                     for ln in query_line_numbers:
*/
      }

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":604
 *             # 3. Line Number Matching (prefer tight ranges)
 *             line_match_boost = 0.0
 *             if query_line_numbers:             # <<<<<<<<<<<<<<
 *                 start_line = chunk.get("start_line", 0)
 *                 end_line = chunk.get("end_line", 0)
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":620
 *             # 4. Final hybrid combination
 *             # Adjust alpha based on intent
 *             effective_alpha = alpha             # <<<<<<<<<<<<<<
 *             if intent == "symbol":
 *                 effective_alpha = 0.35  # lean towards keyword matching
*/
    __pyx_v_effective_alpha = __pyx_v_alpha;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":621
 *             # Adjust alpha based on intent
 *             effective_alpha = alpha
 *             if intent == "symbol":             # <<<<<<<<<<<<<<
 *                 effective_alpha = 0.35  # lean towards keyword matching
 *             elif intent == "usage":
*/
    __pyx_t_25 = (__Pyx_PyUnicode_Equals(__pyx_v_intent, __pyx_mstate_global->__pyx_n_u_symbol, Py_EQ)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 621, __pyx_L1_error)
    if (__pyx_t_25) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":622
 *             effective_alpha = alpha
 *             if intent == "symbol":
 *                 effective_alpha = 0.35  # lean towards keyword matching             # <<<<<<<<<<<<<<
 *             elif intent == "usage":
 *                 effective_alpha = 0.40  # content/keyword heavy
*/
      __pyx_v_effective_alpha = 0.35;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":621
 *             # Adjust alpha based on intent
 *             effective_alpha = alpha
 *             if intent == "symbol":             # <<<<<<<<<<<<<<
 *                 effective_alpha = 0.35  # lean towards keyword matching
 *             elif intent == "usage":
*/
      goto __pyx_L142;
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":623
 *             if intent == "symbol":
 *                 effective_alpha = 0.35  # lean towards keyword matching
 *             elif intent == "usage":             # <<<<<<<<<<<<<<
 *                 effective_alpha = 0.40  # content/keyword heavy
 *             elif intent == "broad":
*/
    __pyx_t_25 = (__Pyx_PyUnicode_Equals(__pyx_v_intent, __pyx_mstate_global->__pyx_n_u_usage, Py_EQ)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 623, __pyx_L1_error)
    if (__pyx_t_25) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":624
 *                 effective_alpha = 0.35  # lean towards keyword matching
 *             elif intent == "usage":
 *                 effective_alpha = 0.40  # content/keyword heavy             # <<<<<<<<<<<<<<
 *             elif intent == "broad":
 *                 effective_alpha = 0.45  # balanced but more keyword
*/
      __pyx_v_effective_alpha = 0.40;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":623
 *             if intent == "symbol":
 *                 effective_alpha = 0.35  # lean towards keyword matching
 *             elif intent == "usage":             # <<<<<<<<<<<<<<
 *                 effective_alpha = 0.40  # content/keyword heavy
 *             elif intent == "broad":
*/
      goto __pyx_L142;
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":625
 *             elif intent == "usage":
 *                 effective_alpha = 0.40  # content/keyword heavy
 *             elif intent == "broad":             # <<<<<<<<<<<<<<
 *                 effective_alpha = 0.45  # balanced but more keyword
 *             elif intent == "line":
*/
    __pyx_t_25 = (__Pyx_PyUnicode_Equals(__pyx_v_intent, __pyx_mstate_global->__pyx_n_u_broad, Py_EQ)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 625, __pyx_L1_error)
    if (__pyx_t_25) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":626
 *                 effective_alpha = 0.40  # content/keyword heavy
 *             elif intent == "broad":
 *                 effective_alpha = 0.45  # balanced but more keyword             # <<<<<<<<<<<<<<
 *             elif intent == "line":
 *                 effective_alpha = 0.30  # line match dominates
*/
      __pyx_v_effective_alpha = 0.45;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":625
 *             elif intent == "usage":
 *                 effective_alpha = 0.40  # content/keyword heavy
 *             elif intent == "broad":             # <<<<<<<<<<<<<<
 *                 effective_alpha = 0.45  # balanced but more keyword
 *             elif intent == "line":
*/
      goto __pyx_L142;
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":627
 *             elif intent == "broad":
 *                 effective_alpha = 0.45  # balanced but more keyword
 *             elif intent == "line":             # <<<<<<<<<<<<<<
 *                 effective_alpha = 0.30  # line match dominates
 * 
*/
    __pyx_t_25 = (__Pyx_PyUnicode_Equals(__pyx_v_intent, __pyx_mstate_global->__pyx_n_u_line, Py_EQ)); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 627, __pyx_L1_error)
    if (__pyx_t_25) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":628
 *                 effective_alpha = 0.45  # balanced but more keyword
 *             elif intent == "line":
 *                 effective_alpha = 0.30  # line match dominates             # <<<<<<<<<<<<<<
 * 
 *             final_score = (
*/
      __pyx_v_effective_alpha = 0.30;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":627
 *             elif intent == "broad":
 *                 effective_alpha = 0.45  # balanced but more keyword
 *             elif intent == "line":             # <<<<<<<<<<<<<<
 *                 effective_alpha = 0.30  # line match dominates
 * 
*/
    }
    __pyx_L142:;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":631
 * 
 *             final_score = (
 *                 vec_score * effective_alpha             # <<<<<<<<<<<<<<
 *                 + kw_score * (1.0 - effective_alpha)
 *                 + line_match_boost
*/
    __pyx_t_10 = PyFloat_FromDouble(__pyx_v_effective_alpha); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_13 = PyNumber_Multiply(__pyx_v_vec_score, __pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":632
 *             final_score = (
 *                 vec_score * effective_alpha
 *                 + kw_score * (1.0 - effective_alpha)             # <<<<<<<<<<<<<<
 *                 + line_match_boost
 *             )
*/
    __pyx_t_10 = PyFloat_FromDouble((1.0 - __pyx_v_effective_alpha)); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_2 = PyNumber_Multiply(__pyx_v_kw_score, __pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyNumber_Add(__pyx_t_13, __pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":633
 *                 vec_score * effective_alpha
 *                 + kw_score * (1.0 - effective_alpha)
 *                 + line_match_boost             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    __pyx_t_2 = PyNumber_Add(__pyx_t_10, __pyx_v_line_match_boost); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF_SET(__pyx_v_final_score, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":637
 * 
 *             # Minimum threshold
 *             if final_score > 0.01:             # <<<<<<<<<<<<<<
 *                 summary_chunk = {
 *                     k: v for k, v in chunk.items()
*/
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_final_score, __pyx_mstate_global->__pyx_float_0_01, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 637, __pyx_L1_error)
    __pyx_t_25 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_25 < 0))) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_25) {

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":638
 *             # Minimum threshold
 *             if final_score > 0.01:
 *                 summary_chunk = {             # <<<<<<<<<<<<<<
 *                     k: v for k, v in chunk.items()
 *                     if k not in (
*/
      { /* enter inner scope */
        __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 638, __pyx_L146_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":639
 *             if final_score > 0.01:
 *                 summary_chunk = {
 *                     k: v for k, v in chunk.items()             # <<<<<<<<<<<<<<
 *                     if k not in (
 *                         "hash_id", "embedding_id", "vector",
*/
        __pyx_t_31 = 0;
        if (unlikely(__pyx_v_chunk == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
          __PYX_ERR(0, 639, __pyx_L146_error)
        }
        __pyx_t_13 = __Pyx_dict_iterator(__pyx_v_chunk, 0, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_24), (&__pyx_t_16)); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 639, __pyx_L146_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_XDECREF(__pyx_t_10);
        __pyx_t_10 = __pyx_t_13;
        __pyx_t_13 = 0;
        while (1) {
          __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_10, __pyx_t_24, &__pyx_t_31, &__pyx_t_13, &__pyx_t_7, NULL, __pyx_t_16);
          if (unlikely(__pyx_t_9 == 0)) break;
          if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 639, __pyx_L146_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_XDECREF_SET(__pyx_9genexpr11__pyx_v_k, __pyx_t_13);
          __pyx_t_13 = 0;
          __Pyx_XDECREF_SET(__pyx_9genexpr11__pyx_v_v, __pyx_t_7);
          __pyx_t_7 = 0;

          /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":640
 *                 summary_chunk = {
 *                     k: v for k, v in chunk.items()
 *                     if k not in (             # <<<<<<<<<<<<<<
 *                         "hash_id", "embedding_id", "vector",
 *                         "token_count", "language"
*/
          __Pyx_INCREF(__pyx_9genexpr11__pyx_v_k);
          __pyx_t_7 = __pyx_9genexpr11__pyx_v_k;
          __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_hash_id, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 640, __pyx_L146_error)
          if (__pyx_t_8) {
          } else {
            __pyx_t_25 = __pyx_t_8;
            goto __pyx_L150_bool_binop_done;
          }
          __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_embedding_id, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 640, __pyx_L146_error)
          if (__pyx_t_8) {
          } else {
            __pyx_t_25 = __pyx_t_8;
            goto __pyx_L150_bool_binop_done;
          }
          __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_vector, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 640, __pyx_L146_error)
          if (__pyx_t_8) {
          } else {
            __pyx_t_25 = __pyx_t_8;
            goto __pyx_L150_bool_binop_done;
          }
          __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_token_count, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 640, __pyx_L146_error)
          if (__pyx_t_8) {
          } else {
            __pyx_t_25 = __pyx_t_8;
            goto __pyx_L150_bool_binop_done;
          }
          __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_language, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 640, __pyx_L146_error)
          __pyx_t_25 = __pyx_t_8;
          __pyx_L150_bool_binop_done:;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_8 = __pyx_t_25;
          if (__pyx_t_8) {

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":639
 *             if final_score > 0.01:
 *                 summary_chunk = {
 *                     k: v for k, v in chunk.items()             # <<<<<<<<<<<<<<
 *                     if k not in (
 *                         "hash_id", "embedding_id", "vector",
*/
            if (unlikely(PyDict_SetItem(__pyx_t_2, (PyObject*)__pyx_9genexpr11__pyx_v_k, (PyObject*)__pyx_9genexpr11__pyx_v_v))) __PYX_ERR(0, 639, __pyx_L146_error)

            /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":640
 *                 summary_chunk = {
 *                     k: v for k, v in chunk.items()
 *                     if k not in (             # <<<<<<<<<<<<<<
 *                         "hash_id", "embedding_id", "vector",
 *                         "token_count", "language"
*/
          }
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_k); __pyx_9genexpr11__pyx_v_k = 0;
        __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v); __pyx_9genexpr11__pyx_v_v = 0;
        goto __pyx_L155_exit_scope;
        __pyx_L146_error:;
        __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_k); __pyx_9genexpr11__pyx_v_k = 0;
        __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v); __pyx_9genexpr11__pyx_v_v = 0;
        goto __pyx_L1_error;
        __pyx_L155_exit_scope:;
      } /* exit inner scope */
      __Pyx_XDECREF_SET(__pyx_v_summary_chunk, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":647
 * 
 *                 scored_chunks.append({
 *                     "file_path": file_path,             # <<<<<<<<<<<<<<
 *                     "chunk": summary_chunk,
 *                     "score": round(final_score, 3)
*/
      __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 647, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_file_path, __pyx_v_file_path) < (0)) __PYX_ERR(0, 647, __pyx_L1_error)

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":648
 *                 scored_chunks.append({
 *                     "file_path": file_path,
 *                     "chunk": summary_chunk,             # <<<<<<<<<<<<<<
 *                     "score": round(final_score, 3)
 *                 })
*/
      if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_chunk, __pyx_v_summary_chunk) < (0)) __PYX_ERR(0, 647, __pyx_L1_error)

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":649
 *                     "file_path": file_path,
 *                     "chunk": summary_chunk,
 *                     "score": round(final_score, 3)             # <<<<<<<<<<<<<<
 *                 })
 * 
*/
      __pyx_t_7 = NULL;
      __pyx_t_3 = 1;
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_final_score, __pyx_mstate_global->__pyx_int_3};
        __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_round, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 649, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_score, __pyx_t_10) < (0)) __PYX_ERR(0, 647, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":646
 *                 }
 * 
 *                 scored_chunks.append({             # <<<<<<<<<<<<<<
 *                     "file_path": file_path,
 *                     "chunk": summary_chunk,
*/
      __pyx_t_26 = __Pyx_PyList_Append(__pyx_v_scored_chunks, __pyx_t_2); if (unlikely(__pyx_t_26 == ((int)-1))) __PYX_ERR(0, 646, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":637
 * 
 *             # Minimum threshold
 *             if final_score > 0.01:             # <<<<<<<<<<<<<<
 *                 summary_chunk = {
 *                     k: v for k, v in chunk.items()
*/
    }

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":476
 *         scored_chunks: List[Dict[str, Any]] = []
 * 
 *         for chunk, file_path in chunk_to_ctx:             # <<<<<<<<<<<<<<
 *             # 1. Vector Score
 *             vec_score = 0.0
*/
  }
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":653
 * 
 *         # Sort and return
 *         scored_chunks.sort(key=lambda x: x["score"], reverse=True)             # <<<<<<<<<<<<<<
 *         return scored_chunks[:top_k]
 * 
*/
  __pyx_t_2 = __pyx_v_scored_chunks;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_26lambda8, 0, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se_3, NULL, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_key, __pyx_t_10, __pyx_t_7, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 653, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_reverse, Py_True, __pyx_t_7, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 653, __pyx_L1_error)
    __pyx_t_15 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_sort, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
  }
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":654
 *         # Sort and return
 *         scored_chunks.sort(key=lambda x: x["score"], reverse=True)
 *         return scored_chunks[:top_k]             # <<<<<<<<<<<<<<
 * 
 *     # =====================================================================
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_top_k);
  __pyx_t_36 = __pyx_v_top_k;
  __pyx_t_8 = (__pyx_t_36 == ((PyObject*)Py_None));
  if (__pyx_t_8) {
    __pyx_t_27 = PY_SSIZE_T_MAX;
  } else {
    __pyx_t_24 = __Pyx_PyIndex_AsSsize_t(__pyx_t_36); if (unlikely((__pyx_t_24 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 654, __pyx_L1_error)
    __pyx_t_27 = __pyx_t_24;
  }
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_15 = __Pyx_PyList_GetSlice(__pyx_v_scored_chunks, 0, __pyx_t_27); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_r = ((PyObject*)__pyx_t_15);
  __pyx_t_15 = 0;
  goto __pyx_L0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":368
 *     # =====================================================================
 * 
 *     def _hybrid_search_chunks(             # <<<<<<<<<<<<<<
 *         self,
 *         agent_id: str,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_36);
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._hybrid_search_chunks", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_intent);
  __Pyx_XDECREF(__pyx_v_query_vector);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_raw_tokens);
  __Pyx_XDECREF(__pyx_v_query_keywords);
  __Pyx_XDECREF(__pyx_v_w);
  __Pyx_XDECREF(__pyx_v_cleaned);
  __Pyx_XDECREF(__pyx_v_query_line_numbers);
  __Pyx_XDECREF(__pyx_v_route_patterns);
  __Pyx_XDECREF(__pyx_v_rt);
  __Pyx_XDECREF(__pyx_v_clean_rt);
  __Pyx_XDECREF(__pyx_v_segments);
  __Pyx_XDECREF(__pyx_v_contexts);
  __Pyx_XDECREF(__pyx_v_all_vectors);
  __Pyx_XDECREF(__pyx_v_all_chunks_flat);
  __Pyx_XDECREF(__pyx_v_chunk_to_ctx);
  __Pyx_XDECREF(__pyx_v_normalized_file_paths_filter);
  __Pyx_XDECREF(__pyx_v_ctx);
  __Pyx_XDECREF(__pyx_v_file_path);
  __Pyx_XDECREF(__pyx_v_normalized_filter);
  __Pyx_XDECREF(__pyx_v_path_lower);
  __Pyx_XDECREF(__pyx_v_chunk);
  __Pyx_XDECREF(__pyx_v_chunk_text_bag);
  __Pyx_XDECREF(__pyx_v_kw);
  __Pyx_XDECREF(__pyx_v_class_names);
  __Pyx_XDECREF(__pyx_v_scored_chunks);
  __Pyx_XDECREF(__pyx_v_vec_score);
  __Pyx_XDECREF(__pyx_v_hash_id);
  __Pyx_XDECREF(__pyx_v_chunk_vec);
  __Pyx_XDECREF(__pyx_v_dot);
  __Pyx_XDECREF(__pyx_v_mag_q);
  __Pyx_XDECREF(__pyx_v_mag_c);
  __Pyx_XDECREF(__pyx_v_kw_score);
  __Pyx_XDECREF(__pyx_v_chunk_kws);
  __Pyx_XDECREF(__pyx_v_chunk_name);
  __Pyx_XDECREF(__pyx_v_chunk_name_parts);
  __Pyx_XDECREF(__pyx_v_chunk_summary);
  __Pyx_XDECREF(__pyx_v_chunk_content);
  __Pyx_XDECREF(__pyx_v_chunk_type);
  __Pyx_XDECREF(__pyx_v_summary_words);
  __Pyx_XDECREF(__pyx_v_content_words);
  __Pyx_XDECREF(__pyx_v_overlap);
  __Pyx_XDECREF(__pyx_v_idf_sum);
  __Pyx_XDECREF(__pyx_v_idf_total);
  __Pyx_XDECREF(__pyx_v_expanded_only);
  __Pyx_XDECREF(__pyx_v_base_kw);
  __Pyx_XDECREF(__pyx_v_qkw);
  __Pyx_XDECREF(__pyx_v_summary_overlap);
  __Pyx_XDECREF(__pyx_v_content_hits);
  __Pyx_XDECREF(__pyx_v_rp);
  __Pyx_XDECREF(__pyx_v_type_query_words);
  __Pyx_XDECREF(__pyx_v_query_type_mentions);
  __Pyx_XDECREF(__pyx_v_qt);
  __Pyx_XDECREF(__pyx_v_query_lower);
  __Pyx_XDECREF(__pyx_v_q_words);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_bigram);
  __Pyx_XDECREF(__pyx_v_line_match_boost);
  __Pyx_XDECREF(__pyx_v_start_line);
  __Pyx_XDECREF(__pyx_v_end_line);
  __Pyx_XDECREF(__pyx_v_span);
  __Pyx_XDECREF(__pyx_v_ln);
  __Pyx_XDECREF(__pyx_v_tightness);
  __Pyx_XDECREF(__pyx_v_score);
  __Pyx_XDECREF(__pyx_v_final_score);
  __Pyx_XDECREF(__pyx_v_summary_chunk);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_seg);
  __Pyx_XDECREF(__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_4generator);
  __Pyx_XDECREF(__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_7generator1);
  __Pyx_XDECREF(__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_10generator2);
  __Pyx_XDECREF(__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_13generator3);
  __Pyx_XDECREF(__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_16generator4);
  __Pyx_XDECREF(__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_19generator5);
  __Pyx_XDECREF(__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_22generator6);
  __Pyx_XDECREF(__pyx_gb_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_21_hybrid_search_chunks_25generator7);
  __Pyx_XDECREF(__pyx_9genexpr10__pyx_v_w);
  __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_k);
  __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":660
 *     # =====================================================================
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _get_chunk_text_bag(chunk: Dict[str, Any]) -> Set[str]:
 *         """Build a set of all lowercase tokens in a chunk (keywords + summary + content + name)."""
*/

/* Python wrapper */
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_15_get_chunk_text_bag(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_14_get_chunk_text_bag, "CodingHybridRetriever._get_chunk_text_bag(dict chunk: Dict[str, Any]) -> Set[str]\n\nBuild a set of all lowercase tokens in a chunk (keywords + summary + content + name).");
static PyMethodDef __pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_15_get_chunk_text_bag = {"_get_chunk_text_bag", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_15_get_chunk_text_bag, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_14_get_chunk_text_bag};
static PyObject *__pyx_pw_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_15_get_chunk_text_bag(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_chunk = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_chunk_text_bag (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_chunk,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 660, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 660, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_get_chunk_text_bag", 0) < (0)) __PYX_ERR(0, 660, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_get_chunk_text_bag", 1, 1, 1, i); __PYX_ERR(0, 660, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 660, __pyx_L3_error)
    }
    __pyx_v_chunk = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_chunk_text_bag", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 660, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._get_chunk_text_bag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_chunk), (&PyDict_Type), 0, "chunk", 2))) __PYX_ERR(0, 661, __pyx_L1_error)
  __pyx_r = __pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_14_get_chunk_text_bag(__pyx_self, __pyx_v_chunk);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_14_get_chunk_text_bag(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_chunk) {
  PyObject *__pyx_v_bag = 0;
  PyObject *__pyx_v_kw = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_chunk_text_bag", 0);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":663
 *     def _get_chunk_text_bag(chunk: Dict[str, Any]) -> Set[str]:
 *         """Build a set of all lowercase tokens in a chunk (keywords + summary + content + name)."""
 *         bag: Set[str] = set()             # <<<<<<<<<<<<<<
 *         for kw in chunk.get("keywords", []):
 *             bag.add(kw.lower())
*/
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bag = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":664
 *         """Build a set of all lowercase tokens in a chunk (keywords + summary + content + name)."""
 *         bag: Set[str] = set()
 *         for kw in chunk.get("keywords", []):             # <<<<<<<<<<<<<<
 *             bag.add(kw.lower())
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("summary", "").lower()))
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_GetItemDefault(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_keywords, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 664, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 664, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_3;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 664, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3));
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3);
        #endif
        ++__pyx_t_3;
      }
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 664, __pyx_L1_error)
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 664, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_kw, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":665
 *         bag: Set[str] = set()
 *         for kw in chunk.get("keywords", []):
 *             bag.add(kw.lower())             # <<<<<<<<<<<<<<
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("summary", "").lower()))
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("content", "").lower()))
*/
    __pyx_t_5 = __pyx_v_kw;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 665, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_7 = PySet_Add(__pyx_v_bag, __pyx_t_2); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 665, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":664
 *         """Build a set of all lowercase tokens in a chunk (keywords + summary + content + name)."""
 *         bag: Set[str] = set()
 *         for kw in chunk.get("keywords", []):             # <<<<<<<<<<<<<<
 *             bag.add(kw.lower())
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("summary", "").lower()))
*/
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":666
 *         for kw in chunk.get("keywords", []):
 *             bag.add(kw.lower())
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("summary", "").lower()))             # <<<<<<<<<<<<<<
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("content", "").lower()))
 *         name = chunk.get("name", "").lower()
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_findall); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_10 = __Pyx_PyDict_GetItemDefault(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_summary, __pyx_mstate_global->__pyx_kp_u__2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_9 = __pyx_t_10;
  __Pyx_INCREF(__pyx_t_9);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_a_z0_9, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_8 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PySet_Type__update, __pyx_v_bag, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":667
 *             bag.add(kw.lower())
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("summary", "").lower()))
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("content", "").lower()))             # <<<<<<<<<<<<<<
 *         name = chunk.get("name", "").lower()
 *         if name:
*/
  __pyx_t_1 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_findall); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_9 = __Pyx_PyDict_GetItemDefault(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_content, __pyx_mstate_global->__pyx_kp_u__2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __pyx_t_9;
  __Pyx_INCREF(__pyx_t_10);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_a_z0_9, __pyx_t_5};
    __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
  }
  __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PySet_Type__update, __pyx_v_bag, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":668
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("summary", "").lower()))
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("content", "").lower()))
 *         name = chunk.get("name", "").lower()             # <<<<<<<<<<<<<<
 *         if name:
 *             bag.add(name)
*/
  __pyx_t_5 = __Pyx_PyDict_GetItemDefault(__pyx_v_chunk, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_kp_u__2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __pyx_t_5;
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 668, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v_name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":669
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("content", "").lower()))
 *         name = chunk.get("name", "").lower()
 *         if name:             # <<<<<<<<<<<<<<
 *             bag.add(name)
 *             bag.update(CodingHybridRetriever._decompose_compound(name))
*/
  __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_name); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 669, __pyx_L1_error)
  if (__pyx_t_11) {

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":670
 *         name = chunk.get("name", "").lower()
 *         if name:
 *             bag.add(name)             # <<<<<<<<<<<<<<
 *             bag.update(CodingHybridRetriever._decompose_compound(name))
 *         return bag
*/
    __pyx_t_7 = PySet_Add(__pyx_v_bag, __pyx_v_name); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 670, __pyx_L1_error)

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":671
 *         if name:
 *             bag.add(name)
 *             bag.update(CodingHybridRetriever._decompose_compound(name))             # <<<<<<<<<<<<<<
 *         return bag
*/
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_decompose_compound); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_name};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 671, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_1 = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PySet_Type__update, __pyx_v_bag, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":669
 *         bag.update(re.findall(r'[a-z0-9_]+', chunk.get("content", "").lower()))
 *         name = chunk.get("name", "").lower()
 *         if name:             # <<<<<<<<<<<<<<
 *             bag.add(name)
 *             bag.update(CodingHybridRetriever._decompose_compound(name))
*/
  }

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":672
 *             bag.add(name)
 *             bag.update(CodingHybridRetriever._decompose_compound(name))
 *         return bag             # <<<<<<<<<<<<<<
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_bag);
  __pyx_r = __pyx_v_bag;
  goto __pyx_L0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":660
 *     # =====================================================================
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _get_chunk_text_bag(chunk: Dict[str, Any]) -> Set[str]:
 *         """Build a set of all lowercase tokens in a chunk (keywords + summary + content + name)."""
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("manhattan_mcp.gitmem_coding.coding_hybrid_retriever.CodingHybridRetriever._get_chunk_text_bag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_bag);
  __Pyx_XDECREF(__pyx_v_kw);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */

static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks[--__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks(PyObject *o) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_doc_freq);
  Py_CLEAR(p->__pyx_v_idf);
  Py_CLEAR(p->__pyx_v_original_query_keywords);
  Py_CLEAR(p->__pyx_v_parent_class);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks))))
  {
    __pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks[__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks++] = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_doc_freq) {
    e = (*v)(p->__pyx_v_doc_freq, a); if (e) return e;
  }
  if (p->__pyx_v_idf) {
    e = (*v)(p->__pyx_v_idf, a); if (e) return e;
  }
  if (p->__pyx_v_original_query_keywords) {
    e = (*v)(p->__pyx_v_original_query_keywords, a); if (e) return e;
  }
  if (p->__pyx_v_parent_class) {
    e = (*v)(p->__pyx_v_parent_class, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks *)o;
  tmp = ((PyObject*)p->__pyx_v_doc_freq);
  p->__pyx_v_doc_freq = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_idf);
  p->__pyx_v_idf = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_original_query_keywords);
  p->__pyx_v_original_query_keywords = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_parent_class);
  p->__pyx_v_parent_class = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks},
  {Py_tp_clear, (void *)__pyx_tp_clear_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks},
  {Py_tp_new, (void *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks},
  {0, 0},
};
static PyType_Spec __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks_spec = {
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.__pyx_scope_struct___hybrid_search_chunks",
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks_slots,
};
#else

static PyTypeObject __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks = {
  PyVarObject_HEAD_INIT(0, 0)
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.""__pyx_scope_struct___hybrid_search_chunks", /*tp_name*/
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks, /*tp_traverse*/
  __pyx_tp_clear_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr[--__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr(PyObject *o) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_s);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr))))
  {
    __pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr[__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr++] = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_s) {
    e = (*v)(p->__pyx_v_s, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr_spec = {
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.__pyx_scope_struct_1_genexpr",
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.""__pyx_scope_struct_1_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr[--__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr(PyObject *o) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_fp);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr))))
  {
    __pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr[__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr++] = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_fp) {
    e = (*v)(p->__pyx_v_fp, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr_spec = {
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.__pyx_scope_struct_2_genexpr",
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.""__pyx_scope_struct_2_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr[--__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr(PyObject *o) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_a);
  Py_CLEAR(p->__pyx_v_b);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr))))
  {
    __pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr[__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr++] = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_a) {
    e = (*v)(p->__pyx_v_a, a); if (e) return e;
  }
  if (p->__pyx_v_b) {
    e = (*v)(p->__pyx_v_b, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr_spec = {
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.__pyx_scope_struct_3_genexpr",
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.""__pyx_scope_struct_3_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr[--__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr(PyObject *o) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_a);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr))))
  {
    __pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr[__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr++] = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_a) {
    e = (*v)(p->__pyx_v_a, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr_spec = {
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.__pyx_scope_struct_4_genexpr",
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.""__pyx_scope_struct_4_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr[--__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr(PyObject *o) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_b);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr))))
  {
    __pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr[__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr++] = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_b) {
    e = (*v)(p->__pyx_v_b, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr_spec = {
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.__pyx_scope_struct_5_genexpr",
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.""__pyx_scope_struct_5_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr[--__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr(PyObject *o) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_t);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr))))
  {
    __pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr[__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr++] = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_t) {
    e = (*v)(p->__pyx_v_t, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr_spec = {
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.__pyx_scope_struct_6_genexpr",
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.""__pyx_scope_struct_6_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr[--__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr(PyObject *o) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_t);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr))))
  {
    __pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr[__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr++] = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_t) {
    e = (*v)(p->__pyx_v_t, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr_spec = {
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.__pyx_scope_struct_7_genexpr",
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.""__pyx_scope_struct_7_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr[--__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr(PyObject *o) {
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_qkw);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr, sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr))))
  {
    __pyx_mstate_global->__pyx_freelist_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr[__pyx_mstate_global->__pyx_freecount_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr++] = ((struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *p = (struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_qkw) {
    e = (*v)(p->__pyx_v_qkw, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr_spec = {
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.__pyx_scope_struct_8_genexpr",
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "manhattan_mcp.gitmem_coding.coding_hybrid_retriever.""__pyx_scope_struct_8_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks)) __PYX_ERR(0, 368, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks_spec, __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks = &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks->tp_dictoffset && __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct___hybrid_search_chunks->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr)) __PYX_ERR(0, 420, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr_spec, __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr) < (0)) __PYX_ERR(0, 420, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr = &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr) < (0)) __PYX_ERR(0, 420, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr->tp_dictoffset && __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_1_genexpr->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr)) __PYX_ERR(0, 430, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr_spec, __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr) < (0)) __PYX_ERR(0, 430, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr = &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr) < (0)) __PYX_ERR(0, 430, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr->tp_dictoffset && __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_2_genexpr->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr)) __PYX_ERR(0, 484, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr_spec, __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr) < (0)) __PYX_ERR(0, 484, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr = &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr) < (0)) __PYX_ERR(0, 484, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr->tp_dictoffset && __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_3_genexpr->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr)) __PYX_ERR(0, 487, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr_spec, __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr) < (0)) __PYX_ERR(0, 487, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr = &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr) < (0)) __PYX_ERR(0, 487, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr->tp_dictoffset && __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_4_genexpr->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr)) __PYX_ERR(0, 488, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr_spec, __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr) < (0)) __PYX_ERR(0, 488, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr = &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr) < (0)) __PYX_ERR(0, 488, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr->tp_dictoffset && __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_5_genexpr->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr)) __PYX_ERR(0, 517, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr_spec, __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr) < (0)) __PYX_ERR(0, 517, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr = &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr) < (0)) __PYX_ERR(0, 517, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr->tp_dictoffset && __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_6_genexpr->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr)) __PYX_ERR(0, 518, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr_spec, __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr) < (0)) __PYX_ERR(0, 518, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr = &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr) < (0)) __PYX_ERR(0, 518, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr->tp_dictoffset && __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_7_genexpr->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr)) __PYX_ERR(0, 575, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr_spec, __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr) < (0)) __PYX_ERR(0, 575, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr = &__pyx_type_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr) < (0)) __PYX_ERR(0, 575, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr->tp_dictoffset && __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever___pyx_scope_struct_8_genexpr->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_coding_hybrid_retriever(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_coding_hybrid_retriever},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "coding_hybrid_retriever",
      __pyx_k_Coding_Hybrid_Retriever_v2_Opti, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit_coding_hybrid_retriever(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_coding_hybrid_retriever(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#if CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
static PY_INT64_T __Pyx_GetCurrentInterpreterId(void) {
    {
        PyObject *module = PyImport_ImportModule("_interpreters"); // 3.13+ I think
        if (!module) {
            PyErr_Clear(); // just try the 3.8-3.12 version
            module = PyImport_ImportModule("_xxsubinterpreters");
            if (!module) goto bad;
        }
        PyObject *current = PyObject_CallMethod(module, "get_current", NULL);
        Py_DECREF(module);
        if (!current) goto bad;
        if (PyTuple_Check(current)) {
            PyObject *new_current = PySequence_GetItem(current, 0);
            Py_DECREF(current);
            current = new_current;
            if (!new_current) goto bad;
        }
        long long as_c_int = PyLong_AsLongLong(current);
        Py_DECREF(current);
        return as_c_int;
    }
  bad:
    PySys_WriteStderr("__Pyx_GetCurrentInterpreterId failed. Try setting the C define CYTHON_PEP489_MULTI_PHASE_INIT=0\n");
    return -1;
}
#endif
#if !CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    static PY_INT64_T main_interpreter_id = -1;
#if CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
    PY_INT64_T current_id = GraalPyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_GRAAL
    PY_INT64_T current_id = PyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
    PY_INT64_T current_id = __Pyx_GetCurrentInterpreterId();
#elif CYTHON_COMPILING_IN_LIMITED_API
    PY_INT64_T current_id = PyInterpreterState_GetID(PyInterpreterState_Get());
#else
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
#endif
    if (unlikely(current_id == -1)) {
        return -1;
    }
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return 0;
    } else if (unlikely(main_interpreter_id != current_id)) {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#endif
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    #if !CYTHON_USE_MODULE_STATE
    if (__Pyx_check_single_interpreter())
        return NULL;
    #endif
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_coding_hybrid_retriever(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'coding_hybrid_retriever' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "coding_hybrid_retriever" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit_coding_hybrid_retriever", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_manhattan_mcp__gitmem_coding__coding_hybrid_retriever) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "manhattan_mcp.gitmem_coding.coding_hybrid_retriever")) {
      if (unlikely((PyDict_SetItemString(modules, "manhattan_mcp.gitmem_coding.coding_hybrid_retriever", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_export_code(__pyx_mstate);
  (void)__Pyx_modinit_function_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_import_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_import_code(__pyx_mstate);
  (void)__Pyx_modinit_function_import_code(__pyx_mstate);
  /*--- Execution code ---*/

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":16
 * Loads vectors from the dedicated CodingVectorStore (vectors.json).
 * """
 * from typing import List, Dict, Any, Optional, Set, Tuple             # <<<<<<<<<<<<<<
 * import os
 * import re
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_List,__pyx_mstate_global->__pyx_n_u_Dict,__pyx_mstate_global->__pyx_n_u_Any,__pyx_mstate_global->__pyx_n_u_Optional,__pyx_mstate_global->__pyx_n_u_Set,__pyx_mstate_global->__pyx_n_u_Tuple};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_typing, __pyx_imported_names, 6, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_List,__pyx_mstate_global->__pyx_n_u_Dict,__pyx_mstate_global->__pyx_n_u_Any,__pyx_mstate_global->__pyx_n_u_Optional,__pyx_mstate_global->__pyx_n_u_Set,__pyx_mstate_global->__pyx_n_u_Tuple};
    for (__pyx_t_3=0; __pyx_t_3 < 6; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 16, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":17
 * """
 * from typing import List, Dict, Any, Optional, Set, Tuple
 * import os             # <<<<<<<<<<<<<<
 * import re
 * import json
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_os, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_os, __pyx_t_2) < (0)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":18
 * from typing import List, Dict, Any, Optional, Set, Tuple
 * import os
 * import re             # <<<<<<<<<<<<<<
 * import json
 * import math
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_re, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 18, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_re, __pyx_t_2) < (0)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":19
 * import os
 * import re
 * import json             # <<<<<<<<<<<<<<
 * import math
 * import string
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_json_2, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_json_2, __pyx_t_2) < (0)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":20
 * import re
 * import json
 * import math             # <<<<<<<<<<<<<<
 * import string
 * from collections import Counter
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_math, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_math, __pyx_t_2) < (0)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":21
 * import json
 * import math
 * import string             # <<<<<<<<<<<<<<
 * from collections import Counter
 * from ..gitmem.embedding import RemoteEmbeddingClient
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_string, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_string, __pyx_t_2) < (0)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":22
 * import math
 * import string
 * from collections import Counter             # <<<<<<<<<<<<<<
 * from ..gitmem.embedding import RemoteEmbeddingClient
 * from .coding_store import CodingContextStore
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Counter};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_collections, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 22, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Counter};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 22, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 22, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":23
 * import string
 * from collections import Counter
 * from ..gitmem.embedding import RemoteEmbeddingClient             # <<<<<<<<<<<<<<
 * from .coding_store import CodingContextStore
 * from .coding_vector_store import CodingVectorStore
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_RemoteEmbeddingClient};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_gitmem_embedding, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_manhattan_mcp_gitmem_embedding, 2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 23, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_RemoteEmbeddingClient};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 23, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":24
 * from collections import Counter
 * from ..gitmem.embedding import RemoteEmbeddingClient
 * from .coding_store import CodingContextStore             # <<<<<<<<<<<<<<
 * from .coding_vector_store import CodingVectorStore
 * from .ast_skeleton import retrieve_path
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_CodingContextStore};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_coding_store, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_manhattan_mcp_gitmem_coding_codi_2, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 24, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_CodingContextStore};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 24, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 24, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":25
 * from ..gitmem.embedding import RemoteEmbeddingClient
 * from .coding_store import CodingContextStore
 * from .coding_vector_store import CodingVectorStore             # <<<<<<<<<<<<<<
 * from .ast_skeleton import retrieve_path
 * import logging
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_CodingVectorStore};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_coding_vector_store, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_manhattan_mcp_gitmem_coding_codi_3, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 25, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_CodingVectorStore};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 25, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 25, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":26
 * from .coding_store import CodingContextStore
 * from .coding_vector_store import CodingVectorStore
 * from .ast_skeleton import retrieve_path             # <<<<<<<<<<<<<<
 * import logging
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_retrieve_path};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_ast_skeleton, __pyx_imported_names, 1, __pyx_mstate_global->__pyx_kp_u_manhattan_mcp_gitmem_coding_ast, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 26, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_retrieve_path};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 26, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 26, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":27
 * from .coding_vector_store import CodingVectorStore
 * from .ast_skeleton import retrieve_path
 * import logging             # <<<<<<<<<<<<<<
 * 
 * logger = logging.getLogger(__name__)
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_logging, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 27, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_logging, __pyx_t_2) < (0)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":29
 * import logging
 * 
 * logger = logging.getLogger(__name__)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_logging); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_getLogger); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 29, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_logger, __pyx_t_2) < (0)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":35
 * 
 * _STOP_WORDS: Set[str] = {
 *     "is", "the", "a", "an", "and", "or", "in", "on", "with",             # <<<<<<<<<<<<<<
 *     "how", "what", "where", "to", "for", "of", "can", "you",
 *     "explain", "from", "pull", "context", "only", "which",
*/
  __pyx_t_2 = PySet_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_is) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_the) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_a) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_an) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_and) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_or) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_in) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_on) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_with) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_how) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_what) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_where) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_to) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_for) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_of) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_can) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_you) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_explain) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_from) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_pull) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_context) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_only) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_which) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_does) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_do) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_that) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_this) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_it) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_but) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_not) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_at) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_by) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_are) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_be) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_been) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_has) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_have) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_was) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_were) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_show) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_me) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_all) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_about) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_tell) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_describe) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_give) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_find) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_list) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_get) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_there) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_when) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_if) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_then) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_so) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_also) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_my) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_i) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_we) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_us) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_our) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_your) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_its) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_any) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_some) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_each) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_every) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_just) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_need) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_want) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_like) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_use) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_used) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_using) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_would) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_could) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_should) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_will) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_shall) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_may) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_might) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_must) < (0)) __PYX_ERR(0, 35, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_STOP_WORDS, __pyx_t_2) < (0)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":50
 * # Broad-intent signals: queries containing these words ask for multiple results
 * _BROAD_INTENT_SIGNALS = {
 *     "all", "every", "list", "show", "related", "overview",             # <<<<<<<<<<<<<<
 *     "relevant", "associated", "connected", "involved",
 * }
*/
  __pyx_t_2 = PySet_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_all) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_every) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_list) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_show) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_related) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_overview) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_relevant) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_associated) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_connected) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_involved) < (0)) __PYX_ERR(0, 50, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_BROAD_INTENT_SIGNALS, __pyx_t_2) < (0)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":55
 * 
 * 
 * class CodingHybridRetriever:             # <<<<<<<<<<<<<<
 *     """
 *     Centralized retrieval logic for coding contexts.
*/
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_mstate_global->__pyx_empty_tuple, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever, (PyObject *) NULL, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_kp_u_Centralized_retrieval_logic_for); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_CONCEPT_MAP, __pyx_mstate_global->__pyx_kp_u_Dict_str_Set_str) < (0)) __PYX_ERR(0, 55, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_SYNONYM_MAP, __pyx_mstate_global->__pyx_kp_u_Dict_str_Set_str) < (0)) __PYX_ERR(0, 55, __pyx_L1_error)
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_annotations, __pyx_t_6) < (0)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":61
 *     """
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         store: CodingContextStore,
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_store, __pyx_mstate_global->__pyx_n_u_CodingContextStore) < (0)) __PYX_ERR(0, 61, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_vector_store, __pyx_mstate_global->__pyx_n_u_CodingVectorStore) < (0)) __PYX_ERR(0, 61, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_embedding_client, __pyx_mstate_global->__pyx_kp_u_Optional_RemoteEmbeddingClient) < (0)) __PYX_ERR(0, 61, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_1__init__, 0, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever___init, NULL, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_mstate_global->__pyx_tuple[7]);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_init, __pyx_t_5) < (0)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":76
 *     CONCEPT_MAP: Dict[str, Set[str]] = {
 *         # Security
 *         "security": {             # <<<<<<<<<<<<<<
 *             "hash", "sha256", "token", "authentication", "password", "secret",
 *             "login", "secure", "permissions", "credentials", "hashed_key",
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(25); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_hash) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_sha256) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_token) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_authentication) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_password) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_secret) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_login) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_secure) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_permissions) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_credentials) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_hashed_key) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_bcrypt) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_jwt) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rate_limit) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_throttle) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_validation) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_oauth) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_encrypt) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_decrypt) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ssl) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_tls) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_certificate) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_verify) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_authorize) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_authorisation) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_authorization) < (0)) __PYX_ERR(0, 77, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_security, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_login) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_authentication) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_password) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_token) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_session) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_oauth) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_credentials) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_sign_in_with_password) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_jwt) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_bcrypt) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_verify) < (0)) __PYX_ERR(0, 84, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_auth, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_login) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_password) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_oauth) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_token) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_session) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_credentials) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_sign_in_with_password) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_flask_login) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_jwt) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_bcrypt) < (0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_authentication, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_oauth) < (0)) __PYX_ERR(0, 92, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_permissions) < (0)) __PYX_ERR(0, 92, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_token) < (0)) __PYX_ERR(0, 92, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rls) < (0)) __PYX_ERR(0, 92, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_role) < (0)) __PYX_ERR(0, 92, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_login_required) < (0)) __PYX_ERR(0, 92, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_authorization, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_flask) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_gevent) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_socketio) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_server) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_render) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_daemon) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_blueprint) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_initialization) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_monkey_patch) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_keep_alive) < (0)) __PYX_ERR(0, 97, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_infrastructure, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_render) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_daemon) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ping) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_keep_alive) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_server) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_health) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_timer) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_background) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_thread) < (0)) __PYX_ERR(0, 101, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_devops, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_render) < (0)) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_server) < (0)) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_keep_alive) < (0)) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_daemon) < (0)) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_health) < (0)) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ping) < (0)) __PYX_ERR(0, 105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_deployment, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_supabase) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_table) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_query) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_insert) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_upsert) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_select) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rls) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_profiles) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_client) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_migration) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_schema) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_sql_2) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_engine) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rollback) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_sqlalchemy) < (0)) __PYX_ERR(0, 110, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_database, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_supabase) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_database) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_table) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_insert) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_store) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_save) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_json_2) < (0)) __PYX_ERR(0, 115, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_persistence, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_supabase) < (0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_database) < (0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_json_2) < (0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_file) < (0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_upload) < (0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_save) < (0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_memory) < (0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rag) < (0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_cache) < (0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_redis) < (0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_storage, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_migration) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_table) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_column) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_alter) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_create) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_drop) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rollback) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_version_control) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_up_sql) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_down_sql) < (0)) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_schema, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_memoize) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_memoization) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ttl) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_decorator) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_redis) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_lru) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_caching) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_in_memory) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_performance) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_cache_result) < (0)) __PYX_ERR(0, 128, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_cache, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_cache) < (0)) __PYX_ERR(0, 132, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_memoize) < (0)) __PYX_ERR(0, 132, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ttl) < (0)) __PYX_ERR(0, 132, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_optimize) < (0)) __PYX_ERR(0, 132, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_speed) < (0)) __PYX_ERR(0, 132, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_latency) < (0)) __PYX_ERR(0, 132, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_profiling) < (0)) __PYX_ERR(0, 132, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_benchmark) < (0)) __PYX_ERR(0, 132, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_async) < (0)) __PYX_ERR(0, 132, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_concurrent) < (0)) __PYX_ERR(0, 132, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_performance, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_cache) < (0)) __PYX_ERR(0, 136, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_memoize) < (0)) __PYX_ERR(0, 136, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_decorator) < (0)) __PYX_ERR(0, 136, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ttl) < (0)) __PYX_ERR(0, 136, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_lru) < (0)) __PYX_ERR(0, 136, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_caching) < (0)) __PYX_ERR(0, 136, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_cache_result) < (0)) __PYX_ERR(0, 136, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_performance) < (0)) __PYX_ERR(0, 136, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_in_memory) < (0)) __PYX_ERR(0, 136, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_memoization, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_register) < (0)) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_signup) < (0)) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_login) < (0)) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_profile) < (0)) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_dashboard) < (0)) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_welcome) < (0)) __PYX_ERR(0, 142, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_onboarding, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_user) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_page) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_template) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_render) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_form) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_dashboard) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_explore) < (0)) __PYX_ERR(0, 145, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_experience, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_validate) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_regex) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_email) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_password) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_check) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_form) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_username_unique) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_whitelist) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_extension_validation) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_pattern) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_format) < (0)) __PYX_ERR(0, 150, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_validation, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_strip) < (0)) __PYX_ERR(0, 155, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_lower) < (0)) __PYX_ERR(0, 155, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_clean) < (0)) __PYX_ERR(0, 155, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_validate) < (0)) __PYX_ERR(0, 155, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_escape) < (0)) __PYX_ERR(0, 155, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_html_escape) < (0)) __PYX_ERR(0, 155, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_regex) < (0)) __PYX_ERR(0, 155, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_sanitization, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_endpoint) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_route) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_json_2) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_post) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_get) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_request) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_response) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_api_key) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rest) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rate_limit) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_throttle) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_middleware) < (0)) __PYX_ERR(0, 161, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_api, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_endpoint) < (0)) __PYX_ERR(0, 165, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_route) < (0)) __PYX_ERR(0, 165, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_json_2) < (0)) __PYX_ERR(0, 165, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_post) < (0)) __PYX_ERR(0, 165, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_get) < (0)) __PYX_ERR(0, 165, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_request) < (0)) __PYX_ERR(0, 165, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_response) < (0)) __PYX_ERR(0, 165, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_rest, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_jsonify) < (0)) __PYX_ERR(0, 168, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_json_2) < (0)) __PYX_ERR(0, 168, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_response) < (0)) __PYX_ERR(0, 168, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_api) < (0)) __PYX_ERR(0, 168, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_parse) < (0)) __PYX_ERR(0, 168, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_data) < (0)) __PYX_ERR(0, 168, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_json_2, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return) < (0)) __PYX_ERR(0, 171, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_jsonify) < (0)) __PYX_ERR(0, 171, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_render_template) < (0)) __PYX_ERR(0, 171, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_redirect) < (0)) __PYX_ERR(0, 171, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_flash) < (0)) __PYX_ERR(0, 171, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_response, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_redirect) < (0)) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_url_for) < (0)) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_flash) < (0)) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_agent_detail) < (0)) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_login_google) < (0)) __PYX_ERR(0, 174, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_redirect, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_throttle) < (0)) __PYX_ERR(0, 179, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ratelimiter) < (0)) __PYX_ERR(0, 179, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_redis) < (0)) __PYX_ERR(0, 179, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_middleware) < (0)) __PYX_ERR(0, 179, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_sliding_window) < (0)) __PYX_ERR(0, 179, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_max_requests) < (0)) __PYX_ERR(0, 179, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_client_ip) < (0)) __PYX_ERR(0, 179, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_api) < (0)) __PYX_ERR(0, 179, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_rate_limit, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rate_limit) < (0)) __PYX_ERR(0, 183, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ratelimiter) < (0)) __PYX_ERR(0, 183, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_redis) < (0)) __PYX_ERR(0, 183, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_middleware) < (0)) __PYX_ERR(0, 183, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_api) < (0)) __PYX_ERR(0, 183, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_throttle, __pyx_t_6) < (0)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_CONCEPT_MAP, __pyx_t_5) < (0)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":189
 *     # Synonym pairs: if query contains left word, also consider right words
 *     SYNONYM_MAP: Dict[str, Set[str]] = {
 *         "forget": {"reset", "forgot", "recover", "lost"},             # <<<<<<<<<<<<<<
 *         "forgot": {"reset", "forget", "recover", "lost"},
 *         "protect": {"security", "rate_limit", "throttle", "guard", "defend"},
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(17); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_reset) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_forgot) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_recover) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_lost) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_forget, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_reset) < (0)) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_forget) < (0)) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_recover) < (0)) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_lost) < (0)) __PYX_ERR(0, 190, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_forgot, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_security) < (0)) __PYX_ERR(0, 191, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rate_limit) < (0)) __PYX_ERR(0, 191, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_throttle) < (0)) __PYX_ERR(0, 191, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_guard) < (0)) __PYX_ERR(0, 191, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_defend) < (0)) __PYX_ERR(0, 191, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_protect, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rate_limit) < (0)) __PYX_ERR(0, 192, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_throttle) < (0)) __PYX_ERR(0, 192, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ddos) < (0)) __PYX_ERR(0, 192, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_overload) < (0)) __PYX_ERR(0, 192, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_flood) < (0)) __PYX_ERR(0, 192, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_overwhelm, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_expiry) < (0)) __PYX_ERR(0, 193, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ttl) < (0)) __PYX_ERR(0, 193, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_refresh) < (0)) __PYX_ERR(0, 193, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_timeout) < (0)) __PYX_ERR(0, 193, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_renew) < (0)) __PYX_ERR(0, 193, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_expire, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_expiry) < (0)) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ttl) < (0)) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_refresh) < (0)) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_timeout) < (0)) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_renew) < (0)) __PYX_ERR(0, 194, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_expires, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_refresh) < (0)) __PYX_ERR(0, 195, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_expiry) < (0)) __PYX_ERR(0, 195, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_extend) < (0)) __PYX_ERR(0, 195, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_token) < (0)) __PYX_ERR(0, 195, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_renew, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_migration) < (0)) __PYX_ERR(0, 196, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_version_control) < (0)) __PYX_ERR(0, 196, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rollback) < (0)) __PYX_ERR(0, 196, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_schema) < (0)) __PYX_ERR(0, 196, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_version, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_migration) < (0)) __PYX_ERR(0, 197, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_version_control) < (0)) __PYX_ERR(0, 197, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_rollback) < (0)) __PYX_ERR(0, 197, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_schema) < (0)) __PYX_ERR(0, 197, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_versioned, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_cache) < (0)) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_caching) < (0)) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_memoization) < (0)) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_decorator) < (0)) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_ttl) < (0)) __PYX_ERR(0, 198, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_memoize, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_performance) < (0)) __PYX_ERR(0, 199, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_cache) < (0)) __PYX_ERR(0, 199, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_speed) < (0)) __PYX_ERR(0, 199, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_efficient) < (0)) __PYX_ERR(0, 199, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_optimize, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_manager) < (0)) __PYX_ERR(0, 200, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_handler) < (0)) __PYX_ERR(0, 200, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_controller) < (0)) __PYX_ERR(0, 200, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_orchestrator) < (0)) __PYX_ERR(0, 200, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_manage, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_manager) < (0)) __PYX_ERR(0, 201, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_handler) < (0)) __PYX_ERR(0, 201, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_controller) < (0)) __PYX_ERR(0, 201, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_orchestrator) < (0)) __PYX_ERR(0, 201, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_managed, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_query) < (0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_insert) < (0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_update) < (0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_delete) < (0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_call) < (0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_invoke) < (0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_interact, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_update) < (0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_modify) < (0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_alter) < (0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_migration) < (0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_edit) < (0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_change, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_update) < (0)) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_modify) < (0)) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_alter) < (0)) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_migration) < (0)) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_edit) < (0)) __PYX_ERR(0, 204, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_changes, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_performance) < (0)) __PYX_ERR(0, 205, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_cache) < (0)) __PYX_ERR(0, 205, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_optimize) < (0)) __PYX_ERR(0, 205, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_slow) < (0)) __PYX_ERR(0, 205, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_heavy) < (0)) __PYX_ERR(0, 205, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_expensive, __pyx_t_6) < (0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_SYNONYM_MAP, __pyx_t_5) < (0)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":217
 *         query: str,
 *         top_k: int = 5,
 *         hybrid_alpha: float = 0.55,             # <<<<<<<<<<<<<<
 *         file_paths_filter: List[str] = None,
 *     ) -> Dict[str, Any]:
*/
  __pyx_t_5 = PyFloat_FromDouble(((double)0.55)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":212
 *     # =====================================================================
 * 
 *     def search(             # <<<<<<<<<<<<<<
 *         self,
 *         agent_id: str,
*/
  __pyx_t_6 = PyTuple_Pack(3, ((PyObject*)__pyx_mstate_global->__pyx_int_5), __pyx_t_5, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_agent_id, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_query, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_top_k, __pyx_mstate_global->__pyx_n_u_int) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_hybrid_alpha, __pyx_mstate_global->__pyx_n_u_float) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_file_paths_filter, __pyx_mstate_global->__pyx_kp_u_List_str) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Dict_str_Any) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_3search, 0, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever_search, NULL, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_search, __pyx_t_4) < (0)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":285
 *     # =====================================================================
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _decompose_compound(token: str) -> Set[str]:
 *         """
*/
  __pyx_t_5 = NULL;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_token, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 285, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Set_str) < (0)) __PYX_ERR(0, 285, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_5_decompose_compound, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__decompose, NULL, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_8};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_decompose_compound, __pyx_t_4) < (0)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":315
 *         return parts
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _extract_line_numbers(query: str) -> List[int]:
 *         """Extract line numbers from query like 'line 447' or 'at line 100'."""
*/
  __pyx_t_8 = NULL;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_query, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 315, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_List_int) < (0)) __PYX_ERR(0, 315, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_7_extract_line_numbers, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__extract_l, NULL, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[13])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_extract_line_numbers, __pyx_t_4) < (0)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":331
 *     # =====================================================================
 * 
 *     def _expand_concepts(self, keywords: Set[str]) -> Set[str]:             # <<<<<<<<<<<<<<
 *         """Expand abstract concept keywords into concrete searchable terms."""
 *         expanded = set(keywords)
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_keywords, __pyx_mstate_global->__pyx_kp_u_Set_str) < (0)) __PYX_ERR(0, 331, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Set_str) < (0)) __PYX_ERR(0, 331, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_9_expand_concepts, 0, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__expand_co, NULL, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[14])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_expand_concepts, __pyx_t_6) < (0)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":345
 *     # =====================================================================
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _detect_query_intent(query: str) -> str:
 *         """
*/
  __pyx_t_4 = NULL;
  __pyx_t_8 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_query, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 345, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 345, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_11_detect_query_intent, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__detect_qu, NULL, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[15])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_8);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 345, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_detect_query_intent, __pyx_t_6) < (0)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":376
 *         file_filter: str = None,
 *         route_tokens: List[str] = None,
 *         is_broad: bool = False,             # <<<<<<<<<<<<<<
 *         file_paths_filter: List[str] = None,
 *     ) -> List[Dict[str, Any]]:
*/
  __pyx_t_6 = __Pyx_PyBool_FromLong(((int)0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":368
 *     # =====================================================================
 * 
 *     def _hybrid_search_chunks(             # <<<<<<<<<<<<<<
 *         self,
 *         agent_id: str,
*/
  __pyx_t_5 = PyTuple_Pack(4, Py_None, Py_None, __pyx_t_6, Py_None); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_agent_id, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_query, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_top_k, __pyx_mstate_global->__pyx_n_u_int) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_alpha, __pyx_mstate_global->__pyx_n_u_float) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_file_filter, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_route_tokens, __pyx_mstate_global->__pyx_kp_u_List_str) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_is_broad, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_file_paths_filter, __pyx_mstate_global->__pyx_kp_u_List_str) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_List_Dict_str_Any) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_13_hybrid_search_chunks, 0, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__hybrid_se_4, NULL, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[16])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_hybrid_search_chunks, __pyx_t_4) < (0)) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":660
 *     # =====================================================================
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _get_chunk_text_bag(chunk: Dict[str, Any]) -> Set[str]:
 *         """Build a set of all lowercase tokens in a chunk (keywords + summary + content + name)."""
*/
  __pyx_t_6 = NULL;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_chunk, __pyx_mstate_global->__pyx_kp_u_Dict_str_Any) < (0)) __PYX_ERR(0, 660, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Set_str) < (0)) __PYX_ERR(0, 660, __pyx_L1_error)
  __pyx_t_8 = __Pyx_CyFunction_New(&__pyx_mdef_13manhattan_mcp_13gitmem_coding_23coding_hybrid_retriever_21CodingHybridRetriever_15_get_chunk_text_bag, __Pyx_CYFUNCTION_STATICMETHOD, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever__get_chunk, NULL, __pyx_mstate_global->__pyx_n_u_manhattan_mcp_gitmem_coding_codi, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[17])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_8);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_8, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_get_chunk_text_bag, __pyx_t_4) < (0)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":55
 * 
 * 
 * class CodingHybridRetriever:             # <<<<<<<<<<<<<<
 *     """
 *     Centralized retrieval logic for coding contexts.
*/
  __pyx_t_4 = __Pyx_Py3ClassCreate(((PyObject*)&PyType_Type), __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever, __pyx_mstate_global->__pyx_empty_tuple, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_CodingHybridRetriever, __pyx_t_4) < (0)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":1
 * """             # <<<<<<<<<<<<<<
 * Coding Hybrid Retriever  v2 (Optimized for Q&A about code)
 * 
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_2) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init manhattan_mcp.gitmem_coding.coding_hybrid_retriever", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init manhattan_mcp.gitmem_coding.coding_hybrid_retriever");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_staticmethod = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_staticmethod); if (!__pyx_builtin_staticmethod) __PYX_ERR(0, 285, __pyx_L1_error)
  __pyx_builtin_sum = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_sum); if (!__pyx_builtin_sum) __PYX_ERR(0, 484, __pyx_L1_error)
  __pyx_builtin_round = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_round); if (!__pyx_builtin_round) __PYX_ERR(0, 649, __pyx_L1_error)
  __pyx_builtin_zip = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_zip); if (!__pyx_builtin_zip) __PYX_ERR(0, 484, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.method_name = &__pyx_mstate->__pyx_n_u_get;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  __pyx_mstate->__pyx_umethod_PyList_Type__tolist.type = (PyObject*)(&PyList_Type);
  __pyx_mstate->__pyx_umethod_PyList_Type__tolist.method_name = &__pyx_mstate->__pyx_n_u_tolist;
  __pyx_mstate->__pyx_umethod_PySet_Type__update.type = (PyObject*)(&PySet_Type);
  __pyx_mstate->__pyx_umethod_PySet_Type__update.method_name = &__pyx_mstate->__pyx_n_u_update;
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__lower.type = (PyObject*)(&PyUnicode_Type);
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__lower.method_name = &__pyx_mstate->__pyx_n_u_lower;
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__lstrip.type = (PyObject*)(&PyUnicode_Type);
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__lstrip.method_name = &__pyx_mstate->__pyx_n_u_lstrip;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":433
 * 
 *         for ctx in contexts:
 *             file_path = ctx.get("file_path", "")             # <<<<<<<<<<<<<<
 * 
 *             # Apply file_paths_filter if provided
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_file_path, __pyx_mstate_global->__pyx_kp_u__2); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":469
 *         class_names: Set[str] = set()
 *         for chunk in all_chunks_flat:
 *             if chunk.get("type", "").lower() in ("class",):             # <<<<<<<<<<<<<<
 *                 class_names.add(chunk.get("name", "").lower())
 * 
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_type, __pyx_mstate_global->__pyx_kp_u__2); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":470
 *         for chunk in all_chunks_flat:
 *             if chunk.get("type", "").lower() in ("class",):
 *                 class_names.add(chunk.get("name", "").lower())             # <<<<<<<<<<<<<<
 * 
 *         #  D. Score each chunk
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_name, __pyx_mstate_global->__pyx_kp_u__2); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":503
 *             chunk_name = chunk.get("name", "").lower()
 *             chunk_name_parts = self._decompose_compound(chunk_name)
 *             chunk_summary = chunk.get("summary", "").lower()             # <<<<<<<<<<<<<<
 *             chunk_content = chunk.get("content", "").lower()
 *             chunk_type = chunk.get("type", "").lower()
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_summary, __pyx_mstate_global->__pyx_kp_u__2); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":504
 *             chunk_name_parts = self._decompose_compound(chunk_name)
 *             chunk_summary = chunk.get("summary", "").lower()
 *             chunk_content = chunk.get("content", "").lower()             # <<<<<<<<<<<<<<
 *             chunk_type = chunk.get("type", "").lower()
 * 
*/
  __pyx_mstate_global->__pyx_tuple[4] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_content, __pyx_mstate_global->__pyx_kp_u__2); if (unlikely(!__pyx_mstate_global->__pyx_tuple[4])) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[4]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[4]);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":605
 *             line_match_boost = 0.0
 *             if query_line_numbers:
 *                 start_line = chunk.get("start_line", 0)             # <<<<<<<<<<<<<<
 *                 end_line = chunk.get("end_line", 0)
 *                 if start_line or end_line:
*/
  __pyx_mstate_global->__pyx_tuple[5] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_start_line, __pyx_mstate_global->__pyx_int_0); if (unlikely(!__pyx_mstate_global->__pyx_tuple[5])) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[5]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[5]);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":606
 *             if query_line_numbers:
 *                 start_line = chunk.get("start_line", 0)
 *                 end_line = chunk.get("end_line", 0)             # <<<<<<<<<<<<<<
 *                 if start_line or end_line:
 *                     span = max(end_line - start_line, 1)
*/
  __pyx_mstate_global->__pyx_tuple[6] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_n_u_end_line, __pyx_mstate_global->__pyx_int_0); if (unlikely(!__pyx_mstate_global->__pyx_tuple[6])) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[6]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[6]);

  /* "manhattan_mcp/gitmem_coding/coding_hybrid_retriever.py":61
 *     """
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         store: CodingContextStore,
*/
  __pyx_mstate_global->__pyx_tuple[7] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[7])) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[7]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[7]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<8; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 11; } index[] = {{2},{130},{14},{19},{39},{20},{9},{9},{179},{31},{8},{1},{0},{1},{1},{3},{1},{1},{1},{10},{41},{8},{37},{12},{46},{5},{12},{21},{2},{4},{3},{4},{7},{6},{11},{2},{3},{2},{4},{5},{9},{5},{3},{5},{4},{10},{3},{4},{2},{40},{40},{47},{30},{3},{4},{3},{2},{3},{3},{6},{5},{3},{4},{58},{16},{7},{6},{5},{3},{4},{4},{4},{4},{5},{4},{4},{3},{21},{11},{18},{21},{30},{41},{42},{38},{43},{41},{60},{56},{61},{43},{28},{17},{7},{4},{15},{10},{4},{8},{20},{21},{11},{11},{3},{5},{1},{1},{5},{12},{8},{3},{15},{11},{5},{4},{5},{2},{3},{15},{3},{3},{7},{3},{10},{12},{5},{18},{2},{4},{14},{13},{13},{9},{1},{10},{3},{7},{8},{6},{2},{4},{9},{6},{12},{5},{6},{9},{4},{5},{3},{2},{5},{12},{7},{4},{11},{3},{11},{6},{7},{5},{5},{13},{9},{10},{16},{13},{14},{12},{10},{9},{6},{5},{17},{11},{7},{5},{11},{8},{11},{7},{6},{9},{18},{5},{12},{19},{11},{6},{7},{10},{9},{7},{12},{19},{13},{7},{8},{10},{5},{5},{2},{6},{11},{3},{6},{9},{4},{8},{4},{19},{9},{7},{6},{6},{10},{8},{20},{6},{2},{2},{7},{8},{4},{3},{8},{4},{1},{4},{4},{15},{15},{9},{5},{5},{16},{12},{7},{8},{8},{6},{6},{5},{16},{8},{15},{13},{9},{10},{6},{7},{6},{7},{7},{3},{6},{20},{21},{4},{13},{11},{9},{17},{6},{11},{4},{7},{8},{5},{5},{5},{5},{3},{6},{6},{4},{6},{2},{4},{8},{8},{9},{7},{3},{9},{19},{6},{16},{4},{5},{5},{7},{3},{4},{7},{10},{4},{6},{5},{3},{11},{12},{21},{1},{3},{7},{9},{2},{6},{2},{9},{14},{8},{14},{6},{3},{6},{8},{6},{8},{2},{8},{13},{2},{5},{3},{4},{7},{4},{3},{1},{3},{8},{2},{8},{8},{8},{7},{4},{4},{16},{9},{4},{2},{16},{13},{3},{6},{7},{5},{12},{14},{4},{5},{3},{6},{1},{5},{5},{8},{6},{7},{7},{51},{4},{12},{3},{2},{11},{7},{6},{13},{6},{7},{10},{5},{9},{6},{6},{10},{7},{12},{4},{2},{4},{8},{16},{4},{4},{28},{17},{8},{3},{3},{5},{2},{2},{10},{4},{8},{2},{12},{23},{2},{3},{7},{8},{8},{9},{4},{12},{5},{5},{8},{4},{10},{7},{11},{11},{11},{4},{3},{4},{11},{7},{8},{9},{7},{4},{11},{1},{7},{3},{2},{12},{5},{14},{18},{11},{15},{19},{12},{3},{10},{11},{10},{2},{7},{8},{5},{7},{5},{8},{7},{18},{8},{6},{15},{5},{7},{5},{8},{4},{7},{13},{6},{7},{3},{4},{8},{5},{5},{17},{14},{12},{2},{6},{2},{1},{12},{4},{6},{5},{13},{6},{14},{6},{6},{8},{3},{8},{6},{4},{4},{3},{6},{7},{12},{10},{6},{5},{6},{4},{21},{6},{14},{4},{2},{8},{4},{4},{4},{5},{5},{8},{3},{10},{4},{3},{10},{12},{6},{7},{5},{3},{6},{5},{3},{7},{13},{19},{15},{13},{8},{6},{1},{5},{4},{8},{4},{8},{4},{3},{4},{5},{4},{6},{8},{5},{9},{7},{5},{3},{2},{5},{11},{6},{6},{5},{10},{3},{4},{16},{16},{6},{6},{6},{6},{6},{7},{2},{5},{3},{4},{4},{15},{5},{1},{8},{10},{5},{6},{9},{6},{12},{6},{7},{15},{9},{1},{4},{7},{3},{2},{7},{4},{4},{4},{5},{5},{9},{4},{4},{5},{1},{3},{4},{3},{2},{2},{180},{2},{151},{123},{43},{2015},{105},{389},{2},{2},{2},{80},{46},{2},{8}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (4705 bytes) */
const char* const cstring = "(\265/\375`\305 \275\222\000\212\270\350%H\360\2626\007\314\300D\030[\005\263Ly@0\235)\032\035V!\205\306\302\366\023y#5\"E\354\026\271Z\220\265\226K\226\031\254\231\363\266\355\031\327\336W3\263\352\374\267\3533~\373\346\332\254\312\321\377\367\334\2713\253\366\0018\002\357\001m\002\240\316\213\0327875R)\024983(\014\034\235\024U}\316\r\355y\301\240\264&u\242\251\311\301\271\301\261I\321\250\2415.lR\200$*\247yU\305Y\235\221\330\371\212\310\366\252j\224\2620\330m\224\377J\203\230R\276\371\367\033\376z\236cJ9\207A\372;\177^\336\236\243\224[l)\315rV\2442\r\214\323\013\252\003\243\206\346\006\207&\345\342t\243\302&Eunjtnl(\212\023N\316\t\272\262;\352\253'{\320\225\361\036\236\365l\236]/\363\214\253l\270\263\347\367];\003\267~\312Y\255\275\272\227\227\227M\357\333\332Y\267\353\316\266\3164\235\351\354\365e_\367e\234\227}\346z\235\371\2468\363\277\317\332\224\357\232Q\357=nW\331\267y\024W\356e\025\274\031ge\267\272|\377\254\036\234\267\216\254\272\252\216\214\363x\327e]\226W\331\266\302.,\025\376\277Z\335\226\333{\313\276o\313\266\354B\013\210\022;\003\307\203a\363<\266W\343\351v\325\262\315\007[\237\337 \206\254\333\354\353\357B\237m{h\210\341\301\361h<\027\302\267\256\354\363\336(\314\335\366\341\333^\037\327\373\334[[4\036L9\256^X\361\031Q\242%\003\206\0336\\N;>\031nd\270A?\270l\330\341RwF\031\317\010\004\213\211\227\022o/\215\3679;\267~8\331\357[S\274\313j\313\215X(\317\030W\226\021\307\337\361]\277Q\346\217G`~\215T6\243l\377\367\342#lAm\244\312{\327\273i\240\216\3272\036d\\`\324\300\030a\375\243\327}\315\336\347F\333v\374E3\342\265\343\243\347\371\206c{c\207o\353\202e\364\322\017\266\270\277\266\252F8[^\365\343_q\257y57n|\352\306\013\237F\0324\337;|\263(\272\215Wo\304\267\332\363xe\267\213\345\027\364F\034\256\243\013[g\276\275\214\226Q\267\351\272Y\216\253\367{\264\037[\315\313\331\346=\317\361\n[.o#\235U\243\315\256\362\035\335\352z\253\371\353\021\367;\354\255\232\343\247\031!\240\300\022v\243\\\365\\us\213\353\326\337~~\377f\275\257\306\032\334\374\202\371\013""\377\363\236S\215\253\353?\333q\333\366\374\352u\267\337\365z\207\317/\375\252)\377Mo\245\274\025\262Z\255\026\370\335\013~;\353\357\313\337\363\275-\335\233\357\372\375\352~\365j0\357\274\262\236\345_\306\031gU\346\031S\314\351\313\333\027\344\262\346\335\312z\257k\270\271\334U\376_\275\315\367\367h\016\323\326wA\035\346\313\275\266\340\347\025\305\366\256\362\275\024\333\273\237e\357k\253\367W\270\336\220\025\262X<\324\3017\250\343\245\262\233\333m)\335v[\356]\327\365\277_\203|\0035\337U\253\260}\351\214-\327\267\362\314-\rs\367ru\374\326\357\336U;\356w\355:p\365\2558^\351_\255\262\213\275aP\225\265\352\363\262\316*.\363\232\257\212u-\367{w\274~\3729Uq\366V\327\316\330\326\273\265\265z\343\177]\234\365*\177\3709{m\365~\263,\372eNU*\356\377\313\232\2438\314\034\317\334\376\314\265^\253\266\314Q\2329\025\267\277\354z\315\352m\343\367^\371~\257z\256\352\2359\256\362\312q\272f\255\333\225\303\331\373\312q\317\353\353\355\343.\2307\2557\247s\270\271\355(\367\030\277\326 \366\300\355\357\375\235\357\366\024\333\355\263t\343\376Y\231s\215\353{\317-\245=|\243y\263\366\n\327n{\225\345\272n\233\353\372\321\273\361\013\356\327\364\273\255n/\215\203\032W\263\326.\307V\177\017^m\2634\276s\326\250W\365\312j\254n\303\257\341\177\3555\376\275\364\246\275Wq\310\242\257W\254\255j\332\357\330V\347\3578\250\363\226e\273\341\327\256\334\363j\267\274w}]_\317\242\366\253\257M\361\255y\337Z\273\357\326\315\351\275\225\263\327\326U\345`\326j\245\177\277&\201\236\225 \2242$[\\\2001\225*H\r\014N\022\005(R\301\330\022\320E\242\212\236\360\014s\2349B\234!0\234{d\021\t\n\231\037\312\r0\0010\035%\252\3641\272tn\207\353\344\000\000\221 (\222\206\214\030\347\nh\005\210\203\255\300\266Y\301\014\231\035J\017\244\212q\300\210\"d\352\322\3054\312\3500\035\002I\201\020\263U\316\220N\035\262\222\231\312y\322\037\324\322X\352\265w\325$\201\341\344V\\\227@23z\3501K\314\027\244jD\215\256\236#\022\013\031-\364\030bJ\013\250\002\325\200\325@8I\275E,\351=H\345\014\351\323'\220\304P\243\017\261U\240\3340\341""\224\351\020Fb\007\306\n&\222Db@9O\304\022\004\007J\304\024\024\221\230II\010\314EiR\232F\347(\302\310\211\022m\036\210\304\032\244\304H\030\004m\375\307O\375\2111g\312\222r#cH\031\343i\004\273LH\027\211\004\205\000\255h\231%\352h\001\345<\2113~`Zb\212X\363\243\340\000\000\004AN\244\206\225\020,\004fB\303\251\241\301Y\305\360d\"\221)F\223Q\324C:\n\0214\001\311\200\225`<\312Z\256\2241\310LC\204\2319u\225xB4\211<\204t\321M\235\233:\004\221\240Zv\350\255\037\006.\261\202\030\022u~\024\210\004\221z\250\353\210($\261P\327\242\214\310`$\026\032;\364\222\336A,\021C)~FDb- \034\322\0312\212tMlP;\252\237t\007'\261\332OT1F4!\211\351\236\32271\205$f\032Ic\212\016\212\006D\222\221\030I\334#\007\000\024\010b\022MFb\255\037\231\237\004\"\261J\026 [c\312\250\323O}\206H@$\021\211\241\272\204\003\000\026\0041\221\031J\261\023\220\023i2?\273C\203\371\325\023\336k\303\347\335f\303\360\265\227\267\373\341\207\273\206\230\343\032\206\334\323\375\340\273\300\226\305\240\3466\270\301\r\322\013~ \367\201\037x\351\345\3727\017\377r\236\271\272\255\306\337q}\357\363\277Z\345\374f\315{\355\017\334\237\371\336\340f\271\256|\337\326~\335z[\334\336os\237\367{\226?k\343\260\275\373\003m\210Wv\207\335\276\267\003\007\230\332U\325st\253V\277_<&\222D\206\310\035\2755\352\2240\245\200\322\016\037U\242\005?!\245\213V7\320E:bI\205\2740\340\014A\221\241TEP\312\224N/\345\\\021M\200\032\024\370\260\352+\375A\213\350liV\251C0\221H\356rU\031cz\01369\242\253B\177\200\"\226\210\244\030W\330\261\3535D\346\201rg\244\321A\324\0362\245C\367\020\202\261\230\016J\021)\032Y\372\214hRSP\034\205\022K!2\004\005\246\231a9\363A,i\365\t\"A\025h\224\034H!\345\210\030(\t\2462\246\264@\340\304\347\207\2044R\030\271\013bI\247\020S`\n\305H#\005\222\034\324\271\001\261\330f\275\343\t\225\030\nV\023s\222J\030\024\343J\004\224\262\206\214\020\324\"SB\324R\303\253\207\010\225<\003F\016u\\\031c(8\211Mh\215,\2420\200\201R\013@\246T>\354^k*,,\231\273LA\031uH!\262\303\370\255>\n\271\210\202j\371c\244\031{\204\314\020\023Ei*e\220 H}""\243F\013\241\010\233\031c\n0wb\2140$\037YZeN\231yv\316\035\324\271\003\326\302\354A\276\000}\200=0yH\033\225\010\021R\233\2240n\020\nt\021\366N\217u\262P'\014\020\016\363d\232\230,&\021\312\2041C\224\316\022\313\246\235Z\212\023\025\000f\"\203I\301\004A\341,\205`\247\227S\024Sq \212\351\334\324U\210'$\241 \0323\316\0315'\014\214\007(EH\013ch$\235\274l\243\005\362\004\271b\\9\tB\3018S@/XN\231Q\300\326%\220%\344K\177@\022\204\343\306y\303\346\3240\t\022H=\332\350\022\270\355\334^\234/@\234%Z\306\0004A)X'c\315L\351\344}\302H\354T\252<8\030\t\"\231\025\316\223\006u,0j#\250\261\302HPK\024)\030\235\304D\r\264\024yB\326\224NR\260\032\023\220\000\240\025\032N\023r#\240\2022\246z\251?\310P\206VH\004=B\260\027\345\210\314\230@\246\374\004?\022\0242\216\250\344\213\311\224Q\226\312\0262D\352\214\004B\245\016YZ\031g\364\223\255rP\031QyQ9O0\243\212\036\241\216\241\211|0\206\230\364\003\016D1\235\324\231\3129\035\000\325\300(\300f\314\020-gk\264\035\245\301\311\214\261\202\311y\252\321Ul\2346b\2341R\247\014\240\023\320\n\030h\346\004\204p\250\303\006\233\260\3069\206\212FF\232\024\322\030S@\200\020R\211L8\244\330\374CV\314\270td\204F\002\221 A\222\244 u\2461l\234_7\227\207\314le\020\301\334\332\000\272\t\245C\321+\245;\006\010\273\300l\021{\247\260\265\372-\nL\254\255\372\202Y\"{\026\276n8\020\023o\361\315.\325\373.s\322\262\251\265y\r\354E\277\362\243\321\275Q\313&\016\347\333\271HB\373\014j\325\321\244\004\245Avz/\305B\211\315\224\260\243\250\017X3\374s\016\270;\360S\014\357c\215\003\3707\373\232\316\277'\264\024Q\263\2740l>H\223@{\221\311\240'\022\372$\232|$5*\000W\350\0305\301\362lq>!=\017\276\220&\2704\370|X p\025!\024\222\266\204_\361\240@.YE\363G\024\341\274\361\373\002{\035)u\321\275\251Wy \213\002\263\266D\241m\365\307 \342h\027\266\336\re`\310\r\243\376\016y\242\n>\310w\245;B\007^\226\255tiL\325{B\261\203\236-\213\271\033\270\331\267\227\014s\010\372\201HT\354\201\241\210\213\343\023\n\215\245\213a\333\217s\373\250\010n\275\201\330n\311c\233\026\265\362\014\207n\231E""\242\330\"\206\275\215_\302\2628\341\\D\224\252K\007\276\251|\3761-SIcx1S\251\273\020\332$\003\312\236\261M\312\211\025*\320\237\265\324\326;\332\244\211\314\361\3639B\262e\004\341\260\005g\344\243\223iTz\"X\\9A\013x\344\314t\"s\016-\265\352\227~B\270/\366j\004G(mN\031\274\316\245\334j\177\014\277\350\003\274\226\347\245O\2773y\256\310'\013m<\374l\217\374,y\205\337j\355\330\221ldp\251\232\210\r]^\332\010s)\003\013Y\304\010\004\320\204\\o\265\233I\223\234(\335\335\230\\(H\001\013{\205&\227\324\036\277\365H\376\347\n\332\241\254w\265\275s\010^F\313\252\001#\262\326\300o\322\"$q\221s8\276+.\010S \213\244:`.>TP\221\223\233e9\244\325\265\300\211i\220\256\341\001j\207\006\027\3533\311c\300\017F\330\215ex\232\022k\332\226\307\277\036A`Xr\217D\346y`V\036i\250\242\360\203\235\261e\372,I\372\216\313\302\257V\222\377\262\240\007@\350,\014U\210qe\356\317\361\255\035\274\335\226s\032\033\243V\272P\010H\220\335\367\340\341@s\334B\237\303Ylf\304\231r\027\302\251?\240\246\307\307\223.H]\005\365\332pRID\263\036l\267,h\323\266\207@\243*7\3759\233Bua%{\307%\271*\255P\340%\366\271\333h\037\361w|m\375*daJO\253\240\363\263r\002\273\026\3461gd\351\216\231-BX\305G>\346^\204\223\343C\216<\226\247\301\314GP3\260j\264\356\332'\305\334\244`\024~ \375)\222\0220\220\210^\241\246/\325\214p\257^\317\002X\031\224\352\355\3614\311\022\021\363\351\202\271J\020w\250\026k\263a\363\203 \0025\341\204\205\221\006HJ\1774-\230BG\312\2413\325\320|\016\203k\024\\x1\303ZC%\240\"\030UF\007\262\004b\005\262\330Xq\016\246H\352\350<#\252\330\350\276\344\337\311\205\037\235\206\326\0261\005\035d=\203\023!\264<c\031\337\n\253\216\255\373ITC\230\2523R%\306\3040\364\260Y\320 9E\372\306\312\342\344\320\202\256\030\221Io\253$D\250W\367@\r\307\336\237k\037\205\252\320\205\021\371N,\251K\023r\236\341\304*aa\243ui\370\340D>z\232\035\250\343\334\310L\361\027\372\310\310N\033\336\222T\242\240`h|\013\023Pk\221?\227\014jx]2\246\302\310\310\017\243\025V\236\317\217\275\334>\364)\007nK\023T\032D\234\3526\210\271Zy*\014m\264);""\335R\313\364'!\367\346\220BR(>\312\377\301\342\324\377-\007\341\2600o\317=\260\335\301\033\330\205\357\014\227rL\010`a\254\027\006E!\t^\024\253~\374\231\016s\325\241;\274\\\254~`\203\257\275R\356\214>\220\354\311&p3\004IC\324|\273\362\360MO*:\017\376JQ\270\244\374j*\2514\020!#\214A\317v\234\005\013,K\247\273,-\354[\003\220\373X\2050\001\2059bVE\2648\216dU\342\001\317B4\033\017\010\363\014\004\332\037\357f\235&_N\315q\002\376\333\277\300O4^\313D\202\216\376~\005)Z(\363].\374\227\341\353>%$x\354\017^;\333\215\314B\214\220\302\264=\016\256WH\360\220\334\260'pY\345\365\227R\205 \302\271k\232\271\2418|\250n\371\226U\222p\316\010\3104}\263\\\305\006A,9\027f\327#em\221\254s\212Y\370\347\236\025I\236\016\360sh\330[\330\354\233\377\230\267\227WA\324\256\035fX\214fl\006q\2771v\002\231\3652E\246?q\322\030\311\305\005\374\371\344\307\022\266e\353G\033\314\244!\241hXZ\205\377\273^\335\304\014\205\334\267\345\3135\243]\002s\026\024|0[\351H$\231\365\272z\226aK\254Gq\027&\322\230\036\372\036\305=r!\250\340V\254\357\234D\353d\002\266\\\033n\250\257\036\352L\205\330\261\360\207tk\252O\372Y\272\210Ds\240-0\361\232\376\211#h\214~\003\303\211d\252&\251i\242\312-\361R\237\217R\371A\313Y\321\362\024\230fz\374\030\210\323\n\327\200#\221\312m\010\373&0P\305\301)`l\377\253\3607|\243o\214\376\273Jb\275}\305m.<\322\352\3422\346\241\342\337\365\273\226`+\301;\034\313\232B\205\204q#,\030\316u\3738\317\0266\253^<\362\032\330\234\200\312\366vp\365\212\343\234\303\016\275f\330\201\021\242\224\217\034\264X\032\206\014\305i\260\203e\224c\026\"\373\355b\252\344R\206\270DY\362\217QS6\256b\201a\317u;\021Py/yN(\2040\026\016\320\333\341\031u\\\231\206e\022\366\265\265U<\236-,`z\355\007~\323\257KP\037\376c\313\020I>\311\361\250\364\016\306J\362\311\247\351\265\3155\020\336);( \315?\001\373\246\372\226d@G\034a\210\272\363\266\275\201\342\207\033\377\272\354Nb>q\214}\357WQ\013\236\242\032\346\350\272MErrFoH\322\310\240\022\335>wm4\350\2175|,\001\374\342xx|\262\310\241\004i\245\325\276\343.Q\205y\362\241dz{""\355h\221\253\344\034\240\264!\262#\020;\032\321mO\362\316P\344\372\265\252\342\027\251\"\250\276J\370\016\310=\364\000\330\327\364\347\034g\030>)\202\301\310\025H\305~\232\264\n\260n\315\032\026 \303\240\t\202M\351\000\"\222\273\320\331\334\367\3450W\257\261\337z\375C\201\026\247\234a\231\230\261X$t\307\2451\254\341\203\242\230(\373\306\201\313s`9\342g8\265\316w6AW\316\265\353T&x4\237\302b\365\220\234\303r\376\216\002\254\350\027#\001\\\210%\364A9\006\257\276\350\036?\275\003?W\366\220\007\023>\2338!s\220\001t\213\254\200\226\316P\315\376\227\336\214\262\237\217\352\206\257\016\335\250\005\220\276\273F\257\364B\336Q7\nS\367\304\347\035\260\035'\261\343\310\267\332\036\006\265\014@\024\232\276^\263\315\334\2126\200;AC\331\325\245~\343\201\220gy\276\211\355\361\304\202\324\373\r\263\224\340q\344\000e\003k\375\317\254!%\331T\030/6\323\236\032\005\205\240uW\030c^\302\022\242\r/\202\371)a:\311\226\005{\256\014\356I\243\246\\\311\375\023K5\240E\303\232\2662\277\002\250_\320\320:;bZ\360\267\324$\3435J\320\320ihkbr\356b\264y\340S\013\301\226\202\013]\0270?\213\206\254\254\350oW5\202\027\2315\324\233\212ITM\004\365t\005\220\021\221\343\335(W\326\325K\200\211\265\030'm\352\220\242~\266ZT\235\320\327\375\302y\303\351W\025k\262\342\306\233k$\n\017\252Z\251\030\244G\263rH\001\330Sm\006\254L\204\241f\010\010\034\331A?c\036\313M\377\246E\3629\360#\307\344f\005\323\"zN\374\3536dh\313\rQ\242\0048\231eU\264[\266\2332sY\356\202\300\005\227\234\005\253_\000R\002";
    PyObject *data = __Pyx_DecompressString(cstring, 4705, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (4708 bytes) */
const char* const cstring = "BZh91AY&SY\354\274\263\342\000\002\023\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\300@@@@@@@@@@@@\000@\000`\022?zC\225\3335m\2720\266\342\026\262h\031R!IB\240\010@\205AQ'p\366\240\220<\036\032\232h\202j\236jh\332\2464\032jcJ{$c&S\321\211=6\201FM4\301&\233\324\324m1L\312\033Hh\365\036)\371F$\364\207\2504 \000\231\nl\211\2214zM\023\322i\251\243\3241=M\2502\003 \000\000\000\000\000\031\032b\000\"\236\231\022M\000\000\000\000\031\032\000\036\232&\215\031\000\0000\200hh\000\000\000h\000\224\320B\004h\246&!\246\215\002\243\331D\323\324\014\200i\240\001\240\000\000\000\000\000\006\200zM\020i\211\201\006\000&\232i\246\000#\001\030\2310\t\200\000\214#\000\000\214\000\2312a1\002SHH\324\322='\2504hzjh\006\206\214@h2h\000\000\32024\000\000\320bz\200i\351\036\240\322b\3214\342\322 \246\205\027\210\2312\031\"\263Y\260\306k\037\237\321fQhG\367\033Y*\265C\220\342w\204\344\"\314<Z\314T\3116\371(>D\025\365\000h\005\026\214\363\223JD&\003;8\004\200L\230Ha$\231\220\220\204\204(\320\225H\210\030\241\ne\022\363\000\265\323\264\206)B\326\222\0233$32@\220pw\031\336\326\006\255\234\330iy\363j}L\303,\3565\201\222\031\nX\032RC\r\347\231d\207\357b[F\t9p\324\340\317\310\346GEL\273\372\007\233+\3242\263\253=\204\254J\272\340s8\343Ah\331\230\3230\334\313\r\200B\311\t;\013\006\255\206\304\231\036\007\026a\266@$iF@\201:\212V\025\002\265'\230s\200uzFt\215\004$F\032E%(\316R\220\241LJR\017\221\023\305\367\270\200q\330\313:\210\016$q+\004\264\305\205\263\352\230t \201\034\373}\315\321<l\367\210\215t\347y\263,\n\351\364\016h3\246H\2420\307\273&\367C\221\306v\357\023F|\215k\220 +>\323\017}\240\361\316@t\027\263\372\277l|C\326\365:}E'\307\340\263\311\361\376~O\333s\227\231\203\352\274b\031\261\323\001\353\310+\035\245\270\302B\334\200ie\210X\030:X\021\306\027k|\033\340I\3407\200G\274\177S\330\035\240\246\244\207x\211\362b3oR\275\317\226y\016\006b\004\361\325@\371\225\n1+w\235\376\250%&\217!\270\n\n\025\004\373\370N\310)AL\274x\265\254\313\277k\235\305\307O\307\372\236U\316s""\324R\333.\377N\036\237\252Y\306\342\375\247\365\365\377\277J\031Uh:\n_6\td\221\026,=X\327\303\272\207\021\267F\035;\332\\{{\250\352\351\350\350\002/\232#\221e\025\307\370\024^v\200\203z\275\352\027\217\307\213\375\201\025\020[$\245\366q\177\237_\034\330\327\341\357\016\321j\222}r\227y}f\245\"\230\275\005\355\307D;\247\260(\311k\037\013\351=v\225,6&\201<(C\237\226\310\246\323@\316\017\243\220\244\312\367g\263:y\272\272\"\317\363\324\311\347\311\2440\306[\031c<\376O\030\214@\210\023!\341\214G\336\373/'\220y\n\275\352\n\373i\3663\373\217Xk\337\000\305\321\220\332\314-V\2406\206\341)\006y\267\3614\337y\246\274\306nC\336f\246A\"C0$\2420gI\277*\357\037-\375\202\260\325\353\3272.\313\331\355\302\240V\244]\350\332M!3\247\232\350\241\010\250\220I\363\232\202p\246\r\t\376\332h0\241\360v\337\252\020\361Rr\235\010\242\323,>\254jn0w\327b\356\336\233\215a\342\325\276\r\2407\024@\355\334\027\261\245_\333\203x'\001\n\020\205\207\256${\245\306\205\025\304@\200\003\303\234(AZ\027\004`\200\20390\240\336\216W\222\353\260@\201\001\242\037S\261\244g_\007\233h<\350\352u\340\246\373\334\371l\245)\201\244k\321\316\336\276\317\256\236\034\374S\331\273\220\"\260\300,\273\032\221k\251\202\032\215\335-o)\240i\200f\324R\315\032\347\031$G\364\215\273\235\377(\002\254\353P=o#,t\036\252Tq\317\237\\{\366\261\ru\030\215}\250\350\3661\303\004\247U\n\202\224\242\204.M%\006\206\216\r\353\367\rhl./\353\354\245J\242 D6\253\013\\{W\263[O\031L+\267?\300?\267'\310w.\377\264l\"\216:Ggjqy\321\240\346\0252\250\031q\311Z\3378\351\310\245\020D2`%O0\254\246V\326,\231\217\366\266\330Q\312\373=[\3343\027\027\254\353\002\342\217\363\033C<\202I(\2520{AS \321\3256*j1\0343\346\370\2743\302 B!\243\353$\344k\263\360b#b(\0253\204\032\360\206\333<;\203\037\237\002\203\360\3427\326\3316\305\266\345\372\217$_\222\2614\370\322sY\225v\205fe,J\301\266T\n\373\306P\354\\\331dZs\237\033\3062#\364\357\316X\301\3172\373\353\"_m\273\335\331+i\261h\343O)\360N\332\305k\325c\320\335\377{\364\275A\364\377\233n\256\002\236H\234\230jj\333""\246\243a\367\311\233\230\007\002Q\367\315\307:\277\234\030\235\316\321\275\327K\275\033\276!\356\310\303\014b\265\222\375\277<\036\034\346\340\243\267\223{\330\332R\333\246|\227\026\300\036$\004\017~\027\004\362\304\234nW\200?B\017Y\210\270\025\376\036.]{+\230\312\321\023 /\231\311\220I\"bd\240\006\322\026\032\034\214\303\014\212F\201}\256H\347h4\237\234\310\243\007i\312\362&\301\2760$\307\033S\345\237\275\253\235Fw\243a\262\025\227\221\337^-\364\343[i\351\233|\035\353\016\027\305\361\202\327\346\024\321\t8)\211\224a1!\305\277q\377\263\027\201\223\334@\356\207)J\375\220\325\033wu\367\366#\345\372\373\327\243\036q|\257\031\351\356p\005\360Z\200\360\034\000\260r\367\360{\231\200\001\374@ \230\365d\3354\3347\016\033\362\032m\345\350\310\365\030\327g\211\355,\226O\220\206\355\213\"\233\016@\214\023C\003\214\336\266-\310\255\250\353\236>\013o\205^X\366\246\333\212\325\355\263\241h\366<\344=\265\332a\373+\331\263\353\344v?+\253\212Ii\320\345\032\243V\244\372\306S0\254\354>:/\025\346\032\366\3414\261\273\322\232*\245Kf\0213;\315\004\200\025i\350\312D\212\255U\213\240\271*\232\315\315\264\363\210\360\027Dn\014\266y\2014'\351yf\233\236h\261\\\255~\2335\246\307c\365\311,\324\260b\251\272\310\354\265\321E]\224D\267R~\274\241\314\220$\2043$$\016\361\225\356\232\351S\227^\354\333\343\253\353\256Z,\266xN\346\212S:\263\262\202y\366v\007g\265w\3734\333\342\342\237\272Y\333w\330\355\035\017k\217\332\255\027{?a\001\025tUf\363\\\263\253\261\223\004\021\257\305}r\245\237\252\265\254\363:\231^!\316\033Wa\362j\t5\247\337l\205\307\223\326\222j\370\325n\315\222\274S\350\256\215\364\262\30400s\222\272Mr\306C\321\250\236\350I\246e8\031\305\222fg\201\367\2377\005\251S{\020^sT\201\231\003\224D]\333\223R\017\311\35001`\342\200\244\2623\350fl\252\206\223\036\370\336Q'F\031\363*\210P\354\241\366Ps\333U5\217\302y\344\373g\246\335F\233sZ\311\240R\244\010\337\244\024Yi\034 \311)\346\2402i\310\t5\315R\330\265\200\325aR\323H\022k\276\270\342\232\203\202@\311\370+\271\307\321\302\330\276\372\367\270oN""\365\237\025\227.\027\022eb~\203!\362\321\321\231\235\031ev\256\232s\005\035c\006`\312\360[g\242\321\352s\020\201!\236=\352\2547e\\\027~<\201\364\257]\t\021\305_A\240\234\346<,\014\210\241N#\210\353\333\350Nf,\211\330\010\006(\245K-\326TI\002\314=\034\355\212G\266\327\204\304\036\263\2728\361H\355\235\026\030\205\220\313\244\263\036\006\202\r1\340\231\231&I\204\204\223o\352\351\200\354\025-\3669\212+\227A\n\372\016\311\336\225g\222\017\225TZ\327kFY\271&k\252\344\235\t\271\207\303\300\323wI\230[\216\367e\035rvp\212\254\306]\313\272_\033d\344\253\"\231\304\235\310\024\020DG)\204\230'\353\226\026\263\262\204\305\2722\247\201\230\2353f\355nS\232\025\267\345\2038\035\202'\210\203H\020\223\213\231*\345h\2664\300\221\240\000t\224U~M\215\352\223\243\245\275\244\276^N,$\223h\230\365\344P\241WF\313qPb\340E\337D\353\035\234N\256\247ff\303\273\250\266\357\307\206|\033\021\366W\356\242\307\261\036_\033\346!&\021\202\006`\316\255yl\226\003\223\002\350\213\330\373\240\323\341\000\334\250\320 &\036\272\204\201\267@\333\234\010\232\370\272qC\nj\327\223\024\242S\270t\360\231\211\3115\227\025\260\210OD1\365\235<,y\334j\265\036\255\034\275i\361\275\330H6\267J\277\314~|\333\350w\235]@\343\244\317b\202\317=\362_\370\0375\343\211d\0008\207\203v\247%v$`6d A\315W\020g\301\002\371\345\005\271\333\220\232\344\023-\236\0012V\366k\026)E\023E\244\271#V\361\270\231\000\2630v6=\022I\021\233\363\330U\031\263\263\302^s/\010\345\24500\326`ZU\010!\352\024\307d*\347d@\326\206Y\267\2336\205\310\303\341\220N\357\005\223*\365\020\333\222b\300\357\342\210\247\322=\353\327L\317q\273.WN\207\317\272\020t\264p\363f7L\214u3K\2606\250\367j\035\005\214rU\357l'U\310\235\323:\264n\274@\034O\026\334P\252`m\342\347\036 \371\033\364\361\236\317_<\023\223\244:~\255hhIz\323\320\254CZI7\337\t\270\341\314\\!q\274J\226w\207~\305MO$&|\246H\226M#\247\204\354\334\346\271oAd\316\235#\255\3510\301aJa\323!\241\365|\241\246 \031&\010q\240W\243#^qI\005\321\221\207\036SJ\030H2@\344\260\210C\261\rJ\020<\0171v\311q\261r\377\202\327""\341\202\257\264o\252H\350\356\037\026\035\245$\372\317h\336\0032\033\223CW\2136\237vL\331/&\017\213\200\325\207Z.\017Pm\302l\203}\245\331\2457U\006\220RO\323\316\364[\322\341\305\0041\242\031\315\357\305\203\007\014q\353\320\2463\263\3660C\202\3158\222T\325\311\271\020\313\256\254 \323\235\243\231\325F\226\344\243\241\2451rA\336\322\001U\311\032\253\326\327\243\014\327\231\246\016\315@\262Rr=\335\275q\235\006`\032\214\322\007\335\034i)\0207\246\232\016\003N\311\014\340\017\020\227R\204M\266B\261\312r\310\nG\200\256\247\202\3329_\231v`\030\343x\026\016\20052\226g+\2133\021\266W\226'48\307*:\2559/\005\230g\244\0247\345\220u;m\250-\207\271\232\231Qv9\232\311\342'\356\210v\371\000G\275\217[\250_2k\354\352\036)=\245E$\365\361\251{\242\253\250\313fL\307B;\224\3138\354\235\220\373\307i=\357\020=E_\237h\024\256\235\t\201\323y#\314\273\244\256\221\343,\336I2\307wf;\362\271\244\306\221\033\357\344\3556\313|\370\335\364\253\302\215\261\006\373\334\362\334gKd\365\227\244\030\207\000R\364\231\366F\357L\320\311$\222\204\320\254Y\264\213\233r\310\266\275\036\345\214e\214\032b\324\245\004\277L>\316\314\353\032N\363H\201\324\371\346\335\357a\rgN\002\020\222]\021\211)g.\000n\335\313\314<\311<S\024\337\346\222\325\251a\3465\315\304\234\213v\366\210\214\265\014X^NT\026\366\353\026\001\314\213Pb\267\036\345\236\246\217\303t\326\253\007s9\344.\366\234`\373\357\3555\262\305\334\331\337\024\222b\207\022[\241b\253\246\210\215\205\336\027\354\241\005\345\325X\354\360+JZ\2614<\217\270\274+pq\311\256\244^\332\331z\r\244\2675ni\320\032\332\r\364^i\245k\213\356\370\2077\355A/\342r\033[\304\021\342\316\n\0165\006oRSq\274A\241\311u\001\306\377\010%4\306\2700\3671\2244\265\020\352p\014)\\^\373\027\261/\223\3728\2511\325Tl{X\360\360\364\372}\307\253\036<\374^\217ouW)\035\310gu$.$\373\025\232\305\rc\314\361\005\021\231\342\247\351\177)\0225\210\024x\336\367\356\240#5d[G\316\\\310\302ld\310\261\017\244>\311;\275\316\334F\225\236\227H\014\223^\223_'65\234\364\273F!\226i\242r\325\336^|\245\362r\317l""\357\2458\232\274\251\243U\346\2474\272\311\243~\374i\313\032\026\300\271d\326\023:\031\nV\206\222\307\031I\n\010\262.$\260x\343q\215\014\236\267sP1\224\001\225\363B\002E\020\321\253U\334h\324\323\204\331B\262\020\002\007\023Ei\313s\023\213Tx\253\027\036f\016\010\310.d\006Vc\214H>na\261\202\014\245\216\363GU\351\314C\230\r\334\274\327\217F\363\254F^KZDFg\335G\227\002\332\347\366\264A\251\030\002(\023\260N\200\0339\210\020B\263^\257Cue\216\240\303P\336\3339>\t\273\247\026\2773\003 F\006\341\270\265\332\311m\330\3475\344d\271\313l\232zh\305\245\231\266d\225\361\177\n\n/f\261\035\335u\276\355\270\262.z-\341\035YTY&\342\373[\335\301O\226\367\267\210\347\235T\256c\244_\026I\240k\273\313\314\262\317\253\250\267y\366\266\270d\027\265DD\243\000\n\322E\267Q\263\243\321\334K\000\240`IJ\377 \026\320\007;D\r\234\351\305]\254r\337F\366X#\325\334\356\352\000\240\006\354\325\345\305\324<\254>\350\031\001\002\351J\213\231\205\034Y\223\342\273\355\273\334#\276\035\310;)D\207K,\031O\031\230\204-\253\000e!7\3010/\013cz\206\357\210\022fl\264\326\216\315\274\303\311G\320Od\267\217E\323\216e\302P\211pI\261\335\306K\034L\351\321\223'\020\232]\246\256_\223\036<O\002HV\370\016D\312#\013\016=\301\211,1e\240\373\211\231\341(4|T!\231\031B\262\271\234\312\213\262\310O\301\226om\346SL?J\211\216&,\241\271+_y\231\205\003\2249\350\017r\201t\306n`M\020\013\202x6[\023q\016AY.\005\351\033\201Z2\3260-\014\022\221DR|*i\260I\345d\351N\034\374y\345\256\017\343\374\025\003\014QO*\322\026FM\032\350RE\037\330\037[\rI\352\001K\244\315B\004\"\202\35326<!\262\227fnML\254D\241J?\272^%B\324\022\220\301\017\211s-H\373C\343H\007wF\220\256F\252\265\215R\023V\263eZ\r\272\353`s\245-\204\334h\301\002U\2234S\316+\017\231\003\256+\203;\"\303<\312^\253\350\261[=\000\363O\321d}\005\205\363X\224\242x\022v\354Y\260L!\262\254)\364\312\025\342%u\n\275{\245\030\342Kj\t$\214\255\237\321\335\240\233\002\300\205\231\330vY\"&X\256\237\n\252;\002\021d\225s\t!Ui\250B\271\007\3543{R\247\2615!\013\2048N\303|\273\177\275:\234\025\031+zZ"">\n|\346\037.J\302\215j|W\202\275kUA\327H|\240\232\032\020\353y\344\010PM\"\017\337.\020\260\315@\332+\350\217\200\241a(\205A*\336 \263\203\200<\301\250\207\374a\014B\374\\\205\203\305\222\000\206\006\361\020\377A\321\032X\010\327c\243\002\013&&\227t7W\241\337\242tB\351P:^A\241j\326\215\021$Q\231\235\036\322mO\245\2470=;\316\214\377O\3263\246\013\342T\274\301\255\263C\327\275\246\316\305\373Q#\215\357l\351\333\372T\024\260\313\003c\\M\023\247\230L\344\257\022&\274\276\372\247t\n[|4\032\273\362\364\224\333\023\264\017\212g!#?s@\024\336\377\000\340\325\235\2647\247\356\364\313\236\202\233\225\0275;\351G\217\2570\256I\221\341wRJS#\027\033\254'\023\323\271\033\210\2605\220@\260*\321\332\364P\374R\316\356Pw\261y\3717\367\374=\227_9\030\232\303\341,7\352 \323/\357/\334\3025\007\276\250\203\030\\\306Kl\271\217\203\261\014]\"\350L\243\027Z\256\0160\357Y]Ec\373\355\017g\030\362s\374\221F\017\2564\314k\322\302\334\007\025F\235E\240\302\211\344\250\310\036I\262b\367\250x\263\374v\223\330`\253\025SI\346\352\331M%W\353RR\265\360\363\364f\231M9\374yE\354\263\203,[(&\013z6\023\343\016\317\220\241\355\245L\324\244MO\360\242c;\222;\274\337\310\254C\205c\361\360\321\217\320Ccb\370Y9C\216\252\036>\346^\255\224]p\237\204iM\231\017D\363\251\231P\217\274\323F4_\233\210!\363x\212\305O\017\2339\3164R\356~&_\243:i\343\314\2313v\213\257\206\361\255\363\372]\330\262\234\224\351>\255\013\247\377\027rE8P\220\354\274\263\342";
    PyObject *data = __Pyx_DecompressString(cstring, 4708, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (4719 bytes) */
const char* const cstring = "x\332\235X\311\177\323X\266&E\025\025\252BW\234\2110\004\034\022\010\243\251\004\212\261kHA\030^3e`\250\002Z-K\327\266\210,\311\272WqL\247\272{\231\245\226Zj\251\245\226^z\231\245\226^\346O\250?\341}\347^\231\004\032\352\365\353\374\344;\351\016\347\236\363\235\357\034e\346\304WE\374\335b\216\360u\333z\313\314\242\317\204o\2615\335.\332n\3252\212\025\327/\032\256i9UT\216`\353\202\227\324\"\267^\266\034\306\213\234\325uG`*g\272o\324\212\247\2371C\270>?S\324\035\263X\017la]\340V\325\301\226l]7D\261\256\013\243\206\r\325>\267-C\274\344\302?_\234wZ\257wz\313L6^\277^\250\227\231)\005\2502\207\371\272\260\\\247X\321-\033\322\222t\215\200\371\255\342\314\003\213\213\227\357o\366Z\216Y\216P\r\332\355\221+XQ\324tQ\274\325\0225ld\361\242\311l\253L\0333\273U\304$\354\301|\232\344\024\237,<\271p\371\332ey\023\237\275\301\305p\337\240l\330:\347\270\272[)\226\003\013\027t\212\242\3451^*\336\257\024[nPt\030\204\023n\321\303\274\335\013D\2159\320\223\240FqFw\034W\310\373hX\216\033\316\024M\313\307!\326\032\243\325wt\233\263\322c\217f\350\366\313%V\207\364\357\324q\313\266`\267\327==\375x\361\247\231\033\305W\245\342K\375\302\333o/\\\327^\237\243\326\353s\033/\347/\374\372Z\266\317\252\366\271\323?~\2773\2701}F7M\r\242\260W\345\323\272mo\2605ht\303\206\3166x\315m\026\353l\303\305\320\232\305\232g^\2251\351\225\371\367K\347\177Sm\232`\361\215f\215\371L5,\243V:\033p\266\001\315C\255\206\3300\260+f\227\312:\257\275*\333\200\315+~\366\225yN\265\371\217\350\335\240\002\033\237;S2J\206\347\225\014\216\207\233\026\327\3136c\016\225\025hq\365\002\341\322\251\032\245\252[\252\225j\230Y\023u\310\252\246\230\2457\372\232^z\303\361\270\016\212\365U\306\274\013\000\367\032+\255\212\222\035\350\245:\360\n\004\010\335\321\352\206W\252Z\242\316\352\232\002yI\347B\343\253\314f\302u\376h\236\2524\016\244\263\377`\336\232\364\211OO/\261\236YKu\263\344\325\274\222\327*\371%\277\\\362y\211C\177:J\216f\255\304\0336\367\215\213\357\355r\361\275C/\346\207\326Ze\3372\265\334\245\231\217=y\200\333\303]z\366,""\3615f\013V\342M\253\"J\302\255\333%8\270\340\353%\261.Jk\001+\255c\250\245S\201\337[\253\n\307\322~^z<\177[\273\377he\341\321\212\266|\377\356\243\371\007\313\267\036?\272\265\360dE{8\377\344\226<\376\226\242\213e\272\262\032\271'\345Y\352\211\363\321\301\222\246Y\216%4\355\023oMf\270u\317\345L\223u\340\230\237\234(\240sM\262\203FHt\304'f\262u\017\376\215\375\034\203y\202\177r\226 ,k\204X\315\t`.\377SS\253LhF-pV5R\200V\326\253\237\230\230\033H\021\247Z\302K\177\266]\330\233\377P\"\272[\367\374\377j\255eV\376\253u\177\266\365z\331\324\177\370\177,\376\370T5E\275S\001!\007B@\244@<}\347\376\203\005m\341\0050\264|\377\361#B\321\343\245\205[\363\313\013D\326=\322\323\264'\255u\374h\201\366\010\332\\b\225\217\362\240\266\274\362\370\211\366\374\361\322\355\345\345_\036=~\364\313CB\"\310q%\360l\246\351z\331\r\204^\245\231@\006\242\207j[&\250\tO~\027\r\024#\250\253\374\225\353\266W\323\241\030W\267\211\312\034\302\211\266C\333\234:-\335\263\360h\253\254\245\373\014<\357\032\026b\211\271\233It\336r\014YX.(\301\207,D|8+@\234\t(, \202\312=\251\347\372\240\275]\235\267\357uX\271\254\033\253U\237\300\017l\201T\231\266\332\244\312\321\353\254l\370-O\224Y\031\244Yf\216Q\203\277\257\226\255\252\017\303\312R+\273.\027eX|U\026\274l\007\314\363\341\"xa\227}W7\313\201(\267\014\335\2501Y\200A8\3028\265\211y\241\037\003\007\331\232\247\373\002\334\004\267\361\205U!\371\231\201\250Y\315KN\353W\245b\2257\310\004\302\021\252\263\332\344\252AB\357\264\362Me?'\253\367])\357\271\232!\326\3636B\257j\301j\312\2162\336j\232\252\340\216\226\0009\346]:\205\347\001\331\260\031\304\247B\021\205j\372B\325\302]e\352-3\r\2112Uj\226gH\032\2600\007\244\300\310\036\206\rR\332\035\025>\302\374\206k\333\024\336\201\0344\203\272\223s\016U\201\357\323\001\256\343`\006\316\313u\245*\255fA)y[\346O\312\212\275\241\246\353\233<\317\317zi\032\325>\035\350\033n`cCx\236\341\031\200(\314\3443\223 \007hC\215\246\016\217r\000\330Z\331\325}\323\004,\351G\2102M\227\177\204si\004\t\023Ne\022n&\2530\032\005\330\261\261g""\273\255:\2667\241`\037\251\325\307\270\330dk\256\307\315\212\351j\232\351\032\252\250\370\254a\272\214\233\2560\335\246\243!\324\231\276\3531F(4a\304JEeG\232t\314\235\256p=\370_\005\030$\373 \302\";$~x\027U5e\271\235\276\205\373K\321!\267\344t\324\236+e\253R\017\270\306\271\224\010}\030\037T\027{\347\265F\312\204l\275\256\353\330-t\230\303!\0315\300\210X\211\026r;UrY\321,[\267\210\344m\227^\221\331 \206,9e\205H\303AP2A\374X\370\251\340\226\364\323z&\227\035\024\340*\331\364tQ{\327\340;odI\354\n\220\370\330\3021\351\007\277\246\312\242\267p\217\232L\267*\266\253\013\024\256\211\\\033\017\234\211J\227\312:\375\360\326\253\370.\334\253\0228\206*I\342^\315\3630\206\205x\036\270\325*\363?\022!\253\320\265#>L\206\252P!\021\235W\r\000L\260\212\t8\327 \033\036\372\301\214TA\353`\337\232\276\306j\014L]C\271\326BbJ\231\241\246L\231G.\211\233\217\2061\013!\023\017\221\016U\002\024o\203\324\200w\220\233\003O\207`\256\337\262\234\212\017f\367\003C\004>\353%+TZ\364\005%\215e9\234\030\321\021\n\352\2754\330r\326@(T\332k@\014\267\270&\331VC\343]L\260$Wq\270;%\260\364\263*\2557\001\027o\232b\025\227\304#\235}\265\271\332T\346\353\205l\033\234\033 \252!\202\001o-\333B\354\301\206\0220\273(\243\007 N\371\275\355h6I\220\007F8\275\352\347\341\017\251\266-\rF%\314!SoYhU\027\357\230j\303k\003\240\332\264i{\267\211\351~`\323\207\224\007\376\206\353Q\321\320 \004\346\242tp\232*MU\371\377A\002\375a.\213\033!\262\255\313\263\031\027\274\256\203r\310D\271\rT\223)\243\341T\304\374<(\240YsMUr\330\032\220j\"p\327\255*\340B\021R.\307\251\225\026\312\000\336\243\275_s\220%\314@N\205\350\n\323\324[2ri\273\312]\n\247oAx\200p\310Y\344G\266\366o>\371\376\273|\200& \323\200\255\\\031\372+\256\343:\222\241\241\020b\031\027IR\035\213\200\035\340\030Z\220\224\214\024\241*\235[\321m\0170.w\003\237\322~[\367d\005;\367\276\002\250\306\007\234\215#\253\014\001\230\300 \265\2056g2\"\323\227,\355CB\321O\223\206F\213\204\005\307I* \202\204i,N\354\305\321\004\306\t\214\214>n=\327C\014\201\263x\276<\203\032.i\"""\257\270\252i\246\357R\274\360\002\333\366\210E\002i\222FC\205\271\306j\263\201]\032\201n+\205\313{\276\177Y\325\333\315\225\371\010\t\275\253\t\n\020\252KI\204FA\213$WC\312\t|\235 \301\260Y\335\022\362\237\004\324`\030o\252\004\201\373\214\";THq\200>\337\251\306(\242\031\257\371\254\312\326Q\220\"0\201\234\323\224\025\235S\263<\205\021\214\2605\035\361\232\350\337W%\250\261\356\321|tY3\3079\305\016*<\2278F\r 5\343=\277\220\250B'\360\035\237\334\004\223\360\265\350\2025\221\tP\232\"\263F\342\032&\213\335@U\003\271I\271\352\3457\364|\351\316\300\001\327\211\352\224\217q\020.%yu]\022\221,\314\234N\025\267\346\014\233\013\311)\357@\000E\256\303di\211\026gU<\244x\274\246\344\010e\005\231\254\t\334Axy\005\t'\215l\225\273\030Z\3108t\332\263\246\317}w\005\245m\363\032\2459\364\017\013\372o\023\345fM\0138\355\001\227\006\003\017\254'\351\244\211@\207\211\000\0019\206\261\212\024\0215\022CWb\235\300\313L\356\331\340a*(\270\342\263\273\201O\005\272o\2137H\025\3408\270\206\204\031\247\017\002#'\025\264\003N\t\037\274I\346}P\036\351\317\251J-\"\302\344\231m^\345*\313;\273,\322\033\312\335\266\327\225\327\341\201'34\336\252\227]\033\344Y\246\344\313\266{\250\201\021\021\223\005#\217\243\177x\341\033C~f\320\377iD\rp\004Lt\023\245+\004V\242n\n\242@\334\205\203V\030\314O\225/pKW\302@\026\232\314#\025,\204K1D\346^2\\R\016\207\276M\276\244\374i\347*\262\257\374J\212\257\376\341\025x\224\343\005\036\"\017\303w\032() \253\003\276\266\006F\tx\300\241\303\200\323c\342\347\323Ob p,\354\026pl\262\226\247Il']B+`\262\340\360b\025'\225;\357N\307\241U\220<A\214\226\250J\313\323\346\274\313\314f\023~\211\000\201\250^m\352\274\311\232\314F\032\214\312gM\350\025\274\351\310\177~\311\177|\241 \206\340\242i\3316\341\257I\240\\o\271\001\036\377\255\345\265g\223\371\177\315w\247\316%\263\277\377i\317\376c\321b\267\1770\374\"|\036\315G+\361X\334H\366%z\267\377\353\315\313\233\215\356\300p8\373\373\276=\373\007\320\343\341dw`0\3742\014\242;\361d<\333\035\034\013\215h,\362iQwp8\274\024\352x\367s\244wG""\016E#\321b\244\323\322\203a9\352\217\373\262\311\307[\215n\377\300\346\035\332\246\020\016\205W\242\241\350J\\\350\016|C[\207\227C?*t\007G\303\225\250\020Mn\367\037\330\\\t\013\341\311p\215\004\374f\263\021I\251\257\244\372v\377\221hV\355t2\024\321l\364 \351\243MD8\033\376\034V\242y\022\376*v\234\013_@\0107y\232N\247z\372\367\316T\347\331\326\354\377\361\362\233\315 \274\035\365E\343\361p|'\231\244\331\263\275\315\347\251\321\014\365\354\340\371\354\374O\235\276NA\n\006\261\246\317'\363\277\177\265g\377\201\315\205p,l\320\252\271\315\347\341|6z*\326\245\022w\r\375\330n|8to\253O\016m\367\217\343\354\241\350r\024\304\363\361\263\344Rb\244C\351\325\266\224\343\322\246\276\371\317\310 \215\311\325\362\350\355o\006\273c\007\273\375\207Ie\003\233\367C(k \0338JZ@]\314\212\263\351p\372\240\323\207\251C\303]\314VO\377(\315\034\013a\351!\030D\252t\377Wd\257\241p$\033=\233L\002\036\270\321\311\030\033\355\357\016\034\211.g\307\277M\367AW\215\\\r\341?\342\305\356\340\361h#\271\232N\2228\277\341\320\201\241\360t4\231\035Y\350\374\262\245o5h\303\261\360it*\356\353\366\223. \343B\210\033\340dXv)Z\213\027\343J\362\260=\324\226j^\207A\257\305W\241\370\301c\221\251Pv,\252b\222\231\235\375\241\255Cu\020\272\026\351\221\334z*\236\302+\t\263\303\321H6QJ\364D\2768\026\255d\223W\323F\273\217z\362\022\322\220\203\341>\\y\360H4\027=\213ga\341\013\251\337.\364\316\220of\243\333\361\347\361\335\344Zz\245]h\237l\363\316t\307\334\232\336\252fO\237\251\211/\222\305\337\373\367\354\037\001d\327\324\231o\261\007\3442\243\013\361?\322\305\364Mgo\007\266\3746\305\245\257\267\013\333\37531\317\316\336\314n\376-\373[3k\256\223\245\356\302\204\003\343\321^\330\272\021\037\300\216\373\366\034\030\314\2769\237\334Mg\311\231\346\240\2653\020\361/I3\205C\215nC;\360\262i\014\254\343^_\264\227\332A\347\336\326\374\326\263l\371i\366\364\327\354Wl\216\013LD\277@\241\363\330\"\033>\031?Gk\344 <k4\262\342Fv\372f\373j\347Dga\353P\266\264\234-\257t\307\017\221N\366G\303\270t_|8\231%\2036c\235\034\372ht7\236\243""\035\024*\207\243\371l\342\242R\357\004^I\027$\274\rL\220\262\277\303\275\365w\n&20\340\316#\000b\364<\306\026\364\002v#\312\231\336\265\366}\177\233JV\322\002\031\201\224\362E\274\222\024\222\323\351T\372\254=K\n\277\230\350Js\337\307}\333\320]\037\301\210\311\271_\303UXz\231\014NZ\375:\276\014\036\033H\037v\n\244\267\337p\273\257\222i8S!=\007\305\341r\020\355p4\025-\307\004\220\321\tL\370\002\0000\222\341\354\374\275\255\275`\002H\276kl\241\263\014\027\035\231\202A\026\222\221d\031\216P\306Q\007\307\273#E\271\305\201\361\260\261=p\022\036!U\240\244\032 ;(*,\307\373\010^\207\242\203\320\363Hv\022\260hOn\017\034\202a\010\346\327 \177%\205\373\034\217D6uU\335\343h\264\020\217@\202Ux\360\035p\300\277\017|\260|\0333n\341\334\317\342\323\360\337\037\325\222]\003\331\215\207\331C#3L\022\370X\364k\354'\307\200\377c\035?\273\017\000\275\316^\377U\302l{\360pt1\031J$\020\241\212c`\035\234Kw\335\033_\316f\036n-gO\026\267G\246\343{\311\317\010\026#\247\240\245BrQz\361\310d\\\210O%\375\351gR\327\2423\227-\000\240\317\263\347/\266\261\0239k\201\02008\022\336\005\351\000\235\"\272\204\2301\216\200Dx<4AV\351\216\303\257\262\213\363\340\330\017\007h\203\251\354\304\215\366\2116\324K\244\242\244<\007%`\306O\235\317@\346\213\331\035\370C9+\0334}\346\335\244\251l\352f{\256\275H\3476\272\343\263@\304L{\270=\337\376\353\326\234\274U\266\270\232\255\326\263\272C\353\2108\324\272\361h\037\311x\004\242\032\361\261\204\003\225\313\260\321Q\362\361\243\023\357\3564\035\337O^\265\017w\256o!(\\L~k\377\245\3636[|\231\275|E\222\272\351R\332\220\2369\023\213d\367\256s\344$\361S8\300\313\366\336\366\245\266\201{\037\205\263\321\336\375{\n\247\210i\207\3017<\232$\024\336H\236\245\263\351\355v\037x\007\027\371-\276\025\377\023\336wtb{\374\202\244\222B1j\020Y\261\370JR sN\342\210\225x\024\320\031Ky{\n\206ivt\262\301\002 \244G\034 \272\256l9!EYN>\203\303\224\323/\001\305\317\244\246qNSF\237\361\031\260\303\370!:\3458\0211\310\251;B\221\344\017\013\\\343\000\t\245hl\"z\032O\203f\300\226\344\356\337""\201q\347\343W\344\373\303\341My\nA%jA\212\363D\177\357\024u\023H\033K\032\333G\201\226d!\035\225nxt:\276\235\313\213\316\\:\231]Z\350,v'\340\232\240\225\237c[Z\213\364\252\203\316Ot\376g\313\310\026\227vf\222l\270\212\212kD[\203'\342\311n\201\330y\366\017\333\333\003\007\272P\356\t\004\276\301\241\360\014\300a\306'b\331\231\244M\00777\240w\\\021\222(\036\036\001\226\277\200\241O\245\371\000\364\tL^\002\351\223^\311\330\307\310\000\322\215\310\030\213T<\205y\276O\373\210\004)\232NR0\376.}\321^Ta\027)\027\222\220\2230\375v\377\361\250\241\202\354Px\235\030\373j\332l\227;`\223Q\231\341\301\223\244{\366%\205\367\246\301\271(vO\205\21320/*m\010\204\241\305\036k\365\262\235<\217\240N\236A\344\311\303\030%{z>F\332\241\304a8\274\032\315\304\343\311xz\250=\323\221\271\3135\244}\343\260\342:D\223\331\321\215\350E\3742\335\337\036\247\367\243\341/Q-\266v\336^\217\356!4\234J\373U0\037\nGU\222\227G\220\303\321\311\017\263\010$k\304\360h\255\205KHI\357\313\330.\363\314S\260\035\261\r|CW\016r\r@\272\233^J+\304&\005\265\374Rh\003\236&\245!\024\005g)\200\345\t1\\\211\2448\202\340\261\030\255\342\026><\n\212 \357ld\343\247\201C\\\374p4\215D\341Yr\035N\272\017\336|pK\312>\034Ngc\310\025)p\325\263\251\313\304\3702\216\035\212\344\315q\035\305\220\373\277\222)R>&[\304W\350.#X\026\222E\334\250/\373\374L2A\371\260J\275w\262k\272\350\024\345\321\335\301\361\350K\360\377\347\361\203\264/-\374\301\033\262\346\346\237(BSr>.cV\0050\034\240{\t\200\370%.6\205\300\2677\235KWH\321q#z\013\322G\236\370\277\334\232\227+";
    PyObject *data = __Pyx_DecompressString(cstring, 4719, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (8645 bytes) */
const char* const bytes = "'\"\n    Centralized retrieval logic for coding contexts.\n    Combines semantic search (Vectors) and multi-signal exact matching.\n    Dict[str, Any]Dict[str, Set[str]]Embedding generation failed for query 'List[Dict[str, Any]]List[int]List[str]Note that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.Optional[RemoteEmbeddingClient]Set[str]?/@': \\. [a-z0-9_]+[a-z]+|[A-Z][a-z]*|[A-Z]+(?=[A-Z][a-z]|$)add_note\\b(all|every|list|show me|overview)\\b\\b(\\d{3,})\\b\\b(how is|where is|which.*use|interact|call)\\b.bash\\bline\\s*\\d+\\blines?\\s*:?\\s*(\\d+).c.cpp.cs.cssdisableenableflask-logingc.go.h.hpp.htmlisenabled.java.js.json.jsxkeep-alive.kt.lua.mmanhattan_mcp.gitmem_coding.ast_skeletonmanhattan_mcp.gitmem_coding.coding_storemanhattan_mcp.gitmem_coding.coding_vector_storemanhattan_mcp.gitmem.embedding.md.php.py.r.rb.rs.scala.scss.sh.sqlsrc/manhattan_mcp/gitmem_coding/coding_hybrid_retriever.pysummary overview.svelte.swift.toml.ts.tsx.txt.vue.xml.yaml.yml.zigAny_BROAD_INTENT_SIGNALSCONCEPT_MAPCodingContextStoreCodingHybridRetrieverCodingHybridRetriever.__init__CodingHybridRetriever._decompose_compoundCodingHybridRetriever._detect_query_intentCodingHybridRetriever._expand_conceptsCodingHybridRetriever._extract_line_numbersCodingHybridRetriever._get_chunk_text_bagCodingHybridRetriever._hybrid_search_chunks.<locals>.genexprCodingHybridRetriever._hybrid_search_chunks.<locals>.idfCodingHybridRetriever._hybrid_search_chunks.<locals>.<lambda>CodingHybridRetriever._hybrid_search_chunksCodingHybridRetriever.searchCodingVectorStoreCounterDictFILE_EXTENSIONSIGNORECASEListOptional__Pyx_PyDict_NextRefRemoteEmbeddingClient_STOP_WORDSSYNONYM_MAPSetTuple_aaboutagent_detailagent_idallall_chunks_flatall_vectorsalphaalsoalteranand__annotations__anyapiapi_keyareassociatedast_skeletonasyncasyncio.coroutinesatauthauthenticationauthorisationauthorizationauthorizebbackg""roundbagbase_kwbasenamebcryptbebeenbenchmarkbigrambigram_boostblockblocksblueprintboolbroadbutbycachecache_resultcachingcallcamel_partscancertificatechangechangescheckchunkchunk_contentchunk_kwschunk_namechunk_name_partschunk_summarychunk_text_bagchunk_to_ctxchunk_typechunk_vecchunksclass__class_getitem__class_namesclassescleanclean_queryclean_rtclean_tokencleanedclientclient_ipcline_in_tracebackclosecoding_storecoding_vector_storecollectionscolumnconceptconcurrentconnectedcontentcontent_hitscontent_match_boostcontent_wordscontextcontextscontrollercouldcountcpcreatecredentialsctxdaemondashboarddatadatabaseddos_decompose_compounddecoratordecryptdefenddeletedeploymentdescribe_detect_query_intentdevopsdfdo__doc__doc_freqdoesdotdown_sqldropeeachediteffective_alphaeffective_top_kefficientemailembedembedding_clientembedding_idencryptend_lineendpointengineescapeevery_expand_conceptsexpandedexpanded_creditexpanded_onlyexpensiveexperienceexpireexpiresexpiryexplainexploreextextendextension_validation_extract_line_numbersfilefile_contextsfile_filterfile_pathfile_paths_filterfilterfinal_scorefindfindallfinditerflashflaskfloatfloodforforgetforgotformformatfpfrom__func__functionfunctionsgenexprgetgetLogger_get_chunk_text_baggeventgitmem.embeddinggivegroupguardhandlerhashashhash_idhashed_keyhavehealthheavyhowhtml_escapehybrid_alpha_hybrid_search_chunksiidfidf_sumidf_totalifimportinin_memoryinfrastructure__init__initializationinsertintintentinteractinvokeinvolvedisis_broad_is_coroutineititemsitsjsonjsonifyjustjwtkkeykeywordskwkw_score<lambda>languagelatencylikelineline_match_boostline_numslistln_load_agent_data_load_vectorslogloggerloggingloginlogin_googlelogin_requiredlostlowerlrulstripmmag_cmag_q__main__managemanagedmanagermanhattan_mcp.gitmem_coding.coding_hybrid_retrievermathmax_requestsmaymememoizationmemoizememory__metaclass__methodmethodsmiddlewaremightmigrationmodifymodule__module__modulesmonkey_patchmustmyname__name__name_match_boostneednextnormalized_file_paths_filternorm""alized_filternormpathnotnumoauthofononboardingonlyoptimizeororchestratororiginal_query_keywordsosouroverlapoverloadoverviewoverwhelmpageparent_classparsepartspasswordpathpath_lowerpatternperformancepermissionspersistencepingpoppost__prepare__profileprofilesprofilingprotectpullpunctuationqq_wordsqkwqt__qualname__queryquery_keywordsquery_line_numbersquery_lowerquery_lower_setquery_type_mentionsquery_vectorragrate_limitratelimiterraw_tokensrerecoverredirectredisrefreshregexregisterrelatedrelationship_boostrelevantrenderrender_templaterenewrequestresetresponserestresultsretrieve_pathreturnreverserlsrolerollbackroundrouteroute_match_boostroute_patternsroute_tokensrprstriprtssanitizationsaveschemascorescored_chunkssearchsearch_resultssecretsecuresecuritysegsegmentsselectselfsendsepserversession__set_name__setdefaultsha256shallshouldshowsign_in_with_passwordsignupsliding_windowslowsosocketiosomesortspanspeedsplitsplitextsqlsqlalchemysqrtsslstart_linestaticmethodstatusstoragestorestrstringstripsumsummarysummary_chunksummary_match_boostsummary_overlapsummary_wordssupabasesymbolttabletelltemplateterm__test__thatthethentherethisthreadthrottlethrowtightnesstimeouttimertlstotokentoken_counttokenstolisttop_ktotal_docsttltypetype_match_boosttype_query_wordstypingup_sqlupdateuploadupserturl_forususageuseuseduserusername_uniqueusingvvalidatevalidationvaluevaluesvec_scorevectorvector_storeverifyversionversion_controlversionedwwantwarningwaswewelcomewerewhatwhenwherewhichwhitelistwillwithwouldxyouyourzip\2701\250A\200A\330#+\2501\360\016\000\t\036\230Q\330\010\020\220\005\220W\230A\230T\240\026\240q\250\006\250a\330\010\013\2104\210q\330\014\023\2201\360\006\000\t\014\2104\210s\220!\330\014\020\220\007\220u\230F\240!\2401\330\020\026\220c\230\026\230r\240\026\240q\330\020\023\2203\220a\220u\230B\230a\330\024\031\230\024\230Q\230a\360\006\000\t\027\220b\230\010\240\001\320!O\310q\330\010\014\210F\220!\330\014\021\220\022\2206\230\022\2306\240\021\330\014\017\210s\220!\2204\220r\230""\021\330\020\025\220T\230\021\230!\340\010\r\210T\220\021\220%\220v\230Q\330\010\017\210q\230A\200A\330#6\260a\340\010\033\2301\330\010\014\210F\220%\220t\2301\230L\250\001\330\014\017\210t\2201\220B\220f\230A\330\010\013\2107\220!\2202\220X\230Q\230o\250U\260$\260a\260{\300#\300V\3101\330\010\013\2107\220!\2202\220X\230Q\230o\250U\260$\260a\260{\300#\300V\3101\330\010\017\210u\220D\230\001\230\030\240\023\240F\250!\330\010\013\2101\330\014\017\210t\2201\220A\330\014\017\210w\220a\320\027,\320,@\300\001\300\021\330\010\017\210q\200A\330$,\250A\360\n\000\t\r\210E\220\026\220q\330\010\013\2102\210W\220A\320\025&\240a\330\014\023\2201\330\010\013\2102\210W\220A\320\025?\270q\330\014\023\2201\330\010\013\2102\210W\220A\320\025H\310\001\330\014\023\2201\340\010\030\230\001\230\022\2304\230u\240A\240V\2503\250c\260\022\2607\270!\330\010\013\2103\210a\210\177\230c\240\021\330\014\023\2201\330\010\017\210q\200A\340\017\020\330\026\027\330\010\032\230!\340\010\014\210I\220Q\330\010\014\320\014\034\230A\330\010\014\320\014 \320 1\260\023\260L\300\001\200A\340\022\023\330\017\020\330\017\020\330\017\020\330\010\025\220Q\330\010\026\220a\330\010\022\220!\330\010\033\2301\330\t\n\360\006\000\t\022\220\024\320\025*\250!\2501\360\n\000\t%\240A\330\010\t\330\014\033\2304\320\0370\260\006\260a\260q\330\014\017\210w\220a\220~\240Q\330\020\037\230|\2507\260!\330\010\017\210}\230A\330\014\022\220(\230!\320\033E\300Y\310a\310q\360\006\000\t\026\220U\230&\240\001\330\010&\240a\330\010\014\210E\220\021\330\014\026\220a\220v\230R\230v\240Q\240f\250M\270\022\2701\330\014\017\210x\220t\2308\2407\250!\330\020\036\230d\240!\2401\330\020\036\230g\240Q\240d\320*>\270a\270q\330\010\026\220h\230a\230q\360\006\000\t#\240#\240Q\240a\360\006\000\t\032\230\024\320\035.\250a\250q\360\006\000\t\036\230T\320!7\260q\270\001\360\006\000\t%\240A\330\010\013\2101\330\014\020\220\006\220a\330\020\033\2302\230V\2401\240F\250-\260r\270\021\330\020\036\230g\240Q\240a\330\020\033\2301\230D\240\004\240G\2508\2606""\270\021\270%\270s\300$\300d\310$\310g\320UV\330\020\036\230g\240X\250Q\360\010\000\t\024\2204\220v\320\035.\250a\250z\270\021\330\010\026\220d\230-\240~\260Q\260j\300\003\3001\340\0100\260\001\330\0109\270\021\340\010'\240s\320*;\320;`\320`w\320wx\340\010\014\210G\2201\330\014\030\230\003\2304\230q\240\r\250Q\360\006\000\r\020\320\017,\250G\2601\330\020\023\2202\220U\230)\2401\240K\250w\260a\330\024\025\340\014\017\210q\330\020$\240K\250x\260q\270\005\270R\270u\300H\310A\310V\320SU\320UZ\320Z`\320`a\330\020\035\230Y\240f\250A\330\020\023\320\023%\240W\250A\330\024\027\220r\230\025\230i\240q\320(;\2707\300\"\300E\310\031\320RS\320ST\330\030\031\330\014\020\220\t\230\023\230D\240\001\240\032\2501\330\020\037\230w\240a\240q\330\020\034\230G\2402\240W\250A\340\010\030\230\001\230\023\230A\320\035/\250q\360\006\000\t\035\230G\2401\330\010\014\210I\220Q\330\014\035\230T\320!5\260Q\260a\330\014\020\220\006\220a\330\020\023\2203\220c\230\021\330\024\034\230A\230W\240A\340\010\020\220\006\220h\230a\360\016\000\t$\2401\330\010\014\210I\220Q\330\014\017\210u\220D\230\001\230\030\240\023\240F\250#\250T\260\021\330\020\033\2304\230q\240\005\240T\250\021\250(\260#\260V\2701\360\010\000\t/\250a\340\010\014\210G\220=\240\001\340\014\030\230\001\330\014\026\220e\2304\230q\240\013\2503\250e\2604\260q\270\001\330\014\030\230\013\2404\240q\250\014\260M\300\021\340\014\017\210}\230D\240\n\250$\250c\260\021\260+\270R\270q\330\020\021\330\024\032\230#\230S\240\001\360\006\000\025\035\230D\240\005\240Q\240c\250\023\320,H\310\003\3101\330\024\034\230D\240\005\240Q\240c\250\023\320,E\300S\310\001\330\024#\2401\240E\250\024\250S\260\006\260b\270\001\330\027\030\330\024 \240\001\360\006\000\r\030\220q\340\014%\240Q\330\014\020\220\006\220e\2304\230q\240\014\250A\330\020\031\230\024\230Q\230b\240\006\240a\330\020\031\230\027\240\001\240\024\320%9\270\021\270!\340\014\031\230\025\230d\240!\2408\2503\250f\260A\330\014\037\230t\320#7\260q\270\001\330\014\034\230E\240\024\240Q\240k\260\023\260F""\270!\330\014\034\230E\240\024\240Q\240k\260\023\260F\270!\330\014\031\230\025\230d\240!\2408\2503\250f\260A\340\014\034\230C\230q\240\002\240(\250!\250?\270!\330\014\034\230C\230q\240\002\240(\250!\250?\320:M\320Mc\320cd\360\006\000\r\036\230Z\240r\250\036\260r\270\036\300r\320IZ\320Z]\320]^\340\014\017\210q\340\020\032\230/\250\022\2501\330\020\023\2201\330\024\036\230c\240\024\240Q\330\024 \240\003\2404\320'M\310S\320PQ\340\024$\240H\250B\250a\330\024&\240c\250\021\250/\270\022\2701\330\024!\240\021\240&\250\010\260\002\260+\270R\270t\3002\320EU\320UW\320WX\340\024\036\230a\360\006\000\021$\2401\330\020\024\220G\2301\330\024\027\220t\2303\230a\330\030+\2501\330\030\031\330\031\035\230S\240\001\330\030.\250a\320/A\300\021\330\031\035\230S\240\001\330\030.\250a\320/A\300\021\360\006\000\021#\320\":\270\"\270A\330\020&\240a\330\020\023\2201\330\024+\2503\250a\320/@\300\002\300#\300Q\320F`\320`b\320bc\360\006\000\021'\240a\330\020\023\2201\330\024#\320#;\2702\270Q\330\024\027\220q\330\0301\260\021\260'\270\023\270A\270^\3102\310S\320PQ\320Qk\320km\320mn\360\006\000\021%\240A\330\020\023\2201\330\024\030\230\006\230a\330\030\033\2303\230c\240\036\250s\260#\260S\270\001\330\0340\260\001\330\034\035\360\006\000\021$\2401\330\020$\240I\250\\\270\032\3009\310A\330$/\250}\270K\300z\320Q[\320[\\\330\020&\240o\260R\260q\330\020\023\320\023'\240t\2501\330\024\030\230\006\230a\330\030\033\2302\230W\240A\240U\250#\250[\270\003\2703\270c\300\021\330\034/\250q\330\034\035\360\010\000\021&\240Q\330\020\023\2204\220s\230!\330\024#\240:\250V\2601\260D\270\001\270\021\330\024\027\220}\240C\240\177\260a\330\034\035\340\030-\250Q\360\006\000\021 \230q\330\020\036\230e\2406\250\021\340\020\032\230!\2302\230T\240\025\240k\260\026\260s\270#\270R\270w\300a\330\020\024\220E\230\025\230a\230s\240!\2409\250B\250a\330\024\035\230W\240A\240S\250\002\250$\250b\260\007\260q\270\002\270\"\270A\330\024\027\220w\230c\240\021\330\030'\240q\330\030\031\360\006\000\021\037\230a\230q\330\024\025\330""\024\026\220a\330\024\026\220a\330\024\026\220a\330\024\026\220a\330\024\026\220a\330\024\026\220a\330\024\026\220a\360\010\000\r \230q\330\014\017\210q\330\020\035\230U\240$\240a\240~\260Q\330\020\033\2305\240\004\240A\240\\\260\021\330\020\023\220;\230c\240\021\330\024\036\230a\230y\250\002\250,\260a\330\024\030\230\006\230a\330\030\033\230;\240c\250\026\250q\340\034+\2501\250E\260\025\260b\270\001\330\034$\240D\250\002\250$\250b\260\001\330\0342\260!\3203E\300Q\330\035 \240\001\240\023\240B\240l\260#\260S\270\003\2703\270a\270s\300\"\300J\310c\320QR\330\0342\260!\3203E\300Q\360\010\000\r\037\230a\330\014\017\210w\220c\230\021\330\020\"\240!\330\021\030\230\003\2301\330\020\"\240!\330\021\030\230\003\2301\330\020\"\240!\330\021\030\230\003\2301\330\020\"\240!\340\014\r\330\020\032\230\"\230A\330\020\022\220)\2303\230d\240\"\240A\330\020\022\220!\360\010\000\r\020\210|\2302\230Q\330\020 \240\001\330\024\027\220r\230\024\230S\240\005\240U\250&\260\001\330\024\027\220r\230\021\330\030#\320#3\2601\330\030'\240q\360\010\000\021\036\230W\240A\330\024!\240\021\330\024\035\230Q\330\024\035\230U\240!\240=\260\001\360\010\000\t\026\220U\230!\2304\320\0375\260X\270Q\330\010\017\210}\230B\230a\200A\330%-\250Q\340\010\037\230q\330\010\014\210E\220\022\2209\230A\320\0357\260w\270b\300\001\330\014\025\220W\230A\230S\240\001\240\021\240&\250\001\250\021\330\010\014\210E\220\022\2209\230A\320\035.\250a\330\014\022\220#\220Q\220a\220v\230Q\230a\330\014\017\210t\2202\220Q\330\020\031\230\027\240\001\240\021\330\010\017\210q\200A\340\022\023\330\017\020\330\010\017\210q\330\010\026\220a\330\010\033\2301\330\t\n\360\026\000\t\027\220a\330\010\026\220a\330\010\"\240!\340\010\t\330\014\023\2207\230'\240\030\250\030\260\031\270'\300\021\330\014\023\2208\2306\240\030\250\026\250x\260w\270a\330\014\023\220:\230X\240[\260\t\270\030\300\021\330\014\025\220Y\230h\240i\250x\260w\270a\330\014\023\2209\230H\240F\250&\260\010\270\001\360\006\000\t\022\220\025\220f\230A\330\010\014\210I\220Q\330""\014\032\230%\230v\240Q\240f\250M\270\022\2701\330\014\017\210t\2201\330\020\021\330\014\017\210v\220R\220u\230I\240Q\240a\330\014\017\210s\220&\230\003\2303\230a\330\020\036\230a\330\020\036\230e\2408\2501\250G\2603\260f\270A\330\020\021\330\014\017\210t\2203\220l\240$\240d\250!\330\020\034\230G\2401\240A\340\010\013\2104\210q\330\014\032\230!\360\006\000\t\033\230#\230Q\230k\250\026\250r\260\026\260q\330\010\023\2204\220q\320\030(\250\002\250!\340\010\032\230$\230g\240V\2509\260D\270\006\270c\300\027\310\001\360\006\000\t\023\220$\320\026,\250A\330\014\026\220m\320#4\260A\330\014\030\230\001\330\014\031\230\021\330\014\025\220Q\330\014\036\230a\360\006\000\t\n\330\014\026\220a\330\014\025\220Q\330\014\026\220a\330\014\027\220q\330\014\025\220S\230\001\230\021\250Q\240Q\240\001\320\004)\250\035\260a\340\010\023\2203\220a\220q\330\010\014\210F\220!\330\014\017\210s\220#\220T\230\021\330\020\030\230\007\230q\240\004\240L\260\001\260\021\330\014\017\210s\220#\220T\230\021\330\020\030\230\007\230q\240\004\240L\260\001\260\021\330\010\017\210q\210\016\220h\230a\330\014\021\220\030\230\024\230Q\230f\240A\330\014\023\2204\220t\2302\230[\250\002\250#\250S\260\003\2602\260T\270\022\2701\240q\230z\250\021\250!\2501";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 608; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 76) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 608; i < 625; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 625; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 608;
      for (Py_ssize_t i=0; i<17; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab;
    double const c_constants[] = {0.0,0.4,0.5,0.7,1.0,0.01,20.0};
    for (int i = 0; i < 7; i++) {
      numbertab[i] = PyFloat_FromDouble(c_constants[i]);
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 7;
    int8_t const cint_constants_1[] = {0,1,3,5,10};
    int32_t const cint_constants_4[] = {50000L};
    for (int i = 0; i < 6; i++) {
      numbertab[i] = PyLong_FromLong((i < 5 ? cint_constants_1[i - 0] : cint_constants_4[i - 5]));
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<13; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 4;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 7;
    unsigned int flags : 10;
    unsigned int first_line : 10;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 420};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 430};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_fp};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_kp_b_iso88591_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 484};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_a, __pyx_mstate->__pyx_n_u_b};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_kp_b_iso88591__11, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 487};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_a};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_kp_b_iso88591_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 488};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_b};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_kp_b_iso88591_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 517};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_t};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_kp_b_iso88591_Q_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 518};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_t};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_kp_b_iso88591_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 575};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_qkw};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_kp_b_iso88591_A_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 460};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_term, __pyx_mstate->__pyx_n_u_df};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_idf, __pyx_mstate->__pyx_kp_b_iso88591_ha_QfA_4t2_S_2T_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 653};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_x};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_lambda, __pyx_mstate->__pyx_kp_b_iso88591_z_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 61};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_store, __pyx_mstate->__pyx_n_u_vector_store, __pyx_mstate->__pyx_n_u_embedding_client};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_init, __pyx_mstate->__pyx_kp_b_iso88591_A_IQ_A_1_L, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {6, 0, 0, 19, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 212};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_agent_id, __pyx_mstate->__pyx_n_u_query, __pyx_mstate->__pyx_n_u_top_k, __pyx_mstate->__pyx_n_u_hybrid_alpha, __pyx_mstate->__pyx_n_u_file_paths_filter, __pyx_mstate->__pyx_n_u_file_filter, __pyx_mstate->__pyx_n_u_clean_query, __pyx_mstate->__pyx_n_u_route_tokens, __pyx_mstate->__pyx_n_u_FILE_EXTENSIONS, __pyx_mstate->__pyx_n_u_tokens, __pyx_mstate->__pyx_n_u_token, __pyx_mstate->__pyx_n_u_clean_token, __pyx_mstate->__pyx_n_u__5, __pyx_mstate->__pyx_n_u_ext, __pyx_mstate->__pyx_n_u_query_lower_set, __pyx_mstate->__pyx_n_u_is_broad, __pyx_mstate->__pyx_n_u_effective_top_k, __pyx_mstate->__pyx_n_u_results};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_search, __pyx_mstate->__pyx_kp_b_iso88591_A_q_a_1_a_a_7_86_xwa_X_Yhixwa_9H, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 285};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_token, __pyx_mstate->__pyx_n_u_parts, __pyx_mstate->__pyx_n_u_clean, __pyx_mstate->__pyx_n_u_seg, __pyx_mstate->__pyx_n_u_camel_parts, __pyx_mstate->__pyx_n_u_cp};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_decompose_compound, __pyx_mstate->__pyx_kp_b_iso88591_A_1_Q_WAT_q_a_4q_1_4s_uF_1_c_r_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 315};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_query, __pyx_mstate->__pyx_n_u_line_nums, __pyx_mstate->__pyx_n_u_m_2, __pyx_mstate->__pyx_n_u_num};
    __pyx_mstate_global->__pyx_codeobj_tab[13] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_extract_line_numbers, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_q_E_9A_7wb_WAS_E_9A_a_QavQa, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[13])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 331};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_keywords, __pyx_mstate->__pyx_n_u_expanded, __pyx_mstate->__pyx_n_u_kw};
    __pyx_mstate_global->__pyx_codeobj_tab[14] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_expand_concepts, __pyx_mstate->__pyx_kp_b_iso88591_a_3aq_F_s_T_q_L_s_T_q_L_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[14])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 345};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_query, __pyx_mstate->__pyx_n_u_q_2, __pyx_mstate->__pyx_n_u_content_words, __pyx_mstate->__pyx_n_u_w};
    __pyx_mstate_global->__pyx_codeobj_tab[15] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_detect_query_intent, __pyx_mstate->__pyx_kp_b_iso88591_A_A_E_q_2WA_a_1_2WA_q_1_2WA_H_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[15])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {9, 0, 0, 103, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 368};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_agent_id, __pyx_mstate->__pyx_n_u_query, __pyx_mstate->__pyx_n_u_top_k, __pyx_mstate->__pyx_n_u_alpha, __pyx_mstate->__pyx_n_u_file_filter, __pyx_mstate->__pyx_n_u_route_tokens, __pyx_mstate->__pyx_n_u_is_broad, __pyx_mstate->__pyx_n_u_file_paths_filter, __pyx_mstate->__pyx_n_u_intent, __pyx_mstate->__pyx_n_u_query_vector, __pyx_mstate->__pyx_n_u_e, __pyx_mstate->__pyx_n_u_raw_tokens, __pyx_mstate->__pyx_n_u_query_keywords, __pyx_mstate->__pyx_n_u_w, __pyx_mstate->__pyx_n_u_cleaned, __pyx_mstate->__pyx_n_u_original_query_keywords, __pyx_mstate->__pyx_n_u_query_line_numbers, __pyx_mstate->__pyx_n_u_route_patterns, __pyx_mstate->__pyx_n_u_rt, __pyx_mstate->__pyx_n_u_clean_rt, __pyx_mstate->__pyx_n_u_segments, __pyx_mstate->__pyx_n_u_contexts, __pyx_mstate->__pyx_n_u_all_vectors, __pyx_mstate->__pyx_n_u_all_chunks_flat, __pyx_mstate->__pyx_n_u_chunk_to_ctx, __pyx_mstate->__pyx_n_u_normalized_file_paths_filter, __pyx_mstate->__pyx_n_u_ctx, __pyx_mstate->__pyx_n_u_file_path, __pyx_mstate->__pyx_n_u_normalized_filter, __pyx_mstate->__pyx_n_u_path_lower, __pyx_mstate->__pyx_n_u_chunk, __pyx_mstate->__pyx_n_u_total_docs, __pyx_mstate->__pyx_n_u_doc_freq, __pyx_mstate->__pyx_n_u_chunk_text_bag, __pyx_mstate->__pyx_n_u_kw, __pyx_mstate->__pyx_n_u_idf, __pyx_mstate->__pyx_n_u_idf, __pyx_mstate->__pyx_n_u_class_names, __pyx_mstate->__pyx_n_u_scored_chunks, __pyx_mstate->__pyx_n_u_vec_score, __pyx_mstate->__pyx_n_u_hash_id, __pyx_mstate->__pyx_n_u_chunk_vec, __pyx_mstate->__pyx_n_u_dot, __pyx_mstate->__pyx_n_u_mag_q, __pyx_mstate->__pyx_n_u_mag_c, __pyx_mstate->__pyx_n_u_kw_score, __pyx_mstate->__pyx_n_u_chunk_kws, __pyx_mstate->__pyx_n_u_chunk_name, __pyx_mstate->__pyx_n_u_chunk_name_parts, __pyx_mstate->__pyx_n_u_chunk_summary, __pyx_mstate->__pyx_n_u_chunk_content, __pyx_mstate->__pyx_n_u_chunk_type, __pyx_mstate->__pyx_n_u_summary_words, __pyx_mstate->__pyx_n_u_content_words, __pyx_mstate->__pyx_n_u_overlap, __pyx_mstate->__pyx_n_u_idf_sum, __pyx_mstate->__pyx_n_u_idf_total, __pyx_mstate->__pyx_n_u_expanded_only, __pyx_mstate->__pyx_n_u_expanded_credit, __pyx_mstate->__pyx_n_u_base_kw, __pyx_mstate->__pyx_n_u_name_match_boost, __pyx_mstate->__pyx_n_u_qkw, __pyx_mstate->__pyx_n_u_summary_overlap, __pyx_mstate->__pyx_n_u_summary_match_boost, __pyx_mstate->__pyx_n_u_content_match_boost, __pyx_mstate->__pyx_n_u_content_hits, __pyx_mstate->__pyx_n_u_route_match_boost, __pyx_mstate->__pyx_n_u_rp, __pyx_mstate->__pyx_n_u_type_match_boost, __pyx_mstate->__pyx_n_u_type_query_words, __pyx_mstate->__pyx_n_u_query_type_mentions, __pyx_mstate->__pyx_n_u_qt, __pyx_mstate->__pyx_n_u_relationship_boost, __pyx_mstate->__pyx_n_u_parent_class, __pyx_mstate->__pyx_n_u_bigram_boost, __pyx_mstate->__pyx_n_u_query_lower, __pyx_mstate->__pyx_n_u_q_words, __pyx_mstate->__pyx_n_u_i, __pyx_mstate->__pyx_n_u_bigram, __pyx_mstate->__pyx_n_u_line_match_boost, __pyx_mstate->__pyx_n_u_start_line, __pyx_mstate->__pyx_n_u_end_line, __pyx_mstate->__pyx_n_u_span, __pyx_mstate->__pyx_n_u_ln, __pyx_mstate->__pyx_n_u_tightness, __pyx_mstate->__pyx_n_u_score, __pyx_mstate->__pyx_n_u_effective_alpha, __pyx_mstate->__pyx_n_u_final_score, __pyx_mstate->__pyx_n_u_summary_chunk, __pyx_mstate->__pyx_n_u_seg, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_n_u_w, __pyx_mstate->__pyx_n_u_k, __pyx_mstate->__pyx_n_u_v};
    __pyx_mstate_global->__pyx_codeobj_tab[16] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_hybrid_search_chunks, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_a_1_1_A_4_0_aq_wa_Q_7_A_EYaq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[16])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 660};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_chunk, __pyx_mstate->__pyx_n_u_bag, __pyx_mstate->__pyx_n_u_kw, __pyx_mstate->__pyx_n_u_name};
    __pyx_mstate_global->__pyx_codeobj_tab[17] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_src_manhattan_mcp_gitmem_coding, __pyx_mstate->__pyx_n_u_get_chunk_text_bag, __pyx_mstate->__pyx_kp_b_iso88591_A_6a_1_F_t1L_t1BfA_7_2XQoU_a_V1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[17])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* Generator.init */
  if (likely(__pyx_Generator_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#if !CYTHON_COMPILING_IN_CPYTHON && CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    Py_ssize_t i;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    for (i = 0; i < n; i++) {
        if (unlikely(__Pyx_PyTuple_SET_ITEM(res, i, src[i]) < (0))) {
            Py_DECREF(res);
            return NULL;
        }
        Py_INCREF(src[i]);
    }
    return res;
}
#elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL ||\
        !(CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS)
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length, length2;
        int kind;
        void *data1, *data2;
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return -1;
        #endif
        length2 = __Pyx_PyUnicode_GET_LENGTH(s2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length2 < 0)) return -1;
        #endif
        if (length != length2) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    return (equals == Py_EQ);
return_ne:
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = __Pyx_PyTuple_GET_SIZE(kwnames);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(n == -1)) return NULL;
    #endif
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        if (s == namei) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        int eq = __Pyx_PyUnicode_Equals(s, namei, Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs;
    PyObject *dict;
#if !CYTHON_ASSUME_SAFE_SIZE
    nkwargs = PyTuple_Size(kwnames);
    if (unlikely(nkwargs < 0)) return NULL;
#else
    nkwargs = PyTuple_GET_SIZE(kwnames);
#endif
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
#if !CYTHON_ASSUME_SAFE_MACROS
        PyObject *key = PyTuple_GetItem(kwnames, i);
        if (!key) goto bad;
#else
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
#endif
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCallOneArg) */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) != (0)) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
#if CYTHON_VECTORCALL && !CYTHON_COMPILING_IN_LIMITED_API
  #if PY_VERSION_HEX < 0x03090000
    #define __Pyx_PyVectorcall_Function(callable) _PyVectorcall_Function(callable)
  #elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE vectorcallfunc __Pyx_PyVectorcall_Function(PyObject *callable) {
    PyTypeObject *tp = Py_TYPE(callable);
    #if defined(__Pyx_CyFunction_USED)
    if (__Pyx_CyFunction_CheckExact(callable)) {
        return __Pyx_CyFunction_func_vectorcall(callable);
    }
    #endif
    if (!PyType_HasFeature(tp, Py_TPFLAGS_HAVE_VECTORCALL)) {
        return NULL;
    }
    assert(PyCallable_Check(callable));
    Py_ssize_t offset = tp->tp_vectorcall_offset;
    assert(offset > 0);
    vectorcallfunc ptr;
    memcpy(&ptr, (char *) callable + offset, sizeof(ptr));
    return ptr;
}
  #else
    #define __Pyx_PyVectorcall_Function(callable) PyVectorcall_Function(callable)
  #endif
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject *const *args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
          #if CYTHON_COMPILING_IN_LIMITED_API
            return PyObject_Vectorcall(func, args, _nargs, NULL);
          #else
            vectorcallfunc f = __Pyx_PyVectorcall_Function(func);
            if (f) {
                return f(func, args, _nargs, NULL);
            }
          #endif
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_mstate_global->__pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
#elif CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject **args, Py_ssize_t nargs, PyObject *kwnames) {
        return _PyObject_Vectorcall
            (method, args ? args+1 : NULL, nargs ? nargs-1 : 0, kwnames);
}
#else
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *const *args, Py_ssize_t nargs, PyObject *kwnames) {
    return
#if PY_VERSION_HEX < 0x03090000
    _PyObject_Vectorcall
#else
    PyObject_Vectorcall
#endif
        (method, args ? args+1 : NULL, nargs ? (size_t) nargs-1 : 0, kwnames);
}
#endif
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
     METH_VARARGS | METH_KEYWORDS,
#else
     METH_FASTCALL | METH_KEYWORDS,
#endif
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method, *result=NULL;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    result = method;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            result = unbound_method;
        }
    }
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    if (unlikely(target->method)) {
        Py_DECREF(result);
    } else
#endif
    target->method = result;
    return 0;
}

/* CallUnboundCMethod0 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        if (likely(cfunc->flag == METH_NOARGS))
            return __Pyx_CallCFunction(cfunc, self, NULL);
        if (likely(cfunc->flag == METH_FASTCALL))
            return __Pyx_CallCFunctionFast(cfunc, self, NULL, 0);
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, NULL, 0, NULL);
        if (likely(cfunc->flag == (METH_VARARGS | METH_KEYWORDS)))
            return __Pyx_CallCFunctionWithKeywords(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple, NULL);
        if (cfunc->flag == METH_VARARGS)
            return __Pyx_CallCFunction(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple);
        return __Pyx__CallUnboundCMethod0(cfunc, self);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod0(&tmp_cfunc, self);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod0(cfunc, self);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *result;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
    result = __Pyx_PyObject_CallOneArg(cfunc->method, self);
    return result;
}

/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, args, 2);
        }
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, 2, NULL);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod2(&tmp_cfunc, self, arg1, arg2);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *result = NULL;
        PyObject *args = PyTuple_New(2);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
        return result;
    }
#endif
    {
        PyObject *args[4] = {NULL, self, arg1, arg2};
        return __Pyx_PyObject_FastCall(cfunc->method, args+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
    }
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* pybuiltin_invalid (used by pyint_simplify) */
static void __Pyx_PyBuiltin_Invalid(PyObject *obj, const char *type_name, const char *argname) {
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    if (argname) {
        PyErr_Format(PyExc_TypeError,
            "Argument '%.200s' has incorrect type (expected %.200s, got " __Pyx_FMT_TYPENAME ")",
            argname, type_name, obj_type_name
        );
    } else {
        PyErr_Format(PyExc_TypeError,
            "Expected %.200s, got " __Pyx_FMT_TYPENAME,
            type_name, obj_type_name
        );
    }
    __Pyx_DECREF_TypeName(obj_type_name);
}

/* pyint_simplify */
static CYTHON_INLINE int __Pyx_PyInt_FromNumber(PyObject **number_var, const char *argname, int accept_none) {
    PyObject *number = *number_var;
    if (likely((accept_none && number == Py_None) || PyLong_CheckExact(number))) {
        return 0;
    }
    PyObject *int_object;
    if (likely(PyNumber_Check(number))) {
        int_object = PyNumber_Long(number);
        if (unlikely(!int_object)) goto bad;
    } else {
        __Pyx_PyBuiltin_Invalid(number, "int", argname);
        goto bad;
    }
    *number_var = int_object;
    Py_DECREF(number);
    return 0;
bad:
    *number_var = NULL;
    Py_DECREF(number);
    return -1;
}

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* PyDictVersioning (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        if (!PyErr_Occurred())
            PyErr_SetNone(PyExc_NameError);
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
    PyErr_Clear();
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    if (unlikely(__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, name, &result) == -1)) PyErr_Clear();
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return result;
    }
#else
    result = _PyDict_GetItem_KnownHash(__pyx_mstate_global->__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* PyObjectCallNoArg (used by pyfrozenset_new) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* pyfrozenset_new (used by PySetContains) */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it) {
    if (it) {
        PyObject* result;
#if CYTHON_COMPILING_IN_PYPY
        PyObject* args;
        args = PyTuple_Pack(1, it);
        if (unlikely(!args))
            return NULL;
        result = PyObject_Call((PyObject*)&PyFrozenSet_Type, args, NULL);
        Py_DECREF(args);
        return result;
#else
        if (PyFrozenSet_CheckExact(it)) {
            Py_INCREF(it);
            return it;
        }
        result = PyFrozenSet_New(it);
        if (unlikely(!result))
            return NULL;
        if ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
#if CYTHON_COMPILING_IN_LIMITED_API
            || __Pyx_get_runtime_version() >= 0x030A0000
#endif
            )
            return result;
        {
            Py_ssize_t size = __Pyx_PySet_GET_SIZE(result);
            if (likely(size > 0))
                return result;
#if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely(size < 0)) {
                Py_DECREF(result);
                return NULL;
            }
#endif
        }
        Py_DECREF(result);
#endif
    }
    return __Pyx_PyObject_CallNoArg((PyObject*) &PyFrozenSet_Type);
}

/* PySetContains */
static int __Pyx_PySet_ContainsUnhashable(PyObject *set, PyObject *key) {
    int result = -1;
    if (PySet_Check(key) && PyErr_ExceptionMatches(PyExc_TypeError)) {
        PyObject *tmpkey;
        PyErr_Clear();
        tmpkey = __Pyx_PyFrozenSet_New(key);
        if (tmpkey != NULL) {
            result = PySet_Contains(set, tmpkey);
            Py_DECREF(tmpkey);
        }
    }
    return result;
}
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq) {
    int result = PySet_Contains(set, key);
    if (unlikely(result < 0)) {
        result = __Pyx_PySet_ContainsUnhashable(set, key);
    }
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyObjectVectorCallKwBuilder (used by PyObjectVectorCallMethodKwBuilder) */
#if CYTHON_VECTORCALL
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_PyObject_FastCallDict;
    if (__Pyx_PyTuple_SET_ITEM(builder, n, key) != (0)) return -1;
    Py_INCREF(key);
    args[n] = value;
    return 0;
}
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_VectorcallBuilder_AddArgStr;
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n);
}
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    PyObject *pyKey = PyUnicode_FromString(key);
    if (!pyKey) return -1;
    return __Pyx_VectorcallBuilder_AddArg(pyKey, value, builder, args, n);
}
#else // CYTHON_VECTORCALL
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, CYTHON_UNUSED PyObject **args, CYTHON_UNUSED int n) {
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return PyDict_SetItem(builder, key, value);
}
#endif

/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* PyObjectCall2Args (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    int was_initialized =  __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return __Pyx_CallCFunction(cfunc, self, arg);
        } else if (flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, &arg, 1);
        } else if (flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, &arg, 1, NULL);
        }
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod1(&tmp_cfunc, self, arg);
    }
#endif
    PyObject* result = __Pyx__CallUnboundCMethod1(cfunc, self, arg);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *args = PyTuple_New(1);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
    } else
#endif
    {
        result = __Pyx_PyObject_Call2Args(cfunc->method, self, arg);
    }
    return result;
}

/* set_iter */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    is_set = is_set || likely(PySet_CheckExact(iterable) || PyFrozenSet_CheckExact(iterable));
    *p_source_is_set = is_set;
    if (likely(is_set)) {
        *p_orig_length = PySet_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
    }
#else
    CYTHON_UNUSED_VAR(is_set);
    *p_source_is_set = 0;
#endif
    *p_orig_length = 0;
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set) {
    if (!CYTHON_COMPILING_IN_CPYTHON || PY_VERSION_HEX >= 0x030d0000 || unlikely(!source_is_set)) {
        *value = PyIter_Next(iter_obj);
        if (unlikely(!*value)) {
            return __Pyx_IterFinish();
        }
        CYTHON_UNUSED_VAR(orig_length);
        CYTHON_UNUSED_VAR(ppos);
        return 1;
    }
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    if (unlikely(PySet_GET_SIZE(iter_obj) != orig_length)) {
        PyErr_SetString(
            PyExc_RuntimeError,
            "set changed size during iteration");
        return -1;
    }
    {
        Py_hash_t hash;
        int ret = _PySet_NextEntry(iter_obj, ppos, value, &hash);
        assert (ret != -1);
        if (likely(ret)) {
            Py_INCREF(*value);
            return 1;
        }
    }
#endif
    return 0;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS)) {
        return __Pyx_PyList_GetItemRefFast(o, wrapped_i, unsafe_shared);
    } else
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyList_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyTuple_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)) {
            return __Pyx_PyList_GetItemRefFast(o, n, unsafe_shared);
        } else if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            return __Pyx_NewRef(PyList_GET_ITEM(o, n));
        }
    } else
    #if !CYTHON_AVOID_BORROWED_REFS
    if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            return __Pyx_NewRef(PyTuple_GET_ITEM(o, n));
        }
    } else
    #endif
#endif
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
    {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (!is_list && mm && mm->mp_subscript) {
            PyObject *r, *key = PyLong_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (is_list || likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    (void)wraparound;
    (void)boundscheck;
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_mstate_global->__pyx_n_u_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* RaiseClosureNameError */
static void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* PyFloatBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_AddObjC(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check) {
    const double b = floatval;
    double a, result;
    CYTHON_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    if (likely(PyFloat_CheckExact(op1))) {
        a = __Pyx_PyFloat_AS_DOUBLE(op1);
        
    } else
    if (likely(PyLong_CheckExact(op1))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsZero(op1)) {
            a = 0.0;
            
        } else if (__Pyx_PyLong_IsCompact(op1)) {
            a = (double) __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                case 2:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                        a = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -2)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                case 3:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                        a = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -3)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                case 4:
                    if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                        a = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -4)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                default:
        #endif
                    a = PyLong_AsDouble(op1);
                    if (unlikely(a == -1.0 && PyErr_Occurred())) return NULL;
        #if CYTHON_USE_PYLONG_INTERNALS
            }
        }
        #endif
    } else {
        return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
    }
        result = a + b;
        return PyFloat_FromDouble(result);
}
#endif

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op2);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    calculate_long:
        {
            long x;
            x = a + b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla + llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_AddObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) + (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_AddObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_AddObjC(op1, op2, inplace);
}
#endif

/* RaiseUnboundLocalError */
static void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* GetException (used by pep479) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C0000
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#elif __PYX_LIMITED_VERSION_HEX > 0x030C0000
    local_value = PyErr_GetRaisedException();
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
#if __PYX_LIMITED_VERSION_HEX > 0x030C0000
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
#else
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
#endif // __PYX_LIMITED_VERSION_HEX > 0x030C0000
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#elif __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    PyErr_SetHandledException(local_value);
    Py_XDECREF(local_value);
    Py_XDECREF(local_type);
    Py_XDECREF(local_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
#if __PYX_LIMITED_VERSION_HEX <= 0x030C0000
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
#endif
}

/* pep479 */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen) {
    PyObject *exc, *val, *tb, *cur_exc, *new_exc;
    __Pyx_PyThreadState_declare
    int is_async_stopiteration = 0;
    CYTHON_MAYBE_UNUSED_VAR(in_async_gen);
    __Pyx_PyThreadState_assign
    cur_exc = __Pyx_PyErr_CurrentExceptionType();
    if (likely(!__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopIteration))) {
        if (in_async_gen && unlikely(__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopAsyncIteration))) {
            is_async_stopiteration = 1;
        } else {
            return;
        }
    }
    __Pyx_GetException(&exc, &val, &tb);
    Py_XDECREF(exc);
    Py_XDECREF(tb);
    new_exc = PyObject_CallFunction(PyExc_RuntimeError, "s",
        is_async_stopiteration ? "async generator raised StopAsyncIteration" :
        in_async_gen ? "async generator raised StopIteration" :
        "generator raised StopIteration");
    if (!new_exc) {
        Py_XDECREF(val);
        return;
    }
    PyException_SetCause(new_exc, val); // steals ref to val
    PyErr_SetObject(PyExc_RuntimeError, new_exc);
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* HasAttr */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    if (max_char > 1114111) max_char = 1114111;
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - result_ulength < 0))
        goto overflow;
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = values[i];
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (__Pyx_PyUnicode_READY(uval) == (-1))
            goto bad;
        #endif
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(ulength < 0)) goto bad;
        #endif
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    Py_ssize_t i;
    PyObject *result = NULL;
    PyObject *value_tuple = PyTuple_New(value_count);
    if (unlikely(!value_tuple)) return NULL;
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    for (i=0; i<value_count; i++) {
        if (__Pyx_PyTuple_SET_ITEM(value_tuple, i, values[i]) != (0)) goto bad;
        Py_INCREF(values[i]);
    }
    result = PyUnicode_Join(__pyx_mstate_global->__pyx_empty_unicode, value_tuple);
bad:
    Py_DECREF(value_tuple);
    return result;
#endif
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* py_set_discard_unhashable (used by py_set_discard) */
static int __Pyx_PySet_DiscardUnhashable(PyObject *set, PyObject *key) {
    PyObject *tmpkey;
    int rv;
    if (likely(!PySet_Check(key) || !PyErr_ExceptionMatches(PyExc_TypeError)))
        return -1;
    PyErr_Clear();
    tmpkey = __Pyx_PyFrozenSet_New(key);
    if (tmpkey == NULL)
        return -1;
    rv = PySet_Discard(set, tmpkey);
    Py_DECREF(tmpkey);
    return rv;
}

/* py_set_discard */
static CYTHON_INLINE int __Pyx_PySet_Discard(PyObject *set, PyObject *key) {
    int found = PySet_Discard(set, key);
    if (unlikely(found < 0)) {
        found = __Pyx_PySet_DiscardUnhashable(set, key);
    }
    return found;
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static Py_ssize_t __Pyx_GetTypeDictOffset(void) {
    PyObject *tp_dictoffset_o;
    Py_ssize_t tp_dictoffset;
    tp_dictoffset_o = PyObject_GetAttrString((PyObject*)(&PyType_Type), "__dictoffset__");
    if (unlikely(!tp_dictoffset_o)) return -1;
    tp_dictoffset = PyLong_AsSsize_t(tp_dictoffset_o);
    Py_DECREF(tp_dictoffset_o);
    if (unlikely(tp_dictoffset == 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' doesn't have a dictoffset");
        return -1;
    } else if (unlikely(tp_dictoffset < 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' has an unexpected negative dictoffset. "
            "Please report this as Cython bug");
        return -1;
    }
    return tp_dictoffset;
}
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp) {
    static Py_ssize_t tp_dictoffset = 0;
    if (unlikely(tp_dictoffset == 0)) {
        tp_dictoffset = __Pyx_GetTypeDictOffset();
        if (unlikely(tp_dictoffset == -1 && PyErr_Occurred())) {
            tp_dictoffset = 0; // try again next time?
            return NULL;
        }
    }
    return *(PyObject**)((char*)tp + tp_dictoffset);
}
#endif

/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType (used by FetchCommonType) */
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if __PYX_LIMITED_VERSION_HEX > 0x030900B1
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#else
    const PyType_Slot *slot = spec->slots;
    int changed = 0;
#if !CYTHON_COMPILING_IN_LIMITED_API
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
#if !CYTHON_COMPILING_IN_CPYTHON
        const
#endif  // !CYTHON_COMPILING_IN_CPYTHON)
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_vectorcall_offset = memb->offset;
                    changed = 1;
                }
#endif  // CYTHON_METH_FASTCALL
#if !CYTHON_COMPILING_IN_PYPY
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                    Py_DECREF(descr);
                    if (unlikely(set_item_result < 0)) {
                        return -1;
                    }
                    changed = 1;
                }
#endif  // !CYTHON_COMPILING_IN_PYPY
            }
            memb++;
        }
    }
#endif  // !CYTHON_COMPILING_IN_LIMITED_API
#if !CYTHON_COMPILING_IN_PYPY
    slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_getset)
        slot++;
    if (slot && slot->slot == Py_tp_getset) {
        PyGetSetDef *getset = (PyGetSetDef*) slot->pfunc;
        while (getset && getset->name) {
            if (getset->name[0] == '_' && getset->name[1] == '_' && strcmp(getset->name, "__module__") == 0) {
                PyObject *descr = PyDescr_NewGetSet(type, getset);
                if (unlikely(!descr))
                    return -1;
                #if CYTHON_COMPILING_IN_LIMITED_API
                PyObject *pyname = PyUnicode_FromString(getset->name);
                if (unlikely(!pyname)) {
                    Py_DECREF(descr);
                    return -1;
                }
                int set_item_result = __Pyx_SetItemOnTypeDict(type, pyname, descr);
                Py_DECREF(pyname);
                #else
                CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
                int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                #endif
                Py_DECREF(descr);
                if (unlikely(set_item_result < 0)) {
                    return -1;
                }
                changed = 1;
            }
            ++getset;
        }
    }
#else
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#endif  // !CYTHON_COMPILING_IN_PYPY
    if (changed)
        PyType_Modified(type);
#endif  // PY_VERSION_HEX > 0x030900B1
    return 0;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  static PyObject *__Pyx_PyImport_AddModuleObjectRef(PyObject *name) {
      PyObject *module_dict = PyImport_GetModuleDict();
      PyObject *m;
      if (PyMapping_GetOptionalItem(module_dict, name, &m) < 0) {
          return NULL;
      }
      if (m != NULL && PyModule_Check(m)) {
          return m;
      }
      Py_XDECREF(m);
      m = PyModule_NewObject(name);
      if (m == NULL)
          return NULL;
      if (PyDict_CheckExact(module_dict)) {
          PyObject *new_m;
          (void)PyDict_SetDefaultRef(module_dict, name, m, &new_m);
          Py_DECREF(m);
          return new_m;
      } else {
           if (PyObject_SetItem(module_dict, name, m) != 0) {
                Py_DECREF(m);
                return NULL;
            }
            return m;
      }
  }
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *py_name = PyUnicode_FromString(name);
      if (!py_name) return NULL;
      PyObject *module = __Pyx_PyImport_AddModuleObjectRef(py_name);
      Py_DECREF(py_name);
      return module;
  }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif

/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject* __Pyx_PyType_FromMetaclass(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *result = __Pyx_PyType_FromModuleAndSpec(module, spec, bases);
    if (result && metaclass) {
        PyObject *old_tp = (PyObject*)Py_TYPE(result);
    Py_INCREF((PyObject*)metaclass);
#if __PYX_LIMITED_VERSION_HEX >= 0x03090000
        Py_SET_TYPE(result, metaclass);
#else
        result->ob_type = metaclass;
#endif
        Py_DECREF(old_tp);
    }
    return result;
}
#else
#define __Pyx_PyType_FromMetaclass(me, mo, s, b) PyType_FromMetaclass(me, mo, s, b)
#endif
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t expected_basicsize) {
    Py_ssize_t basicsize;
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (expected_basicsize == 0) {
        return 0; // size is inherited, nothing useful to check
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
    if (unlikely(!py_basicsize)) return -1;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = NULL;
    if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) return -1;
#else
    basicsize = ((PyTypeObject*) cached_type)->tp_basicsize;
#endif
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module = NULL, *cached_type = NULL, *abi_module_dict, *new_cached_type, *py_object_name;
    int get_item_ref_result;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    py_object_name = PyUnicode_FromString(object_name);
    if (!py_object_name) return NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) goto done;
    abi_module_dict = PyModule_GetDict(abi_module);
    if (!abi_module_dict) goto done;
    get_item_ref_result = __Pyx_PyDict_GetItemRef(abi_module_dict, py_object_name, &cached_type);
    if (get_item_ref_result == 1) {
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else if (unlikely(get_item_ref_result == -1)) {
        goto bad;
    }
    cached_type = __Pyx_PyType_FromMetaclass(
        metaclass,
        CYTHON_USE_MODULE_STATE ? module : abi_module,
        spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    new_cached_type = __Pyx_PyDict_SetDefault(abi_module_dict, py_object_name, cached_type);
    if (unlikely(new_cached_type != cached_type)) {
        if (unlikely(!new_cached_type)) goto bad;
        Py_DECREF(cached_type);
        cached_type = new_cached_type;
        if (__Pyx_VerifyCachedType(
                cached_type,
                object_name,
                spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else {
        Py_DECREF(new_cached_type);
    }
done:
    Py_XDECREF(abi_module);
    Py_DECREF(py_object_name);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CommonTypesMetaclass (used by CythonFunctionShared) */
static PyObject* __pyx_CommonTypesMetaclass_get_module(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED void* context) {
    return PyUnicode_FromString(__PYX_ABI_MODULE_NAME);
}
#if __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject* __pyx_CommonTypesMetaclass_call(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwds) {
    PyErr_SetString(PyExc_TypeError, "Cannot instantiate Cython internal types");
    return NULL;
}
static int __pyx_CommonTypesMetaclass_setattr(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *attr, CYTHON_UNUSED PyObject *value) {
    PyErr_SetString(PyExc_TypeError, "Cython internal types are immutable");
    return -1;
}
#endif
static PyGetSetDef __pyx_CommonTypesMetaclass_getset[] = {
    {"__module__", __pyx_CommonTypesMetaclass_get_module, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_CommonTypesMetaclass_slots[] = {
    {Py_tp_getset, (void *)__pyx_CommonTypesMetaclass_getset},
    #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {Py_tp_call, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_new, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_setattro, (void*)__pyx_CommonTypesMetaclass_setattr},
    #endif
    {0, 0}
};
static PyType_Spec __pyx_CommonTypesMetaclass_spec = {
    __PYX_TYPE_MODULE_PREFIX "_common_types_metatype",
    0,
    0,
    Py_TPFLAGS_IMMUTABLETYPE |
    Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT,
    __pyx_CommonTypesMetaclass_slots
};
static int __pyx_CommonTypesMetaclass_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    PyObject *bases = PyTuple_Pack(1, &PyType_Type);
    if (unlikely(!bases)) {
        return -1;
    }
    mstate->__pyx_CommonTypesMetaclassType = __Pyx_FetchCommonTypeFromSpec(NULL, module, &__pyx_CommonTypesMetaclass_spec, bases);
    Py_DECREF(bases);
    if (unlikely(mstate->__pyx_CommonTypesMetaclassType == NULL)) {
        return -1;
    }
    return 0;
}

/* CallTypeTraverse (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i;
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos;
    #else
    Py_ssize_t pos;
    #endif
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    #if !CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t nkw = PyDict_Size(kw);
    if (unlikely(nkw == -1)) return NULL;
    #else
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    #endif
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = 0;
    i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (__Pyx_PyDict_NextRef(kw, &pos, &key, &value)) {
        keys_are_strings &=
        #if CYTHON_COMPILING_IN_LIMITED_API
            PyType_GetFlags(Py_TYPE(key));
        #else
            Py_TYPE(key)->tp_flags;
        #endif
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(PyTuple_SetItem(kwnames, i, key) < 0)) goto cleanup;
        #else
        PyTuple_SET_ITEM(kwnames, i, key);
        #endif
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(pos);
    #endif
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    Py_ssize_t kw_size =
        likely(kw == NULL) ?
        0 :
#if !CYTHON_ASSUME_SAFE_SIZE
        PyDict_Size(kw);
#else
        PyDict_GET_SIZE(kw);
#endif
    if (kw_size == 0) {
        return vc(func, args, nargs, NULL);
    }
#if !CYTHON_ASSUME_SAFE_SIZE
    else if (unlikely(kw_size == -1)) {
        return NULL;
    }
#endif
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* PyFloatBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_TrueDivideCObj(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check) {
    const double a = floatval;
    double b, result;
    CYTHON_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    if (likely(PyFloat_CheckExact(op2))) {
        b = __Pyx_PyFloat_AS_DOUBLE(op2);
        if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
    } else
    if (likely(PyLong_CheckExact(op2))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsZero(op2)) {
            b = 0.0;
            if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
        } else if (__Pyx_PyLong_IsCompact(op2)) {
            b = (double) __Pyx_PyLong_CompactValue(op2);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op2);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op2);
            switch (size) {
                case -2:
                case 2:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                        b = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -2)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                case 3:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                        b = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -3)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                case 4:
                    if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                        b = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -4)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                default:
        #endif
                    b = PyLong_AsDouble(op2);
                    if (unlikely(b == -1.0 && PyErr_Occurred())) return NULL;
                    #if !CYTHON_USE_PYLONG_INTERNALS
                    if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
                    #endif
        #if CYTHON_USE_PYLONG_INTERNALS
            }
        }
        #endif
    } else {
        return (inplace ? PyNumber_InPlaceTrueDivide : PyNumber_TrueDivide)(op1, op2);
    }
        result = a / b;
        return PyFloat_FromDouble(result);
}
#endif

/* PyFloatBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_AddCObj(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check) {
    const double a = floatval;
    double b, result;
    CYTHON_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    if (likely(PyFloat_CheckExact(op2))) {
        b = __Pyx_PyFloat_AS_DOUBLE(op2);
        
    } else
    if (likely(PyLong_CheckExact(op2))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsZero(op2)) {
            b = 0.0;
            
        } else if (__Pyx_PyLong_IsCompact(op2)) {
            b = (double) __Pyx_PyLong_CompactValue(op2);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op2);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op2);
            switch (size) {
                case -2:
                case 2:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                        b = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -2)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                case 3:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                        b = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -3)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                case 4:
                    if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                        b = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -4)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                default:
        #endif
                    b = PyLong_AsDouble(op2);
                    if (unlikely(b == -1.0 && PyErr_Occurred())) return NULL;
        #if CYTHON_USE_PYLONG_INTERNALS
            }
        }
        #endif
    } else {
        return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
    }
        result = a + b;
        return PyFloat_FromDouble(result);
}
#endif

/* py_abs */
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject *__Pyx_PyLong_AbsNeg(PyObject *n) {
#if PY_VERSION_HEX >= 0x030C00A7
    if (likely(__Pyx_PyLong_IsCompact(n))) {
        return PyLong_FromSize_t(__Pyx_PyLong_CompactValueUnsigned(n));
    }
#else
    if (likely(Py_SIZE(n) == -1)) {
        return PyLong_FromUnsignedLong(__Pyx_PyLong_Digits(n)[0]);
    }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
    {
        PyObject *copy = _PyLong_Copy((PyLongObject*)n);
        if (likely(copy)) {
            #if PY_VERSION_HEX >= 0x030C00A7
            ((PyLongObject*)copy)->long_value.lv_tag ^= ((PyLongObject*)copy)->long_value.lv_tag & _PyLong_SIGN_MASK;
            #else
            __Pyx_SET_SIZE(copy, -Py_SIZE(copy));
            #endif
        }
        return copy;
    }
#else
    return PyNumber_Negative(n);
#endif
}
#endif

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(tp);
    PyErr_Format(PyExc_AttributeError,
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}
#endif

/* PyObjectCallMethod0 (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* RaiseNoneIterError (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else {
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(t);
 #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely(size < 0)) return;
 #endif
      if (size < index) {
        __Pyx_RaiseNeedMoreValuesError(size);
      } else {
        __Pyx_RaiseTooManyValuesError(index);
      }
    }
}

/* UnpackTuple2 (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
        PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple) {
    if (likely(is_tuple || PyTuple_Check(tuple))) {
        Py_ssize_t size;
        if (has_known_size) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        size = __Pyx_PyTuple_GET_SIZE(tuple);
        if (likely(size == 2)) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        if (size >= 0) {
            __Pyx_UnpackTupleError(tuple, 2);
        }
        return -1;
    } else {
        return __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple);
    }
}
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
    value1 = __Pyx_PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = __Pyx_PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#else
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
#if !CYTHON_AVOID_BORROWED_REFS
static CYTHON_INLINE int __Pyx_dict_iter_next_source_is_dict(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem) {
    PyObject *key, *value;
    if (unlikely(orig_length != PyDict_Size(iter_obj))) {
        PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
        return -1;
    }
    if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
        return 0;
    }
    if (pitem) {
        PyObject* tuple = PyTuple_New(2);
        if (unlikely(!tuple)) {
            return -1;
        }
        Py_INCREF(key);
        Py_INCREF(value);
        #if CYTHON_ASSUME_SAFE_MACROS
        PyTuple_SET_ITEM(tuple, 0, key);
        PyTuple_SET_ITEM(tuple, 1, value);
        #else
        if (unlikely(PyTuple_SetItem(tuple, 0, key) < 0)) {
            Py_DECREF(value);
            Py_DECREF(tuple);
            return -1;
        }
        if (unlikely(PyTuple_SetItem(tuple, 1, value) < 0)) {
            Py_DECREF(tuple);
            return -1;
        }
        #endif
        *pitem = tuple;
    } else {
        if (pkey) {
            Py_INCREF(key);
            *pkey = key;
        }
        if (pvalue) {
            Py_INCREF(value);
            *pvalue = value;
        }
    }
    return 1;
}
#endif
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_AVOID_BORROWED_REFS
    if (source_is_dict) {
        int result;
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_BEGIN_CRITICAL_SECTION(iter_obj);
#endif
        result = __Pyx_dict_iter_next_source_is_dict(iter_obj, orig_length, ppos, pkey, pvalue, pitem);
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_END_CRITICAL_SECTION();
#endif
        return result;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(tuple_size < 0)) return -1;
        #endif
        if (unlikely(pos >= tuple_size)) return 0;
        *ppos = pos + 1;
        #if CYTHON_ASSUME_SAFE_MACROS
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        #else
        next_item = PyTuple_GetItem(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
        #endif
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t list_size = __Pyx_PyList_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(list_size < 0)) return -1;
        #endif
        if (unlikely(pos >= list_size)) return 0;
        *ppos = pos + 1;
        next_item = __Pyx_PyList_GetItemRef(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* SliceTupleAndList */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    return __Pyx_PyTuple_FromArray(((PyTupleObject*)src)->ob_item + start, length);
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice_locked(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (length <= 0) {
        return PyList_New(0);
    }
    return __Pyx_PyList_FromArray(((PyListObject*)src)->ob_item + start, length);
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(src);
    result = __Pyx_PyList_GetSlice_locked(src, start, stop);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
#endif // CYTHON_COMPILING_IN_CPYTHON

/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyBytes_CheckExact(key) || PyUnicode_CheckExact(key) || PyLong_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* ValidateBasesTuple (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_SIZE
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (unlikely(n < 0)) return -1;
#endif
    for (i = 1; i < n; i++)
    {
        PyTypeObject *b;
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !CYTHON_USE_TYPE_SLOTS
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* ImportImpl (used by Import) */
static int __Pyx__Import_GetModule(PyObject *qualname, PyObject **module) {
    PyObject *imported_module = PyImport_GetModule(qualname);
    if (unlikely(!imported_module)) {
        *module = NULL;
        if (PyErr_Occurred()) {
            return -1;
        }
        return 0;
    }
    *module = imported_module;
    return 1;
}
static int __Pyx__Import_Lookup(PyObject *qualname, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject **module) {
    PyObject *imported_module;
    PyObject *top_level_package_name;
    Py_ssize_t i;
    int status, module_found;
    Py_ssize_t dot_index;
    module_found = __Pyx__Import_GetModule(qualname, &imported_module);
    if (unlikely(!module_found || module_found == -1)) {
        *module = NULL;
        return module_found;
    }
    if (imported_names) {
        for (i = 0; i < len_imported_names; i++) {
            PyObject *imported_name = imported_names[i];
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
            int has_imported_attribute = PyObject_HasAttr(imported_module, imported_name);
#else
            int has_imported_attribute = PyObject_HasAttrWithError(imported_module, imported_name);
            if (unlikely(has_imported_attribute == -1)) goto error;
#endif
            if (!has_imported_attribute) {
                goto not_found;
            }
        }
        *module = imported_module;
        return 1;
    }
    dot_index = PyUnicode_FindChar(qualname, '.', 0, PY_SSIZE_T_MAX, 1);
    if (dot_index == -1) {
        *module = imported_module;
        return 1;
    }
    if (unlikely(dot_index == -2)) goto error;
    top_level_package_name = PyUnicode_Substring(qualname, 0, dot_index);
    if (unlikely(!top_level_package_name)) goto error;
    Py_DECREF(imported_module);
    status = __Pyx__Import_GetModule(top_level_package_name, module);
    Py_DECREF(top_level_package_name);
    return status;
error:
    Py_DECREF(imported_module);
    *module = NULL;
    return -1;
not_found:
    Py_DECREF(imported_module);
    *module = NULL;
    return 0;
}
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *from_list = 0;
    int module_found;
    if (!qualname) {
        qualname = name;
    }
    module_found = __Pyx__Import_Lookup(qualname, imported_names, len_imported_names, &module);
    if (likely(module_found == 1)) {
        return module;
    } else if (unlikely(module_found == -1)) {
        return NULL;
    }
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    if (imported_names) {
#if CYTHON_COMPILING_IN_CPYTHON
        from_list = __Pyx_PyList_FromArray(imported_names, len_imported_names);
        if (unlikely(!from_list))
            goto bad;
#else
        from_list = PyList_New(len_imported_names);
        if (unlikely(!from_list)) goto bad;
        for (Py_ssize_t i=0; i<len_imported_names; ++i) {
            if (PyList_SetItem(from_list, i, __Pyx_NewRef(imported_names[i])) < 0) goto bad;
        }
#endif
    }
    if (level == -1) {
        const char* package_sep = strchr(__Pyx_MODULE_NAME, '.');
        if (package_sep != (0)) {
            module = PyImport_ImportModuleLevelObject(
                name, moddict, empty_dict, from_list, 1);
            if (unlikely(!module)) {
                if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                    goto bad;
                PyErr_Clear();
            }
        }
        level = 0;
    }
    if (!module) {
        module = PyImport_ImportModuleLevelObject(
            name, moddict, empty_dict, from_list, level);
    }
bad:
    Py_XDECREF(from_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__8);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* CalculateMetaclass (used by Py3ClassCreate) */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_SIZE
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
        metaclass = &PyType_Type;
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* PyObjectLookupSpecial (used by Py3ClassCreate) */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_mstate_global->__pyx_n_u_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_module_2, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_mstate_global->__pyx_n_u_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_mstate_global->__pyx_n_u_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
    Py_XDECREF(owned_metaclass);
    return result;
}

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static __Pyx_CachedCodeObjectType *__pyx__find_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line) {
    __Pyx_CachedCodeObjectType* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!code_cache->entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if (unlikely(pos >= code_cache->count) || unlikely(code_cache->entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = code_cache->entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__find_code_object;
    return NULL; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just miss.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type old_count = __pyx_atomic_incr_acq_rel(&code_cache->accessor_count);
    if (old_count < 0) {
        __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
        return NULL;
    }
#endif
    __Pyx_CachedCodeObjectType *result = __pyx__find_code_object(code_cache, code_line);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
#endif
    return result;
#endif
}
static void __pyx__insert_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line, __Pyx_CachedCodeObjectType* code_object)
{
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = code_cache->entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            code_cache->entries = entries;
            code_cache->max_count = 64;
            code_cache->count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if ((pos < code_cache->count) && unlikely(code_cache->entries[pos].code_line == code_line)) {
        __Pyx_CachedCodeObjectType* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_INCREF(code_object);
        Py_DECREF(tmp);
        return;
    }
    if (code_cache->count == code_cache->max_count) {
        int new_max = code_cache->max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            code_cache->entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        code_cache->entries = entries;
        code_cache->max_count = new_max;
    }
    for (i=code_cache->count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    code_cache->count++;
    Py_INCREF(code_object);
}
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__insert_code_object;
    return; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just fail.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type expected = 0;
    if (!__pyx_atomic_int_cmp_exchange(&code_cache->accessor_count, &expected, INT_MIN)) {
        return;
    }
#endif
    __pyx__insert_code_object(code_cache, code_line, code_object);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_sub(&code_cache->accessor_count, INT_MIN);
#endif
#endif
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result = PyObject_Call(replace, __pyx_mstate_global->__pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!code_object) {
        code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
        if (unlikely(!code_object)) goto bad;
        py_py_line = PyLong_FromLong(py_line);
        if (unlikely(!py_py_line)) goto bad;
        if (c_line) {
            py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        } else {
            py_funcname = PyUnicode_FromString(funcname);
        }
        if (unlikely(!py_funcname)) goto bad;
        dict = PyDict_New();
        if (unlikely(!dict)) goto bad;
        {
            PyObject *old_code_object = code_object;
            code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
            Py_DECREF(old_code_object);
        }
        if (unlikely(!code_object)) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, code_object);
    } else {
        dict = PyDict_New();
    }
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    if (c_line) {
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
    }
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_mstate_global->__pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module_2);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__10);
    }
    goto done;
}
#endif

/* CIntFromPyVerify (used by CIntFromPy) */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyLong_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyLong_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* RaiseException (used by CoroutineBase) */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
#elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}

/* IterNextPlain (used by CoroutineBase) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *__Pyx_GetBuiltinNext_LimitedAPI(void) {
    if (unlikely(!__pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache))
        __pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache = __Pyx_GetBuiltinName(__pyx_mstate_global->__pyx_n_u_next);
    return __pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next_Plain(PyObject *iterator) {
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    PyObject *result;
    PyObject *next = __Pyx_GetBuiltinNext_LimitedAPI();
    if (unlikely(!next)) return NULL;
    result = PyObject_CallFunctionObjArgs(next, iterator, NULL);
    return result;
#else
    (void)__Pyx_GetBuiltinName; // only for early limited API
    iternextfunc iternext = __Pyx_PyObject_GetIterNextFunc(iterator);
    assert(iternext);
    return iternext(iterator);
#endif
}

/* PyObjectCallMethod1 (used by CoroutineBase) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* ReturnWithStopIteration (used by CoroutineBase) */
static void __Pyx__ReturnWithStopIteration(PyObject* value, int async);
static CYTHON_INLINE void __Pyx_ReturnWithStopIteration(PyObject* value, int async, int iternext) {
    if (value == Py_None) {
        if (async || !iternext)
            PyErr_SetNone(async ? PyExc_StopAsyncIteration : PyExc_StopIteration);
        return;
    }
    __Pyx__ReturnWithStopIteration(value, async);
}
static void __Pyx__ReturnWithStopIteration(PyObject* value, int async) {
#if CYTHON_COMPILING_IN_CPYTHON
    __Pyx_PyThreadState_declare
#endif
    PyObject *exc;
    PyObject *exc_type = async ? PyExc_StopAsyncIteration : PyExc_StopIteration;
#if CYTHON_COMPILING_IN_CPYTHON
    if ((PY_VERSION_HEX >= (0x030C00A6)) || unlikely(PyTuple_Check(value) || PyExceptionInstance_Check(value))) {
        if (PY_VERSION_HEX >= (0x030e00A1)) {
            exc = __Pyx_PyObject_CallOneArg(exc_type, value);
        } else {
            PyObject *args_tuple = PyTuple_New(1);
            if (unlikely(!args_tuple)) return;
            Py_INCREF(value);
            PyTuple_SET_ITEM(args_tuple, 0, value);
            exc = PyObject_Call(exc_type, args_tuple, NULL);
            Py_DECREF(args_tuple);
        }
        if (unlikely(!exc)) return;
    } else {
        Py_INCREF(value);
        exc = value;
    }
    #if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    #if CYTHON_USE_EXC_INFO_STACK
    if (!__pyx_tstate->exc_info->exc_value)
    #else
    if (!__pyx_tstate->exc_type)
    #endif
    {
        Py_INCREF(exc_type);
        __Pyx_ErrRestore(exc_type, exc, NULL);
        return;
    }
    #endif
#else
    exc = __Pyx_PyObject_CallOneArg(exc_type, value);
    if (unlikely(!exc)) return;
#endif
    PyErr_SetObject(exc_type, exc);
    Py_DECREF(exc);
}

/* CoroutineBase (used by Generator) */
#if !CYTHON_COMPILING_IN_LIMITED_API
#include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6 && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#endif // CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void
__Pyx_Coroutine_Undelegate(__pyx_CoroutineObject *gen) {
#if CYTHON_USE_AM_SEND
    gen->yieldfrom_am_send = NULL;
#endif
    Py_CLEAR(gen->yieldfrom);
}
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    CYTHON_UNUSED_VAR(__pyx_tstate);
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
        else if (likely(__Pyx_IS_TYPE(ev, (PyTypeObject*)PyExc_StopIteration))) {
            #if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
            value = PyObject_GetAttr(ev, __pyx_mstate_global->__pyx_n_u_value);
            if (unlikely(!value)) goto limited_api_failure;
            #else
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            #endif
            Py_DECREF(ev);
        }
        else if (unlikely(PyTuple_Check(ev))) {
            Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(ev);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely(tuple_size < 0)) {
                Py_XDECREF(tb);
                Py_DECREF(ev);
                Py_DECREF(et);
                return -1;
            }
            #endif
            if (tuple_size >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#elif CYTHON_ASSUME_SAFE_MACROS
                value = PySequence_ITEM(ev, 0);
#else
                value = PySequence_GetItem(ev, 0);
                if (!value) goto limited_api_failure;
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_GetAttr(ev, __pyx_mstate_global->__pyx_n_u_value);
#else
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
#endif
    Py_DECREF(ev);
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!value)) return -1;
#endif
    *pvalue = value;
    return 0;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL || !CYTHON_ASSUME_SAFE_MACROS
  limited_api_failure:
    Py_XDECREF(et);
    Py_XDECREF(tb);
    Py_XDECREF(ev);
    return -1;
#endif
}
static CYTHON_INLINE
__Pyx_PySendResult __Pyx_Coroutine_status_from_result(PyObject **retval) {
    if (*retval) {
        return PYGEN_NEXT;
    } else if (likely(__Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, retval) == 0)) {
        return PYGEN_RETURN;
    } else {
        return PYGEN_ERROR;
    }
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_CLEAR(exc_state->exc_value);
#else
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
#endif
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(__pyx_CoroutineObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
static void __Pyx_Coroutine_AlreadyTerminatedError(PyObject *gen, PyObject *value, int closing) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    CYTHON_MAYBE_UNUSED_VAR(closing);
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
__Pyx_PySendResult __Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, PyObject **result, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(__Pyx_Coroutine_get_is_running(self));  // Callers should ensure is_running
    if (unlikely(self->resume_label == -1)) {
        __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
        return PYGEN_ERROR;
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_value) {
        #if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        #else
        PyObject *exc_tb;
        #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
        exc_tb = PyException_GetTraceback(exc_state->exc_value);
        #elif PY_VERSION_HEX >= 0x030B00a4
        exc_tb = ((PyBaseExceptionObject*) exc_state->exc_value)->traceback;
        #else
        exc_tb = exc_state->exc_traceback;
        #endif
        if (exc_tb) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
            #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
            Py_DECREF(exc_tb);
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    retval = self->body(self, tstate, value);
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    *result = retval;
    if (self->resume_label == -1) {
        return likely(retval) ? PYGEN_RETURN : PYGEN_ERROR;
    }
    return PYGEN_NEXT;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(exc_state);
#else
    PyObject *exc_tb;
    #if PY_VERSION_HEX >= 0x030B00a4
    if (!exc_state->exc_value) return;
    exc_tb = PyException_GetTraceback(exc_state->exc_value);
    #else
    exc_tb = exc_state->exc_traceback;
    #endif
    if (likely(exc_tb)) {
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
        #if PY_VERSION_HEX >= 0x030B00a4
        Py_DECREF(exc_tb);
        #endif
    }
#endif
}
#define __Pyx_Coroutine_MethodReturnFromResult(gen, result, retval, iternext)\
    ((result) == PYGEN_NEXT ? (retval) : __Pyx__Coroutine_MethodReturnFromResult(gen, result, retval, iternext))
static PyObject *
__Pyx__Coroutine_MethodReturnFromResult(PyObject* gen, __Pyx_PySendResult result, PyObject *retval, int iternext) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if (likely(result == PYGEN_RETURN)) {
        int is_async = 0;
        #ifdef __Pyx_AsyncGen_USED
        is_async = __Pyx_AsyncGen_CheckExact(gen);
        #endif
        __Pyx_ReturnWithStopIteration(retval, is_async, iternext);
        Py_XDECREF(retval);
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
#if PY_VERSION_HEX < 0x030d00A1
            _PyGen_SetStopIterationValue(result);
#else
            if (!PyTuple_Check(result) && !PyExceptionInstance_Check(result)) {
                PyErr_SetObject(PyExc_StopIteration, result);
            } else {
                PyObject *exc = __Pyx_PyObject_CallOneArg(PyExc_StopIteration, result);
                if (likely(exc != NULL)) {
                    PyErr_SetObject(PyExc_StopIteration, exc);
                    Py_DECREF(exc);
                }
            }
#endif
        }
        Py_DECREF(result);
        result = NULL;
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE __Pyx_PySendResult
__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen, PyObject** retval) {
    __Pyx_PySendResult result;
    PyObject *val = NULL;
    assert(__Pyx_Coroutine_get_is_running(gen));
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    result = __Pyx_Coroutine_SendEx(gen, val, retval, 0);
    Py_XDECREF(val);
    return result;
}
#if CYTHON_USE_AM_SEND
static __Pyx_PySendResult
__Pyx_Coroutine_SendToDelegate(__pyx_CoroutineObject *gen, __Pyx_pyiter_sendfunc gen_am_send, PyObject *value, PyObject **retval) {
    PyObject *ret = NULL;
    __Pyx_PySendResult delegate_result, result;
    assert(__Pyx_Coroutine_get_is_running(gen));
    delegate_result = gen_am_send(gen->yieldfrom, value, &ret);
    if (delegate_result == PYGEN_NEXT) {
        assert (ret != NULL);
        *retval = ret;
        return PYGEN_NEXT;
    }
    assert (delegate_result != PYGEN_ERROR || ret == NULL);
    __Pyx_Coroutine_Undelegate(gen);
    result = __Pyx_Coroutine_SendEx(gen, ret, retval, 0);
    Py_XDECREF(ret);
    return result;
}
#endif
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval = NULL;
    __Pyx_PySendResult result = __Pyx_Coroutine_AmSend(self, value, &retval);
    return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 0);
}
static __Pyx_PySendResult
__Pyx_Coroutine_AmSend(PyObject *self, PyObject *value, PyObject **retval) {
    __Pyx_PySendResult result;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        *retval = __Pyx_Coroutine_AlreadyRunningError(gen);
        return PYGEN_ERROR;
    }
    #if CYTHON_USE_AM_SEND
    if (gen->yieldfrom_am_send) {
        result = __Pyx_Coroutine_SendToDelegate(gen, gen->yieldfrom_am_send, value, retval);
    } else
    #endif
    if (gen->yieldfrom) {
        PyObject *yf = gen->yieldfrom;
        PyObject *ret;
      #if !CYTHON_USE_AM_SEND
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
      #endif
        {
            #if !CYTHON_COMPILING_IN_LIMITED_API || __PYX_LIMITED_VERSION_HEX >= 0x03080000
            if (value == Py_None && PyIter_Check(yf))
                ret = __Pyx_PyIter_Next_Plain(yf);
            else
            #endif
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_mstate_global->__pyx_n_u_send, value);
        }
        if (likely(ret)) {
            __Pyx_Coroutine_unset_is_running(gen);
            *retval = ret;
            return PYGEN_NEXT;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, retval);
    } else {
        result = __Pyx_Coroutine_SendEx(gen, value, retval, 0);
    }
    __Pyx_Coroutine_unset_is_running(gen);
    return result;
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    __Pyx_PySendResult result;
    PyObject *retval = NULL;
    CYTHON_UNUSED_VAR(gen);
    assert(__Pyx_Coroutine_get_is_running(gen));
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        result = __Pyx_Coroutine_Close(yf, &retval);
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        result = __Pyx_Coroutine_Close(yf, &retval);
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        result = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf);
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
        result = PYGEN_RETURN;
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
        result = PYGEN_RETURN;
    } else
    #endif
    {
        PyObject *meth;
        result = PYGEN_RETURN;
        meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_mstate_global->__pyx_n_u_close);
        if (unlikely(!meth)) {
            if (unlikely(PyErr_Occurred())) {
                PyErr_WriteUnraisable(yf);
            }
        } else {
            retval = __Pyx_PyObject_CallNoArg(meth);
            Py_DECREF(meth);
            if (unlikely(!retval)) {
                result = PYGEN_ERROR;
            }
        }
    }
    Py_XDECREF(retval);
    return result == PYGEN_ERROR ? -1 : 0;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __Pyx_PySendResult result;
    PyObject *retval = NULL;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    }
    #if CYTHON_USE_AM_SEND
    if (gen->yieldfrom_am_send) {
        result = __Pyx_Coroutine_SendToDelegate(gen, gen->yieldfrom_am_send, Py_None, &retval);
    } else
    #endif
    if (gen->yieldfrom) {
        PyObject *yf = gen->yieldfrom;
        PyObject *ret;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && (PY_VERSION_HEX < 0x030A00A3 || !CYTHON_USE_AM_SEND)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
            ret = __Pyx_PyIter_Next_Plain(yf);
        if (likely(ret)) {
            __Pyx_Coroutine_unset_is_running(gen);
            return ret;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, &retval);
    } else {
        result = __Pyx_Coroutine_SendEx(gen, Py_None, &retval, 0);
    }
    __Pyx_Coroutine_unset_is_running(gen);
    return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 1);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, PyObject *arg) {
    PyObject *retval = NULL;
    __Pyx_PySendResult result;
    CYTHON_UNUSED_VAR(arg);
    result = __Pyx_Coroutine_Close(self, &retval);
    if (unlikely(result == PYGEN_ERROR))
        return NULL;
    Py_XDECREF(retval);
    Py_RETURN_NONE;
}
static __Pyx_PySendResult
__Pyx_Coroutine_Close(PyObject *self, PyObject **retval) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PySendResult result;
    PyObject *yf;
    int err = 0;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        *retval = __Pyx_Coroutine_AlreadyRunningError(gen);
        return PYGEN_ERROR;
    }
    yf = gen->yieldfrom;
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    result = __Pyx_Coroutine_SendEx(gen, NULL, retval, 1);
    if (result == PYGEN_ERROR) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_Coroutine_unset_is_running(gen);
        if (!__Pyx_PyErr_Occurred()) {
            return PYGEN_RETURN;
        } else if (likely(__Pyx_PyErr_ExceptionMatches2(PyExc_GeneratorExit, PyExc_StopIteration))) {
            __Pyx_PyErr_Clear();
            return PYGEN_RETURN;
        }
        return PYGEN_ERROR;
    } else if (likely(result == PYGEN_RETURN && *retval == Py_None)) {
        __Pyx_Coroutine_unset_is_running(gen);
        return PYGEN_RETURN;
    } else {
        const char *msg;
        Py_DECREF(*retval);
        *retval = NULL;
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
            msg = "async generator ignored GeneratorExit";
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        __Pyx_Coroutine_unset_is_running(gen);
        return PYGEN_ERROR;
    }
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen)))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    yf = gen->yieldfrom;
    if (yf) {
        __Pyx_PySendResult result;
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                goto propagate_exception;
            goto throw_here;
        }
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_mstate_global->__pyx_n_u_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (unlikely(PyErr_Occurred())) {
                    __Pyx_Coroutine_unset_is_running(gen);
                    return NULL;
                }
                __Pyx_Coroutine_Undelegate(gen);
                goto throw_here;
            }
            if (likely(args)) {
                ret = __Pyx_PyObject_Call(meth, args, NULL);
            } else {
                PyObject *cargs[4] = {NULL, typ, val, tb};
                ret = __Pyx_PyObject_FastCall(meth, cargs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
            }
            Py_DECREF(meth);
        }
        Py_DECREF(yf);
        if (ret) {
            __Pyx_Coroutine_unset_is_running(gen);
            return ret;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, &ret);
        __Pyx_Coroutine_unset_is_running(gen);
        return __Pyx_Coroutine_MethodReturnFromResult(self, result, ret, 0);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
propagate_exception:
    {
        PyObject *retval = NULL;
        __Pyx_PySendResult result = __Pyx_Coroutine_SendEx(gen, NULL, &retval, 0);
        __Pyx_Coroutine_unset_is_running(gen);
        return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 0);
    }
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (unlikely(!PyArg_UnpackTuple(args, "throw", 1, 3, &typ, &val, &tb)))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_VISIT(exc_state->exc_value);
#else
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
#endif
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    {
        int e = __Pyx_call_type_traverse((PyObject*)gen, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    #if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    if (gen->gi_weakreflist != NULL)
    #endif
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if CYTHON_USE_TP_FINALIZE
        if (unlikely(PyObject_CallFinalizerFromDealloc(self)))
#else
        {
            destructor del = __Pyx_PyObject_GetSlot(gen, tp_del, destructor);
            if (del) del(self);
        }
        if (unlikely(Py_REFCNT(self) > 0))
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    __Pyx_PyHeapTypeObject_GC_Del(gen);
}
#if CYTHON_USE_TP_FINALIZE
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *retval = NULL;
        __Pyx_PySendResult result = __Pyx_Coroutine_Close(self, &retval);
        if (result == PYGEN_ERROR) {
            PyErr_WriteUnraisable(self);
        } else {
            Py_XDECREF(retval);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
}
#endif
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_name;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_name, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_qualname;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_qualname, value);
    return 0;
}
static PyObject *
__Pyx__Coroutine_get_frame(__pyx_CoroutineObject *self)
{
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyObject *frame;
    #if PY_VERSION_HEX >= 0x030d0000
    Py_BEGIN_CRITICAL_SECTION(self);
    #endif
    frame = self->gi_frame;
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        PyObject *globals = PyDict_New();
        if (unlikely(!globals)) return NULL;
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            globals,                        /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        Py_DECREF(globals);
        if (unlikely(!frame))
            return NULL;
        if (unlikely(self->gi_frame)) {
            Py_DECREF(frame);
            frame = self->gi_frame;
        } else {
            self->gi_frame = frame;
        }
    }
    Py_INCREF(frame);
    #if PY_VERSION_HEX >= 0x030d0000
    Py_END_CRITICAL_SECTION();
    #endif
    return frame;
#else
    CYTHON_UNUSED_VAR(self);
    Py_RETURN_NONE;
#endif
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, void *context) {
    CYTHON_UNUSED_VAR(context);
    PyObject *frame = self->gi_frame;
    if (frame)
        return __Pyx_NewRef(frame);
    return __Pyx__Coroutine_get_frame(self);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->yieldfrom_am_send = NULL;
    #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_LIMITED_API
    gen->gi_exc_state.exc_value = NULL;
    #else
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
    #endif
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    gen->gi_weakreflist = NULL;
#endif
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}
static char __Pyx_Coroutine_test_and_set_is_running(__pyx_CoroutineObject *gen) {
    char result;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    result = gen->is_running;
    gen->is_running = 1;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
    return result;
}
static void __Pyx_Coroutine_unset_is_running(__pyx_CoroutineObject *gen) {
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    assert(gen->is_running);
    gen->is_running = 0;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
}
static char __Pyx_Coroutine_get_is_running(__pyx_CoroutineObject *gen) {
    char result;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    result = gen->is_running;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
    return result;
}
static PyObject *__Pyx_Coroutine_get_is_running_getter(PyObject *gen, void *closure) {
    CYTHON_UNUSED_VAR(closure);
    char result = __Pyx_Coroutine_get_is_running((__pyx_CoroutineObject*)gen);
    if (result) Py_RETURN_TRUE;
    else Py_RETURN_FALSE;
}
#if __PYX_HAS_PY_AM_SEND == 2
static void __Pyx_SetBackportTypeAmSend(PyTypeObject *type, __Pyx_PyAsyncMethodsStruct *static_amsend_methods, __Pyx_pyiter_sendfunc am_send) {
    Py_ssize_t ptr_offset = (char*)(type->tp_as_async) - (char*)type;
    if (ptr_offset < 0 || ptr_offset > type->tp_basicsize) {
        return;
    }
    memcpy((void*)static_amsend_methods, (void*)(type->tp_as_async), sizeof(*type->tp_as_async));
    static_amsend_methods->am_send = am_send;
    type->tp_as_async = __Pyx_SlotTpAsAsync(static_amsend_methods);
}
#endif
static PyObject *__Pyx_Coroutine_fail_reduce_ex(PyObject *self, PyObject *arg) {
    CYTHON_UNUSED_VAR(arg);
    __Pyx_TypeName self_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE((PyObject*)self));
    PyErr_Format(PyExc_TypeError, "cannot pickle '" __Pyx_FMT_TYPENAME "' object",
                         self_type_name);
    __Pyx_DECREF_TypeName(self_type_name);
    return NULL;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {"__reduce_ex__", (PyCFunction) __Pyx_Coroutine_fail_reduce_ex, METH_O, 0},
    {"__reduce__", (PyCFunction) __Pyx_Coroutine_fail_reduce_ex, METH_NOARGS, 0},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {"gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     PyDoc_STR("object being iterated by 'yield from', or None")},
    {"gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {"__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), 0, 0},
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CoroutineObject, gi_weakreflist), READONLY, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {"__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     PyDoc_STR("name of the generator"), 0},
    {"__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     PyDoc_STR("qualified name of the generator"), 0},
    {"gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     PyDoc_STR("Frame of the generator"), 0},
    {"gi_running", __Pyx_Coroutine_get_is_running_getter, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_GeneratorType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_Coroutine_dealloc},
    {Py_tp_traverse, (void *)__Pyx_Coroutine_traverse},
    {Py_tp_iter, (void *)PyObject_SelfIter},
    {Py_tp_iternext, (void *)__Pyx_Generator_Next},
    {Py_tp_methods, (void *)__pyx_Generator_methods},
    {Py_tp_members, (void *)__pyx_Generator_memberlist},
    {Py_tp_getset, (void *)__pyx_Generator_getsets},
    {Py_tp_getattro, (void *) PyObject_GenericGetAttr},
#if CYTHON_USE_TP_FINALIZE
    {Py_tp_finalize, (void *)__Pyx_Coroutine_del},
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    {Py_am_send, (void *)__Pyx_Coroutine_AmSend},
#endif
    {0, 0},
};
static PyType_Spec __pyx_GeneratorType_spec = {
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_WEAKREF |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | __Pyx_TPFLAGS_HAVE_AM_SEND,
    __pyx_GeneratorType_slots
};
#if __PYX_HAS_PY_AM_SEND == 2
static __Pyx_PyAsyncMethodsStruct __pyx_Generator_as_async;
#endif
static int __pyx_Generator_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_GeneratorType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_GeneratorType_spec, NULL);
    if (unlikely(!mstate->__pyx_GeneratorType)) {
        return -1;
    }
#if __PYX_HAS_PY_AM_SEND == 2
    __Pyx_SetBackportTypeAmSend(mstate->__pyx_GeneratorType, &__pyx_Generator_as_async, &__Pyx_Coroutine_AmSend);
#endif
    return 0;
}
static PyObject *__Pyx_Generator_GetInlinedResult(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *retval = NULL;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    }
    __Pyx_PySendResult result = __Pyx_Coroutine_SendEx(gen, Py_None, &retval, 0);
    __Pyx_Coroutine_unset_is_running(gen);
    (void) result;
    assert (result == PYGEN_RETURN || result == PYGEN_ERROR);
    assert ((result == PYGEN_RETURN && retval != NULL) || (result == PYGEN_ERROR && retval == NULL));
    return retval;
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#if CYTHON_COMPILING_IN_LIMITED_API
    static PyObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                       PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                       PyObject *fv, PyObject *cell, PyObject* fn,
                                       PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030B0000
  static PyCodeObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                         PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                         PyObject *fv, PyObject *cell, PyObject* fn,
                                         PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, __pyx_mstate_global->__pyx_empty_bytes);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030c00A1
    if (likely(result))
        result->_co_firsttraceable = 0;
    #endif
    return result;
  }
#elif !CYTHON_COMPILING_IN_PYPY
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
) {
    PyObject *code_obj = NULL, *varnames_tuple_dedup = NULL, *code_bytes = NULL;
    Py_ssize_t var_count = (Py_ssize_t) descr.nlocals;
    PyObject *varnames_tuple = PyTuple_New(var_count);
    if (unlikely(!varnames_tuple)) return NULL;
    for (Py_ssize_t i=0; i < var_count; i++) {
        Py_INCREF(varnames[i]);
        if (__Pyx_PyTuple_SET_ITEM(varnames_tuple, i, varnames[i]) != (0)) goto done;
    }
    #if CYTHON_COMPILING_IN_LIMITED_API
    varnames_tuple_dedup = PyDict_GetItem(tuple_dedup_map, varnames_tuple);
    if (!varnames_tuple_dedup) {
        if (unlikely(PyDict_SetItem(tuple_dedup_map, varnames_tuple, varnames_tuple) < 0)) goto done;
        varnames_tuple_dedup = varnames_tuple;
    }
    #else
    varnames_tuple_dedup = PyDict_SetDefault(tuple_dedup_map, varnames_tuple, varnames_tuple);
    if (unlikely(!varnames_tuple_dedup)) goto done;
    #endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(varnames_tuple_dedup);
    #endif
    if (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table != NULL && !CYTHON_COMPILING_IN_GRAAL) {
        Py_ssize_t line_table_length = __Pyx_PyBytes_GET_SIZE(line_table);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(line_table_length == -1)) goto done;
        #endif
        Py_ssize_t code_len = (line_table_length * 2 + 4) & ~3LL;
        code_bytes = PyBytes_FromStringAndSize(NULL, code_len);
        if (unlikely(!code_bytes)) goto done;
        char* c_code_bytes = PyBytes_AsString(code_bytes);
        if (unlikely(!c_code_bytes)) goto done;
        memset(c_code_bytes, 0, (size_t) code_len);
    }
    code_obj = (PyObject*) __Pyx__PyCode_New(
        (int) descr.argcount,
        (int) descr.num_posonly_args,
        (int) descr.num_kwonly_args,
        (int) descr.nlocals,
        0,
        (int) descr.flags,
        code_bytes ? code_bytes : __pyx_mstate_global->__pyx_empty_bytes,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        varnames_tuple_dedup,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        filename,
        funcname,
        (int) descr.first_line,
        (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table) ? line_table : __pyx_mstate_global->__pyx_empty_bytes
    );
done:
    Py_XDECREF(code_bytes);
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(varnames_tuple_dedup);
    #endif
    Py_DECREF(varnames_tuple);
    return code_obj;
}

/* DecompressString */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo) {
    PyObject *module = NULL, *decompress, *compressed_bytes, *decompressed;
    const char* module_name = algo == 3 ? "compression.zstd" : algo == 2 ? "bz2" : "zlib";
    PyObject *methodname = PyUnicode_FromString("decompress");
    if (unlikely(!methodname)) return NULL;
    #if __PYX_LIMITED_VERSION_HEX >= 0x030e0000
    if (algo == 3) {
        PyObject *fromlist = Py_BuildValue("[O]", methodname);
        if (unlikely(!fromlist)) goto bad;
        module = PyImport_ImportModuleLevel("compression.zstd", NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
    } else
    #endif
        module = PyImport_ImportModule(module_name);
    if (unlikely(!module)) goto import_failed;
    decompress = PyObject_GetAttr(module, methodname);
    if (unlikely(!decompress)) goto import_failed;
    {
        #ifdef __cplusplus
            char *memview_bytes = const_cast<char*>(s);
        #else
            #if defined(__clang__)
              #pragma clang diagnostic push
              #pragma clang diagnostic ignored "-Wcast-qual"
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic push
              #pragma GCC diagnostic ignored "-Wcast-qual"
            #endif
            char *memview_bytes = (char*) s;
            #if defined(__clang__)
              #pragma clang diagnostic pop
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic pop
            #endif
        #endif
        #if CYTHON_COMPILING_IN_LIMITED_API && !defined(PyBUF_READ)
        int memview_flags = 0x100;
        #else
        int memview_flags = PyBUF_READ;
        #endif
        compressed_bytes = PyMemoryView_FromMemory(memview_bytes, length, memview_flags);
    }
    if (unlikely(!compressed_bytes)) {
        Py_DECREF(decompress);
        goto bad;
    }
    decompressed = PyObject_CallFunctionObjArgs(decompress, compressed_bytes, NULL);
    Py_DECREF(compressed_bytes);
    Py_DECREF(decompress);
    Py_DECREF(module);
    Py_DECREF(methodname);
    return decompressed;
import_failed:
    PyErr_Format(PyExc_ImportError,
        "Failed to import '%.20s.decompress' - cannot initialise module strings. "
        "String compression was configured with the C macro 'CYTHON_COMPRESS_STRINGS=%d'.",
        module_name, algo);
bad:
    Py_XDECREF(module);
    Py_DECREF(methodname);
    return NULL;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
#ifndef CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#if (CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX >= 0x030C0000)
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 1
#else
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 0
#endif
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE && !CYTHON_ATOMICS
#error "Module state with PEP489 requires atomics. Currently that's one of\
 C11, C++11, gcc atomic intrinsics or MSVC atomic intrinsics"
#endif
#if !CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#define __Pyx_ModuleStateLookup_Lock()
#define __Pyx_ModuleStateLookup_Unlock()
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
static PyMutex __Pyx_ModuleStateLookup_mutex = {0};
#define __Pyx_ModuleStateLookup_Lock() PyMutex_Lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() PyMutex_Unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(__cplusplus) && __cplusplus >= 201103L
#include <mutex>
static std::mutex __Pyx_ModuleStateLookup_mutex;
#define __Pyx_ModuleStateLookup_Lock() __Pyx_ModuleStateLookup_mutex.lock()
#define __Pyx_ModuleStateLookup_Unlock() __Pyx_ModuleStateLookup_mutex.unlock()
#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ > 201112L) && !defined(__STDC_NO_THREADS__)
#include <threads.h>
static mtx_t __Pyx_ModuleStateLookup_mutex;
static once_flag __Pyx_ModuleStateLookup_mutex_once_flag = ONCE_FLAG_INIT;
static void __Pyx_ModuleStateLookup_initialize_mutex(void) {
    mtx_init(&__Pyx_ModuleStateLookup_mutex, mtx_plain);
}
#define __Pyx_ModuleStateLookup_Lock()\
  call_once(&__Pyx_ModuleStateLookup_mutex_once_flag, __Pyx_ModuleStateLookup_initialize_mutex);\
  mtx_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() mtx_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(HAVE_PTHREAD_H)
#include <pthread.h>
static pthread_mutex_t __Pyx_ModuleStateLookup_mutex = PTHREAD_MUTEX_INITIALIZER;
#define __Pyx_ModuleStateLookup_Lock() pthread_mutex_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() pthread_mutex_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(_WIN32)
#include <Windows.h>  // synchapi.h on its own doesn't work
static SRWLOCK __Pyx_ModuleStateLookup_mutex = SRWLOCK_INIT;
#define __Pyx_ModuleStateLookup_Lock() AcquireSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() ReleaseSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#else
#error "No suitable lock available for CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE.\
 Requires C standard >= C11, or C++ standard >= C++11,\
 or pthreads, or the Windows 32 API, or Python >= 3.13."
#endif
typedef struct {
    int64_t id;
    PyObject *module;
} __Pyx_InterpreterIdAndModule;
typedef struct {
    char interpreter_id_as_index;
    Py_ssize_t count;
    Py_ssize_t allocated;
    __Pyx_InterpreterIdAndModule table[1];
} __Pyx_ModuleStateLookupData;
#define __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE 32
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_int_type __Pyx_ModuleStateLookup_read_counter = 0;
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_ptr_type __Pyx_ModuleStateLookup_data = 0;
#else
static __Pyx_ModuleStateLookupData* __Pyx_ModuleStateLookup_data = NULL;
#endif
static __Pyx_InterpreterIdAndModule* __Pyx_State_FindModuleStateLookupTableLowerBound(
        __Pyx_InterpreterIdAndModule* table,
        Py_ssize_t count,
        int64_t interpreterId) {
    __Pyx_InterpreterIdAndModule* begin = table;
    __Pyx_InterpreterIdAndModule* end = begin + count;
    if (begin->id == interpreterId) {
        return begin;
    }
    while ((end - begin) > __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
        __Pyx_InterpreterIdAndModule* halfway = begin + (end - begin)/2;
        if (halfway->id == interpreterId) {
            return halfway;
        }
        if (halfway->id < interpreterId) {
            begin = halfway;
        } else {
            end = halfway;
        }
    }
    for (; begin < end; ++begin) {
        if (begin->id >= interpreterId) return begin;
    }
    return begin;
}
static PyObject *__Pyx_State_FindModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return NULL;
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData* data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
    {
        __pyx_atomic_incr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        if (likely(data)) {
            __Pyx_ModuleStateLookupData* new_data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_acquire(&__Pyx_ModuleStateLookup_data);
            if (likely(data == new_data)) {
                goto read_finished;
            }
        }
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        __Pyx_ModuleStateLookup_Lock();
        __pyx_atomic_incr_relaxed(&__Pyx_ModuleStateLookup_read_counter);
        data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
        __Pyx_ModuleStateLookup_Unlock();
    }
  read_finished:;
#else
    __Pyx_ModuleStateLookupData* data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_InterpreterIdAndModule* found = NULL;
    if (unlikely(!data)) goto end;
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            found = data->table+interpreter_id;
        }
    } else {
        found = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
    }
  end:
    {
        PyObject *result=NULL;
        if (found && found->id == interpreter_id) {
            result = found->module;
        }
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
#endif
        return result;
    }
}
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static void __Pyx_ModuleStateLookup_wait_until_no_readers(void) {
    while (__pyx_atomic_load(&__Pyx_ModuleStateLookup_read_counter) != 0);
}
#else
#define __Pyx_ModuleStateLookup_wait_until_no_readers()
#endif
static int __Pyx_State_AddModuleInterpIdAsIndex(__Pyx_ModuleStateLookupData **old_data, PyObject* module, int64_t interpreter_id) {
    Py_ssize_t to_allocate = (*old_data)->allocated;
    while (to_allocate <= interpreter_id) {
        if (to_allocate == 0) to_allocate = 1;
        else to_allocate *= 2;
    }
    __Pyx_ModuleStateLookupData *new_data = *old_data;
    if (to_allocate != (*old_data)->allocated) {
         new_data = (__Pyx_ModuleStateLookupData *)realloc(
            *old_data,
            sizeof(__Pyx_ModuleStateLookupData)+(to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
        if (!new_data) {
            PyErr_NoMemory();
            return -1;
        }
        for (Py_ssize_t i = new_data->allocated; i < to_allocate; ++i) {
            new_data->table[i].id = i;
            new_data->table[i].module = NULL;
        }
        new_data->allocated = to_allocate;
    }
    new_data->table[interpreter_id].module = module;
    if (new_data->count < interpreter_id+1) {
        new_data->count = interpreter_id+1;
    }
    *old_data = new_data;
    return 0;
}
static void __Pyx_State_ConvertFromInterpIdAsIndex(__Pyx_ModuleStateLookupData *data) {
    __Pyx_InterpreterIdAndModule *read = data->table;
    __Pyx_InterpreterIdAndModule *write = data->table;
    __Pyx_InterpreterIdAndModule *end = read + data->count;
    for (; read<end; ++read) {
        if (read->module) {
            write->id = read->id;
            write->module = read->module;
            ++write;
        }
    }
    data->count = write - data->table;
    for (; write<end; ++write) {
        write->id = 0;
        write->module = NULL;
    }
    data->interpreter_id_as_index = 0;
}
static int __Pyx_State_AddModule(PyObject* module, CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    int result = 0;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *old_data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *old_data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_ModuleStateLookupData *new_data = old_data;
    if (!new_data) {
        new_data = (__Pyx_ModuleStateLookupData *)calloc(1, sizeof(__Pyx_ModuleStateLookupData));
        if (!new_data) {
            result = -1;
            PyErr_NoMemory();
            goto end;
        }
        new_data->allocated = 1;
        new_data->interpreter_id_as_index = 1;
    }
    __Pyx_ModuleStateLookup_wait_until_no_readers();
    if (new_data->interpreter_id_as_index) {
        if (interpreter_id < __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
            result = __Pyx_State_AddModuleInterpIdAsIndex(&new_data, module, interpreter_id);
            goto end;
        }
        __Pyx_State_ConvertFromInterpIdAsIndex(new_data);
    }
    {
        Py_ssize_t insert_at = 0;
        {
            __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
                new_data->table, new_data->count, interpreter_id);
            assert(lower_bound);
            insert_at = lower_bound - new_data->table;
            if (unlikely(insert_at < new_data->count && lower_bound->id == interpreter_id)) {
                lower_bound->module = module;
                goto end;  // already in table, nothing more to do
            }
        }
        if (new_data->count+1 >= new_data->allocated) {
            Py_ssize_t to_allocate = (new_data->count+1)*2;
            new_data =
                (__Pyx_ModuleStateLookupData*)realloc(
                    new_data,
                    sizeof(__Pyx_ModuleStateLookupData) +
                    (to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
            if (!new_data) {
                result = -1;
                new_data = old_data;
                PyErr_NoMemory();
                goto end;
            }
            new_data->allocated = to_allocate;
        }
        ++new_data->count;
        int64_t last_id = interpreter_id;
        PyObject *last_module = module;
        for (Py_ssize_t i=insert_at; i<new_data->count; ++i) {
            int64_t current_id = new_data->table[i].id;
            new_data->table[i].id = last_id;
            last_id = current_id;
            PyObject *current_module = new_data->table[i].module;
            new_data->table[i].module = last_module;
            last_module = current_module;
        }
    }
  end:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, new_data);
#else
    __Pyx_ModuleStateLookup_data = new_data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return result;
}
static int __Pyx_State_RemoveModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *data = __Pyx_ModuleStateLookup_data;
#endif
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            data->table[interpreter_id].module = NULL;
        }
        goto done;
    }
    {
        __Pyx_ModuleStateLookup_wait_until_no_readers();
        __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
        if (!lower_bound) goto done;
        if (lower_bound->id != interpreter_id) goto done;
        __Pyx_InterpreterIdAndModule *end = data->table+data->count;
        for (;lower_bound<end-1; ++lower_bound) {
            lower_bound->id = (lower_bound+1)->id;
            lower_bound->module = (lower_bound+1)->module;
        }
    }
    --data->count;
    if (data->count == 0) {
        free(data);
        data = NULL;
    }
  done:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, data);
#else
    __Pyx_ModuleStateLookup_data = data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return 0;
}
#endif

/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
